Class: Verizon::ARequestBodyForUsage
- Defined in:
- lib/verizon/models/a_request_body_for_usage.rb
Overview
ARequestBodyForUsage Model.
Instance Attribute Summary collapse
-
#device_id ⇒ Array[ReadySimDeviceId]
TODO: Write general description for this method.
-
#end_time ⇒ DateTime
TODO: Write general description for this method.
-
#start_time ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ ARequestBodyForUsage
constructor
A new instance of ARequestBodyForUsage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_end_time ⇒ Object
- #to_custom_start_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ ARequestBodyForUsage
Returns a new instance of ARequestBodyForUsage.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 48 def initialize(device_id: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id unless device_id == SKIP @start_time = start_time unless start_time == SKIP @end_time = end_time unless end_time == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_id ⇒ Array[ReadySimDeviceId]
TODO: Write general description for this method
15 16 17 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 15 def device_id @device_id end |
#end_time ⇒ DateTime
TODO: Write general description for this method
23 24 25 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 23 def end_time @end_time end |
#start_time ⇒ DateTime
TODO: Write general description for this method
19 20 21 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 19 def start_time @start_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_id = nil unless hash['deviceId'].nil? device_id = [] hash['deviceId'].each do |structure| device_id << (ReadySimDeviceId.from_hash(structure) if structure) end end device_id = SKIP unless hash.key?('deviceId') start_time = if hash.key?('startTime') (DateTimeHelper.from_rfc3339(hash['startTime']) if hash['startTime']) else SKIP end end_time = if hash.key?('endTime') (DateTimeHelper.from_rfc3339(hash['endTime']) if hash['endTime']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ARequestBodyForUsage.new(device_id: device_id, start_time: start_time, end_time: end_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['start_time'] = 'startTime' @_hash['end_time'] = 'endTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 35 def self.optionals %w[ device_id start_time end_time ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, start_time: #{@start_time.inspect},"\ " end_time: #{@end_time.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_end_time ⇒ Object
103 104 105 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 103 def to_custom_end_time DateTimeHelper.to_rfc3339(end_time) end |
#to_custom_start_time ⇒ Object
99 100 101 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 99 def to_custom_start_time DateTimeHelper.to_rfc3339(start_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/verizon/models/a_request_body_for_usage.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, start_time: #{@start_time}, end_time:"\ " #{@end_time}, additional_properties: #{@additional_properties}>" end |