Class: Verizon::Acceleration

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/acceleration.rb

Overview

Acceleration Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(x: SKIP, y: SKIP, z: SKIP, additional_properties: nil) ⇒ Acceleration

Returns a new instance of Acceleration.



47
48
49
50
51
52
53
54
55
# File 'lib/verizon/models/acceleration.rb', line 47

def initialize(x: SKIP, y: SKIP, z: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @x = x unless x == SKIP
  @y = y unless y == SKIP
  @z = z unless z == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#xString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/acceleration.rb', line 14

def x
  @x
end

#yString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/acceleration.rb', line 18

def y
  @y
end

#zString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/acceleration.rb', line 22

def z
  @z
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/verizon/models/acceleration.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  x = hash.key?('x') ? hash['x'] : SKIP
  y = hash.key?('y') ? hash['y'] : SKIP
  z = hash.key?('z') ? hash['z'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Acceleration.new(x: x,
                   y: y,
                   z: z,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/acceleration.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['x'] = 'x'
  @_hash['y'] = 'y'
  @_hash['z'] = 'z'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/acceleration.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/acceleration.rb', line 34

def self.optionals
  %w[
    x
    y
    z
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/verizon/models/acceleration.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} x: #{@x.inspect}, y: #{@y.inspect}, z: #{@z.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/verizon/models/acceleration.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} x: #{@x}, y: #{@y}, z: #{@z}, additional_properties:"\
  " #{@additional_properties}>"
end