Class: Verizon::AccountConsentCreate
- Defined in:
- lib/verizon/models/account_consent_create.rb
Overview
AccountConsentCreate Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The numeric name of the account, including leading zeros.
-
#device_list ⇒ Array[Object]
An array of device identifiers.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list: SKIP, account_name: SKIP, additional_properties: nil) ⇒ AccountConsentCreate
constructor
A new instance of AccountConsentCreate.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list: SKIP, account_name: SKIP, additional_properties: nil) ⇒ AccountConsentCreate
Returns a new instance of AccountConsentCreate.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/account_consent_create.rb', line 41 def initialize(device_list: SKIP, account_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_list = device_list unless device_list == SKIP @account_name = account_name unless account_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The numeric name of the account, including leading zeros.
18 19 20 |
# File 'lib/verizon/models/account_consent_create.rb', line 18 def account_name @account_name end |
#device_list ⇒ Array[Object]
An array of device identifiers
14 15 16 |
# File 'lib/verizon/models/account_consent_create.rb', line 14 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/account_consent_create.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_list = hash.key?('deviceList') ? hash['deviceList'] : SKIP account_name = hash.key?('accountName') ? hash['accountName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountConsentCreate.new(device_list: device_list, account_name: account_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/account_consent_create.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['device_list'] = 'deviceList' @_hash['account_name'] = 'accountName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/account_consent_create.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/account_consent_create.rb', line 29 def self.optionals %w[ device_list account_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/verizon/models/account_consent_create.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_list: #{@device_list.inspect}, account_name:"\ " #{@account_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/verizon/models/account_consent_create.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_list: #{@device_list}, account_name: #{@account_name},"\ " additional_properties: #{@additional_properties}>" end |