Class: Verizon::AccountConsentUpdate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_consent_update.rb

Overview

AccountConsentUpdate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, all_device_consent: SKIP, additional_properties: nil) ⇒ AccountConsentUpdate

Returns a new instance of AccountConsentUpdate.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/account_consent_update.rb', line 41

def initialize(account_name: SKIP, all_device_consent: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name =  unless  == SKIP
  @all_device_consent = all_device_consent unless all_device_consent == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The numeric name of the account, including leading zeros.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/account_consent_update.rb', line 14

def 
  @account_name
end

The consent setting to use for all the devices in the account.

Returns:

  • (Integer)


18
19
20
# File 'lib/verizon/models/account_consent_update.rb', line 18

def all_device_consent
  @all_device_consent
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/verizon/models/account_consent_update.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  all_device_consent =
    hash.key?('allDeviceConsent') ? hash['allDeviceConsent'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountConsentUpdate.new(account_name: ,
                           all_device_consent: all_device_consent,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/account_consent_update.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['all_device_consent'] = 'allDeviceConsent'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/account_consent_update.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/account_consent_update.rb', line 29

def self.optionals
  %w[
    account_name
    all_device_consent
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/verizon/models/account_consent_update.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, all_device_consent:"\
  " #{@all_device_consent.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/verizon/models/account_consent_update.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, all_device_consent: #{@all_device_consent},"\
  " additional_properties: #{@additional_properties}>"
end