Class: Verizon::AccountDeviceList
- Defined in:
- lib/verizon/models/account_device_list.rb
Overview
A list of deviceId objects to use when requesting information from multiple devices.
Instance Attribute Summary collapse
-
#device_ids ⇒ Array[DeviceId]
All identifiers for the device.
-
#ipaddress ⇒ String
All identifiers for the device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_ids:, ipaddress: SKIP, additional_properties: nil) ⇒ AccountDeviceList
constructor
A new instance of AccountDeviceList.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_ids:, ipaddress: SKIP, additional_properties: nil) ⇒ AccountDeviceList
Returns a new instance of AccountDeviceList.
41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/account_device_list.rb', line 41 def initialize(device_ids:, ipaddress: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_ids = device_ids @ipaddress = ipaddress unless ipaddress == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_ids ⇒ Array[DeviceId]
All identifiers for the device.
15 16 17 |
# File 'lib/verizon/models/account_device_list.rb', line 15 def device_ids @device_ids end |
#ipaddress ⇒ String
All identifiers for the device.
19 20 21 |
# File 'lib/verizon/models/account_device_list.rb', line 19 def ipaddress @ipaddress end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/account_device_list.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_ids = nil unless hash['deviceIds'].nil? device_ids = [] hash['deviceIds'].each do |structure| device_ids << (DeviceId.from_hash(structure) if structure) end end device_ids = nil unless hash.key?('deviceIds') ipaddress = hash.key?('ipAddress') ? hash['ipAddress'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountDeviceList.new(device_ids: device_ids, ipaddress: ipaddress, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/account_device_list.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['device_ids'] = 'deviceIds' @_hash['ipaddress'] = 'ipAddress' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/account_device_list.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/verizon/models/account_device_list.rb', line 30 def self.optionals %w[ ipaddress ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/verizon/models/account_device_list.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_ids: #{@device_ids.inspect}, ipaddress: #{@ipaddress.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/verizon/models/account_device_list.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_ids: #{@device_ids}, ipaddress: #{@ipaddress},"\ " additional_properties: #{@additional_properties}>" end |