Class: Verizon::AccountDeviceListFilter
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AccountDeviceListFilter
- Defined in:
- lib/verizon/models/account_device_list_filter.rb
Overview
Filter for a list of devices.
Instance Attribute Summary collapse
-
#device_identifier_filters ⇒ Array[DeviceIdSearch]
Specify the kind of the device identifier, the type of match, and the string that you want to match.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_identifier_filters:, additional_properties: nil) ⇒ AccountDeviceListFilter
constructor
A new instance of AccountDeviceListFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_identifier_filters:, additional_properties: nil) ⇒ AccountDeviceListFilter
Returns a new instance of AccountDeviceListFilter.
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 34 def initialize(device_identifier_filters:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_identifier_filters = device_identifier_filters @additional_properties = additional_properties end |
Instance Attribute Details
#device_identifier_filters ⇒ Array[DeviceIdSearch]
Specify the kind of the device identifier, the type of match, and the string that you want to match.
15 16 17 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 15 def device_identifier_filters @device_identifier_filters end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 43 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_identifier_filters = nil unless hash['deviceIdentifierFilters'].nil? device_identifier_filters = [] hash['deviceIdentifierFilters'].each do |structure| device_identifier_filters << (DeviceIdSearch.from_hash(structure) if structure) end end device_identifier_filters = nil unless hash.key?('deviceIdentifierFilters') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountDeviceListFilter.new(device_identifier_filters: device_identifier_filters, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['device_identifier_filters'] = 'deviceIdentifierFilters' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_identifier_filters: #{@device_identifier_filters.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/verizon/models/account_device_list_filter.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_identifier_filters: #{@device_identifier_filters},"\ " additional_properties: #{@additional_properties}>" end |