Class: Verizon::AccountGroupShareCreateTriggerRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_group_share_create_trigger_request.rb

Overview

AccountGroupShareCreateTriggerRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(trigger_name: SKIP, account_name: SKIP, trigger_category: SKIP, price_plan_trigger: SKIP, notification: SKIP, active: SKIP) ⇒ AccountGroupShareCreateTriggerRequest

Returns a new instance of AccountGroupShareCreateTriggerRequest.



65
66
67
68
69
70
71
72
73
74
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 65

def initialize(trigger_name: SKIP, account_name: SKIP,
               trigger_category: SKIP, price_plan_trigger: SKIP,
               notification: SKIP, active: SKIP)
  @trigger_name = trigger_name unless trigger_name == SKIP
  @account_name =  unless  == SKIP
  @trigger_category = trigger_category unless trigger_category == SKIP
  @price_plan_trigger = price_plan_trigger unless price_plan_trigger == SKIP
  @notification = notification unless notification == SKIP
  @active = active unless active == SKIP
end

Instance Attribute Details

#account_nameString

The numeric name of the account and must include leading zeroes

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 18

def 
  @account_name
end

#activeActive

A flag to indicate of the trigger is active, true, or not, false

Returns:



34
35
36
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 34

def active
  @active
end

#notificationNotificationarray

The type of trigger being created or modified

Returns:



30
31
32
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 30

def notification
  @notification
end

#price_plan_triggerAccountGroupShareObject

The type of trigger being created or modified



26
27
28
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 26

def price_plan_trigger
  @price_plan_trigger
end

#trigger_categoryTriggerCategory

The type of trigger being created or modified

Returns:



22
23
24
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 22

def trigger_category
  @trigger_category
end

#trigger_nameString

The user defined name of the trigger

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 14

def trigger_name
  @trigger_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  trigger_name = hash.key?('triggerName') ? hash['triggerName'] : SKIP
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  trigger_category =
    hash.key?('triggerCategory') ? hash['triggerCategory'] : SKIP
  price_plan_trigger = AccountGroupShareObject.from_hash(hash['pricePlanTrigger']) if
    hash['pricePlanTrigger']
  notification = Notificationarray.from_hash(hash['notification']) if hash['notification']
  active = hash.key?('active') ? hash['active'] : SKIP

  # Create object from extracted values.
  AccountGroupShareCreateTriggerRequest.new(trigger_name: trigger_name,
                                            account_name: ,
                                            trigger_category: trigger_category,
                                            price_plan_trigger: price_plan_trigger,
                                            notification: notification,
                                            active: active)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['trigger_name'] = 'triggerName'
  @_hash['account_name'] = 'accountName'
  @_hash['trigger_category'] = 'triggerCategory'
  @_hash['price_plan_trigger'] = 'pricePlanTrigger'
  @_hash['notification'] = 'notification'
  @_hash['active'] = 'active'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 49

def self.optionals
  %w[
    trigger_name
    account_name
    trigger_category
    price_plan_trigger
    notification
    active
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



101
102
103
104
105
106
107
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 101

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



118
119
120
121
122
123
124
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 118

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} trigger_name: #{@trigger_name.inspect}, account_name:"\
  " #{@account_name.inspect}, trigger_category: #{@trigger_category.inspect},"\
  " price_plan_trigger: #{@price_plan_trigger.inspect}, notification:"\
  " #{@notification.inspect}, active: #{@active.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
115
# File 'lib/verizon/models/account_group_share_create_trigger_request.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} trigger_name: #{@trigger_name}, account_name: #{@account_name},"\
  " trigger_category: #{@trigger_category}, price_plan_trigger: #{@price_plan_trigger},"\
  " notification: #{@notification}, active: #{@active}>"
end