Class: Verizon::AccountGroupShareUpdateTriggerRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AccountGroupShareUpdateTriggerRequest
- Defined in:
- lib/verizon/models/account_group_share_update_trigger_request.rb
Overview
AccountGroupShareUpdateTriggerRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The numeric name of the account and must include leading zeroes.
-
#active ⇒ Active
A flag to indicate of the trigger is active, true, or not, false.
-
#data_trigger ⇒ AccountGroupShareObject
The type of trigger being created or modified.
-
#notification ⇒ Notificationarray
The type of trigger being created or modified.
-
#trigger_category ⇒ TriggerCategory
The type of trigger being created or modified.
-
#trigger_id ⇒ String
The system assigned UUID of the trigger.
-
#trigger_name ⇒ String
The user defined name of the trigger.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(trigger_id: SKIP, trigger_name: SKIP, account_name: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP, active: SKIP) ⇒ AccountGroupShareUpdateTriggerRequest
constructor
A new instance of AccountGroupShareUpdateTriggerRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(trigger_id: SKIP, trigger_name: SKIP, account_name: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP, active: SKIP) ⇒ AccountGroupShareUpdateTriggerRequest
Returns a new instance of AccountGroupShareUpdateTriggerRequest.
71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 71 def initialize(trigger_id: SKIP, trigger_name: SKIP, account_name: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP, active: SKIP) @trigger_id = trigger_id unless trigger_id == SKIP @trigger_name = trigger_name unless trigger_name == SKIP @account_name = account_name unless account_name == SKIP @trigger_category = trigger_category unless trigger_category == SKIP @data_trigger = data_trigger unless data_trigger == SKIP @notification = notification unless notification == SKIP @active = active unless active == SKIP end |
Instance Attribute Details
#account_name ⇒ String
The numeric name of the account and must include leading zeroes
22 23 24 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 22 def account_name @account_name end |
#active ⇒ Active
A flag to indicate of the trigger is active, true, or not, false
38 39 40 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 38 def active @active end |
#data_trigger ⇒ AccountGroupShareObject
The type of trigger being created or modified
30 31 32 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 30 def data_trigger @data_trigger end |
#notification ⇒ Notificationarray
The type of trigger being created or modified
34 35 36 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 34 def notification @notification end |
#trigger_category ⇒ TriggerCategory
The type of trigger being created or modified
26 27 28 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 26 def trigger_category @trigger_category end |
#trigger_id ⇒ String
The system assigned UUID of the trigger
14 15 16 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 14 def trigger_id @trigger_id end |
#trigger_name ⇒ String
The user defined name of the trigger
18 19 20 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 18 def trigger_name @trigger_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. trigger_id = hash.key?('triggerId') ? hash['triggerId'] : SKIP trigger_name = hash.key?('triggerName') ? hash['triggerName'] : SKIP account_name = hash.key?('accountName') ? hash['accountName'] : SKIP trigger_category = hash.key?('triggerCategory') ? hash['triggerCategory'] : SKIP data_trigger = AccountGroupShareObject.from_hash(hash['dataTrigger']) if hash['dataTrigger'] notification = Notificationarray.from_hash(hash['notification']) if hash['notification'] active = hash.key?('active') ? hash['active'] : SKIP # Create object from extracted values. AccountGroupShareUpdateTriggerRequest.new(trigger_id: trigger_id, trigger_name: trigger_name, account_name: account_name, trigger_category: trigger_category, data_trigger: data_trigger, notification: notification, active: active) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['trigger_id'] = 'triggerId' @_hash['trigger_name'] = 'triggerName' @_hash['account_name'] = 'accountName' @_hash['trigger_category'] = 'triggerCategory' @_hash['data_trigger'] = 'dataTrigger' @_hash['notification'] = 'notification' @_hash['active'] = 'active' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 54 def self.optionals %w[ trigger_id trigger_name account_name trigger_category data_trigger notification active ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
109 110 111 112 113 114 115 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 109 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
126 127 128 129 130 131 132 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 126 def inspect class_name = self.class.name.split('::').last "<#{class_name} trigger_id: #{@trigger_id.inspect}, trigger_name: #{@trigger_name.inspect},"\ " account_name: #{@account_name.inspect}, trigger_category: #{@trigger_category.inspect},"\ " data_trigger: #{@data_trigger.inspect}, notification: #{@notification.inspect}, active:"\ " #{@active.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
118 119 120 121 122 123 |
# File 'lib/verizon/models/account_group_share_update_trigger_request.rb', line 118 def to_s class_name = self.class.name.split('::').last "<#{class_name} trigger_id: #{@trigger_id}, trigger_name: #{@trigger_name}, account_name:"\ " #{@account_name}, trigger_category: #{@trigger_category}, data_trigger: #{@data_trigger},"\ " notification: #{@notification}, active: #{@active}>" end |