Class: Verizon::AccountLabels

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_labels.rb

Overview

Maximum of 2,000 objects are allowed in the array.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(devices:, label: SKIP, additional_properties: nil) ⇒ AccountLabels

Returns a new instance of AccountLabels.



40
41
42
43
44
45
46
47
# File 'lib/verizon/models/account_labels.rb', line 40

def initialize(devices:, label: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @devices = devices
  @label = label unless label == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#devicesArray[DeviceList]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/account_labels.rb', line 14

def devices
  @devices
end

#labelArray[DeviceLabels]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/account_labels.rb', line 18

def label
  @label
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/verizon/models/account_labels.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (DeviceList.from_hash(structure) if structure)
    end
  end

  devices = nil unless hash.key?('devices')
  # Parameter is an array, so we need to iterate through it
  label = nil
  unless hash['label'].nil?
    label = []
    hash['label'].each do |structure|
      label << (DeviceLabels.from_hash(structure) if structure)
    end
  end

  label = SKIP unless hash.key?('label')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountLabels.new(devices: devices,
                    label: label,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/account_labels.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['devices'] = 'devices'
  @_hash['label'] = 'label'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/verizon/models/account_labels.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/verizon/models/account_labels.rb', line 29

def self.optionals
  %w[
    label
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
# File 'lib/verizon/models/account_labels.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices.inspect}, label: #{@label.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/verizon/models/account_labels.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices}, label: #{@label}, additional_properties:"\
  " #{@additional_properties}>"
end