Class: Verizon::AccountLead

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_lead.rb

Overview

A successful response returns an array of lead objects.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(address: SKIP, lead_id: SKIP, lead_state: SKIP, additional_properties: nil) ⇒ AccountLead

Returns a new instance of AccountLead.



49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/account_lead.rb', line 49

def initialize(address: SKIP, lead_id: SKIP, lead_state: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address = address unless address == SKIP
  @lead_id = lead_id unless lead_id == SKIP
  @lead_state = lead_state unless lead_state == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressAddress

The customer address for the line’s primary place of use, for line usage taxation.

Returns:



15
16
17
# File 'lib/verizon/models/account_lead.rb', line 15

def address
  @address
end

#lead_idString

Unique number for each lead. Use this value in the leadId parameter when activating devices to credit the activations to the lead.

Returns:

  • (String)


20
21
22
# File 'lib/verizon/models/account_lead.rb', line 20

def lead_id
  @lead_id
end

#lead_stateString

The current state of the lead, such as “Qualified” or “Closed.”

Returns:

  • (String)


24
25
26
# File 'lib/verizon/models/account_lead.rb', line 24

def lead_state
  @lead_state
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/verizon/models/account_lead.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  address = Address.from_hash(hash['address']) if hash['address']
  lead_id = hash.key?('leadId') ? hash['leadId'] : SKIP
  lead_state = hash.key?('leadState') ? hash['leadState'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountLead.new(address: address,
                  lead_id: lead_id,
                  lead_state: lead_state,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/verizon/models/account_lead.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['lead_id'] = 'leadId'
  @_hash['lead_state'] = 'leadState'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/verizon/models/account_lead.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/verizon/models/account_lead.rb', line 36

def self.optionals
  %w[
    address
    lead_id
    lead_state
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/verizon/models/account_lead.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, lead_id: #{@lead_id.inspect}, lead_state:"\
  " #{@lead_state.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/verizon/models/account_lead.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, lead_id: #{@lead_id}, lead_state: #{@lead_state},"\
  " additional_properties: #{@additional_properties}>"
end