Class: Verizon::AccountLevelCreateTrigger
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AccountLevelCreateTrigger
- Defined in:
- lib/verizon/models/account_level_create_trigger.rb
Overview
AccountLevelCreateTrigger Model.
Instance Attribute Summary collapse
-
#data_trigger ⇒ DataTrigger
The type of trigger being created or modified.
-
#ecpd_id ⇒ String
The Enterprise Customer Profile Database ID.
-
#notification ⇒ Notificationarray
The type of trigger being created or modified.
-
#trigger_category ⇒ TriggerCategory
The type of trigger being created or modified.
-
#trigger_name ⇒ String
The user defined name of the trigger.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP) ⇒ AccountLevelCreateTrigger
constructor
A new instance of AccountLevelCreateTrigger.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP) ⇒ AccountLevelCreateTrigger
Returns a new instance of AccountLevelCreateTrigger.
59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 59 def initialize(trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP) @trigger_name = trigger_name unless trigger_name == SKIP @ecpd_id = ecpd_id unless ecpd_id == SKIP @trigger_category = trigger_category unless trigger_category == SKIP @data_trigger = data_trigger unless data_trigger == SKIP @notification = notification unless notification == SKIP end |
Instance Attribute Details
#data_trigger ⇒ DataTrigger
The type of trigger being created or modified
26 27 28 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 26 def data_trigger @data_trigger end |
#ecpd_id ⇒ String
The Enterprise Customer Profile Database ID
18 19 20 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 18 def ecpd_id @ecpd_id end |
#notification ⇒ Notificationarray
The type of trigger being created or modified
30 31 32 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 30 def notification @notification end |
#trigger_category ⇒ TriggerCategory
The type of trigger being created or modified
22 23 24 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 22 def trigger_category @trigger_category end |
#trigger_name ⇒ String
The user defined name of the trigger
14 15 16 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 14 def trigger_name @trigger_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. trigger_name = hash.key?('triggerName') ? hash['triggerName'] : SKIP ecpd_id = hash.key?('ecpdId') ? hash['ecpdId'] : SKIP trigger_category = hash.key?('triggerCategory') ? hash['triggerCategory'] : SKIP data_trigger = DataTrigger.from_hash(hash['dataTrigger']) if hash['dataTrigger'] notification = Notificationarray.from_hash(hash['notification']) if hash['notification'] # Create object from extracted values. AccountLevelCreateTrigger.new(trigger_name: trigger_name, ecpd_id: ecpd_id, trigger_category: trigger_category, data_trigger: data_trigger, notification: notification) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['trigger_name'] = 'triggerName' @_hash['ecpd_id'] = 'ecpdId' @_hash['trigger_category'] = 'triggerCategory' @_hash['data_trigger'] = 'dataTrigger' @_hash['notification'] = 'notification' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 44 def self.optionals %w[ trigger_name ecpd_id trigger_category data_trigger notification ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} trigger_name: #{@trigger_name.inspect}, ecpd_id: #{@ecpd_id.inspect},"\ " trigger_category: #{@trigger_category.inspect}, data_trigger: #{@data_trigger.inspect},"\ " notification: #{@notification.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/verizon/models/account_level_create_trigger.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} trigger_name: #{@trigger_name}, ecpd_id: #{@ecpd_id}, trigger_category:"\ " #{@trigger_category}, data_trigger: #{@data_trigger}, notification: #{@notification}>" end |