Class: Verizon::AccountLicenseDeviceListItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AccountLicenseDeviceListItem
- Defined in:
- lib/verizon/models/account_license_device_list_item.rb
Overview
The list of devices that have licenses assigned, including the date and time of when each license was assigned.
Instance Attribute Summary collapse
-
#assignment_time ⇒ DateTime
Timestamp of when a license was assigned to the device.
-
#device_id ⇒ String
Device IMEI.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id: SKIP, assignment_time: SKIP, additional_properties: nil) ⇒ AccountLicenseDeviceListItem
constructor
A new instance of AccountLicenseDeviceListItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_assignment_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id: SKIP, assignment_time: SKIP, additional_properties: nil) ⇒ AccountLicenseDeviceListItem
Returns a new instance of AccountLicenseDeviceListItem.
43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 43 def initialize(device_id: SKIP, assignment_time: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id unless device_id == SKIP @assignment_time = assignment_time unless assignment_time == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#assignment_time ⇒ DateTime
Timestamp of when a license was assigned to the device.
20 21 22 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 20 def assignment_time @assignment_time end |
#device_id ⇒ String
Device IMEI.
16 17 18 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 16 def device_id @device_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = hash.key?('deviceId') ? hash['deviceId'] : SKIP assignment_time = if hash.key?('assignmentTime') (DateTimeHelper.from_rfc3339(hash['assignmentTime']) if hash['assignmentTime']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountLicenseDeviceListItem.new(device_id: device_id, assignment_time: assignment_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['assignment_time'] = 'assignmentTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 31 def self.optionals %w[ device_id assignment_time ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, assignment_time:"\ " #{@assignment_time.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_assignment_time ⇒ Object
78 79 80 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 78 def to_custom_assignment_time DateTimeHelper.to_rfc3339(assignment_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/verizon/models/account_license_device_list_item.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, assignment_time: #{@assignment_time},"\ " additional_properties: #{@additional_properties}>" end |