Class: Verizon::AccountService
- Defined in:
- lib/verizon/models/account_service.rb
Overview
Service associated with the account.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the service plan.
-
#name ⇒ String
The name of the service plan.
-
#states ⇒ Array[State]
The state of the service plan.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, description: SKIP, states: SKIP, additional_properties: nil) ⇒ AccountService
constructor
A new instance of AccountService.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, description: SKIP, states: SKIP, additional_properties: nil) ⇒ AccountService
Returns a new instance of AccountService.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/account_service.rb', line 47 def initialize(name: SKIP, description: SKIP, states: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @description = description unless description == SKIP @states = states unless states == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#description ⇒ String
The description of the service plan.
18 19 20 |
# File 'lib/verizon/models/account_service.rb', line 18 def description @description end |
#name ⇒ String
The name of the service plan.
14 15 16 |
# File 'lib/verizon/models/account_service.rb', line 14 def name @name end |
#states ⇒ Array[State]
The state of the service plan.
22 23 24 |
# File 'lib/verizon/models/account_service.rb', line 22 def states @states end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/verizon/models/account_service.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP # Parameter is an array, so we need to iterate through it states = nil unless hash['states'].nil? states = [] hash['states'].each do |structure| states << (State.from_hash(structure) if structure) end end states = SKIP unless hash.key?('states') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountService.new(name: name, description: description, states: states, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/account_service.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['states'] = 'states' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/account_service.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/account_service.rb', line 34 def self.optionals %w[ name description states ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/verizon/models/account_service.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, description: #{@description.inspect}, states:"\ " #{@states.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/verizon/models/account_service.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, description: #{@description}, states: #{@states},"\ " additional_properties: #{@additional_properties}>" end |