Class: Verizon::AccountShareCreateTriggerRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AccountShareCreateTriggerRequest
- Defined in:
- lib/verizon/models/account_share_create_trigger_request.rb
Overview
AccountShareCreateTriggerRequest Model.
Instance Attribute Summary collapse
-
#active ⇒ Active
A flag to indicate of the trigger is active, true, or not, false.
-
#ecpd_id ⇒ String
The Enterprise Customer Profile Database ID.
-
#notification ⇒ Notificationarray
The type of trigger being created or modified.
-
#price_plan_trigger ⇒ AccountSharePricePlanTrigger
The type of trigger being created or modified.
-
#trigger_category ⇒ TriggerCategory
The type of trigger being created or modified.
-
#trigger_name ⇒ String
The user defined name of the trigger.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, price_plan_trigger: SKIP, notification: SKIP, active: SKIP, additional_properties: nil) ⇒ AccountShareCreateTriggerRequest
constructor
A new instance of AccountShareCreateTriggerRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, price_plan_trigger: SKIP, notification: SKIP, active: SKIP, additional_properties: nil) ⇒ AccountShareCreateTriggerRequest
Returns a new instance of AccountShareCreateTriggerRequest.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 65 def initialize(trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, price_plan_trigger: SKIP, notification: SKIP, active: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @trigger_name = trigger_name unless trigger_name == SKIP @ecpd_id = ecpd_id unless ecpd_id == SKIP @trigger_category = trigger_category unless trigger_category == SKIP @price_plan_trigger = price_plan_trigger unless price_plan_trigger == SKIP @notification = notification unless notification == SKIP @active = active unless active == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#active ⇒ Active
A flag to indicate of the trigger is active, true, or not, false
34 35 36 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 34 def active @active end |
#ecpd_id ⇒ String
The Enterprise Customer Profile Database ID
18 19 20 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 18 def ecpd_id @ecpd_id end |
#notification ⇒ Notificationarray
The type of trigger being created or modified
30 31 32 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 30 def notification @notification end |
#price_plan_trigger ⇒ AccountSharePricePlanTrigger
The type of trigger being created or modified
26 27 28 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 26 def price_plan_trigger @price_plan_trigger end |
#trigger_category ⇒ TriggerCategory
The type of trigger being created or modified
22 23 24 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 22 def trigger_category @trigger_category end |
#trigger_name ⇒ String
The user defined name of the trigger
14 15 16 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 14 def trigger_name @trigger_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 81 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. trigger_name = hash.key?('triggerName') ? hash['triggerName'] : SKIP ecpd_id = hash.key?('ecpdId') ? hash['ecpdId'] : SKIP trigger_category = hash.key?('triggerCategory') ? hash['triggerCategory'] : SKIP price_plan_trigger = AccountSharePricePlanTrigger.from_hash(hash['pricePlanTrigger']) if hash['pricePlanTrigger'] notification = Notificationarray.from_hash(hash['notification']) if hash['notification'] active = hash.key?('active') ? hash['active'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountShareCreateTriggerRequest.new(trigger_name: trigger_name, ecpd_id: ecpd_id, trigger_category: trigger_category, price_plan_trigger: price_plan_trigger, notification: notification, active: active, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['trigger_name'] = 'triggerName' @_hash['ecpd_id'] = 'ecpdId' @_hash['trigger_category'] = 'triggerCategory' @_hash['price_plan_trigger'] = 'pricePlanTrigger' @_hash['notification'] = 'notification' @_hash['active'] = 'active' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 49 def self.optionals %w[ trigger_name ecpd_id trigger_category price_plan_trigger notification active ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
113 114 115 116 117 118 119 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 113 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
130 131 132 133 134 135 136 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 130 def inspect class_name = self.class.name.split('::').last "<#{class_name} trigger_name: #{@trigger_name.inspect}, ecpd_id: #{@ecpd_id.inspect},"\ " trigger_category: #{@trigger_category.inspect}, price_plan_trigger:"\ " #{@price_plan_trigger.inspect}, notification: #{@notification.inspect}, active:"\ " #{@active.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 |
# File 'lib/verizon/models/account_share_create_trigger_request.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} trigger_name: #{@trigger_name}, ecpd_id: #{@ecpd_id}, trigger_category:"\ " #{@trigger_category}, price_plan_trigger: #{@price_plan_trigger}, notification:"\ " #{@notification}, active: #{@active}, additional_properties: #{@additional_properties}>" end |