Class: Verizon::AccountStatesAndServices

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_states_and_services.rb

Overview

Returns a list and details of all custom services and states defined for a specified account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(engagement:, additional_properties: nil) ⇒ AccountStatesAndServices

Returns a new instance of AccountStatesAndServices.



34
35
36
37
38
39
40
# File 'lib/verizon/models/account_states_and_services.rb', line 34

def initialize(engagement:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @engagement = engagement
  @additional_properties = additional_properties
end

Instance Attribute Details

#engagementArray[Engagement]

The engagements associated with the account.

Returns:



15
16
17
# File 'lib/verizon/models/account_states_and_services.rb', line 15

def engagement
  @engagement
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/verizon/models/account_states_and_services.rb', line 43

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  engagement = nil
  unless hash['engagement'].nil?
    engagement = []
    hash['engagement'].each do |structure|
      engagement << (Engagement.from_hash(structure) if structure)
    end
  end

  engagement = nil unless hash.key?('engagement')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountStatesAndServices.new(engagement: engagement,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/verizon/models/account_states_and_services.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['engagement'] = 'engagement'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/verizon/models/account_states_and_services.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/verizon/models/account_states_and_services.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/verizon/models/account_states_and_services.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} engagement: #{@engagement.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/verizon/models/account_states_and_services.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} engagement: #{@engagement}, additional_properties:"\
  " #{@additional_properties}>"
end