Class: Verizon::AddDevicesResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/add_devices_result.rb

Overview

Contains the device identifiers and a success or failure response for each device in the request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids: SKIP, response: SKIP, additional_properties: nil) ⇒ AddDevicesResult

Returns a new instance of AddDevicesResult.



42
43
44
45
46
47
48
49
# File 'lib/verizon/models/add_devices_result.rb', line 42

def initialize(device_ids: SKIP, response: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_ids = device_ids unless device_ids == SKIP
  @response = response unless response == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_idsArray[DeviceId]

Identifiers for the device.

Returns:



15
16
17
# File 'lib/verizon/models/add_devices_result.rb', line 15

def device_ids
  @device_ids
end

#responseString

The success message or error message for the current device.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/add_devices_result.rb', line 19

def response
  @response
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/models/add_devices_result.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (DeviceId.from_hash(structure) if structure)
    end
  end

  device_ids = SKIP unless hash.key?('deviceIds')
  response = hash.key?('response') ? hash['response'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddDevicesResult.new(device_ids: device_ids,
                       response: response,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/add_devices_result.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'deviceIds'
  @_hash['response'] = 'response'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/add_devices_result.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/verizon/models/add_devices_result.rb', line 30

def self.optionals
  %w[
    device_ids
    response
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/verizon/models/add_devices_result.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, response: #{@response.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/verizon/models/add_devices_result.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, response: #{@response}, additional_properties:"\
  " #{@additional_properties}>"
end