Class: Verizon::AggregateUsage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/aggregate_usage.rb

Overview

AggregateUsage Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_id: SKIP, account_name: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ AggregateUsage

Returns a new instance of AggregateUsage.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/verizon/models/aggregate_usage.rb', line 54

def initialize(device_id: SKIP, account_name: SKIP, start_time: SKIP,
               end_time: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_id = device_id unless device_id == SKIP
  @account_name =  unless  == SKIP
  @start_time = start_time unless start_time == SKIP
  @end_time = end_time unless end_time == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The numeric name of the account, in the format “0000123456-00001”. Leading zeros must be included.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/aggregate_usage.rb', line 19

def 
  @account_name
end

#device_idGioDeviceId

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/aggregate_usage.rb', line 14

def device_id
  @device_id
end

#end_timeString

The end date of the time period being queried as “$datetime”

Returns:

  • (String)


27
28
29
# File 'lib/verizon/models/aggregate_usage.rb', line 27

def end_time
  @end_time
end

#start_timeString

The start date of the time period queried as “$datetime”

Returns:

  • (String)


23
24
25
# File 'lib/verizon/models/aggregate_usage.rb', line 23

def start_time
  @start_time
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/verizon/models/aggregate_usage.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  device_id = GioDeviceId.from_hash(hash['deviceId']) if hash['deviceId']
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  start_time = hash.key?('startTime') ? hash['startTime'] : SKIP
  end_time = hash.key?('endTime') ? hash['endTime'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AggregateUsage.new(device_id: device_id,
                     account_name: ,
                     start_time: start_time,
                     end_time: end_time,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/verizon/models/aggregate_usage.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_id'] = 'deviceId'
  @_hash['account_name'] = 'accountName'
  @_hash['start_time'] = 'startTime'
  @_hash['end_time'] = 'endTime'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/verizon/models/aggregate_usage.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
46
47
# File 'lib/verizon/models/aggregate_usage.rb', line 40

def self.optionals
  %w[
    device_id
    account_name
    start_time
    end_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/verizon/models/aggregate_usage.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_id: #{@device_id.inspect}, account_name: #{@account_name.inspect},"\
  " start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/verizon/models/aggregate_usage.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_id: #{@device_id}, account_name: #{@account_name}, start_time:"\
  " #{@start_time}, end_time: #{@end_time}, additional_properties: #{@additional_properties}>"
end