Class: Verizon::AggregateUsageError
- Defined in:
- lib/verizon/models/aggregate_usage_error.rb
Overview
Error reported by a device.
Instance Attribute Summary collapse
-
#error_message ⇒ String
A general error message.
-
#error_response ⇒ IErrorMessage
Error message.
-
#imei ⇒ HplImei
The International Mobile Equipment Identifier of the device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imei: SKIP, error_message: SKIP, error_response: SKIP, additional_properties: nil) ⇒ AggregateUsageError
constructor
A new instance of AggregateUsageError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imei: SKIP, error_message: SKIP, error_response: SKIP, additional_properties: nil) ⇒ AggregateUsageError
Returns a new instance of AggregateUsageError.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 47 def initialize(imei: SKIP, error_message: SKIP, error_response: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @imei = imei unless imei == SKIP @error_message = unless == SKIP @error_response = error_response unless error_response == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#error_message ⇒ String
A general error message.
18 19 20 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 18 def @error_message end |
#error_response ⇒ IErrorMessage
Error message.
22 23 24 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 22 def error_response @error_response end |
#imei ⇒ HplImei
The International Mobile Equipment Identifier of the device.
14 15 16 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 14 def imei @imei end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imei = HplImei.from_hash(hash['imei']) if hash['imei'] = hash.key?('errorMessage') ? hash['errorMessage'] : SKIP error_response = IErrorMessage.from_hash(hash['errorResponse']) if hash['errorResponse'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AggregateUsageError.new(imei: imei, error_message: , error_response: error_response, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['imei'] = 'imei' @_hash['error_message'] = 'errorMessage' @_hash['error_response'] = 'errorResponse' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 34 def self.optionals %w[ imei error_message error_response ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei.inspect}, error_message: #{@error_message.inspect},"\ " error_response: #{@error_response.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/verizon/models/aggregate_usage_error.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei}, error_message: #{@error_message}, error_response:"\ " #{@error_response}, additional_properties: #{@additional_properties}>" end |