Class: Verizon::AggregatedReportCallbackResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/aggregated_report_callback_result.rb

Overview

Aggregated usage report (Asynchronous).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(txid:, status: SKIP, additional_properties: nil) ⇒ AggregatedReportCallbackResult

Returns a new instance of AggregatedReportCallbackResult.



45
46
47
48
49
50
51
52
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 45

def initialize(txid:, status: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @txid = txid
  @status = status unless status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#statusAggregatedReportCallbackStatus

QUEUED or COMPLETED. Requests for IoT devices with cacheMode=0 (cached) have status=COMPLETED; all other requests are QUEUED.



23
24
25
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 23

def status
  @status
end

#txidString

A unique string (UUID) that associates the request with the location report information that is sent in asynchronous callback message.ThingSpace will send a separate callback message for each device that was in the request. All of the callback messages will have the same txid.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 18

def txid
  @txid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  txid = hash.key?('txid') ? hash['txid'] : nil
  status = hash.key?('status') ? hash['status'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AggregatedReportCallbackResult.new(txid: txid,
                                     status: status,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['txid'] = 'txid'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 34

def self.optionals
  %w[
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} txid: #{@txid.inspect}, status: #{@status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/verizon/models/aggregated_report_callback_result.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} txid: #{@txid}, status: #{@status}, additional_properties:"\
  " #{@additional_properties}>"
end