Class: Verizon::AnomalyTriggerResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/anomaly_trigger_result.rb

Overview

A result containing a list of anomaly triggers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(triggers: SKIP) ⇒ AnomalyTriggerResult

Returns a new instance of AnomalyTriggerResult.



35
36
37
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 35

def initialize(triggers: SKIP)
  @triggers = triggers unless triggers == SKIP
end

Instance Attribute Details

#triggersArray[Object]

Trigger value chunk details.

Returns:

  • (Array[Object])


14
15
16
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 14

def triggers
  @triggers
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  triggers = hash.key?('triggers') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:TriggersListOptions), hash['triggers']
  ) : SKIP

  # Create object from extracted values.
  AnomalyTriggerResult.new(triggers: triggers)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['triggers'] = 'triggers'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 24

def self.optionals
  %w[
    triggers
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



54
55
56
57
58
59
60
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 54

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} triggers: #{@triggers.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/verizon/models/anomaly_trigger_result.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} triggers: #{@triggers}>"
end