Class: Verizon::AnomalyTriggersApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/anomaly_triggers_api.rb

Overview

AnomalyTriggersApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#create_anomaly_detection_trigger(body) ⇒ ApiResponse

This corresponds to the M2M-MC SOAP interface, “‘CreateTrigger“`. Request

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/verizon/apis/anomaly_triggers_api.rb', line 94

def create_anomaly_detection_trigger(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyDetectionTrigger.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             IntelligenceResultException)
                .local_error('401',
                             'Unauthorized',
                             IntelligenceResultException)
                .local_error('403',
                             'Forbidden',
                             IntelligenceResultException)
                .local_error('404',
                             'Not Found / Does not exist',
                             IntelligenceResultException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             IntelligenceResultException)
                .local_error('429',
                             'Too many requests',
                             IntelligenceResultException)
                .local_error('default',
                             'Error response',
                             IntelligenceResultException))
    .execute
end

#delete_anomaly_detection_trigger(trigger_id) ⇒ ApiResponse

Deletes a specific trigger ID deleted

Parameters:

  • trigger_id (String)

    Required parameter: The trigger ID to be

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/verizon/apis/anomaly_triggers_api.rb', line 179

def delete_anomaly_detection_trigger(trigger_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/m2m/v1/triggers/{triggerId}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(trigger_id, key: 'triggerId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyDetectionTrigger.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             IntelligenceResultException))
    .execute
end

#list_anomaly_detection_trigger_settings(trigger_id) ⇒ ApiResponse

This corresponds to the M2M-MC SOAP interface, “‘GetTriggers“`.

Parameters:

  • trigger_id (String)

    Required parameter: trigger ID

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/verizon/apis/anomaly_triggers_api.rb', line 136

def list_anomaly_detection_trigger_settings(trigger_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/triggers/{triggerId}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(trigger_id, key: 'triggerId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetTriggerResponseList.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad request',
                             IntelligenceResultException)
                .local_error('401',
                             'Unauthorized',
                             IntelligenceResultException)
                .local_error('403',
                             'Forbidden',
                             IntelligenceResultException)
                .local_error('404',
                             'Not Found / Does not exist',
                             IntelligenceResultException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             IntelligenceResultException)
                .local_error('429',
                             'Too many requests',
                             IntelligenceResultException)
                .local_error('default',
                             'Error response',
                             IntelligenceResultException))
    .execute
end

#list_anomaly_detection_triggersApiResponse

This corresponds to the M2M-MC SOAP interface, “‘GetTriggers“`.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/verizon/apis/anomaly_triggers_api.rb', line 11

def list_anomaly_detection_triggers
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetTriggerResponseList.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad request',
                             IntelligenceResultException)
                .local_error('401',
                             'Unauthorized',
                             IntelligenceResultException)
                .local_error('403',
                             'Forbidden',
                             IntelligenceResultException)
                .local_error('404',
                             'Not Found / Does not exist',
                             IntelligenceResultException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             IntelligenceResultException)
                .local_error('429',
                             'Too many requests',
                             IntelligenceResultException)
                .local_error('default',
                             'Error response',
                             IntelligenceResultException))
    .execute
end

#update_anomaly_detection_trigger(body) ⇒ ApiResponse

This corresponds to the M2M-MC SOAP interface, “‘UpdateTriggerRequest“`. Request

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/verizon/apis/anomaly_triggers_api.rb', line 51

def update_anomaly_detection_trigger(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/m2m/v1/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyDetectionTrigger.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             IntelligenceResultException)
                .local_error('401',
                             'Unauthorized',
                             IntelligenceResultException)
                .local_error('403',
                             'Forbidden',
                             IntelligenceResultException)
                .local_error('404',
                             'Not Found / Does not exist',
                             IntelligenceResultException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             IntelligenceResultException)
                .local_error('429',
                             'Too many requests',
                             IntelligenceResultException)
                .local_error('default',
                             'Error response',
                             IntelligenceResultException))
    .execute
end