Class: Verizon::AnomalyTriggersV2Api

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/anomaly_triggers_v2_api.rb

Overview

AnomalyTriggersV2Api

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#create_anomaly_detection_trigger_v2(body) ⇒ ApiResponse

Creates the trigger to identify an anomaly. ActiveTriggerIndicator]] body Required parameter: Request to create an anomaly trigger.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
# File 'lib/verizon/apis/anomaly_triggers_v2_api.rb', line 14

def create_anomaly_detection_trigger_v2(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v2/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true)
                            .validator(proc do |value|
                              UnionTypeLookUp.get(:CreateTriggerRequestOptions)
                                             .validate(value)
                            end))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyDetectionTrigger.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'An error occurred.',
                             IntelligenceResultException))
    .execute
end

#list_anomaly_detection_trigger_settings_v2(trigger_id) ⇒ ApiResponse

Retrieves the values for a specific trigger ID. specific trigger.

Parameters:

  • trigger_id (String)

    Required parameter: The trigger ID of a

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/apis/anomaly_triggers_v2_api.rb', line 72

def list_anomaly_detection_trigger_settings_v2(trigger_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v2/triggers/{triggerId}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(trigger_id, key: 'triggerId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyTriggerResult.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'An error occurred.',
                             IntelligenceResultException))
    .execute
end

#update_anomaly_detection_trigger_v2(body) ⇒ ApiResponse

Updates an existing trigger using the account name. parameter: Request to update existing trigger.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/verizon/apis/anomaly_triggers_v2_api.rb', line 43

def update_anomaly_detection_trigger_v2(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/m2m/v2/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true)
                            .validator(proc do |value|
                              UnionTypeLookUp.get(:UpdateTriggerRequestOptions)
                                             .validate(value)
                            end))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(IntelligenceSuccessResult.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'An error occurred.',
                             IntelligenceResultException))
    .execute
end