Class: Verizon::AppConfigResponseErrorException

Inherits:
APIException
  • Object
show all
Defined in:
lib/verizon/exceptions/app_config_response_error_exception.rb

Overview

error response structure

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ AppConfigResponseErrorException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



23
24
25
26
27
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 23

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#descriptionString

The detailed description of the error

Returns:

  • (String)


18
19
20
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 18

def description
  @description
end

#errorString

The short summary of the error

Returns:

  • (String)


14
15
16
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 14

def error
  @error
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



46
47
48
49
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 46

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error: #{@error.inspect}, description: #{@description.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



40
41
42
43
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 40

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error: #{@error}, description: #{@description}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



32
33
34
35
36
37
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 32

def unbox(hash)
  return nil unless hash

  @error = hash.key?('error') ? hash['error'] : nil
  @description = hash.key?('description') ? hash['description'] : nil
end