Class: Verizon::AsynchronousLocationRequestResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/asynchronous_location_request_result.rb

Overview

AsynchronousLocationRequestResult Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(txid: SKIP, status: SKIP, estimated_duration: SKIP, additional_properties: nil) ⇒ AsynchronousLocationRequestResult

Returns a new instance of AsynchronousLocationRequestResult.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 47

def initialize(txid: SKIP, status: SKIP, estimated_duration: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @txid = txid unless txid == SKIP
  @status = status unless status == SKIP
  @estimated_duration = estimated_duration unless estimated_duration == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#estimated_durationString

Estimated number of minutes required to complete the report.

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 22

def estimated_duration
  @estimated_duration
end

#statusReportStatus

Status of the report.

Returns:



18
19
20
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 18

def status
  @status
end

#txidString

The transaction ID of the report.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 14

def txid
  @txid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  txid = hash.key?('txid') ? hash['txid'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  estimated_duration =
    hash.key?('estimatedDuration') ? hash['estimatedDuration'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AsynchronousLocationRequestResult.new(txid: txid,
                                        status: status,
                                        estimated_duration: estimated_duration,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['txid'] = 'txid'
  @_hash['status'] = 'status'
  @_hash['estimated_duration'] = 'estimatedDuration'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 34

def self.optionals
  %w[
    txid
    status
    estimated_duration
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} txid: #{@txid.inspect}, status: #{@status.inspect}, estimated_duration:"\
  " #{@estimated_duration.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/verizon/models/asynchronous_location_request_result.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} txid: #{@txid}, status: #{@status}, estimated_duration:"\
  " #{@estimated_duration}, additional_properties: #{@additional_properties}>"
end