Class: Verizon::BilledusageListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/billedusage_list_request.rb

Overview

Information required to associate a usage segmentation label with a device to retrieve billing.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name:, labels: SKIP, device_ids: SKIP, billing_cycle: SKIP, additional_properties: nil) ⇒ BilledusageListRequest

Returns a new instance of BilledusageListRequest.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/verizon/models/billedusage_list_request.rb', line 53

def initialize(account_name:, labels: SKIP, device_ids: SKIP,
               billing_cycle: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name = 
  @labels = labels unless labels == SKIP
  @device_ids = device_ids unless device_ids == SKIP
  @billing_cycle = billing_cycle unless billing_cycle == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/verizon/models/billedusage_list_request.rb', line 15

def 
  @account_name
end

#billing_cycleBillingCycle

TODO: Write general description for this method

Returns:



27
28
29
# File 'lib/verizon/models/billedusage_list_request.rb', line 27

def billing_cycle
  @billing_cycle
end

#device_idsArray[DeviceList]

TODO: Write general description for this method

Returns:



23
24
25
# File 'lib/verizon/models/billedusage_list_request.rb', line 23

def device_ids
  @device_ids
end

#labelsLabelsList

TODO: Write general description for this method

Returns:



19
20
21
# File 'lib/verizon/models/billedusage_list_request.rb', line 19

def labels
  @labels
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/verizon/models/billedusage_list_request.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : nil
  labels = LabelsList.from_hash(hash['labels']) if hash['labels']
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (DeviceList.from_hash(structure) if structure)
    end
  end

  device_ids = SKIP unless hash.key?('deviceIds')
  billing_cycle = BillingCycle.from_hash(hash['billingCycle']) if hash['billingCycle']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BilledusageListRequest.new(account_name: ,
                             labels: labels,
                             device_ids: device_ids,
                             billing_cycle: billing_cycle,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/verizon/models/billedusage_list_request.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['labels'] = 'labels'
  @_hash['device_ids'] = 'deviceIds'
  @_hash['billing_cycle'] = 'billingCycle'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/verizon/models/billedusage_list_request.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
46
# File 'lib/verizon/models/billedusage_list_request.rb', line 40

def self.optionals
  %w[
    labels
    device_ids
    billing_cycle
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/verizon/models/billedusage_list_request.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, labels: #{@labels.inspect},"\
  " device_ids: #{@device_ids.inspect}, billing_cycle: #{@billing_cycle.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
# File 'lib/verizon/models/billedusage_list_request.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, labels: #{@labels}, device_ids:"\
  " #{@device_ids}, billing_cycle: #{@billing_cycle}, additional_properties:"\
  " #{@additional_properties}>"
end