Class: Verizon::BullseyeServiceResult
- Defined in:
- lib/verizon/models/bullseye_service_result.rb
Overview
Status of Hyper Precise Location on the device.
Instance Attribute Summary collapse
-
#account_number ⇒ HplAccountnumber
The numeric ID of the account and must include leading zeroes.
-
#device_list ⇒ Array[DeviceServiceInformation]
List of devices.
-
#response_type ⇒ ApiResponseCode
ResponseCode and/or a message indicating success or failure of the request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_number: SKIP, device_list: SKIP, response_type: SKIP, additional_properties: nil) ⇒ BullseyeServiceResult
constructor
A new instance of BullseyeServiceResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_number: SKIP, device_list: SKIP, response_type: SKIP, additional_properties: nil) ⇒ BullseyeServiceResult
Returns a new instance of BullseyeServiceResult.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 49 def initialize(account_number: SKIP, device_list: SKIP, response_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_number = account_number unless account_number == SKIP @device_list = device_list unless device_list == SKIP @response_type = response_type unless response_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_number ⇒ HplAccountnumber
The numeric ID of the account and must include leading zeroes. This value is indentical to ‘accountName`.
15 16 17 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 15 def account_number @account_number end |
#device_list ⇒ Array[DeviceServiceInformation]
List of devices.
19 20 21 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 19 def device_list @device_list end |
#response_type ⇒ ApiResponseCode
ResponseCode and/or a message indicating success or failure of the request.
24 25 26 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 24 def response_type @response_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_number = HplAccountnumber.from_hash(hash['accountNumber']) if hash['accountNumber'] # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (DeviceServiceInformation.from_hash(structure) if structure) end end device_list = SKIP unless hash.key?('deviceList') response_type = ApiResponseCode.from_hash(hash['responseType']) if hash['responseType'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BullseyeServiceResult.new(account_number: account_number, device_list: device_list, response_type: response_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['account_number'] = 'accountNumber' @_hash['device_list'] = 'deviceList' @_hash['response_type'] = 'responseType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 42 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 36 def self.optionals %w[ account_number device_list response_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number.inspect}, device_list:"\ " #{@device_list.inspect}, response_type: #{@response_type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/verizon/models/bullseye_service_result.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number}, device_list: #{@device_list},"\ " response_type: #{@response_type}, additional_properties: #{@additional_properties}>" end |