Class: Verizon::CallbackRegistrationResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/callback_registration_result.rb

Overview

CallbackRegistrationResult Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account: SKIP, name: SKIP, additional_properties: nil) ⇒ CallbackRegistrationResult

Returns a new instance of CallbackRegistrationResult.



41
42
43
44
45
46
47
48
# File 'lib/verizon/models/callback_registration_result.rb', line 41

def initialize(account: SKIP, name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account =  unless  == SKIP
  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountString

The name of the account that registered the callback URL.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/callback_registration_result.rb', line 14

def 
  @account
end

#nameCallbackServiceName

The name of the callback service.

Returns:



18
19
20
# File 'lib/verizon/models/callback_registration_result.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/verizon/models/callback_registration_result.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account') ? hash['account'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CallbackRegistrationResult.new(account: ,
                                 name: name,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/callback_registration_result.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account'] = 'account'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/callback_registration_result.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/callback_registration_result.rb', line 29

def self.optionals
  %w[
    account
    name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/verizon/models/callback_registration_result.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account: #{@account.inspect}, name: #{@name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/verizon/models/callback_registration_result.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account: #{@account}, name: #{@name}, additional_properties:"\
  " #{@additional_properties}>"
end