Class: Verizon::Carriercode1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/carriercode1.rb

Overview

Carriercode1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(carrier_code: SKIP, percentage: SKIP, additional_properties: nil) ⇒ Carriercode1

Returns a new instance of Carriercode1.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/carriercode1.rb', line 41

def initialize(carrier_code: SKIP, percentage: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @carrier_code = carrier_code unless carrier_code == SKIP
  @percentage = percentage unless percentage == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#carrier_codeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/carriercode1.rb', line 14

def carrier_code
  @carrier_code
end

#percentageAllowanceThreshold

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/carriercode1.rb', line 18

def percentage
  @percentage
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/verizon/models/carriercode1.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  carrier_code = hash.key?('carrierCode') ? hash['carrierCode'] : SKIP
  percentage = AllowanceThreshold.from_hash(hash['percentage']) if hash['percentage']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Carriercode1.new(carrier_code: carrier_code,
                   percentage: percentage,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/carriercode1.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['carrier_code'] = 'carrierCode'
  @_hash['percentage'] = 'percentage'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/carriercode1.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/carriercode1.rb', line 29

def self.optionals
  %w[
    carrier_code
    percentage
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Carriercode1 | Hash)

    value against the validation is performed.



74
75
76
77
78
79
80
# File 'lib/verizon/models/carriercode1.rb', line 74

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/verizon/models/carriercode1.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_code: #{@carrier_code.inspect}, percentage: #{@percentage.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/verizon/models/carriercode1.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_code: #{@carrier_code}, percentage: #{@percentage},"\
  " additional_properties: #{@additional_properties}>"
end