Class: Verizon::ChangePwnDeviceIpaddressResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/change_pwn_device_ipaddress_response.rb

Overview

Response to change PWN device ip address.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id: SKIP, additional_properties: nil) ⇒ ChangePwnDeviceIpaddressResponse

Returns a new instance of ChangePwnDeviceIpaddressResponse.



36
37
38
39
40
41
42
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 36

def initialize(request_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique string that associates the request with the results that are sent via a callback service.

Returns:

  • (String)


15
16
17
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 15

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('requestId') ? hash['requestId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ChangePwnDeviceIpaddressResponse.new(request_id: request_id,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'requestId'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 25

def self.optionals
  %w[
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
68
# File 'lib/verizon/models/change_pwn_device_ipaddress_response.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end