Class: Verizon::ChangePwnDeviceProfileRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::ChangePwnDeviceProfileRequest
- Defined in:
- lib/verizon/models/change_pwn_device_profile_request.rb
Overview
ChangePwnDeviceProfileRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
TODO: Write general description for this method.
-
#device_list ⇒ Array[PwnDeviceList]
TODO: Write general description for this method.
-
#new_profile ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, device_list:, new_profile:, additional_properties: nil) ⇒ ChangePwnDeviceProfileRequest
constructor
A new instance of ChangePwnDeviceProfileRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, device_list:, new_profile:, additional_properties: nil) ⇒ ChangePwnDeviceProfileRequest
Returns a new instance of ChangePwnDeviceProfileRequest.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 43 def initialize(account_name:, device_list:, new_profile:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @device_list = device_list @new_profile = new_profile @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[PwnDeviceList]
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 18 def device_list @device_list end |
#new_profile ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 22 def new_profile @new_profile end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (PwnDeviceList.from_hash(structure) if structure) end end device_list = nil unless hash.key?('deviceList') new_profile = hash.key?('newProfile') ? hash['newProfile'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ChangePwnDeviceProfileRequest.new(account_name: account_name, device_list: device_list, new_profile: new_profile, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_list'] = 'deviceList' @_hash['new_profile'] = 'newProfile' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_list:"\ " #{@device_list.inspect}, new_profile: #{@new_profile.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/verizon/models/change_pwn_device_profile_request.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_list: #{@device_list}, new_profile:"\ " #{@new_profile}, additional_properties: #{@additional_properties}>" end |