Class: Verizon::ComputeResourcesType
- Defined in:
- lib/verizon/models/compute_resources_type.rb
Overview
Compute resources of a service profile.
Instance Attribute Summary collapse
-
#gpu ⇒ Gpu
GPU resources of a service profile.
-
#min_ramgb ⇒ Integer
Minimum RAM required in Gigabytes.
-
#min_storage_gb ⇒ Integer
Minimum storage requirement in Gigabytes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gpu: SKIP, min_ramgb: SKIP, min_storage_gb: SKIP) ⇒ ComputeResourcesType
constructor
A new instance of ComputeResourcesType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gpu: SKIP, min_ramgb: SKIP, min_storage_gb: SKIP) ⇒ ComputeResourcesType
Returns a new instance of ComputeResourcesType.
47 48 49 50 51 |
# File 'lib/verizon/models/compute_resources_type.rb', line 47 def initialize(gpu: SKIP, min_ramgb: SKIP, min_storage_gb: SKIP) @gpu = gpu unless gpu == SKIP @min_ramgb = min_ramgb unless min_ramgb == SKIP @min_storage_gb = min_storage_gb unless min_storage_gb == SKIP end |
Instance Attribute Details
#gpu ⇒ Gpu
GPU resources of a service profile.
14 15 16 |
# File 'lib/verizon/models/compute_resources_type.rb', line 14 def gpu @gpu end |
#min_ramgb ⇒ Integer
Minimum RAM required in Gigabytes.
18 19 20 |
# File 'lib/verizon/models/compute_resources_type.rb', line 18 def min_ramgb @min_ramgb end |
#min_storage_gb ⇒ Integer
Minimum storage requirement in Gigabytes.
22 23 24 |
# File 'lib/verizon/models/compute_resources_type.rb', line 22 def min_storage_gb @min_storage_gb end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/compute_resources_type.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gpu = Gpu.from_hash(hash['GPU']) if hash['GPU'] min_ramgb = hash.key?('minRAMGB') ? hash['minRAMGB'] : SKIP min_storage_gb = hash.key?('minStorageGB') ? hash['minStorageGB'] : SKIP # Create object from extracted values. ComputeResourcesType.new(gpu: gpu, min_ramgb: min_ramgb, min_storage_gb: min_storage_gb) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/compute_resources_type.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['gpu'] = 'GPU' @_hash['min_ramgb'] = 'minRAMGB' @_hash['min_storage_gb'] = 'minStorageGB' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/compute_resources_type.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/compute_resources_type.rb', line 34 def self.optionals %w[ gpu min_ramgb min_storage_gb ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/verizon/models/compute_resources_type.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} gpu: #{@gpu.inspect}, min_ramgb: #{@min_ramgb.inspect}, min_storage_gb:"\ " #{@min_storage_gb.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/verizon/models/compute_resources_type.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} gpu: #{@gpu}, min_ramgb: #{@min_ramgb}, min_storage_gb:"\ " #{@min_storage_gb}>" end |