Class: Verizon::ConnectivityCallbacksApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/connectivity_callbacks_api.rb

Overview

ConnectivityCallbacksApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#deregister_callback(aname, sname) ⇒ ApiResponse

Stops ThingSpace from sending callback messages for the specified account and service.

Parameters:

  • aname (String)

    Required parameter: Account name.

  • sname (String)

    Required parameter: Service name.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/verizon/apis/connectivity_callbacks_api.rb', line 70

def deregister_callback(aname,
                        sname)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/m2m/v1/callbacks/{aname}/name/{sname}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(sname, key: 'sname')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CallbackActionResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Error response.',
                             ConnectivityManagementResultException))
    .execute
end

#list_registered_callbacks(aname) ⇒ ApiResponse

Returns the name and endpoint URL of the callback listening services registered for a given account.

Parameters:

  • aname (String)

    Required parameter: Account name.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/verizon/apis/connectivity_callbacks_api.rb', line 13

def list_registered_callbacks(aname)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/callbacks/{aname}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ConnectivityManagementCallback.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Error response.',
                             ConnectivityManagementResultException))
    .execute
end

#register_callback(aname, body) ⇒ ApiResponse

You are responsible for creating and running a listening process on your server at that URL. register a callback.

Parameters:

  • aname (String)

    Required parameter: Account name.

  • body (RegisterCallbackRequest)

    Required parameter: Request to

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/verizon/apis/connectivity_callbacks_api.rb', line 40

def register_callback(aname,
                      body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/callbacks/{aname}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CallbackActionResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Error response.',
                             ConnectivityManagementResultException))
    .execute
end