Class: Verizon::ConsentTransactionId
- Defined in:
- lib/verizon/models/consent_transaction_id.rb
Overview
The transaction ID of the request that you want to cancel, from the POST /devicelocations synchronus response.
Instance Attribute Summary collapse
-
#status ⇒ String
TODO: Write general description for this method.
-
#transaction_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transaction_id: SKIP, status: SKIP, additional_properties: nil) ⇒ ConsentTransactionId
constructor
A new instance of ConsentTransactionId.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transaction_id: SKIP, status: SKIP, additional_properties: nil) ⇒ ConsentTransactionId
Returns a new instance of ConsentTransactionId.
42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 42 def initialize(transaction_id: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transaction_id = transaction_id unless transaction_id == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#status ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 19 def status @status end |
#transaction_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 15 def transaction_id @transaction_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConsentTransactionId.new(transaction_id: transaction_id, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['transaction_id'] = 'transactionId' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 30 def self.optionals %w[ transaction_id status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/consent_transaction_id.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id}, status: #{@status},"\ " additional_properties: #{@additional_properties}>" end |