Class: Verizon::CreateIoTApplicationRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::CreateIoTApplicationRequest
- Defined in:
- lib/verizon/models/create_io_t_application_request.rb
Overview
The request body must include the UUID of the subscription that you want to update plus any properties that you want to change.
Instance Attribute Summary collapse
-
#app_name ⇒ String
A user defined name for the application being deployed in Azure IoT Central.
-
#billing_account_id ⇒ String
The ThingSpace ID of the authenticating billing account.
-
#client_id ⇒ String
The Azure ClientID of the associated Azure target account.
-
#client_secret ⇒ String
The Azure Client Secret of the associated Azure target account.
-
#email_i_ds ⇒ String
The “email IDs” to be added to/sent to with this API.
-
#resourcegroup ⇒ String
The Azure Resource group of the associated Azure target account.
-
#sample_io_tc_app ⇒ String
This is the reference Azure IoT Central application developed by Verizon.
-
#subscription_id ⇒ String
The Azure Subscription ID of the associated Azure target account.
-
#tenant_id ⇒ String
The Azure Tenant ID of the associated Azure target account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(app_name: SKIP, billing_account_id: SKIP, client_id: SKIP, client_secret: SKIP, email_i_ds: SKIP, resourcegroup: SKIP, sample_io_tc_app: SKIP, subscription_id: SKIP, tenant_id: SKIP, additional_properties: nil) ⇒ CreateIoTApplicationRequest
constructor
A new instance of CreateIoTApplicationRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(app_name: SKIP, billing_account_id: SKIP, client_id: SKIP, client_secret: SKIP, email_i_ds: SKIP, resourcegroup: SKIP, sample_io_tc_app: SKIP, subscription_id: SKIP, tenant_id: SKIP, additional_properties: nil) ⇒ CreateIoTApplicationRequest
Returns a new instance of CreateIoTApplicationRequest.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 85 def initialize(app_name: SKIP, billing_account_id: SKIP, client_id: SKIP, client_secret: SKIP, email_i_ds: SKIP, resourcegroup: SKIP, sample_io_tc_app: SKIP, subscription_id: SKIP, tenant_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @app_name = app_name unless app_name == SKIP @billing_account_id = billing_account_id unless billing_account_id == SKIP @client_id = client_id unless client_id == SKIP @client_secret = client_secret unless client_secret == SKIP @email_i_ds = email_i_ds unless email_i_ds == SKIP @resourcegroup = resourcegroup unless resourcegroup == SKIP @sample_io_tc_app = sample_io_tc_app unless sample_io_tc_app == SKIP @subscription_id = subscription_id unless subscription_id == SKIP @tenant_id = tenant_id unless tenant_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#app_name ⇒ String
A user defined name for the application being deployed in Azure IoT Central.
16 17 18 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 16 def app_name @app_name end |
#billing_account_id ⇒ String
The ThingSpace ID of the authenticating billing account
20 21 22 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 20 def billing_account_id @billing_account_id end |
#client_id ⇒ String
The Azure ClientID of the associated Azure target account
24 25 26 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 24 def client_id @client_id end |
#client_secret ⇒ String
The Azure Client Secret of the associated Azure target account
28 29 30 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 28 def client_secret @client_secret end |
#email_i_ds ⇒ String
The “email IDs” to be added to/sent to with this API.
32 33 34 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 32 def email_i_ds @email_i_ds end |
#resourcegroup ⇒ String
The Azure Resource group of the associated Azure target account
36 37 38 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 36 def resourcegroup @resourcegroup end |
#sample_io_tc_app ⇒ String
This is the reference Azure IoT Central application developed by Verizon.
40 41 42 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 40 def sample_io_tc_app @sample_io_tc_app end |
#subscription_id ⇒ String
The Azure Subscription ID of the associated Azure target account
44 45 46 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 44 def subscription_id @subscription_id end |
#tenant_id ⇒ String
The Azure Tenant ID of the associated Azure target account
48 49 50 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 48 def tenant_id @tenant_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 105 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. app_name = hash.key?('appName') ? hash['appName'] : SKIP billing_account_id = hash.key?('billingAccountID') ? hash['billingAccountID'] : SKIP client_id = hash.key?('clientID') ? hash['clientID'] : SKIP client_secret = hash.key?('clientSecret') ? hash['clientSecret'] : SKIP email_i_ds = hash.key?('emailIDs') ? hash['emailIDs'] : SKIP resourcegroup = hash.key?('resourcegroup') ? hash['resourcegroup'] : SKIP sample_io_tc_app = hash.key?('sampleIOTcApp') ? hash['sampleIOTcApp'] : SKIP subscription_id = hash.key?('subscriptionID') ? hash['subscriptionID'] : SKIP tenant_id = hash.key?('tenantID') ? hash['tenantID'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreateIoTApplicationRequest.new(app_name: app_name, billing_account_id: billing_account_id, client_id: client_id, client_secret: client_secret, email_i_ds: email_i_ds, resourcegroup: resourcegroup, sample_io_tc_app: sample_io_tc_app, subscription_id: subscription_id, tenant_id: tenant_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['app_name'] = 'appName' @_hash['billing_account_id'] = 'billingAccountID' @_hash['client_id'] = 'clientID' @_hash['client_secret'] = 'clientSecret' @_hash['email_i_ds'] = 'emailIDs' @_hash['resourcegroup'] = 'resourcegroup' @_hash['sample_io_tc_app'] = 'sampleIOTcApp' @_hash['subscription_id'] = 'subscriptionID' @_hash['tenant_id'] = 'tenantID' @_hash end |
.nullables ⇒ Object
An array for nullable fields
81 82 83 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 81 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 66 def self.optionals %w[ app_name billing_account_id client_id client_secret email_i_ds resourcegroup sample_io_tc_app subscription_id tenant_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
153 154 155 156 157 158 159 160 161 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 153 def inspect class_name = self.class.name.split('::').last "<#{class_name} app_name: #{@app_name.inspect}, billing_account_id:"\ " #{@billing_account_id.inspect}, client_id: #{@client_id.inspect}, client_secret:"\ " #{@client_secret.inspect}, email_i_ds: #{@email_i_ds.inspect}, resourcegroup:"\ " #{@resourcegroup.inspect}, sample_io_tc_app: #{@sample_io_tc_app.inspect},"\ " subscription_id: #{@subscription_id.inspect}, tenant_id: #{@tenant_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
143 144 145 146 147 148 149 150 |
# File 'lib/verizon/models/create_io_t_application_request.rb', line 143 def to_s class_name = self.class.name.split('::').last "<#{class_name} app_name: #{@app_name}, billing_account_id: #{@billing_account_id},"\ " client_id: #{@client_id}, client_secret: #{@client_secret}, email_i_ds: #{@email_i_ds},"\ " resourcegroup: #{@resourcegroup}, sample_io_tc_app: #{@sample_io_tc_app}, subscription_id:"\ " #{@subscription_id}, tenant_id: #{@tenant_id}, additional_properties:"\ " #{@additional_properties}>" end |