Class: Verizon::CreateTargetRequestFields

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/create_target_request_fields.rb

Overview

CreateTargetRequestFields Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(httpheaders: SKIP, devicetypes: SKIP, additional_properties: nil) ⇒ CreateTargetRequestFields

Returns a new instance of CreateTargetRequestFields.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/create_target_request_fields.rb', line 41

def initialize(httpheaders: SKIP, devicetypes: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @httpheaders = httpheaders unless httpheaders == SKIP
  @devicetypes = devicetypes unless devicetypes == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#devicetypesArray[String]

List of device types.

Returns:

  • (Array[String])


18
19
20
# File 'lib/verizon/models/create_target_request_fields.rb', line 18

def devicetypes
  @devicetypes
end

#httpheadersFieldsHttpHeaders

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/create_target_request_fields.rb', line 14

def httpheaders
  @httpheaders
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/verizon/models/create_target_request_fields.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  httpheaders = FieldsHttpHeaders.from_hash(hash['httpheaders']) if hash['httpheaders']
  devicetypes = hash.key?('devicetypes') ? hash['devicetypes'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateTargetRequestFields.new(httpheaders: httpheaders,
                                devicetypes: devicetypes,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/create_target_request_fields.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['httpheaders'] = 'httpheaders'
  @_hash['devicetypes'] = 'devicetypes'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/create_target_request_fields.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/create_target_request_fields.rb', line 29

def self.optionals
  %w[
    httpheaders
    devicetypes
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/verizon/models/create_target_request_fields.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} httpheaders: #{@httpheaders.inspect}, devicetypes: #{@devicetypes.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/verizon/models/create_target_request_fields.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} httpheaders: #{@httpheaders}, devicetypes: #{@devicetypes},"\
  " additional_properties: #{@additional_properties}>"
end