Class: Verizon::Customernamequery
- Defined in:
- lib/verizon/models/customernamequery.rb
Overview
Customernamequery Model.
Instance Attribute Summary collapse
-
#customer_name ⇒ Array[CustomerName]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(customer_name: SKIP) ⇒ Customernamequery
constructor
A new instance of Customernamequery.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(customer_name: SKIP) ⇒ Customernamequery
Returns a new instance of Customernamequery.
35 36 37 |
# File 'lib/verizon/models/customernamequery.rb', line 35 def initialize(customer_name: SKIP) @customer_name = customer_name unless customer_name == SKIP end |
Instance Attribute Details
#customer_name ⇒ Array[CustomerName]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/customernamequery.rb', line 14 def customer_name @customer_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/customernamequery.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it customer_name = nil unless hash['customerName'].nil? customer_name = [] hash['customerName'].each do |structure| customer_name << (CustomerName.from_hash(structure) if structure) end end customer_name = SKIP unless hash.key?('customerName') # Create object from extracted values. Customernamequery.new(customer_name: customer_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/customernamequery.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['customer_name'] = 'customerName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/customernamequery.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/customernamequery.rb', line 24 def self.optionals %w[ customer_name ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/verizon/models/customernamequery.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/verizon/models/customernamequery.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} customer_name: #{@customer_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/verizon/models/customernamequery.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} customer_name: #{@customer_name}>" end |