Class: Verizon::DailyUsage
- Defined in:
- lib/verizon/models/daily_usage.rb
Overview
DailyUsage Model.
Instance Attribute Summary collapse
-
#device_id ⇒ GioDeviceId
TODO: Write general description for this method.
-
#earliest ⇒ String
The start date of the time period queried as “$datetime”.
-
#latest ⇒ String
The end date of the time period being queried as “$datetime”.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id: SKIP, earliest: SKIP, latest: SKIP, additional_properties: nil) ⇒ DailyUsage
constructor
A new instance of DailyUsage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id: SKIP, earliest: SKIP, latest: SKIP, additional_properties: nil) ⇒ DailyUsage
Returns a new instance of DailyUsage.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/daily_usage.rb', line 47 def initialize(device_id: SKIP, earliest: SKIP, latest: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id unless device_id == SKIP @earliest = earliest unless earliest == SKIP @latest = latest unless latest == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_id ⇒ GioDeviceId
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/daily_usage.rb', line 14 def device_id @device_id end |
#earliest ⇒ String
The start date of the time period queried as “$datetime”
18 19 20 |
# File 'lib/verizon/models/daily_usage.rb', line 18 def earliest @earliest end |
#latest ⇒ String
The end date of the time period being queried as “$datetime”
22 23 24 |
# File 'lib/verizon/models/daily_usage.rb', line 22 def latest @latest end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/verizon/models/daily_usage.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = GioDeviceId.from_hash(hash['deviceId']) if hash['deviceId'] earliest = hash.key?('earliest') ? hash['earliest'] : SKIP latest = hash.key?('latest') ? hash['latest'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DailyUsage.new(device_id: device_id, earliest: earliest, latest: latest, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/daily_usage.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['earliest'] = 'earliest' @_hash['latest'] = 'latest' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/daily_usage.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/daily_usage.rb', line 34 def self.optionals %w[ device_id earliest latest ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/verizon/models/daily_usage.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, earliest: #{@earliest.inspect}, latest:"\ " #{@latest.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/verizon/models/daily_usage.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, earliest: #{@earliest}, latest: #{@latest},"\ " additional_properties: #{@additional_properties}>" end |