Class: Verizon::DailyUsageItem
- Defined in:
- lib/verizon/models/daily_usage_item.rb
Overview
Contains only dates when device had sessions.
Instance Attribute Summary collapse
-
#end_time ⇒ String
End date of session.
-
#num_bytes ⇒ Integer
Amount of data transferred, measured in Bytes.
-
#start_time ⇒ String
Start date of session.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_time: SKIP, end_time: SKIP, num_bytes: SKIP, additional_properties: nil) ⇒ DailyUsageItem
constructor
A new instance of DailyUsageItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_time: SKIP, end_time: SKIP, num_bytes: SKIP, additional_properties: nil) ⇒ DailyUsageItem
Returns a new instance of DailyUsageItem.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/daily_usage_item.rb', line 47 def initialize(start_time: SKIP, end_time: SKIP, num_bytes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_time = start_time unless start_time == SKIP @end_time = end_time unless end_time == SKIP @num_bytes = num_bytes unless num_bytes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#end_time ⇒ String
End date of session. ISO 8601 format.
18 19 20 |
# File 'lib/verizon/models/daily_usage_item.rb', line 18 def end_time @end_time end |
#num_bytes ⇒ Integer
Amount of data transferred, measured in Bytes.
22 23 24 |
# File 'lib/verizon/models/daily_usage_item.rb', line 22 def num_bytes @num_bytes end |
#start_time ⇒ String
Start date of session. ISO 8601 format.
14 15 16 |
# File 'lib/verizon/models/daily_usage_item.rb', line 14 def start_time @start_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/verizon/models/daily_usage_item.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_time = hash.key?('startTime') ? hash['startTime'] : SKIP end_time = hash.key?('endTime') ? hash['endTime'] : SKIP num_bytes = hash.key?('numBytes') ? hash['numBytes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DailyUsageItem.new(start_time: start_time, end_time: end_time, num_bytes: num_bytes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/daily_usage_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['start_time'] = 'startTime' @_hash['end_time'] = 'endTime' @_hash['num_bytes'] = 'numBytes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/daily_usage_item.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/daily_usage_item.rb', line 34 def self.optionals %w[ start_time end_time num_bytes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/verizon/models/daily_usage_item.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect},"\ " num_bytes: #{@num_bytes.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/verizon/models/daily_usage_item.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_time: #{@start_time}, end_time: #{@end_time}, num_bytes:"\ " #{@num_bytes}, additional_properties: #{@additional_properties}>" end |