Class: Verizon::DeviceActivationRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceActivationRequest
- Defined in:
- lib/verizon/models/device_activation_request.rb
Overview
Request for device status to check availability of activation.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The name of a billing account.
-
#devices ⇒ Array[AccountDeviceList]
Up to 10,000 devices that you want to move to a different account, specified by device identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, devices:, additional_properties: nil) ⇒ DeviceActivationRequest
constructor
A new instance of DeviceActivationRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, devices:, additional_properties: nil) ⇒ DeviceActivationRequest
Returns a new instance of DeviceActivationRequest.
39 40 41 42 43 44 45 46 |
# File 'lib/verizon/models/device_activation_request.rb', line 39 def initialize(account_name:, devices:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @devices = devices @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The name of a billing account.
14 15 16 |
# File 'lib/verizon/models/device_activation_request.rb', line 14 def account_name @account_name end |
#devices ⇒ Array[AccountDeviceList]
Up to 10,000 devices that you want to move to a different account, specified by device identifier.
19 20 21 |
# File 'lib/verizon/models/device_activation_request.rb', line 19 def devices @devices end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/verizon/models/device_activation_request.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (AccountDeviceList.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceActivationRequest.new(account_name: account_name, devices: devices, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/device_activation_request.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['devices'] = 'devices' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/verizon/models/device_activation_request.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/verizon/models/device_activation_request.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/verizon/models/device_activation_request.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, devices: #{@devices.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/verizon/models/device_activation_request.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, devices: #{@devices},"\ " additional_properties: #{@additional_properties}>" end |