Class: Verizon::DeviceDiagnosticsApi
- Defined in:
- lib/verizon/apis/device_diagnostics_api.rb
Overview
DeviceDiagnosticsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#device_reachability_status_using_post(body) ⇒ ApiResponse
If the devices do not already exist in the account, this API resource adds them before activation.
-
#retrieve_active_monitors_using_post(body) ⇒ ApiResponse
Retrieve all the active monitors.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#device_reachability_status_using_post(body) ⇒ ApiResponse
If the devices do not already exist in the account, this API resource adds them before activation. Reachability Report Status for a device.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/verizon/apis/device_diagnostics_api.rb', line 14 def device_reachability_status_using_post(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/diagnostics/basic/devicereachability/status', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceManagementResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |
#retrieve_active_monitors_using_post(body) ⇒ ApiResponse
Retrieve all the active monitors. Request.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/apis/device_diagnostics_api.rb', line 39 def retrieve_active_monitors_using_post(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/diagnostics/basic/devicereachability/monitors', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceManagementResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |