Class: Verizon::DeviceExtendedDiagnosticsResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceExtendedDiagnosticsResult
- Defined in:
- lib/verizon/models/device_extended_diagnostics_result.rb
Overview
Result for a request to obtain device extended diagnostics.
Instance Attribute Summary collapse
-
#categories ⇒ Array[DiagnosticsCategory]
The response includes various types of information about the device, grouped into categories.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(categories: SKIP, additional_properties: nil) ⇒ DeviceExtendedDiagnosticsResult
constructor
A new instance of DeviceExtendedDiagnosticsResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(categories: SKIP, additional_properties: nil) ⇒ DeviceExtendedDiagnosticsResult
Returns a new instance of DeviceExtendedDiagnosticsResult.
37 38 39 40 41 42 43 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 37 def initialize(categories: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @categories = categories unless categories == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#categories ⇒ Array[DiagnosticsCategory]
The response includes various types of information about the device, grouped into categories. Each category object contains the category name and a list of Extended Attribute objects as key-value pairs.
16 17 18 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 16 def categories @categories end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it categories = nil unless hash['categories'].nil? categories = [] hash['categories'].each do |structure| categories << (DiagnosticsCategory.from_hash(structure) if structure) end end categories = SKIP unless hash.key?('categories') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceExtendedDiagnosticsResult.new(categories: categories, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['categories'] = 'categories' @_hash end |
.nullables ⇒ Object
An array for nullable fields
33 34 35 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 33 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 29 30 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 26 def self.optionals %w[ categories ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} categories: #{@categories.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/device_extended_diagnostics_result.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} categories: #{@categories}, additional_properties:"\ " #{@additional_properties}>" end |