Class: Verizon::DeviceGroupFilter

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_group_filter.rb

Overview

DeviceGroupFilter Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_group_name: SKIP, individual_or_combined: SKIP, account_name: SKIP, additional_properties: nil) ⇒ DeviceGroupFilter

Returns a new instance of DeviceGroupFilter.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/device_group_filter.rb', line 47

def initialize(device_group_name: SKIP, individual_or_combined: SKIP,
               account_name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_group_name = device_group_name unless device_group_name == SKIP
  @individual_or_combined = individual_or_combined unless individual_or_combined == SKIP
  @account_name =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The numeric name of the account and must include leading zeroes

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/device_group_filter.rb', line 22

def 
  @account_name
end

#device_group_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/device_group_filter.rb', line 14

def device_group_name
  @device_group_name
end

#individual_or_combinedString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/device_group_filter.rb', line 18

def individual_or_combined
  @individual_or_combined
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/verizon/models/device_group_filter.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  device_group_name =
    hash.key?('deviceGroupName') ? hash['deviceGroupName'] : SKIP
  individual_or_combined =
    hash.key?('IndividualOrCombined') ? hash['IndividualOrCombined'] : SKIP
   = hash.key?('accountName') ? hash['accountName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceGroupFilter.new(device_group_name: device_group_name,
                        individual_or_combined: individual_or_combined,
                        account_name: ,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/device_group_filter.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_group_name'] = 'deviceGroupName'
  @_hash['individual_or_combined'] = 'IndividualOrCombined'
  @_hash['account_name'] = 'accountName'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/device_group_filter.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/device_group_filter.rb', line 34

def self.optionals
  %w[
    device_group_name
    individual_or_combined
    account_name
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



85
86
87
88
89
90
91
# File 'lib/verizon/models/device_group_filter.rb', line 85

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/verizon/models/device_group_filter.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_group_name: #{@device_group_name.inspect}, individual_or_combined:"\
  " #{@individual_or_combined.inspect}, account_name: #{@account_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
99
# File 'lib/verizon/models/device_group_filter.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_group_name: #{@device_group_name}, individual_or_combined:"\
  " #{@individual_or_combined}, account_name: #{@account_name}, additional_properties:"\
  " #{@additional_properties}>"
end