Class: Verizon::DeviceIdSearch
- Defined in:
- lib/verizon/models/device_id_search.rb
Overview
Search by device id.
Instance Attribute Summary collapse
-
#contains ⇒ String
The string appears anywhere in the identifer.
-
#endswith ⇒ String
The identifier must end with the specified string.
-
#kind ⇒ String
The type of the device identifier.
-
#startswith ⇒ String
The identifer must start with the specified string.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contains:, kind:, startswith: SKIP, endswith: SKIP, additional_properties: nil) ⇒ DeviceIdSearch
constructor
A new instance of DeviceIdSearch.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contains:, kind:, startswith: SKIP, endswith: SKIP, additional_properties: nil) ⇒ DeviceIdSearch
Returns a new instance of DeviceIdSearch.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/models/device_id_search.rb', line 53 def initialize(contains:, kind:, startswith: SKIP, endswith: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @contains = contains @startswith = startswith unless startswith == SKIP @endswith = endswith unless endswith == SKIP @kind = kind @additional_properties = additional_properties end |
Instance Attribute Details
#contains ⇒ String
The string appears anywhere in the identifer.
14 15 16 |
# File 'lib/verizon/models/device_id_search.rb', line 14 def contains @contains end |
#endswith ⇒ String
The identifier must end with the specified string.
22 23 24 |
# File 'lib/verizon/models/device_id_search.rb', line 22 def endswith @endswith end |
#kind ⇒ String
The type of the device identifier. Valid types of identifiers are:ESN (decimal),EID,ICCID (up to 20 digits),IMEI (up to 16 digits),MDN,MEID (hexadecimal),MSISDN.
28 29 30 |
# File 'lib/verizon/models/device_id_search.rb', line 28 def kind @kind end |
#startswith ⇒ String
The identifer must start with the specified string.
18 19 20 |
# File 'lib/verizon/models/device_id_search.rb', line 18 def startswith @startswith end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/verizon/models/device_id_search.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. contains = hash.key?('contains') ? hash['contains'] : nil kind = hash.key?('kind') ? hash['kind'] : nil startswith = hash.key?('startswith') ? hash['startswith'] : SKIP endswith = hash.key?('endswith') ? hash['endswith'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceIdSearch.new(contains: contains, kind: kind, startswith: startswith, endswith: endswith, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/verizon/models/device_id_search.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['contains'] = 'contains' @_hash['startswith'] = 'startswith' @_hash['endswith'] = 'endswith' @_hash['kind'] = 'kind' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/verizon/models/device_id_search.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 |
# File 'lib/verizon/models/device_id_search.rb', line 41 def self.optionals %w[ startswith endswith ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/verizon/models/device_id_search.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} contains: #{@contains.inspect}, startswith: #{@startswith.inspect},"\ " endswith: #{@endswith.inspect}, kind: #{@kind.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/verizon/models/device_id_search.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} contains: #{@contains}, startswith: #{@startswith}, endswith: #{@endswith},"\ " kind: #{@kind}, additional_properties: #{@additional_properties}>" end |