Class: Verizon::DeviceIdentifier
- Defined in:
- lib/verizon/models/device_identifier.rb
Overview
Device Id details.
Instance Attribute Summary collapse
-
#id ⇒ String
Device Identity number.
-
#kind ⇒ String
Kind of device.
-
#mdn ⇒ String
Device MDN number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(kind:, id:, mdn: SKIP) ⇒ DeviceIdentifier
constructor
A new instance of DeviceIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(kind:, id:, mdn: SKIP) ⇒ DeviceIdentifier
Returns a new instance of DeviceIdentifier.
45 46 47 48 49 |
# File 'lib/verizon/models/device_identifier.rb', line 45 def initialize(kind:, id:, mdn: SKIP) @kind = kind @id = id @mdn = mdn unless mdn == SKIP end |
Instance Attribute Details
#id ⇒ String
Device Identity number.
18 19 20 |
# File 'lib/verizon/models/device_identifier.rb', line 18 def id @id end |
#kind ⇒ String
Kind of device.
14 15 16 |
# File 'lib/verizon/models/device_identifier.rb', line 14 def kind @kind end |
#mdn ⇒ String
Device MDN number.
22 23 24 |
# File 'lib/verizon/models/device_identifier.rb', line 22 def mdn @mdn end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/verizon/models/device_identifier.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. kind = hash.key?('kind') ? hash['kind'] : nil id = hash.key?('id') ? hash['id'] : nil mdn = hash.key?('mdn') ? hash['mdn'] : SKIP # Create object from extracted values. DeviceIdentifier.new(kind: kind, id: id, mdn: mdn) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/device_identifier.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['kind'] = 'kind' @_hash['id'] = 'id' @_hash['mdn'] = 'mdn' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/verizon/models/device_identifier.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/verizon/models/device_identifier.rb', line 34 def self.optionals %w[ mdn ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 |
# File 'lib/verizon/models/device_identifier.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} kind: #{@kind.inspect}, id: #{@id.inspect}, mdn: #{@mdn.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/verizon/models/device_identifier.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} kind: #{@kind}, id: #{@id}, mdn: #{@mdn}>" end |