Class: Verizon::DeviceLevelUpdateTriggerRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_level_update_trigger_request.rb

Overview

DeviceLevelUpdateTriggerRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(trigger_id: SKIP, trigger_name: SKIP, ecpd_id: SKIP, trigger_category: SKIP, data_trigger: SKIP, notification: SKIP, active: SKIP) ⇒ DeviceLevelUpdateTriggerRequest

Returns a new instance of DeviceLevelUpdateTriggerRequest.



71
72
73
74
75
76
77
78
79
80
81
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 71

def initialize(trigger_id: SKIP, trigger_name: SKIP, ecpd_id: SKIP,
               trigger_category: SKIP, data_trigger: SKIP,
               notification: SKIP, active: SKIP)
  @trigger_id = trigger_id unless trigger_id == SKIP
  @trigger_name = trigger_name unless trigger_name == SKIP
  @ecpd_id = ecpd_id unless ecpd_id == SKIP
  @trigger_category = trigger_category unless trigger_category == SKIP
  @data_trigger = data_trigger unless data_trigger == SKIP
  @notification = notification unless notification == SKIP
  @active = active unless active == SKIP
end

Instance Attribute Details

#activeActive

A flag to indicate of the trigger is active, true, or not, false

Returns:



38
39
40
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 38

def active
  @active
end

#data_triggerDataTrigger2

The type of trigger being created or modified

Returns:



30
31
32
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 30

def data_trigger
  @data_trigger
end

#ecpd_idString

The Enterprise Customer Profile Database ID

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 22

def ecpd_id
  @ecpd_id
end

#notificationNotificationarray

The type of trigger being created or modified

Returns:



34
35
36
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 34

def notification
  @notification
end

#trigger_categoryTriggerCategory

The type of trigger being created or modified

Returns:



26
27
28
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 26

def trigger_category
  @trigger_category
end

#trigger_idString

The system assigned UUID of the trigger

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 14

def trigger_id
  @trigger_id
end

#trigger_nameString

The user defined name of the trigger

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 18

def trigger_name
  @trigger_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 84

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  trigger_id = hash.key?('triggerId') ? hash['triggerId'] : SKIP
  trigger_name = hash.key?('triggerName') ? hash['triggerName'] : SKIP
  ecpd_id = hash.key?('ecpdId') ? hash['ecpdId'] : SKIP
  trigger_category =
    hash.key?('triggerCategory') ? hash['triggerCategory'] : SKIP
  data_trigger = DataTrigger2.from_hash(hash['dataTrigger']) if hash['dataTrigger']
  notification = Notificationarray.from_hash(hash['notification']) if hash['notification']
  active = hash.key?('active') ? hash['active'] : SKIP

  # Create object from extracted values.
  DeviceLevelUpdateTriggerRequest.new(trigger_id: trigger_id,
                                      trigger_name: trigger_name,
                                      ecpd_id: ecpd_id,
                                      trigger_category: trigger_category,
                                      data_trigger: data_trigger,
                                      notification: notification,
                                      active: active)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['trigger_id'] = 'triggerId'
  @_hash['trigger_name'] = 'triggerName'
  @_hash['ecpd_id'] = 'ecpdId'
  @_hash['trigger_category'] = 'triggerCategory'
  @_hash['data_trigger'] = 'dataTrigger'
  @_hash['notification'] = 'notification'
  @_hash['active'] = 'active'
  @_hash
end

.nullablesObject

An array for nullable fields



67
68
69
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 67

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 54

def self.optionals
  %w[
    trigger_id
    trigger_name
    ecpd_id
    trigger_category
    data_trigger
    notification
    active
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



109
110
111
112
113
114
115
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 109

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



126
127
128
129
130
131
132
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 126

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} trigger_id: #{@trigger_id.inspect}, trigger_name: #{@trigger_name.inspect},"\
  " ecpd_id: #{@ecpd_id.inspect}, trigger_category: #{@trigger_category.inspect},"\
  " data_trigger: #{@data_trigger.inspect}, notification: #{@notification.inspect}, active:"\
  " #{@active.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



118
119
120
121
122
123
# File 'lib/verizon/models/device_level_update_trigger_request.rb', line 118

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} trigger_id: #{@trigger_id}, trigger_name: #{@trigger_name}, ecpd_id:"\
  " #{@ecpd_id}, trigger_category: #{@trigger_category}, data_trigger: #{@data_trigger},"\
  " notification: #{@notification}, active: #{@active}>"
end