Class: Verizon::DeviceList2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_list2.rb

Overview

DeviceList2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ids: SKIP) ⇒ DeviceList2

Returns a new instance of DeviceList2.



35
36
37
# File 'lib/verizon/models/device_list2.rb', line 35

def initialize(ids: SKIP)
  @ids = ids unless ids == SKIP
end

Instance Attribute Details

#idsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


14
15
16
# File 'lib/verizon/models/device_list2.rb', line 14

def ids
  @ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/verizon/models/device_list2.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ids = hash.key?('ids') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:DeviceList2Ids), hash['ids']
  ) : SKIP

  # Create object from extracted values.
  DeviceList2.new(ids: ids)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/device_list2.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ids'] = 'ids'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/device_list2.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/device_list2.rb', line 24

def self.optionals
  %w[
    ids
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (DeviceList2 | Hash)

    value against the validation is performed.



54
55
56
57
58
59
60
# File 'lib/verizon/models/device_list2.rb', line 54

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
# File 'lib/verizon/models/device_list2.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ids: #{@ids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/verizon/models/device_list2.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ids: #{@ids}>"
end