Class: Verizon::DeviceListResult
- Defined in:
- lib/verizon/models/device_list_result.rb
Overview
Device list information.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#device_count ⇒ Integer
Total device count.
-
#device_list ⇒ Array[V3Device]
List of devices with id in IMEI.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, device_count:, device_list:, additional_properties: nil) ⇒ DeviceListResult
constructor
A new instance of DeviceListResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, device_count:, device_list:, additional_properties: nil) ⇒ DeviceListResult
Returns a new instance of DeviceListResult.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/device_list_result.rb', line 43 def initialize(account_name:, device_count:, device_list:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @device_count = device_count @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account name.
14 15 16 |
# File 'lib/verizon/models/device_list_result.rb', line 14 def account_name @account_name end |
#device_count ⇒ Integer
Total device count.
18 19 20 |
# File 'lib/verizon/models/device_list_result.rb', line 18 def device_count @device_count end |
#device_list ⇒ Array[V3Device]
List of devices with id in IMEI.
22 23 24 |
# File 'lib/verizon/models/device_list_result.rb', line 22 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/verizon/models/device_list_result.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil device_count = hash.key?('deviceCount') ? hash['deviceCount'] : nil # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (V3Device.from_hash(structure) if structure) end end device_list = nil unless hash.key?('deviceList') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceListResult.new(account_name: account_name, device_count: device_count, device_list: device_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/device_list_result.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_count'] = 'deviceCount' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/device_list_result.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/verizon/models/device_list_result.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/verizon/models/device_list_result.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_count:"\ " #{@device_count.inspect}, device_list: #{@device_list.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/verizon/models/device_list_result.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_count: #{@device_count},"\ " device_list: #{@device_list}, additional_properties: #{@additional_properties}>" end |