Class: Verizon::DeviceLocationCallback

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_location_callback.rb

Overview

DeviceLocationCallback Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, url:, additional_properties: nil) ⇒ DeviceLocationCallback

Returns a new instance of DeviceLocationCallback.



38
39
40
41
42
43
44
45
# File 'lib/verizon/models/device_location_callback.rb', line 38

def initialize(name:, url:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @url = url
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameCallbackServiceName

The name of the callback service.

Returns:



14
15
16
# File 'lib/verizon/models/device_location_callback.rb', line 14

def name
  @name
end

#urlString

The location of your callback listener.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/device_location_callback.rb', line 18

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/verizon/models/device_location_callback.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  url = hash.key?('url') ? hash['url'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceLocationCallback.new(name: name,
                             url: url,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/device_location_callback.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/verizon/models/device_location_callback.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/verizon/models/device_location_callback.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/verizon/models/device_location_callback.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, url: #{@url.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/verizon/models/device_location_callback.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, url: #{@url}, additional_properties:"\
  " #{@additional_properties}>"
end