Class: Verizon::DeviceLocationSubscription

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_location_subscription.rb

Overview

DeviceLocationSubscription Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, loc_type: SKIP, max_allowance: SKIP, purchase_time: SKIP, additional_properties: nil) ⇒ DeviceLocationSubscription

Returns a new instance of DeviceLocationSubscription.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/verizon/models/device_location_subscription.rb', line 53

def initialize(account_name: SKIP, loc_type: SKIP, max_allowance: SKIP,
               purchase_time: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name =  unless  == SKIP
  @loc_type = loc_type unless loc_type == SKIP
  @max_allowance = max_allowance unless max_allowance == SKIP
  @purchase_time = purchase_time unless purchase_time == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

Account identifier in “##########-#####”.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/device_location_subscription.rb', line 14

def 
  @account_name
end

#loc_typeString

Location service license type.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/device_location_subscription.rb', line 18

def loc_type
  @loc_type
end

#max_allowanceString

The number of billable location requests allowed per billing cycle.

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/device_location_subscription.rb', line 22

def max_allowance
  @max_allowance
end

#purchase_timeString

Location service purchase time.

Returns:

  • (String)


26
27
28
# File 'lib/verizon/models/device_location_subscription.rb', line 26

def purchase_time
  @purchase_time
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/verizon/models/device_location_subscription.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  loc_type = hash.key?('locType') ? hash['locType'] : SKIP
  max_allowance = hash.key?('maxAllowance') ? hash['maxAllowance'] : SKIP
  purchase_time = hash.key?('purchaseTime') ? hash['purchaseTime'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceLocationSubscription.new(account_name: ,
                                 loc_type: loc_type,
                                 max_allowance: max_allowance,
                                 purchase_time: purchase_time,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/verizon/models/device_location_subscription.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['loc_type'] = 'locType'
  @_hash['max_allowance'] = 'maxAllowance'
  @_hash['purchase_time'] = 'purchaseTime'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/verizon/models/device_location_subscription.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/verizon/models/device_location_subscription.rb', line 39

def self.optionals
  %w[
    account_name
    loc_type
    max_allowance
    purchase_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/verizon/models/device_location_subscription.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, loc_type: #{@loc_type.inspect},"\
  " max_allowance: #{@max_allowance.inspect}, purchase_time: #{@purchase_time.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
96
# File 'lib/verizon/models/device_location_subscription.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, loc_type: #{@loc_type}, max_allowance:"\
  " #{@max_allowance}, purchase_time: #{@purchase_time}, additional_properties:"\
  " #{@additional_properties}>"
end