Class: Verizon::DeviceManagementResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_management_result.rb

Overview

Response to activate service for one or more devices so that they can send and receive data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id: SKIP, additional_properties: nil) ⇒ DeviceManagementResult

Returns a new instance of DeviceManagementResult.



37
38
39
40
41
42
43
# File 'lib/verizon/models/device_management_result.rb', line 37

def initialize(request_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique string that associates the request with the results that are sent via a callback service.

Returns:

  • (String)


16
17
18
# File 'lib/verizon/models/device_management_result.rb', line 16

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/verizon/models/device_management_result.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('requestId') ? hash['requestId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceManagementResult.new(request_id: request_id,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/verizon/models/device_management_result.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'requestId'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/verizon/models/device_management_result.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/verizon/models/device_management_result.rb', line 26

def self.optionals
  %w[
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/verizon/models/device_management_result.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
69
# File 'lib/verizon/models/device_management_result.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end