Class: Verizon::DeviceProfileManagementApi
- Defined in:
- lib/verizon/apis/device_profile_management_api.rb
Overview
DeviceProfileManagementApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#activate_device_through_profile(body) ⇒ ApiResponse
Uses the profile to bring the device under management.
-
#profile_to_activate_device(body) ⇒ ApiResponse
Uses the profile to activate the device.
-
#profile_to_deactivate_device(body) ⇒ ApiResponse
Uses the profile to deactivate the device.
-
#profile_to_set_fallback_attribute(body) ⇒ ApiResponse
Allows the profile to set the fallback attribute to the device.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#activate_device_through_profile(body) ⇒ ApiResponse
Uses the profile to bring the device under management. Profile Query
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/verizon/apis/device_profile_management_api.rb', line 13 def activate_device_through_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/activate_enable', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad request', RestErrorResponseException)) .execute end |
#profile_to_activate_device(body) ⇒ ApiResponse
Uses the profile to activate the device.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/apis/device_profile_management_api.rb', line 37 def profile_to_activate_device(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/activate', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad request', RestErrorResponseException)) .execute end |
#profile_to_deactivate_device(body) ⇒ ApiResponse
Uses the profile to deactivate the device. Profile Query
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/apis/device_profile_management_api.rb', line 62 def profile_to_deactivate_device(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/deactivate', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad request', RestErrorResponseException)) .execute end |
#profile_to_set_fallback_attribute(body) ⇒ ApiResponse
Allows the profile to set the fallback attribute to the device. Profile Query
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/verizon/apis/device_profile_management_api.rb', line 87 def profile_to_set_fallback_attribute(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/setfallbackattribute', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad request', RestErrorResponseException)) .execute end |