Class: Verizon::DeviceProvisioningHistoryListResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceProvisioningHistoryListResult
- Defined in:
- lib/verizon/models/device_provisioning_history_list_result.rb
Overview
Response to return the provisioning history of a specified device during a specified time period.
Instance Attribute Summary collapse
-
#has_more_data ⇒ TrueClass | FalseClass
False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.
-
#provisioning_history ⇒ Array[ProvisioningHistory]
The provisioning history of a specified device during a specified time period.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(has_more_data: SKIP, provisioning_history: SKIP, additional_properties: nil) ⇒ DeviceProvisioningHistoryListResult
constructor
A new instance of DeviceProvisioningHistoryListResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(has_more_data: SKIP, provisioning_history: SKIP, additional_properties: nil) ⇒ DeviceProvisioningHistoryListResult
Returns a new instance of DeviceProvisioningHistoryListResult.
44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 44 def initialize(has_more_data: SKIP, provisioning_history: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @has_more_data = has_more_data unless has_more_data == SKIP @provisioning_history = provisioning_history unless provisioning_history == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#has_more_data ⇒ TrueClass | FalseClass
False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.
16 17 18 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 16 def has_more_data @has_more_data end |
#provisioning_history ⇒ Array[ProvisioningHistory]
The provisioning history of a specified device during a specified time period.
21 22 23 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 21 def provisioning_history @provisioning_history end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP # Parameter is an array, so we need to iterate through it provisioning_history = nil unless hash['provisioningHistory'].nil? provisioning_history = [] hash['provisioningHistory'].each do |structure| provisioning_history << (ProvisioningHistory.from_hash(structure) if structure) end end provisioning_history = SKIP unless hash.key?('provisioningHistory') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceProvisioningHistoryListResult.new(has_more_data: has_more_data, provisioning_history: provisioning_history, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['has_more_data'] = 'hasMoreData' @_hash['provisioning_history'] = 'provisioningHistory' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 32 def self.optionals %w[ has_more_data provisioning_history ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data.inspect}, provisioning_history:"\ " #{@provisioning_history.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/verizon/models/device_provisioning_history_list_result.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data}, provisioning_history:"\ " #{@provisioning_history}, additional_properties: #{@additional_properties}>" end |