Class: Verizon::DeviceResetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_reset_request.rb

Overview

Request body to Performs a device reboot.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, action: SKIP, devices: SKIP, additional_properties: nil) ⇒ DeviceResetRequest

Returns a new instance of DeviceResetRequest.



48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/device_reset_request.rb', line 48

def initialize(account_name: SKIP, action: SKIP, devices: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name =  unless  == SKIP
  @action = action unless action == SKIP
  @devices = devices unless devices == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The name of the account. An account name is usually numeric, and must include any leading zeros.

Returns:

  • (String)


15
16
17
# File 'lib/verizon/models/device_reset_request.rb', line 15

def 
  @account_name
end

#actionString

The action you want to take on the device.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/device_reset_request.rb', line 19

def action
  @action
end

#devicesArray[Device]

The devices for which you want to perform a factory reset or reboot.

Returns:



23
24
25
# File 'lib/verizon/models/device_reset_request.rb', line 23

def devices
  @devices
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/verizon/models/device_reset_request.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  action = hash.key?('action') ? hash['action'] : SKIP
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (Device.from_hash(structure) if structure)
    end
  end

  devices = SKIP unless hash.key?('devices')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceResetRequest.new(account_name: ,
                         action: action,
                         devices: devices,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/verizon/models/device_reset_request.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['action'] = 'action'
  @_hash['devices'] = 'devices'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/device_reset_request.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/verizon/models/device_reset_request.rb', line 35

def self.optionals
  %w[
    account_name
    action
    devices
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/verizon/models/device_reset_request.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, action: #{@action.inspect},"\
  " devices: #{@devices.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/verizon/models/device_reset_request.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, action: #{@action}, devices: #{@devices},"\
  " additional_properties: #{@additional_properties}>"
end