Class: Verizon::DeviceServiceInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_service_information.rb

Overview

Device service information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(imei:, bullseye_enable:, response_type: SKIP, additional_properties: nil) ⇒ DeviceServiceInformation

Returns a new instance of DeviceServiceInformation.



46
47
48
49
50
51
52
53
54
55
# File 'lib/verizon/models/device_service_information.rb', line 46

def initialize(imei:, bullseye_enable:, response_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @response_type = response_type unless response_type == SKIP
  @imei = imei
  @bullseye_enable = bullseye_enable
  @additional_properties = additional_properties
end

Instance Attribute Details

#bullseye_enableHplBullseyeEnable

A flag that shows if Hyper Precise is enabled (true) or disabled (false).

Returns:



23
24
25
# File 'lib/verizon/models/device_service_information.rb', line 23

def bullseye_enable
  @bullseye_enable
end

#imeiHplImei

The International Mobile Equipment Identifier of the device.

Returns:



19
20
21
# File 'lib/verizon/models/device_service_information.rb', line 19

def imei
  @imei
end

#response_typeApiResponseCode

ResponseCode and/or a message indicating success or failure of the request.

Returns:



15
16
17
# File 'lib/verizon/models/device_service_information.rb', line 15

def response_type
  @response_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/models/device_service_information.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  imei = HplImei.from_hash(hash['imei']) if hash['imei']
  bullseye_enable = HplBullseyeEnable.from_hash(hash['BullseyeEnable']) if
    hash['BullseyeEnable']
  response_type = ApiResponseCode.from_hash(hash['responseType']) if hash['responseType']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceServiceInformation.new(imei: imei,
                               bullseye_enable: bullseye_enable,
                               response_type: response_type,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/verizon/models/device_service_information.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['response_type'] = 'responseType'
  @_hash['imei'] = 'imei'
  @_hash['bullseye_enable'] = 'BullseyeEnable'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/verizon/models/device_service_information.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
# File 'lib/verizon/models/device_service_information.rb', line 35

def self.optionals
  %w[
    response_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
94
# File 'lib/verizon/models/device_service_information.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} response_type: #{@response_type.inspect}, imei: #{@imei.inspect},"\
  " bullseye_enable: #{@bullseye_enable.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/verizon/models/device_service_information.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} response_type: #{@response_type}, imei: #{@imei}, bullseye_enable:"\
  " #{@bullseye_enable}, additional_properties: #{@additional_properties}>"
end