Class: Verizon::DeviceServiceManagementApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/device_service_management_api.rb

Overview

DeviceServiceManagementApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#get_device_hyper_precise_status(imei, account_number) ⇒ ApiResponse

Gets the list of a status for hyper-precise location devices. Equipment Identifier of the device. name of the account and must include leading zeroes.

Parameters:

  • imei (HplImei)

    Required parameter: The International Mobile

  • account_number (HplAccountnumber)

    Required parameter: The numeric

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/verizon/apis/device_service_management_api.rb', line 15

def get_device_hyper_precise_status(imei,
                                    )
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/devices/services',
                                 Server::HYPER_PRECISE_LOCATION)
               .query_param(new_parameter(imei, key: 'imei')
                             .is_required(true))
               .query_param(new_parameter(, key: 'accountNumber')
                             .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BullseyeServiceResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request.',
                             HyperPreciseLocationResultException)
                .local_error('401',
                             'Unauthorized request. Access token is missing or invalid.',
                             HyperPreciseLocationResultException)
                .local_error('403',
                             'Forbidden request.',
                             HyperPreciseLocationResultException)
                .local_error('404',
                             'Bad request. Not found.',
                             HyperPreciseLocationResultException)
                .local_error('409',
                             'Bad request. Conflict state.',
                             HyperPreciseLocationResultException)
                .local_error('500',
                             'Internal Server Error.',
                             HyperPreciseLocationResultException))
    .execute
end

#update_device_hyper_precise_status(body) ⇒ ApiResponse

Enable/disable hyper-precise service for a device. and hyper-precise required statuses.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/apis/device_service_management_api.rb', line 56

def update_device_hyper_precise_status(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/devices/services',
                                 Server::HYPER_PRECISE_LOCATION)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BullseyeServiceResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request.',
                             HyperPreciseLocationResultException)
                .local_error('401',
                             'Unauthorized request. Access token is missing or invalid.',
                             HyperPreciseLocationResultException)
                .local_error('403',
                             'Forbidden request.',
                             HyperPreciseLocationResultException)
                .local_error('404',
                             'Bad request. Not found.',
                             HyperPreciseLocationResultException)
                .local_error('409',
                             'Bad request. Conflict state.',
                             HyperPreciseLocationResultException)
                .local_error('500',
                             'Internal Server Error.',
                             HyperPreciseLocationResultException))
    .execute
end