Class: Verizon::DeviceServiceRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_service_request.rb

Overview

Device information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(imei:, bullseye_enable:, additional_properties: nil) ⇒ DeviceServiceRequest

Returns a new instance of DeviceServiceRequest.



38
39
40
41
42
43
44
45
# File 'lib/verizon/models/device_service_request.rb', line 38

def initialize(imei:, bullseye_enable:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @imei = imei
  @bullseye_enable = bullseye_enable
  @additional_properties = additional_properties
end

Instance Attribute Details

#bullseye_enableHplBullseyeEnable

A flag that shows if Hyper Precise is enabled (true) or disabled (false).

Returns:



18
19
20
# File 'lib/verizon/models/device_service_request.rb', line 18

def bullseye_enable
  @bullseye_enable
end

#imeiHplImei

The International Mobile Equipment Identifier of the device.

Returns:



14
15
16
# File 'lib/verizon/models/device_service_request.rb', line 14

def imei
  @imei
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/verizon/models/device_service_request.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  imei = HplImei.from_hash(hash['imei']) if hash['imei']
  bullseye_enable = HplBullseyeEnable.from_hash(hash['BullseyeEnable']) if
    hash['BullseyeEnable']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceServiceRequest.new(imei: imei,
                           bullseye_enable: bullseye_enable,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/device_service_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['imei'] = 'imei'
  @_hash['bullseye_enable'] = 'BullseyeEnable'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/verizon/models/device_service_request.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/verizon/models/device_service_request.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/verizon/models/device_service_request.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} imei: #{@imei.inspect}, bullseye_enable: #{@bullseye_enable.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/verizon/models/device_service_request.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} imei: #{@imei}, bullseye_enable: #{@bullseye_enable},"\
  " additional_properties: #{@additional_properties}>"
end