Class: Verizon::DeviceSoftwareUpgrade
- Defined in:
- lib/verizon/models/device_software_upgrade.rb
Overview
Array of software upgrade objects with the specified status.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier.
-
#device_id ⇒ String
Device identifier.
-
#id ⇒ String
Upgrade identifier.
-
#reason ⇒ String
Software upgrade result reason.
-
#software_name ⇒ String
Software name.
-
#start_date ⇒ Date
Software upgrade start date.
-
#status ⇒ String
Software upgrade status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id:, id:, account_name:, start_date:, status:, reason:, software_name: SKIP, additional_properties: nil) ⇒ DeviceSoftwareUpgrade
constructor
A new instance of DeviceSoftwareUpgrade.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id:, id:, account_name:, start_date:, status:, reason:, software_name: SKIP, additional_properties: nil) ⇒ DeviceSoftwareUpgrade
Returns a new instance of DeviceSoftwareUpgrade.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 65 def initialize(device_id:, id:, account_name:, start_date:, status:, reason:, software_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id @id = id @account_name = account_name @software_name = software_name unless software_name == SKIP @start_date = start_date @status = status @reason = reason @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account identifier.
22 23 24 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 22 def account_name @account_name end |
#device_id ⇒ String
Device identifier.
14 15 16 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 14 def device_id @device_id end |
#id ⇒ String
Upgrade identifier.
18 19 20 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 18 def id @id end |
#reason ⇒ String
Software upgrade result reason.
38 39 40 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 38 def reason @reason end |
#software_name ⇒ String
Software name.
26 27 28 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 26 def software_name @software_name end |
#start_date ⇒ Date
Software upgrade start date.
30 31 32 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 30 def start_date @start_date end |
#status ⇒ String
Software upgrade status.
34 35 36 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 34 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 81 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = hash.key?('deviceId') ? hash['deviceId'] : nil id = hash.key?('id') ? hash['id'] : nil account_name = hash.key?('accountName') ? hash['accountName'] : nil start_date = hash.key?('startDate') ? hash['startDate'] : nil status = hash.key?('status') ? hash['status'] : nil reason = hash.key?('reason') ? hash['reason'] : nil software_name = hash.key?('softwareName') ? hash['softwareName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceSoftwareUpgrade.new(device_id: device_id, id: id, account_name: account_name, start_date: start_date, status: status, reason: reason, software_name: software_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['id'] = 'id' @_hash['account_name'] = 'accountName' @_hash['software_name'] = 'softwareName' @_hash['start_date'] = 'startDate' @_hash['status'] = 'status' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 54 def self.optionals %w[ software_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
120 121 122 123 124 125 126 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 120 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, id: #{@id.inspect}, account_name:"\ " #{@account_name.inspect}, software_name: #{@software_name.inspect}, start_date:"\ " #{@start_date.inspect}, status: #{@status.inspect}, reason: #{@reason.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 117 |
# File 'lib/verizon/models/device_software_upgrade.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, id: #{@id}, account_name: #{@account_name},"\ " software_name: #{@software_name}, start_date: #{@start_date}, status: #{@status}, reason:"\ " #{@reason}, additional_properties: #{@additional_properties}>" end |