Class: Verizon::DeviceUploadRequest
- Defined in:
- lib/verizon/models/device_upload_request.rb
Overview
DeviceUploadRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
TODO: Write general description for this method.
-
#device_sku ⇒ String
TODO: Write general description for this method.
-
#devices ⇒ Array[DeviceList]
TODO: Write general description for this method.
-
#email_address ⇒ String
TODO: Write general description for this method.
-
#upload_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, devices:, email_address:, device_sku:, upload_type:, additional_properties: nil) ⇒ DeviceUploadRequest
constructor
A new instance of DeviceUploadRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, devices:, email_address:, device_sku:, upload_type:, additional_properties: nil) ⇒ DeviceUploadRequest
Returns a new instance of DeviceUploadRequest.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/verizon/models/device_upload_request.rb', line 53 def initialize(account_name:, devices:, email_address:, device_sku:, upload_type:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @devices = devices @email_address = email_address @device_sku = device_sku @upload_type = upload_type @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/device_upload_request.rb', line 14 def account_name @account_name end |
#device_sku ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/verizon/models/device_upload_request.rb', line 26 def device_sku @device_sku end |
#devices ⇒ Array[DeviceList]
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/device_upload_request.rb', line 18 def devices @devices end |
#email_address ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/device_upload_request.rb', line 22 def email_address @email_address end |
#upload_type ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/verizon/models/device_upload_request.rb', line 30 def upload_type @upload_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/verizon/models/device_upload_request.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (DeviceList.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') email_address = hash.key?('emailAddress') ? hash['emailAddress'] : nil device_sku = hash.key?('deviceSku') ? hash['deviceSku'] : nil upload_type = hash.key?('uploadType') ? hash['uploadType'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceUploadRequest.new(account_name: account_name, devices: devices, email_address: email_address, device_sku: device_sku, upload_type: upload_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/verizon/models/device_upload_request.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['devices'] = 'devices' @_hash['email_address'] = 'emailAddress' @_hash['device_sku'] = 'deviceSku' @_hash['upload_type'] = 'uploadType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/verizon/models/device_upload_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/verizon/models/device_upload_request.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/verizon/models/device_upload_request.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, devices: #{@devices.inspect},"\ " email_address: #{@email_address.inspect}, device_sku: #{@device_sku.inspect}, upload_type:"\ " #{@upload_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/verizon/models/device_upload_request.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, devices: #{@devices}, email_address:"\ " #{@email_address}, device_sku: #{@device_sku}, upload_type: #{@upload_type},"\ " additional_properties: #{@additional_properties}>" end |