Class: Verizon::DeviceUsageListResult
- Defined in:
- lib/verizon/models/device_usage_list_result.rb
Overview
Response to return the daily network data usage of a single device during a specified time period.
Instance Attribute Summary collapse
-
#has_more_data ⇒ TrueClass | FalseClass
False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.
-
#usage_history ⇒ Array[Usage]
Placeholder.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(has_more_data: SKIP, usage_history: SKIP, additional_properties: nil) ⇒ DeviceUsageListResult
constructor
A new instance of DeviceUsageListResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(has_more_data: SKIP, usage_history: SKIP, additional_properties: nil) ⇒ DeviceUsageListResult
Returns a new instance of DeviceUsageListResult.
43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 43 def initialize(has_more_data: SKIP, usage_history: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @has_more_data = has_more_data unless has_more_data == SKIP @usage_history = usage_history unless usage_history == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#has_more_data ⇒ TrueClass | FalseClass
False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.
16 17 18 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 16 def has_more_data @has_more_data end |
#usage_history ⇒ Array[Usage]
Placeholder.
20 21 22 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 20 def usage_history @usage_history end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP # Parameter is an array, so we need to iterate through it usage_history = nil unless hash['usageHistory'].nil? usage_history = [] hash['usageHistory'].each do |structure| usage_history << (Usage.from_hash(structure) if structure) end end usage_history = SKIP unless hash.key?('usageHistory') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceUsageListResult.new(has_more_data: has_more_data, usage_history: usage_history, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['has_more_data'] = 'hasMoreData' @_hash['usage_history'] = 'usageHistory' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 31 def self.optionals %w[ has_more_data usage_history ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data.inspect}, usage_history:"\ " #{@usage_history.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/verizon/models/device_usage_list_result.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data}, usage_history: #{@usage_history},"\ " additional_properties: #{@additional_properties}>" end |