Class: Verizon::DiagnosticObservationSetting

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/diagnostic_observation_setting.rb

Overview

Diagnostic observation settings and attributes for a device.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, device: SKIP, attributes: SKIP, additional_properties: nil) ⇒ DiagnosticObservationSetting

Returns a new instance of DiagnosticObservationSetting.



49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 49

def initialize(account_name: SKIP, device: SKIP, attributes: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name =  unless  == SKIP
  @device = device unless device == SKIP
  @attributes = attributes unless attributes == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The name of the billing account for which callback messages will be sent. Format: “##########-#####”.

Returns:

  • (String)


15
16
17
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 15

def 
  @account_name
end

#attributesArray[AttributeSetting]

Streaming RF parameters for which you want to retrieve diagnostic settings.

Returns:



24
25
26
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 24

def attributes
  @attributes
end

#deviceDevice

Identifies a particular IoT device.

Returns:



19
20
21
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 19

def device
  @device
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  device = Device.from_hash(hash['device']) if hash['device']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (AttributeSetting.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DiagnosticObservationSetting.new(account_name: ,
                                   device: device,
                                   attributes: attributes,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['device'] = 'device'
  @_hash['attributes'] = 'attributes'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 36

def self.optionals
  %w[
    account_name
    device
    attributes
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, device: #{@device.inspect},"\
  " attributes: #{@attributes.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/verizon/models/diagnostic_observation_setting.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, device: #{@device}, attributes:"\
  " #{@attributes}, additional_properties: #{@additional_properties}>"
end