Class: Verizon::DiagnosticsCallbacksApi
- Defined in:
- lib/verizon/apis/diagnostics_callbacks_api.rb
Overview
DiagnosticsCallbacksApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_diagnostics_subscription_callback_info(account_name) ⇒ ApiResponse
This endpoint allows user to get the registered callback information of an existing diagnostics subscription.
-
#register_diagnostics_callback_url(body) ⇒ ApiResponse
This endpoint allows user update the callback HTTPS address of an existing diagnostics subscription.
-
#unregister_diagnostics_callback(account_name, service_name) ⇒ ApiResponse
This endpoint allows user to delete a registered callback URL and credential.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#get_diagnostics_subscription_callback_info(account_name) ⇒ ApiResponse
This endpoint allows user to get the registered callback information of an existing diagnostics subscription.
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/verizon/apis/diagnostics_callbacks_api.rb', line 13 def get_diagnostics_subscription_callback_info(account_name) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/callbacks', Server::DEVICE_DIAGNOSTICS) .query_param(new_parameter(account_name, key: 'accountName') .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceDiagnosticsCallback.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Unexpected error.', DeviceDiagnosticsResultException)) .execute end |
#register_diagnostics_callback_url(body) ⇒ ApiResponse
This endpoint allows user update the callback HTTPS address of an existing diagnostics subscription. registration request.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/apis/diagnostics_callbacks_api.rb', line 38 def register_diagnostics_callback_url(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/callbacks', Server::DEVICE_DIAGNOSTICS) .header_param(new_parameter('*/*', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceDiagnosticsCallback.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', DeviceDiagnosticsResultException)) .execute end |
#unregister_diagnostics_callback(account_name, service_name) ⇒ ApiResponse
This endpoint allows user to delete a registered callback URL and credential. notification.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/verizon/apis/diagnostics_callbacks_api.rb', line 65 def unregister_diagnostics_callback(account_name, service_name) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/callbacks', Server::DEVICE_DIAGNOSTICS) .query_param(new_parameter(account_name, key: 'accountName') .is_required(true)) .query_param(new_parameter(service_name, key: 'serviceName') .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceDiagnosticsCallback.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', DeviceDiagnosticsResultException)) .execute end |