Class: Verizon::DiagnosticsFactoryResetApi
- Defined in:
- lib/verizon/apis/diagnostics_factory_reset_api.rb
Overview
DiagnosticsFactoryResetApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#decives_restart(body) ⇒ ApiResponse
Performs a device reboot or a factory reset on the modem portion of the device.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#decives_restart(body) ⇒ ApiResponse
Performs a device reboot or a factory reset on the modem portion of the device. a device reboot.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/verizon/apis/diagnostics_factory_reset_api.rb', line 14 def decives_restart(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/devices/actions/restart', Server::DEVICE_DIAGNOSTICS) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DiagnosticsObservationResult.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response.', DeviceDiagnosticsResultException)) .execute end |