Class: Verizon::DiagnosticsObservationsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/diagnostics_observations_api.rb

Overview

DiagnosticsObservationsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#start_diagnostics_observation(body) ⇒ ApiResponse

This endpoint allows the user to start or change observe diagnostics. observation information.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/verizon/apis/diagnostics_observations_api.rb', line 13

def start_diagnostics_observation(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/devices/attributes/actions/observe',
                                 Server::DEVICE_DIAGNOSTICS)
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DiagnosticsObservationResult.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response.',
                             DeviceDiagnosticsResultException))
    .execute
end

#stop_diagnostics_observation(transaction_id, account_name) ⇒ ApiResponse

This endpoint allows the user to stop or reset observe diagnostics. with the transaction. name.

Parameters:

  • transaction_id (String)

    Required parameter: The ID value associated

  • account_name (String)

    Required parameter: The numeric account

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/verizon/apis/diagnostics_observations_api.rb', line 40

def stop_diagnostics_observation(transaction_id,
                                 )
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/devices/attributes/actions/observe',
                                 Server::DEVICE_DIAGNOSTICS)
               .query_param(new_parameter(transaction_id, key: 'transactionId')
                             .is_required(true))
               .query_param(new_parameter(, key: 'accountName')
                             .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DiagnosticsObservationResult.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response.',
                             DeviceDiagnosticsResultException))
    .execute
end