Class: Verizon::DtoBulkUpdate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_bulk_update.rb

Overview

DtoBulkUpdate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountname: SKIP, resourceidentifiers: SKIP, smartalert: SKIP, additional_properties: nil) ⇒ DtoBulkUpdate

Returns a new instance of DtoBulkUpdate.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/dto_bulk_update.rb', line 47

def initialize(accountname: SKIP, resourceidentifiers: SKIP,
               smartalert: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accountname = accountname unless accountname == SKIP
  @resourceidentifiers = resourceidentifiers unless resourceidentifiers == SKIP
  @smartalert = smartalert unless smartalert == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountnameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_bulk_update.rb', line 14

def accountname
  @accountname
end

#resourceidentifiersArray[TheIDresourceandDeviceId]

The numeric account name, which must include leading zeros

Returns:



18
19
20
# File 'lib/verizon/models/dto_bulk_update.rb', line 18

def resourceidentifiers
  @resourceidentifiers
end

#smartalertBulkUpdateSmartalert

The numeric account name, which must include leading zeros



22
23
24
# File 'lib/verizon/models/dto_bulk_update.rb', line 22

def smartalert
  @smartalert
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/verizon/models/dto_bulk_update.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountname = hash.key?('accountname') ? hash['accountname'] : SKIP
  # Parameter is an array, so we need to iterate through it
  resourceidentifiers = nil
  unless hash['resourceidentifiers'].nil?
    resourceidentifiers = []
    hash['resourceidentifiers'].each do |structure|
      resourceidentifiers << (TheIDresourceandDeviceId.from_hash(structure) if structure)
    end
  end

  resourceidentifiers = SKIP unless hash.key?('resourceidentifiers')
  smartalert = BulkUpdateSmartalert.from_hash(hash['smartalert']) if hash['smartalert']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DtoBulkUpdate.new(accountname: accountname,
                    resourceidentifiers: resourceidentifiers,
                    smartalert: smartalert,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/dto_bulk_update.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountname'] = 'accountname'
  @_hash['resourceidentifiers'] = 'resourceidentifiers'
  @_hash['smartalert'] = 'smartalert'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/dto_bulk_update.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/dto_bulk_update.rb', line 34

def self.optionals
  %w[
    accountname
    resourceidentifiers
    smartalert
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/verizon/models/dto_bulk_update.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname.inspect}, resourceidentifiers:"\
  " #{@resourceidentifiers.inspect}, smartalert: #{@smartalert.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/verizon/models/dto_bulk_update.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname}, resourceidentifiers: #{@resourceidentifiers},"\
  " smartalert: #{@smartalert}, additional_properties: #{@additional_properties}>"
end