Class: Verizon::DtoConfigurationProfile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_configuration_profile.rb

Overview

DtoConfigurationProfile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountname: SKIP, profiles: SKIP, additional_properties: nil) ⇒ DtoConfigurationProfile

Returns a new instance of DtoConfigurationProfile.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/dto_configuration_profile.rb', line 41

def initialize(accountname: SKIP, profiles: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accountname = accountname unless accountname == SKIP
  @profiles = profiles unless profiles == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountnameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_configuration_profile.rb', line 14

def accountname
  @accountname
end

#profilesArray[DtoProfile]

The numeric account name, which must include leading zeros

Returns:



18
19
20
# File 'lib/verizon/models/dto_configuration_profile.rb', line 18

def profiles
  @profiles
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/models/dto_configuration_profile.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountname = hash.key?('accountname') ? hash['accountname'] : SKIP
  # Parameter is an array, so we need to iterate through it
  profiles = nil
  unless hash['profiles'].nil?
    profiles = []
    hash['profiles'].each do |structure|
      profiles << (DtoProfile.from_hash(structure) if structure)
    end
  end

  profiles = SKIP unless hash.key?('profiles')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DtoConfigurationProfile.new(accountname: accountname,
                              profiles: profiles,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/dto_configuration_profile.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountname'] = 'accountname'
  @_hash['profiles'] = 'profiles'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/dto_configuration_profile.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/dto_configuration_profile.rb', line 29

def self.optionals
  %w[
    accountname
    profiles
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/verizon/models/dto_configuration_profile.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname.inspect}, profiles: #{@profiles.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/verizon/models/dto_configuration_profile.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname}, profiles: #{@profiles},"\
  " additional_properties: #{@additional_properties}>"
end