Class: Verizon::DtoConfigurationProfilePath

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_configuration_profile_path.rb

Overview

DtoConfigurationProfilePath Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, resourceidentifier: SKIP, profile: SKIP, additional_properties: nil) ⇒ DtoConfigurationProfilePath

Returns a new instance of DtoConfigurationProfilePath.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 47

def initialize(account_name: SKIP, resourceidentifier: SKIP, profile: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name =  unless  == SKIP
  @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP
  @profile = profile unless profile == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 14

def 
  @account_name
end

#profileDtoProfile

The numeric account name, which must include leading zeros

Returns:



22
23
24
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 22

def profile
  @profile
end

#resourceidentifierDtoResourceidentifier

The numeric account name, which must include leading zeros



18
19
20
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 18

def resourceidentifier
  @resourceidentifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  resourceidentifier = DtoResourceidentifier.from_hash(hash['resourceidentifier']) if
    hash['resourceidentifier']
  profile = DtoProfile.from_hash(hash['profile']) if hash['profile']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DtoConfigurationProfilePath.new(account_name: ,
                                  resourceidentifier: resourceidentifier,
                                  profile: profile,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['resourceidentifier'] = 'resourceidentifier'
  @_hash['profile'] = 'profile'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 34

def self.optionals
  %w[
    account_name
    resourceidentifier
    profile
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, resourceidentifier:"\
  " #{@resourceidentifier.inspect}, profile: #{@profile.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, resourceidentifier: #{@resourceidentifier},"\
  " profile: #{@profile}, additional_properties: #{@additional_properties}>"
end