Class: Verizon::DtoCreateNotificationGroupRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_create_notification_group_request.rb

Overview

DtoCreateNotificationGroupRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(group:, accountname: SKIP, userids: SKIP) ⇒ DtoCreateNotificationGroupRequest

Returns a new instance of DtoCreateNotificationGroupRequest.



46
47
48
49
50
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 46

def initialize(group:, accountname: SKIP, userids: SKIP)
  @accountname = accountname unless accountname == SKIP
  @group = group
  @userids = userids unless userids == SKIP
end

Instance Attribute Details

#accountnameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 14

def accountname
  @accountname
end

#groupDtoNotificationGroupRequestEntity

The numeric account name, which must include leading zeros



18
19
20
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 18

def group
  @group
end

#useridsArray[String]

The numeric account name, which must include leading zeros

Returns:

  • (Array[String])


22
23
24
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 22

def userids
  @userids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  group = DtoNotificationGroupRequestEntity.from_hash(hash['group']) if hash['group']
  accountname = hash.key?('accountname') ? hash['accountname'] : SKIP
  userids = hash.key?('userids') ? hash['userids'] : SKIP

  # Create object from extracted values.
  DtoCreateNotificationGroupRequest.new(group: group,
                                        accountname: accountname,
                                        userids: userids)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountname'] = 'accountname'
  @_hash['group'] = 'group'
  @_hash['userids'] = 'userids'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 34

def self.optionals
  %w[
    accountname
    userids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



74
75
76
77
78
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 74

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname.inspect}, group: #{@group.inspect}, userids:"\
  " #{@userids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



68
69
70
71
# File 'lib/verizon/models/dto_create_notification_group_request.rb', line 68

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname}, group: #{@group}, userids: #{@userids}>"
end