Class: Verizon::DtoDeleteNotificationGroupRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoDeleteNotificationGroupRequest
- Defined in:
- lib/verizon/models/dto_delete_notification_group_request.rb
Overview
DtoDeleteNotificationGroupRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#force ⇒ TrueClass | FalseClass
The numeric account name, which must include leading zeros.
-
#id ⇒ String
UUID of the user record, assigned at creation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, force: SKIP, id: SKIP) ⇒ DtoDeleteNotificationGroupRequest
constructor
A new instance of DtoDeleteNotificationGroupRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, force: SKIP, id: SKIP) ⇒ DtoDeleteNotificationGroupRequest
Returns a new instance of DtoDeleteNotificationGroupRequest.
47 48 49 50 51 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 47 def initialize(accountname: SKIP, force: SKIP, id: SKIP) @accountname = accountname unless accountname == SKIP @force = force unless force == SKIP @id = id unless id == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 14 def accountname @accountname end |
#force ⇒ TrueClass | FalseClass
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 18 def force @force end |
#id ⇒ String
UUID of the user record, assigned at creation
22 23 24 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 22 def id @id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP force = hash.key?('force') ? hash['force'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP # Create object from extracted values. DtoDeleteNotificationGroupRequest.new(accountname: accountname, force: force, id: id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['force'] = 'force' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 34 def self.optionals %w[ accountname force id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, force: #{@force.inspect}, id:"\ " #{@id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/dto_delete_notification_group_request.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, force: #{@force}, id: #{@id}>" end |