Class: Verizon::DtoDeleteUserRequest
- Defined in:
- lib/verizon/models/dto_delete_user_request.rb
Overview
DtoDeleteUserRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#id ⇒ String
UUID of the user record, assigned at creation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, id: SKIP) ⇒ DtoDeleteUserRequest
constructor
A new instance of DtoDeleteUserRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, id: SKIP) ⇒ DtoDeleteUserRequest
Returns a new instance of DtoDeleteUserRequest.
41 42 43 44 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 41 def initialize(accountname: SKIP, id: SKIP) @accountname = accountname unless accountname == SKIP @id = id unless id == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 14 def accountname @accountname end |
#id ⇒ String
UUID of the user record, assigned at creation
18 19 20 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 18 def id @id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP # Create object from extracted values. DtoDeleteUserRequest.new(accountname: accountname, id: id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 29 def self.optionals %w[ accountname id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, id: #{@id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/dto_delete_user_request.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, id: #{@id}>" end |