Class: Verizon::DtoDeviceActionSetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_device_action_set_request.rb

Overview

DtoDeviceActionSetRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountname: SKIP, configuration: SKIP, resourceidentifier: SKIP, additional_properties: nil) ⇒ DtoDeviceActionSetRequest

Returns a new instance of DtoDeviceActionSetRequest.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 47

def initialize(accountname: SKIP, configuration: SKIP,
               resourceidentifier: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accountname = accountname unless accountname == SKIP
  @configuration = configuration unless configuration == SKIP
  @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountnameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 14

def accountname
  @accountname
end

#configurationDtoDeviceActionSetConfiguration

The numeric account name, which must include leading zeros



18
19
20
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 18

def configuration
  @configuration
end

#resourceidentifierDtoDeviceResourceIdentifier

Device identifiers, one or more are required



22
23
24
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 22

def resourceidentifier
  @resourceidentifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountname = hash.key?('accountname') ? hash['accountname'] : SKIP
  configuration = DtoDeviceActionSetConfiguration.from_hash(hash['configuration']) if
    hash['configuration']
  resourceidentifier = DtoDeviceResourceIdentifier.from_hash(hash['resourceidentifier']) if
    hash['resourceidentifier']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DtoDeviceActionSetRequest.new(accountname: accountname,
                                configuration: configuration,
                                resourceidentifier: resourceidentifier,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountname'] = 'accountname'
  @_hash['configuration'] = 'configuration'
  @_hash['resourceidentifier'] = 'resourceidentifier'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 34

def self.optionals
  %w[
    accountname
    configuration
    resourceidentifier
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



85
86
87
88
89
90
91
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 85

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname.inspect}, configuration:"\
  " #{@configuration.inspect}, resourceidentifier: #{@resourceidentifier.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
99
# File 'lib/verizon/models/dto_device_action_set_request.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname}, configuration: #{@configuration},"\
  " resourceidentifier: #{@resourceidentifier}, additional_properties:"\
  " #{@additional_properties}>"
end