Class: Verizon::DtoDeviceConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_device_config.rb

Overview

DtoDeviceConfig Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ble: SKIP) ⇒ DtoDeviceConfig

Returns a new instance of DtoDeviceConfig.



35
36
37
# File 'lib/verizon/models/dto_device_config.rb', line 35

def initialize(ble: SKIP)
  @ble = ble unless ble == SKIP
end

Instance Attribute Details

#bleSensorInsightsBle

Property objects for Bluetooth Low-Energy (BLE) devices

Returns:



14
15
16
# File 'lib/verizon/models/dto_device_config.rb', line 14

def ble
  @ble
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
# File 'lib/verizon/models/dto_device_config.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ble = SensorInsightsBle.from_hash(hash['ble']) if hash['ble']

  # Create object from extracted values.
  DtoDeviceConfig.new(ble: ble)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/dto_device_config.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ble'] = 'ble'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/dto_device_config.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/dto_device_config.rb', line 24

def self.optionals
  %w[
    ble
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (DtoDeviceConfig | Hash)

    value against the validation is performed.



52
53
54
55
56
57
58
# File 'lib/verizon/models/dto_device_config.rb', line 52

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/verizon/models/dto_device_config.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ble: #{@ble.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/verizon/models/dto_device_config.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ble: #{@ble}>"
end