Class: Verizon::DtoGetNetworkHealthScoreResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_get_network_health_score_response.rb

Overview

The values measured are for the network

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(networksummary: SKIP, overallsummary: SKIP) ⇒ DtoGetNetworkHealthScoreResponse

Returns a new instance of DtoGetNetworkHealthScoreResponse.



41
42
43
44
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 41

def initialize(networksummary: SKIP, overallsummary: SKIP)
  @networksummary = networksummary unless networksummary == SKIP
  @overallsummary = overallsummary unless overallsummary == SKIP
end

Instance Attribute Details

#networksummaryArray[DtoHealthScoreMetric]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 14

def networksummary
  @networksummary
end

#overallsummaryArray[DtoHealthScoreMetric]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 18

def overallsummary
  @overallsummary
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  networksummary = nil
  unless hash['networksummary'].nil?
    networksummary = []
    hash['networksummary'].each do |structure|
      networksummary << (DtoHealthScoreMetric.from_hash(structure) if structure)
    end
  end

  networksummary = SKIP unless hash.key?('networksummary')
  # Parameter is an array, so we need to iterate through it
  overallsummary = nil
  unless hash['overallsummary'].nil?
    overallsummary = []
    hash['overallsummary'].each do |structure|
      overallsummary << (DtoHealthScoreMetric.from_hash(structure) if structure)
    end
  end

  overallsummary = SKIP unless hash.key?('overallsummary')

  # Create object from extracted values.
  DtoGetNetworkHealthScoreResponse.new(networksummary: networksummary,
                                       overallsummary: overallsummary)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['networksummary'] = 'networksummary'
  @_hash['overallsummary'] = 'overallsummary'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 29

def self.optionals
  %w[
    networksummary
    overallsummary
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} networksummary: #{@networksummary.inspect}, overallsummary:"\
  " #{@overallsummary.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
# File 'lib/verizon/models/dto_get_network_health_score_response.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} networksummary: #{@networksummary}, overallsummary: #{@overallsummary}>"
end