Class: Verizon::DtoHealthScoreMetric

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_health_score_metric.rb

Overview

DtoHealthScoreMetric Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(metrictype: SKIP, metricvalue: SKIP) ⇒ DtoHealthScoreMetric

Returns a new instance of DtoHealthScoreMetric.



43
44
45
46
# File 'lib/verizon/models/dto_health_score_metric.rb', line 43

def initialize(metrictype: SKIP, metricvalue: SKIP)
  @metrictype = metrictype unless metrictype == SKIP
  @metricvalue = metricvalue unless metricvalue == SKIP
end

Instance Attribute Details

#metrictypeString

The type of measurement and can be overallscore, networkscore, gatewayscore, sensorscore, networkstatus, averagesignalstrength or networkavailabilitylast30

Returns:

  • (String)


16
17
18
# File 'lib/verizon/models/dto_health_score_metric.rb', line 16

def metrictype
  @metrictype
end

#metricvalueString

the value of the ‘metrictype` as a percentage

Returns:

  • (String)


20
21
22
# File 'lib/verizon/models/dto_health_score_metric.rb', line 20

def metricvalue
  @metricvalue
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/verizon/models/dto_health_score_metric.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  metrictype = hash.key?('metrictype') ? hash['metrictype'] : SKIP
  metricvalue = hash.key?('metricvalue') ? hash['metricvalue'] : SKIP

  # Create object from extracted values.
  DtoHealthScoreMetric.new(metrictype: metrictype,
                           metricvalue: metricvalue)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/verizon/models/dto_health_score_metric.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['metrictype'] = 'metrictype'
  @_hash['metricvalue'] = 'metricvalue'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/verizon/models/dto_health_score_metric.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/verizon/models/dto_health_score_metric.rb', line 31

def self.optionals
  %w[
    metrictype
    metricvalue
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
# File 'lib/verizon/models/dto_health_score_metric.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} metrictype: #{@metrictype.inspect}, metricvalue: #{@metricvalue.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/verizon/models/dto_health_score_metric.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} metrictype: #{@metrictype}, metricvalue: #{@metricvalue}>"
end