Class: Verizon::DtoLastReportedTimeRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoLastReportedTimeRequest
- Defined in:
- lib/verizon/models/dto_last_reported_time_request.rb
Overview
DtoLastReportedTimeRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#resourceidentifier ⇒ DtoDeviceResourceIdentifier
Device identifiers, one or more are required.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, resourceidentifier: SKIP, additional_properties: nil) ⇒ DtoLastReportedTimeRequest
constructor
A new instance of DtoLastReportedTimeRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, resourceidentifier: SKIP, additional_properties: nil) ⇒ DtoLastReportedTimeRequest
Returns a new instance of DtoLastReportedTimeRequest.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 41 def initialize(accountname: SKIP, resourceidentifier: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @accountname = accountname unless accountname == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 14 def accountname @accountname end |
#resourceidentifier ⇒ DtoDeviceResourceIdentifier
Device identifiers, one or more are required
18 19 20 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 18 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP resourceidentifier = DtoDeviceResourceIdentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DtoLastReportedTimeRequest.new(accountname: accountname, resourceidentifier: resourceidentifier, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 29 def self.optionals %w[ accountname resourceidentifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, resourceidentifier:"\ " #{@resourceidentifier.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/dto_last_reported_time_request.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, resourceidentifier: #{@resourceidentifier},"\ " additional_properties: #{@additional_properties}>" end |