Class: Verizon::DtoListSmartAlertsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoListSmartAlertsRequest
- Defined in:
- lib/verizon/models/dto_list_smart_alerts_request.rb
Overview
DtoListSmartAlertsRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#filter ⇒ DtoFilter
The numeric account name, which must include leading zeros.
-
#resourceidentifier ⇒ DtoResourceidentifier
The numeric account name, which must include leading zeros.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, filter: SKIP, resourceidentifier: SKIP) ⇒ DtoListSmartAlertsRequest
constructor
A new instance of DtoListSmartAlertsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, filter: SKIP, resourceidentifier: SKIP) ⇒ DtoListSmartAlertsRequest
Returns a new instance of DtoListSmartAlertsRequest.
47 48 49 50 51 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 47 def initialize(accountname: SKIP, filter: SKIP, resourceidentifier: SKIP) @accountname = accountname unless accountname == SKIP @filter = filter unless filter == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 14 def accountname @accountname end |
#filter ⇒ DtoFilter
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 18 def filter @filter end |
#resourceidentifier ⇒ DtoResourceidentifier
The numeric account name, which must include leading zeros
22 23 24 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 22 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP filter = DtoFilter.from_hash(hash['filter']) if hash['filter'] resourceidentifier = DtoResourceidentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] # Create object from extracted values. DtoListSmartAlertsRequest.new(accountname: accountname, filter: filter, resourceidentifier: resourceidentifier) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['filter'] = 'filter' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 34 def self.optionals %w[ accountname filter resourceidentifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, filter: #{@filter.inspect},"\ " resourceidentifier: #{@resourceidentifier.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/verizon/models/dto_list_smart_alerts_request.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, filter: #{@filter}, resourceidentifier:"\ " #{@resourceidentifier}>" end |