Class: Verizon::DtoListUserRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_list_user_request.rb

Overview

DtoListUserRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountname: SKIP, filter: SKIP) ⇒ DtoListUserRequest

Returns a new instance of DtoListUserRequest.



41
42
43
44
# File 'lib/verizon/models/dto_list_user_request.rb', line 41

def initialize(accountname: SKIP, filter: SKIP)
  @accountname = accountname unless accountname == SKIP
  @filter = filter unless filter == SKIP
end

Instance Attribute Details

#accountnameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_list_user_request.rb', line 14

def accountname
  @accountname
end

#filterDtoFilter

The numeric account name, which must include leading zeros

Returns:



18
19
20
# File 'lib/verizon/models/dto_list_user_request.rb', line 18

def filter
  @filter
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/dto_list_user_request.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountname = hash.key?('accountname') ? hash['accountname'] : SKIP
  filter = DtoFilter.from_hash(hash['filter']) if hash['filter']

  # Create object from extracted values.
  DtoListUserRequest.new(accountname: accountname,
                         filter: filter)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/dto_list_user_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountname'] = 'accountname'
  @_hash['filter'] = 'filter'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/dto_list_user_request.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/dto_list_user_request.rb', line 29

def self.optionals
  %w[
    accountname
    filter
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



66
67
68
69
# File 'lib/verizon/models/dto_list_user_request.rb', line 66

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname.inspect}, filter: #{@filter.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
# File 'lib/verizon/models/dto_list_user_request.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname}, filter: #{@filter}>"
end