Class: Verizon::DtoPatchDeviceRequest
- Defined in:
- lib/verizon/models/dto_patch_device_request.rb
Overview
DtoPatchDeviceRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#device ⇒ ResourceDevice
The numeric account name, which must include leading zeros.
-
#resourceidentifier ⇒ DtoDeviceResourceIdentifier
Device identifiers, one or more are required.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, device: SKIP, resourceidentifier: SKIP) ⇒ DtoPatchDeviceRequest
constructor
A new instance of DtoPatchDeviceRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, device: SKIP, resourceidentifier: SKIP) ⇒ DtoPatchDeviceRequest
Returns a new instance of DtoPatchDeviceRequest.
47 48 49 50 51 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 47 def initialize(accountname: SKIP, device: SKIP, resourceidentifier: SKIP) @accountname = accountname unless accountname == SKIP @device = device unless device == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 14 def accountname @accountname end |
#device ⇒ ResourceDevice
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 18 def device @device end |
#resourceidentifier ⇒ DtoDeviceResourceIdentifier
Device identifiers, one or more are required
22 23 24 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 22 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP device = ResourceDevice.from_hash(hash['device']) if hash['device'] resourceidentifier = DtoDeviceResourceIdentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] # Create object from extracted values. DtoPatchDeviceRequest.new(accountname: accountname, device: device, resourceidentifier: resourceidentifier) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['device'] = 'device' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 34 def self.optionals %w[ accountname device resourceidentifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, device: #{@device.inspect},"\ " resourceidentifier: #{@resourceidentifier.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/verizon/models/dto_patch_device_request.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, device: #{@device}, resourceidentifier:"\ " #{@resourceidentifier}>" end |