Class: Verizon::DtoProfile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_profile.rb

Overview

DtoProfile Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(kind: SKIP, version: SKIP, modelid: SKIP, name: SKIP, configuration: SKIP, additional_properties: nil) ⇒ DtoProfile

Returns a new instance of DtoProfile.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/verizon/models/dto_profile.rb', line 59

def initialize(kind: SKIP, version: SKIP, modelid: SKIP, name: SKIP,
               configuration: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @kind = kind unless kind == SKIP
  @version = version unless version == SKIP
  @modelid = modelid unless modelid == SKIP
  @name = name unless name == SKIP
  @configuration = configuration unless configuration == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#configurationObject

profile name

Returns:

  • (Object)


30
31
32
# File 'lib/verizon/models/dto_profile.rb', line 30

def configuration
  @configuration
end

#kindString

profile kind

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_profile.rb', line 14

def kind
  @kind
end

#modelidString

device model id

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/dto_profile.rb', line 22

def modelid
  @modelid
end

#nameString

profile name

Returns:

  • (String)


26
27
28
# File 'lib/verizon/models/dto_profile.rb', line 26

def name
  @name
end

#versionString

The resource version

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/dto_profile.rb', line 18

def version
  @version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/verizon/models/dto_profile.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  kind = hash.key?('kind') ? hash['kind'] : SKIP
  version = hash.key?('version') ? hash['version'] : SKIP
  modelid = hash.key?('modelid') ? hash['modelid'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  configuration = hash.key?('configuration') ? hash['configuration'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DtoProfile.new(kind: kind,
                 version: version,
                 modelid: modelid,
                 name: name,
                 configuration: configuration,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/verizon/models/dto_profile.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['kind'] = 'kind'
  @_hash['version'] = 'version'
  @_hash['modelid'] = 'modelid'
  @_hash['name'] = 'name'
  @_hash['configuration'] = 'configuration'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/verizon/models/dto_profile.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/verizon/models/dto_profile.rb', line 44

def self.optionals
  %w[
    kind
    version
    modelid
    name
    configuration
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



107
108
109
110
111
112
# File 'lib/verizon/models/dto_profile.rb', line 107

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} kind: #{@kind.inspect}, version: #{@version.inspect}, modelid:"\
  " #{@modelid.inspect}, name: #{@name.inspect}, configuration: #{@configuration.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
# File 'lib/verizon/models/dto_profile.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} kind: #{@kind}, version: #{@version}, modelid: #{@modelid}, name: #{@name},"\
  " configuration: #{@configuration}, additional_properties: #{@additional_properties}>"
end