Class: Verizon::DtoQueryMetrics
- Defined in:
- lib/verizon/models/dto_query_metrics.rb
Overview
DtoQueryMetrics Model.
Instance Attribute Summary collapse
-
#days ⇒ Integer
The number of days in a recent period to query.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(days: SKIP) ⇒ DtoQueryMetrics
constructor
A new instance of DtoQueryMetrics.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(days: SKIP) ⇒ DtoQueryMetrics
Returns a new instance of DtoQueryMetrics.
35 36 37 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 35 def initialize(days: SKIP) @days = days unless days == SKIP end |
Instance Attribute Details
#days ⇒ Integer
The number of days in a recent period to query
14 15 16 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 14 def days @days end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. days = hash.key?('days') ? hash['days'] : SKIP # Create object from extracted values. DtoQueryMetrics.new(days: days) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['days'] = 'days' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 24 def self.optionals %w[ days ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} days: #{@days.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/verizon/models/dto_query_metrics.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} days: #{@days}>" end |