Class: Verizon::DtoRemoveUsersFromNotificationGroupRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoRemoveUsersFromNotificationGroupRequest
- Defined in:
- lib/verizon/models/dto_remove_users_from_notification_group_request.rb
Overview
DtoRemoveUsersFromNotificationGroupRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#id ⇒ String
UUID of the user record, assigned at creation.
-
#userids ⇒ Array[String]
UUID of the user record, assigned at creation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, id: SKIP, userids: SKIP, additional_properties: nil) ⇒ DtoRemoveUsersFromNotificationGroupRequest
constructor
A new instance of DtoRemoveUsersFromNotificationGroupRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, id: SKIP, userids: SKIP, additional_properties: nil) ⇒ DtoRemoveUsersFromNotificationGroupRequest
Returns a new instance of DtoRemoveUsersFromNotificationGroupRequest.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 47 def initialize(accountname: SKIP, id: SKIP, userids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @accountname = accountname unless accountname == SKIP @id = id unless id == SKIP @userids = userids unless userids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 14 def accountname @accountname end |
#id ⇒ String
UUID of the user record, assigned at creation
18 19 20 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 18 def id @id end |
#userids ⇒ Array[String]
UUID of the user record, assigned at creation
22 23 24 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 22 def userids @userids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP userids = hash.key?('userids') ? hash['userids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DtoRemoveUsersFromNotificationGroupRequest.new(accountname: accountname, id: id, userids: userids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['id'] = 'id' @_hash['userids'] = 'userids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 34 def self.optionals %w[ accountname id userids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, id: #{@id.inspect}, userids:"\ " #{@userids.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/verizon/models/dto_remove_users_from_notification_group_request.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, id: #{@id}, userids: #{@userids},"\ " additional_properties: #{@additional_properties}>" end |