Class: Verizon::DtoSensorOffBoardingStatusResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_sensor_off_boarding_status_response.rb

Overview

DtoSensorOffBoardingStatusResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(events: SKIP, isstillregistered: SKIP) ⇒ DtoSensorOffBoardingStatusResponse

Returns a new instance of DtoSensorOffBoardingStatusResponse.



41
42
43
44
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 41

def initialize(events: SKIP, isstillregistered: SKIP)
  @events = events unless events == SKIP
  @isstillregistered = isstillregistered unless isstillregistered == SKIP
end

Instance Attribute Details

#eventsArray[DtoSensorBoardingEvent]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 14

def events
  @events
end

#isstillregisteredTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 18

def isstillregistered
  @isstillregistered
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  events = nil
  unless hash['events'].nil?
    events = []
    hash['events'].each do |structure|
      events << (DtoSensorBoardingEvent.from_hash(structure) if structure)
    end
  end

  events = SKIP unless hash.key?('events')
  isstillregistered =
    hash.key?('isstillregistered') ? hash['isstillregistered'] : SKIP

  # Create object from extracted values.
  DtoSensorOffBoardingStatusResponse.new(events: events,
                                         isstillregistered: isstillregistered)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['events'] = 'events'
  @_hash['isstillregistered'] = 'isstillregistered'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 29

def self.optionals
  %w[
    events
    isstillregistered
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} events: #{@events.inspect}, isstillregistered:"\
  " #{@isstillregistered.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/verizon/models/dto_sensor_off_boarding_status_response.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} events: #{@events}, isstillregistered: #{@isstillregistered}>"
end