Class: Verizon::EnablePromoExp1
- Defined in:
- lib/verizon/models/enable_promo_exp1.rb
Overview
EnablePromoExp1 Model.
Instance Attribute Summary collapse
-
#enable_promo_exp ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enable_promo_exp: SKIP, additional_properties: nil) ⇒ EnablePromoExp1
constructor
A new instance of EnablePromoExp1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enable_promo_exp: SKIP, additional_properties: nil) ⇒ EnablePromoExp1
Returns a new instance of EnablePromoExp1.
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 35 def initialize(enable_promo_exp: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @enable_promo_exp = enable_promo_exp unless enable_promo_exp == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#enable_promo_exp ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 14 def enable_promo_exp @enable_promo_exp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enable_promo_exp = hash.key?('enablePromoExp') ? hash['enablePromoExp'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EnablePromoExp1.new(enable_promo_exp: enable_promo_exp, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['enable_promo_exp'] = 'enablePromoExp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 24 def self.optionals %w[ enable_promo_exp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} enable_promo_exp: #{@enable_promo_exp.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/verizon/models/enable_promo_exp1.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} enable_promo_exp: #{@enable_promo_exp}, additional_properties:"\ " #{@additional_properties}>" end |