Class: Verizon::Engagement
- Defined in:
- lib/verizon/models/engagement.rb
Overview
The engagements associated with the account.
Instance Attribute Summary collapse
-
#charging_group ⇒ String
The charging group name.
-
#engagement_id ⇒ String
The engagement ID.
-
#services ⇒ Array[AccountService]
The services associated with the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(engagement_id: SKIP, charging_group: SKIP, services: SKIP, additional_properties: nil) ⇒ Engagement
constructor
A new instance of Engagement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(engagement_id: SKIP, charging_group: SKIP, services: SKIP, additional_properties: nil) ⇒ Engagement
Returns a new instance of Engagement.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/engagement.rb', line 47 def initialize(engagement_id: SKIP, charging_group: SKIP, services: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @engagement_id = engagement_id unless engagement_id == SKIP @charging_group = charging_group unless charging_group == SKIP @services = services unless services == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#charging_group ⇒ String
The charging group name.
18 19 20 |
# File 'lib/verizon/models/engagement.rb', line 18 def charging_group @charging_group end |
#engagement_id ⇒ String
The engagement ID.
14 15 16 |
# File 'lib/verizon/models/engagement.rb', line 14 def engagement_id @engagement_id end |
#services ⇒ Array[AccountService]
The services associated with the account.
22 23 24 |
# File 'lib/verizon/models/engagement.rb', line 22 def services @services end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/verizon/models/engagement.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. engagement_id = hash.key?('engagementId') ? hash['engagementId'] : SKIP charging_group = hash.key?('chargingGroup') ? hash['chargingGroup'] : SKIP # Parameter is an array, so we need to iterate through it services = nil unless hash['services'].nil? services = [] hash['services'].each do |structure| services << (AccountService.from_hash(structure) if structure) end end services = SKIP unless hash.key?('services') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Engagement.new(engagement_id: engagement_id, charging_group: charging_group, services: services, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/engagement.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['engagement_id'] = 'engagementId' @_hash['charging_group'] = 'chargingGroup' @_hash['services'] = 'services' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/engagement.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/engagement.rb', line 34 def self.optionals %w[ engagement_id charging_group services ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/verizon/models/engagement.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} engagement_id: #{@engagement_id.inspect}, charging_group:"\ " #{@charging_group.inspect}, services: #{@services.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/verizon/models/engagement.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} engagement_id: #{@engagement_id}, charging_group: #{@charging_group},"\ " services: #{@services}, additional_properties: #{@additional_properties}>" end |