Class: Verizon::ErrorResponseException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- Verizon::ErrorResponseException
- Defined in:
- lib/verizon/exceptions/error_response_exception.rb
Overview
ErrorResponse class.
Instance Attribute Summary collapse
-
#message ⇒ String
TODO: Write general description for this method.
-
#response_code ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ ErrorResponseException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ ErrorResponseException
The constructor.
23 24 25 26 27 |
# File 'lib/verizon/exceptions/error_response_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/exceptions/error_response_exception.rb', line 18 def @message end |
#response_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/exceptions/error_response_exception.rb', line 14 def response_code @response_code end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
46 47 48 49 |
# File 'lib/verizon/exceptions/error_response_exception.rb', line 46 def inspect class_name = self.class.name.split('::').last "<#{class_name} response_code: #{@response_code.inspect}, message: #{@message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
40 41 42 43 |
# File 'lib/verizon/exceptions/error_response_exception.rb', line 40 def to_s class_name = self.class.name.split('::').last "<#{class_name} response_code: #{@response_code}, message: #{@message}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 37 |
# File 'lib/verizon/exceptions/error_response_exception.rb', line 32 def unbox(hash) return nil unless hash @response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP @message = hash.key?('message') ? hash['message'] : SKIP end |