Class: Verizon::EsimProfileRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/esim_profile_request.rb

Overview

EsimProfileRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(devices: SKIP, carrier_name: SKIP, account_name: SKIP, service_plan: SKIP, mdn_zip_code: SKIP) ⇒ EsimProfileRequest

Returns a new instance of EsimProfileRequest.



59
60
61
62
63
64
65
66
# File 'lib/verizon/models/esim_profile_request.rb', line 59

def initialize(devices: SKIP, carrier_name: SKIP, account_name: SKIP,
               service_plan: SKIP, mdn_zip_code: SKIP)
  @devices = devices unless devices == SKIP
  @carrier_name = carrier_name unless carrier_name == SKIP
  @account_name =  unless  == SKIP
  @service_plan = service_plan unless service_plan == SKIP
  @mdn_zip_code = mdn_zip_code unless mdn_zip_code == SKIP
end

Instance Attribute Details

#account_nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/esim_profile_request.rb', line 22

def 
  @account_name
end

#carrier_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/esim_profile_request.rb', line 18

def carrier_name
  @carrier_name
end

#devicesArray[EsimDeviceList]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/esim_profile_request.rb', line 14

def devices
  @devices
end

#mdn_zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/verizon/models/esim_profile_request.rb', line 30

def mdn_zip_code
  @mdn_zip_code
end

#service_planString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/verizon/models/esim_profile_request.rb', line 26

def service_plan
  @service_plan
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/verizon/models/esim_profile_request.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (EsimDeviceList.from_hash(structure) if structure)
    end
  end

  devices = SKIP unless hash.key?('devices')
  carrier_name = hash.key?('carrierName') ? hash['carrierName'] : SKIP
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  service_plan = hash.key?('servicePlan') ? hash['servicePlan'] : SKIP
  mdn_zip_code = hash.key?('mdnZipCode') ? hash['mdnZipCode'] : SKIP

  # Create object from extracted values.
  EsimProfileRequest.new(devices: devices,
                         carrier_name: carrier_name,
                         account_name: ,
                         service_plan: service_plan,
                         mdn_zip_code: mdn_zip_code)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/verizon/models/esim_profile_request.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['devices'] = 'devices'
  @_hash['carrier_name'] = 'carrierName'
  @_hash['account_name'] = 'accountName'
  @_hash['service_plan'] = 'servicePlan'
  @_hash['mdn_zip_code'] = 'mdnZipCode'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/verizon/models/esim_profile_request.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/verizon/models/esim_profile_request.rb', line 44

def self.optionals
  %w[
    devices
    carrier_name
    account_name
    service_plan
    mdn_zip_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
# File 'lib/verizon/models/esim_profile_request.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices.inspect}, carrier_name: #{@carrier_name.inspect},"\
  " account_name: #{@account_name.inspect}, service_plan: #{@service_plan.inspect},"\
  " mdn_zip_code: #{@mdn_zip_code.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/verizon/models/esim_profile_request.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices}, carrier_name: #{@carrier_name}, account_name:"\
  " #{@account_name}, service_plan: #{@service_plan}, mdn_zip_code: #{@mdn_zip_code}>"
end