Class: Verizon::EsimProfileRequest2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/esim_profile_request2.rb

Overview

EsimProfileRequest2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(devices: SKIP, account_name: SKIP, service_plan: SKIP, mdn_zip_code: SKIP) ⇒ EsimProfileRequest2

Returns a new instance of EsimProfileRequest2.



53
54
55
56
57
58
59
# File 'lib/verizon/models/esim_profile_request2.rb', line 53

def initialize(devices: SKIP, account_name: SKIP, service_plan: SKIP,
               mdn_zip_code: SKIP)
  @devices = devices unless devices == SKIP
  @account_name =  unless  == SKIP
  @service_plan = service_plan unless service_plan == SKIP
  @mdn_zip_code = mdn_zip_code unless mdn_zip_code == SKIP
end

Instance Attribute Details

#account_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/esim_profile_request2.rb', line 18

def 
  @account_name
end

#devicesArray[EsimDeviceList]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/esim_profile_request2.rb', line 14

def devices
  @devices
end

#mdn_zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/verizon/models/esim_profile_request2.rb', line 26

def mdn_zip_code
  @mdn_zip_code
end

#service_planString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/esim_profile_request2.rb', line 22

def service_plan
  @service_plan
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/verizon/models/esim_profile_request2.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (EsimDeviceList.from_hash(structure) if structure)
    end
  end

  devices = SKIP unless hash.key?('devices')
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  service_plan = hash.key?('servicePlan') ? hash['servicePlan'] : SKIP
  mdn_zip_code = hash.key?('mdnZipCode') ? hash['mdnZipCode'] : SKIP

  # Create object from extracted values.
  EsimProfileRequest2.new(devices: devices,
                          account_name: ,
                          service_plan: service_plan,
                          mdn_zip_code: mdn_zip_code)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/verizon/models/esim_profile_request2.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['devices'] = 'devices'
  @_hash['account_name'] = 'accountName'
  @_hash['service_plan'] = 'servicePlan'
  @_hash['mdn_zip_code'] = 'mdnZipCode'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/verizon/models/esim_profile_request2.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/verizon/models/esim_profile_request2.rb', line 39

def self.optionals
  %w[
    devices
    account_name
    service_plan
    mdn_zip_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/verizon/models/esim_profile_request2.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices.inspect}, account_name: #{@account_name.inspect},"\
  " service_plan: #{@service_plan.inspect}, mdn_zip_code: #{@mdn_zip_code.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/verizon/models/esim_profile_request2.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices}, account_name: #{@account_name}, service_plan:"\
  " #{@service_plan}, mdn_zip_code: #{@mdn_zip_code}>"
end