Class: Verizon::EsimRestErrorResponseException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- Verizon::EsimRestErrorResponseException
- Defined in:
- lib/verizon/exceptions/esim_rest_error_response_exception.rb
Overview
eSIMRestErrorResponse class.
Instance Attribute Summary collapse
-
#error_code ⇒ String
TODO: Write general description for this method.
-
#error_message ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ EsimRestErrorResponseException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ EsimRestErrorResponseException
The constructor.
23 24 25 26 27 |
# File 'lib/verizon/exceptions/esim_rest_error_response_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/exceptions/esim_rest_error_response_exception.rb', line 14 def error_code @error_code end |
#error_message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/exceptions/esim_rest_error_response_exception.rb', line 18 def @error_message end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
46 47 48 49 50 |
# File 'lib/verizon/exceptions/esim_rest_error_response_exception.rb', line 46 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, error_message:"\ " #{@error_message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
40 41 42 43 |
# File 'lib/verizon/exceptions/esim_rest_error_response_exception.rb', line 40 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, error_message: #{@error_message}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 37 |
# File 'lib/verizon/exceptions/esim_rest_error_response_exception.rb', line 32 def unbox(hash) return nil unless hash @error_code = hash.key?('errorCode') ? hash['errorCode'] : SKIP @error_message = hash.key?('errorMessage') ? hash['errorMessage'] : SKIP end |