Class: Verizon::ExtendedAttribute
- Defined in:
- lib/verizon/models/extended_attribute.rb
Overview
ExtendedAttribute Model.
Instance Attribute Summary collapse
-
#key ⇒ String
The key indicates if the SMS message was to the device (MtSms) or from the device (MoSms).
-
#value ⇒ String
The number of SMS messages found.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(key: SKIP, value: SKIP, additional_properties: nil) ⇒ ExtendedAttribute
constructor
A new instance of ExtendedAttribute.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(key: SKIP, value: SKIP, additional_properties: nil) ⇒ ExtendedAttribute
Returns a new instance of ExtendedAttribute.
42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/extended_attribute.rb', line 42 def initialize(key: SKIP, value: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @key = key unless key == SKIP @value = value unless value == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#key ⇒ String
The key indicates if the SMS message was to the device (MtSms) or from the device (MoSms)
15 16 17 |
# File 'lib/verizon/models/extended_attribute.rb', line 15 def key @key end |
#value ⇒ String
The number of SMS messages found
19 20 21 |
# File 'lib/verizon/models/extended_attribute.rb', line 19 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/extended_attribute.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. key = hash.key?('key') ? hash['key'] : SKIP value = hash.key?('value') ? hash['value'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ExtendedAttribute.new(key: key, value: value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/extended_attribute.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['key'] = 'key' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/verizon/models/extended_attribute.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/verizon/models/extended_attribute.rb', line 30 def self.optionals %w[ key value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/verizon/models/extended_attribute.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} key: #{@key.inspect}, value: #{@value.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/verizon/models/extended_attribute.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} key: #{@key}, value: #{@value}, additional_properties:"\ " #{@additional_properties}>" end |