Class: Verizon::ExtendedAttributes

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/extended_attributes.rb

Overview

Additional properties associated with data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(key: SKIP, value: SKIP) ⇒ ExtendedAttributes

Returns a new instance of ExtendedAttributes.



41
42
43
44
# File 'lib/verizon/models/extended_attributes.rb', line 41

def initialize(key: SKIP, value: SKIP)
  @key = key unless key == SKIP
  @value = value unless value == SKIP
end

Instance Attribute Details

#keyString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/extended_attributes.rb', line 14

def key
  @key
end

#valueString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/extended_attributes.rb', line 18

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/extended_attributes.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  key = hash.key?('key') ? hash['key'] : SKIP
  value = hash.key?('value') ? hash['value'] : SKIP

  # Create object from extracted values.
  ExtendedAttributes.new(key: key,
                         value: value)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/extended_attributes.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['key'] = 'key'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/extended_attributes.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/extended_attributes.rb', line 29

def self.optionals
  %w[
    key
    value
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



61
62
63
64
65
66
67
# File 'lib/verizon/models/extended_attributes.rb', line 61

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
# File 'lib/verizon/models/extended_attributes.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key.inspect}, value: #{@value.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/verizon/models/extended_attributes.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key}, value: #{@value}>"
end