Class: Verizon::FallBack

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/fall_back.rb

Overview

FallBack Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(devices: SKIP, account_name: SKIP, additional_properties: nil) ⇒ FallBack

Returns a new instance of FallBack.



42
43
44
45
46
47
48
49
50
# File 'lib/verizon/models/fall_back.rb', line 42

def initialize(devices: SKIP, account_name: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @devices = devices unless devices == SKIP
  @account_name =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The numeric name of the account, in the format “0000123456-00001”. Leading zeros must be included.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/fall_back.rb', line 19

def 
  @account_name
end

#devicesArray[DeviceIdarray]

An array containing the ‘deviceId` array.

Returns:



14
15
16
# File 'lib/verizon/models/fall_back.rb', line 14

def devices
  @devices
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/verizon/models/fall_back.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (DeviceIdarray.from_hash(structure) if structure)
    end
  end

  devices = SKIP unless hash.key?('devices')
   = hash.key?('accountName') ? hash['accountName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FallBack.new(devices: devices,
               account_name: ,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/fall_back.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['devices'] = 'devices'
  @_hash['account_name'] = 'accountName'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/fall_back.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/verizon/models/fall_back.rb', line 30

def self.optionals
  %w[
    devices
    account_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/verizon/models/fall_back.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices.inspect}, account_name: #{@account_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/verizon/models/fall_back.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices}, account_name: #{@account_name},"\
  " additional_properties: #{@additional_properties}>"
end