Class: Verizon::FindDeviceByPropertyResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::FindDeviceByPropertyResponse
- Defined in:
- lib/verizon/models/find_device_by_property_response.rb
Overview
Change Configuration resource definition.
Instance Attribute Summary collapse
-
#billingaccountid ⇒ String
Billing account ID of the resource.
-
#createdon ⇒ String
The date the resource was created.
-
#eventretention ⇒ String
The date the resource was created.
-
#iccid ⇒ String
Cellular SIM card identifier.
-
#id ⇒ String
ThingSpace unique ID for the device that was added.
-
#imei ⇒ String
4G hardware device identifier.
-
#kind ⇒ String
Identifies the resource kind.
-
#lastupdated ⇒ String
The date the resource was last updated.
-
#providerid ⇒ String
The device’s service provider.
-
#refid ⇒ String
The value of the refidtype identifier.
-
#refidtype ⇒ String
The device identifier type used to refer to this device.
-
#state ⇒ String
Service state of the device.
-
#version ⇒ String
Version of the underlying schema resource.
-
#versionid ⇒ String
The version of the resource.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(billingaccountid: SKIP, createdon: SKIP, eventretention: SKIP, iccid: SKIP, id: SKIP, imei: SKIP, kind: SKIP, lastupdated: SKIP, providerid: SKIP, refid: SKIP, refidtype: SKIP, state: SKIP, version: SKIP, versionid: SKIP, additional_properties: nil) ⇒ FindDeviceByPropertyResponse
constructor
A new instance of FindDeviceByPropertyResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(billingaccountid: SKIP, createdon: SKIP, eventretention: SKIP, iccid: SKIP, id: SKIP, imei: SKIP, kind: SKIP, lastupdated: SKIP, providerid: SKIP, refid: SKIP, refidtype: SKIP, state: SKIP, version: SKIP, versionid: SKIP, additional_properties: nil) ⇒ FindDeviceByPropertyResponse
Returns a new instance of FindDeviceByPropertyResponse.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 113 def initialize(billingaccountid: SKIP, createdon: SKIP, eventretention: SKIP, iccid: SKIP, id: SKIP, imei: SKIP, kind: SKIP, lastupdated: SKIP, providerid: SKIP, refid: SKIP, refidtype: SKIP, state: SKIP, version: SKIP, versionid: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @billingaccountid = billingaccountid unless billingaccountid == SKIP @createdon = createdon unless createdon == SKIP @eventretention = eventretention unless eventretention == SKIP @iccid = iccid unless iccid == SKIP @id = id unless id == SKIP @imei = imei unless imei == SKIP @kind = kind unless kind == SKIP @lastupdated = lastupdated unless lastupdated == SKIP @providerid = providerid unless providerid == SKIP @refid = refid unless refid == SKIP @refidtype = refidtype unless refidtype == SKIP @state = state unless state == SKIP @version = version unless version == SKIP @versionid = versionid unless versionid == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#billingaccountid ⇒ String
Billing account ID of the resource.
14 15 16 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 14 def billingaccountid @billingaccountid end |
#createdon ⇒ String
The date the resource was created.
18 19 20 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 18 def createdon @createdon end |
#eventretention ⇒ String
The date the resource was created.
22 23 24 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 22 def eventretention @eventretention end |
#iccid ⇒ String
Cellular SIM card identifier.
26 27 28 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 26 def iccid @iccid end |
#id ⇒ String
ThingSpace unique ID for the device that was added.
30 31 32 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 30 def id @id end |
#imei ⇒ String
4G hardware device identifier.
34 35 36 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 34 def imei @imei end |
#kind ⇒ String
Identifies the resource kind.
38 39 40 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 38 def kind @kind end |
#lastupdated ⇒ String
The date the resource was last updated.
42 43 44 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 42 def lastupdated @lastupdated end |
#providerid ⇒ String
The device’s service provider.
46 47 48 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 46 def providerid @providerid end |
#refid ⇒ String
The value of the refidtype identifier.
50 51 52 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 50 def refid @refid end |
#refidtype ⇒ String
The device identifier type used to refer to this device.
54 55 56 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 54 def refidtype @refidtype end |
#state ⇒ String
Service state of the device.
58 59 60 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 58 def state @state end |
#version ⇒ String
Version of the underlying schema resource.
62 63 64 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 62 def version @version end |
#versionid ⇒ String
The version of the resource.
66 67 68 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 66 def versionid @versionid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 139 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. billingaccountid = hash.key?('billingaccountid') ? hash['billingaccountid'] : SKIP createdon = hash.key?('createdon') ? hash['createdon'] : SKIP eventretention = hash.key?('eventretention') ? hash['eventretention'] : SKIP iccid = hash.key?('iccid') ? hash['iccid'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP imei = hash.key?('imei') ? hash['imei'] : SKIP kind = hash.key?('kind') ? hash['kind'] : SKIP lastupdated = hash.key?('lastupdated') ? hash['lastupdated'] : SKIP providerid = hash.key?('providerid') ? hash['providerid'] : SKIP refid = hash.key?('refid') ? hash['refid'] : SKIP refidtype = hash.key?('refidtype') ? hash['refidtype'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP version = hash.key?('version') ? hash['version'] : SKIP versionid = hash.key?('versionid') ? hash['versionid'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FindDeviceByPropertyResponse.new(billingaccountid: billingaccountid, createdon: createdon, eventretention: eventretention, iccid: iccid, id: id, imei: imei, kind: kind, lastupdated: lastupdated, providerid: providerid, refid: refid, refidtype: refidtype, state: state, version: version, versionid: versionid, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 69 def self.names @_hash = {} if @_hash.nil? @_hash['billingaccountid'] = 'billingaccountid' @_hash['createdon'] = 'createdon' @_hash['eventretention'] = 'eventretention' @_hash['iccid'] = 'iccid' @_hash['id'] = 'id' @_hash['imei'] = 'imei' @_hash['kind'] = 'kind' @_hash['lastupdated'] = 'lastupdated' @_hash['providerid'] = 'providerid' @_hash['refid'] = 'refid' @_hash['refidtype'] = 'refidtype' @_hash['state'] = 'state' @_hash['version'] = 'version' @_hash['versionid'] = 'versionid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
109 110 111 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 109 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 89 def self.optionals %w[ billingaccountid createdon eventretention iccid id imei kind lastupdated providerid refid refidtype state version versionid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 196 def inspect class_name = self.class.name.split('::').last "<#{class_name} billingaccountid: #{@billingaccountid.inspect}, createdon:"\ " #{@createdon.inspect}, eventretention: #{@eventretention.inspect}, iccid:"\ " #{@iccid.inspect}, id: #{@id.inspect}, imei: #{@imei.inspect}, kind: #{@kind.inspect},"\ " lastupdated: #{@lastupdated.inspect}, providerid: #{@providerid.inspect}, refid:"\ " #{@refid.inspect}, refidtype: #{@refidtype.inspect}, state: #{@state.inspect}, version:"\ " #{@version.inspect}, versionid: #{@versionid.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
186 187 188 189 190 191 192 193 |
# File 'lib/verizon/models/find_device_by_property_response.rb', line 186 def to_s class_name = self.class.name.split('::').last "<#{class_name} billingaccountid: #{@billingaccountid}, createdon: #{@createdon},"\ " eventretention: #{@eventretention}, iccid: #{@iccid}, id: #{@id}, imei: #{@imei}, kind:"\ " #{@kind}, lastupdated: #{@lastupdated}, providerid: #{@providerid}, refid: #{@refid},"\ " refidtype: #{@refidtype}, state: #{@state}, version: #{@version}, versionid:"\ " #{@versionid}, additional_properties: #{@additional_properties}>" end |