Class: Verizon::FindDeviceByPropertyResponseList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/find_device_by_property_response_list.rb

Overview

A success response includes an array of all matching devices. Each device includes the full device resource definition.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_property: SKIP, additional_properties: nil) ⇒ FindDeviceByPropertyResponseList

Returns a new instance of FindDeviceByPropertyResponseList.



36
37
38
39
40
41
42
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 36

def initialize(device_property: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_property = device_property unless device_property == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_propertyArray[FindDeviceByPropertyResponse]

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 15

def device_property
  @device_property
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_property = nil
  unless hash['DeviceProperty'].nil?
    device_property = []
    hash['DeviceProperty'].each do |structure|
      device_property << (FindDeviceByPropertyResponse.from_hash(structure) if structure)
    end
  end

  device_property = SKIP unless hash.key?('DeviceProperty')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FindDeviceByPropertyResponseList.new(device_property: device_property,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_property'] = 'DeviceProperty'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 25

def self.optionals
  %w[
    device_property
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_property: #{@device_property.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_property: #{@device_property}, additional_properties:"\
  " #{@additional_properties}>"
end