Class: Verizon::FirmwareCampaign
- Defined in:
- lib/verizon/models/firmware_campaign.rb
Overview
Firmware upgrade information.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier.
-
#campaign_name ⇒ String
Campaign name.
-
#campaign_time_window_list ⇒ Array[V3TimeWindow]
List of allowed campaign time windows.
-
#end_date ⇒ Date
Campaign end date.
-
#firmware_from ⇒ String
Old firmware version (for firmware upgrade only).
-
#firmware_name ⇒ String
Firmware name (for firmware upgrade only).
-
#firmware_to ⇒ String
New firmware version (for firmware upgrade only).
-
#id ⇒ String
Upgrade identifier.
-
#make ⇒ String
Available values: LWM2M.
-
#model ⇒ String
Available values: LWM2M.
-
#protocol ⇒ String
Available values: LWM2M.
-
#start_date ⇒ Date
Campaign start date.
-
#status ⇒ String
Campaign status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, account_name:, firmware_from:, firmware_to:, protocol: 'LWM2M', make:, model:, start_date:, end_date:, status:, campaign_name: SKIP, firmware_name: SKIP, campaign_time_window_list: SKIP, additional_properties: nil) ⇒ FirmwareCampaign
constructor
A new instance of FirmwareCampaign.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, account_name:, firmware_from:, firmware_to:, protocol: 'LWM2M', make:, model:, start_date:, end_date:, status:, campaign_name: SKIP, firmware_name: SKIP, campaign_time_window_list: SKIP, additional_properties: nil) ⇒ FirmwareCampaign
Returns a new instance of FirmwareCampaign.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/verizon/models/firmware_campaign.rb', line 97 def initialize(id:, account_name:, firmware_from:, firmware_to:, protocol: 'LWM2M', make:, model:, start_date:, end_date:, status:, campaign_name: SKIP, firmware_name: SKIP, campaign_time_window_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @account_name = account_name @campaign_name = campaign_name unless campaign_name == SKIP @firmware_name = firmware_name unless firmware_name == SKIP @firmware_from = firmware_from @firmware_to = firmware_to @protocol = protocol @make = make @model = model @start_date = start_date @end_date = end_date unless campaign_time_window_list == SKIP @campaign_time_window_list = campaign_time_window_list end @status = status @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account identifier.
18 19 20 |
# File 'lib/verizon/models/firmware_campaign.rb', line 18 def account_name @account_name end |
#campaign_name ⇒ String
Campaign name.
22 23 24 |
# File 'lib/verizon/models/firmware_campaign.rb', line 22 def campaign_name @campaign_name end |
#campaign_time_window_list ⇒ Array[V3TimeWindow]
List of allowed campaign time windows.
58 59 60 |
# File 'lib/verizon/models/firmware_campaign.rb', line 58 def campaign_time_window_list @campaign_time_window_list end |
#end_date ⇒ Date
Campaign end date.
54 55 56 |
# File 'lib/verizon/models/firmware_campaign.rb', line 54 def end_date @end_date end |
#firmware_from ⇒ String
Old firmware version (for firmware upgrade only).
30 31 32 |
# File 'lib/verizon/models/firmware_campaign.rb', line 30 def firmware_from @firmware_from end |
#firmware_name ⇒ String
Firmware name (for firmware upgrade only).
26 27 28 |
# File 'lib/verizon/models/firmware_campaign.rb', line 26 def firmware_name @firmware_name end |
#firmware_to ⇒ String
New firmware version (for firmware upgrade only).
34 35 36 |
# File 'lib/verizon/models/firmware_campaign.rb', line 34 def firmware_to @firmware_to end |
#id ⇒ String
Upgrade identifier.
14 15 16 |
# File 'lib/verizon/models/firmware_campaign.rb', line 14 def id @id end |
#make ⇒ String
Available values: LWM2M.
42 43 44 |
# File 'lib/verizon/models/firmware_campaign.rb', line 42 def make @make end |
#model ⇒ String
Available values: LWM2M.
46 47 48 |
# File 'lib/verizon/models/firmware_campaign.rb', line 46 def model @model end |
#protocol ⇒ String
Available values: LWM2M.
38 39 40 |
# File 'lib/verizon/models/firmware_campaign.rb', line 38 def protocol @protocol end |
#start_date ⇒ Date
Campaign start date.
50 51 52 |
# File 'lib/verizon/models/firmware_campaign.rb', line 50 def start_date @start_date end |
#status ⇒ String
Campaign status.
62 63 64 |
# File 'lib/verizon/models/firmware_campaign.rb', line 62 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/verizon/models/firmware_campaign.rb', line 124 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil account_name = hash.key?('accountName') ? hash['accountName'] : nil firmware_from = hash.key?('firmwareFrom') ? hash['firmwareFrom'] : nil firmware_to = hash.key?('firmwareTo') ? hash['firmwareTo'] : nil protocol = hash['protocol'] ||= 'LWM2M' make = hash.key?('make') ? hash['make'] : nil model = hash.key?('model') ? hash['model'] : nil start_date = hash.key?('startDate') ? hash['startDate'] : nil end_date = hash.key?('endDate') ? hash['endDate'] : nil status = hash.key?('status') ? hash['status'] : nil campaign_name = hash.key?('campaignName') ? hash['campaignName'] : SKIP firmware_name = hash.key?('firmwareName') ? hash['firmwareName'] : SKIP # Parameter is an array, so we need to iterate through it campaign_time_window_list = nil unless hash['campaignTimeWindowList'].nil? campaign_time_window_list = [] hash['campaignTimeWindowList'].each do |structure| campaign_time_window_list << (V3TimeWindow.from_hash(structure) if structure) end end campaign_time_window_list = SKIP unless hash.key?('campaignTimeWindowList') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FirmwareCampaign.new(id: id, account_name: account_name, firmware_from: firmware_from, firmware_to: firmware_to, protocol: protocol, make: make, model: model, start_date: start_date, end_date: end_date, status: status, campaign_name: campaign_name, firmware_name: firmware_name, campaign_time_window_list: campaign_time_window_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/models/firmware_campaign.rb', line 65 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['account_name'] = 'accountName' @_hash['campaign_name'] = 'campaignName' @_hash['firmware_name'] = 'firmwareName' @_hash['firmware_from'] = 'firmwareFrom' @_hash['firmware_to'] = 'firmwareTo' @_hash['protocol'] = 'protocol' @_hash['make'] = 'make' @_hash['model'] = 'model' @_hash['start_date'] = 'startDate' @_hash['end_date'] = 'endDate' @_hash['campaign_time_window_list'] = 'campaignTimeWindowList' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
93 94 95 |
# File 'lib/verizon/models/firmware_campaign.rb', line 93 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
84 85 86 87 88 89 90 |
# File 'lib/verizon/models/firmware_campaign.rb', line 84 def self.optionals %w[ campaign_name firmware_name campaign_time_window_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/verizon/models/firmware_campaign.rb', line 187 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, account_name: #{@account_name.inspect}, campaign_name:"\ " #{@campaign_name.inspect}, firmware_name: #{@firmware_name.inspect}, firmware_from:"\ " #{@firmware_from.inspect}, firmware_to: #{@firmware_to.inspect}, protocol:"\ " #{@protocol.inspect}, make: #{@make.inspect}, model: #{@model.inspect}, start_date:"\ " #{@start_date.inspect}, end_date: #{@end_date.inspect}, campaign_time_window_list:"\ " #{@campaign_time_window_list.inspect}, status: #{@status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
176 177 178 179 180 181 182 183 184 |
# File 'lib/verizon/models/firmware_campaign.rb', line 176 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, account_name: #{@account_name}, campaign_name:"\ " #{@campaign_name}, firmware_name: #{@firmware_name}, firmware_from: #{@firmware_from},"\ " firmware_to: #{@firmware_to}, protocol: #{@protocol}, make: #{@make}, model: #{@model},"\ " start_date: #{@start_date}, end_date: #{@end_date}, campaign_time_window_list:"\ " #{@campaign_time_window_list}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |