Class: Verizon::FirmwareUpgradeChangeResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/firmware_upgrade_change_result.rb

Overview

Upgrade information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, id: SKIP, device_list: SKIP, additional_properties: nil) ⇒ FirmwareUpgradeChangeResult

Returns a new instance of FirmwareUpgradeChangeResult.



49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 49

def initialize(account_name: SKIP, id: SKIP, device_list: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name =  unless  == SKIP
  @id = id unless id == SKIP
  @device_list = device_list unless device_list == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

Account identifier in “##########-#####”.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 14

def 
  @account_name
end

#device_listArray[V1DeviceListItem]

A JSON object for each device that was included in the request, showing the device IMEI, the status of the addition or removal, and additional information about the status.

Returns:



24
25
26
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 24

def device_list
  @device_list
end

#idString

The unique identifier for this upgrade.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 18

def id
  @id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  # Parameter is an array, so we need to iterate through it
  device_list = nil
  unless hash['deviceList'].nil?
    device_list = []
    hash['deviceList'].each do |structure|
      device_list << (V1DeviceListItem.from_hash(structure) if structure)
    end
  end

  device_list = SKIP unless hash.key?('deviceList')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FirmwareUpgradeChangeResult.new(account_name: ,
                                  id: id,
                                  device_list: device_list,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['id'] = 'id'
  @_hash['device_list'] = 'deviceList'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 36

def self.optionals
  %w[
    account_name
    id
    device_list
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, id: #{@id.inspect}, device_list:"\
  " #{@device_list.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/verizon/models/firmware_upgrade_change_result.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, id: #{@id}, device_list: #{@device_list},"\
  " additional_properties: #{@additional_properties}>"
end