Class: Verizon::FirmwareUpgradeDeviceListItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::FirmwareUpgradeDeviceListItem
- Defined in:
- lib/verizon/models/firmware_upgrade_device_list_item.rb
Overview
A JSON object for each device that was included in the upgrade, showing the device IMEI, the status of the upgrade, and additional information about the status.
Instance Attribute Summary collapse
-
#device_id ⇒ String
Device IMEI.
-
#result_reason ⇒ String
Additional details about the status.
-
#status ⇒ String
The status of the upgrade for this device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id: SKIP, status: SKIP, result_reason: SKIP, additional_properties: nil) ⇒ FirmwareUpgradeDeviceListItem
constructor
A new instance of FirmwareUpgradeDeviceListItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id: SKIP, status: SKIP, result_reason: SKIP, additional_properties: nil) ⇒ FirmwareUpgradeDeviceListItem
Returns a new instance of FirmwareUpgradeDeviceListItem.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 50 def initialize(device_id: SKIP, status: SKIP, result_reason: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id unless device_id == SKIP @status = status unless status == SKIP @result_reason = result_reason unless result_reason == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_id ⇒ String
Device IMEI.
16 17 18 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 16 def device_id @device_id end |
#result_reason ⇒ String
Additional details about the status. Not included when status=‘Request Pending.’
25 26 27 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 25 def result_reason @result_reason end |
#status ⇒ String
The status of the upgrade for this device.
20 21 22 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 20 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = hash.key?('deviceId') ? hash['deviceId'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP result_reason = hash.key?('resultReason') ? hash['resultReason'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FirmwareUpgradeDeviceListItem.new(device_id: device_id, status: status, result_reason: result_reason, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['status'] = 'status' @_hash['result_reason'] = 'resultReason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 37 def self.optionals %w[ device_id status result_reason ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, status: #{@status.inspect},"\ " result_reason: #{@result_reason.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/verizon/models/firmware_upgrade_device_list_item.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, status: #{@status}, result_reason:"\ " #{@result_reason}, additional_properties: #{@additional_properties}>" end |