Class: Verizon::FirmwareV1Api

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/firmware_v1_api.rb

Overview

FirmwareV1Api

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#cancel_scheduled_firmware_upgrade(account_name, upgrade_id) ⇒ ApiResponse

Cancel a scheduled firmware upgrade. “##########-#####”. upgrade that you want to cancel.

Parameters:

  • account_name (String)

    Required parameter: Account identifier in

  • upgrade_id (String)

    Required parameter: The UUID of the scheduled

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/verizon/apis/firmware_v1_api.rb', line 135

def cancel_scheduled_firmware_upgrade(,
                                      upgrade_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/upgrades/{accountName}/upgrade/{upgradeId}',
                                 Server::SOFTWARE_MANAGEMENT_V1)
               .template_param(new_parameter(, key: 'accountName')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(upgrade_id, key: 'upgradeId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FotaV1SuccessResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV1ResultException))
    .execute
end

#list_available_firmware(account) ⇒ ApiResponse

Lists all device firmware images available for an account, based on the devices registered to that account. “##########-#####”.

Parameters:

  • account (String)

    Required parameter: Account identifier in

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/verizon/apis/firmware_v1_api.rb', line 14

def list_available_firmware()
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/firmware/{account}',
                                 Server::SOFTWARE_MANAGEMENT_V1)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Firmware.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV1ResultException))
    .execute
end

#list_firmware_upgrade_details(account_name, upgrade_id) ⇒ ApiResponse

Returns information about a specified upgrade, include the target date of the upgrade, the list of devices in the upgrade, and the status of the upgrade for each device. “##########-#####”. returned by POST /upgrades when the upgrade was scheduled.

Parameters:

  • account_name (String)

    Required parameter: Account identifier in

  • upgrade_id (String)

    Required parameter: The UUID of the upgrade,

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/apis/firmware_v1_api.rb', line 68

def list_firmware_upgrade_details(,
                                  upgrade_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/upgrades/{accountName}/upgrade/{upgradeId}',
                                 Server::SOFTWARE_MANAGEMENT_V1)
               .template_param(new_parameter(, key: 'accountName')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(upgrade_id, key: 'upgradeId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FirmwareUpgrade.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV1ResultException))
    .execute
end

#schedule_firmware_upgrade(body) ⇒ ApiResponse

Schedules a firmware upgrade for devices. firmware upgrade request.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/apis/firmware_v1_api.rb', line 39

def schedule_firmware_upgrade(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/upgrades',
                                 Server::SOFTWARE_MANAGEMENT_V1)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FirmwareUpgrade.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV1ResultException))
    .execute
end

#update_firmware_upgrade_devices(account_name, upgrade_id, body) ⇒ ApiResponse

Add or remove devices from a scheduled upgrade. “##########-#####”. returned by POST /upgrades when the upgrade was scheduled. devices to add or remove.

Parameters:

  • account_name (String)

    Required parameter: Account identifier in

  • upgrade_id (String)

    Required parameter: The UUID of the upgrade,

  • body (FirmwareUpgradeChangeRequest)

    Required parameter: List of

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/verizon/apis/firmware_v1_api.rb', line 100

def update_firmware_upgrade_devices(,
                                    upgrade_id,
                                    body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/upgrades/{accountName}/upgrade/{upgradeId}',
                                 Server::SOFTWARE_MANAGEMENT_V1)
               .template_param(new_parameter(, key: 'accountName')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(upgrade_id, key: 'upgradeId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FirmwareUpgradeChangeResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV1ResultException))
    .execute
end