Class: Verizon::FotaV3ResultException

Inherits:
APIException
  • Object
show all
Defined in:
lib/verizon/exceptions/fota_v3_result_exception.rb

Overview

Error response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ FotaV3ResultException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



23
24
25
26
27
# File 'lib/verizon/exceptions/fota_v3_result_exception.rb', line 23

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#error_codeString

Error code string.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/exceptions/fota_v3_result_exception.rb', line 14

def error_code
  @error_code
end

#error_messageString

Error message string.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/exceptions/fota_v3_result_exception.rb', line 18

def error_message
  @error_message
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



46
47
48
49
50
# File 'lib/verizon/exceptions/fota_v3_result_exception.rb', line 46

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code.inspect}, error_message:"\
  " #{@error_message.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



40
41
42
43
# File 'lib/verizon/exceptions/fota_v3_result_exception.rb', line 40

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code}, error_message: #{@error_message}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



32
33
34
35
36
37
# File 'lib/verizon/exceptions/fota_v3_result_exception.rb', line 32

def unbox(hash)
  return nil unless hash

  @error_code = hash.key?('errorCode') ? hash['errorCode'] : nil
  @error_message = hash.key?('errorMessage') ? hash['errorMessage'] : nil
end