Class: Verizon::GetAccountDeviceConsent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/get_account_device_consent.rb

Overview

GetAccountDeviceConsent Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_list: SKIP, account_name: SKIP, all_device_consent: SKIP, additional_properties: nil) ⇒ GetAccountDeviceConsent

Returns a new instance of GetAccountDeviceConsent.



48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/get_account_device_consent.rb', line 48

def initialize(device_list: SKIP, account_name: SKIP,
               all_device_consent: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_list = device_list unless device_list == SKIP
  @account_name =  unless  == SKIP
  @all_device_consent = all_device_consent unless all_device_consent == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

The numeric name of the account, including leading zeros.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/get_account_device_consent.rb', line 18

def 
  @account_name
end

If consent is set at the account level, this value will show the consent level.

Returns:

  • (Integer)


23
24
25
# File 'lib/verizon/models/get_account_device_consent.rb', line 23

def all_device_consent
  @all_device_consent
end

#device_listArray[Object]

An array of device identifiers

Returns:

  • (Array[Object])


14
15
16
# File 'lib/verizon/models/get_account_device_consent.rb', line 14

def device_list
  @device_list
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/verizon/models/get_account_device_consent.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  device_list = hash.key?('deviceList') ? hash['deviceList'] : SKIP
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  all_device_consent =
    hash.key?('allDeviceConsent') ? hash['allDeviceConsent'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetAccountDeviceConsent.new(device_list: device_list,
                              account_name: ,
                              all_device_consent: all_device_consent,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/verizon/models/get_account_device_consent.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_list'] = 'deviceList'
  @_hash['account_name'] = 'accountName'
  @_hash['all_device_consent'] = 'allDeviceConsent'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/get_account_device_consent.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/verizon/models/get_account_device_consent.rb', line 35

def self.optionals
  %w[
    device_list
    account_name
    all_device_consent
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/verizon/models/get_account_device_consent.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_list: #{@device_list.inspect}, account_name:"\
  " #{@account_name.inspect}, all_device_consent: #{@all_device_consent.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/verizon/models/get_account_device_consent.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_list: #{@device_list}, account_name: #{@account_name},"\
  " all_device_consent: #{@all_device_consent}, additional_properties:"\
  " #{@additional_properties}>"
end