Class: Verizon::GetNetworkConditionsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::GetNetworkConditionsRequest
- Defined in:
- lib/verizon/models/get_network_conditions_request.rb
Overview
Get network conditions.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#coordinates ⇒ Coordinates
Coordinates information.
-
#location_type ⇒ String
Type of location detail.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, location_type:, coordinates:) ⇒ GetNetworkConditionsRequest
constructor
A new instance of GetNetworkConditionsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, location_type:, coordinates:) ⇒ GetNetworkConditionsRequest
Returns a new instance of GetNetworkConditionsRequest.
43 44 45 46 47 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 43 def initialize(account_name:, location_type:, coordinates:) @account_name = account_name @location_type = location_type @coordinates = coordinates end |
Instance Attribute Details
#account_name ⇒ String
Account name.
14 15 16 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 14 def account_name @account_name end |
#coordinates ⇒ Coordinates
Coordinates information.
22 23 24 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 22 def coordinates @coordinates end |
#location_type ⇒ String
Type of location detail.
18 19 20 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 18 def location_type @location_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil location_type = hash.key?('locationType') ? hash['locationType'] : nil coordinates = Coordinates.from_hash(hash['coordinates']) if hash['coordinates'] # Create object from extracted values. GetNetworkConditionsRequest.new(account_name: account_name, location_type: location_type, coordinates: coordinates) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['location_type'] = 'locationType' @_hash['coordinates'] = 'coordinates' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, location_type:"\ " #{@location_type.inspect}, coordinates: #{@coordinates.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/verizon/models/get_network_conditions_request.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, location_type: #{@location_type},"\ " coordinates: #{@coordinates}>" end |