Class: Verizon::GioRequestResponse
- Defined in:
- lib/verizon/models/gio_request_response.rb
Overview
GioRequestResponse Model.
Instance Attribute Summary collapse
-
#request_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id: SKIP) ⇒ GioRequestResponse
constructor
A new instance of GioRequestResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id: SKIP) ⇒ GioRequestResponse
Returns a new instance of GioRequestResponse.
35 36 37 |
# File 'lib/verizon/models/gio_request_response.rb', line 35 def initialize(request_id: SKIP) @request_id = request_id unless request_id == SKIP end |
Instance Attribute Details
#request_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/gio_request_response.rb', line 14 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/gio_request_response.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('requestId') ? hash['requestId'] : SKIP # Create object from extracted values. GioRequestResponse.new(request_id: request_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/gio_request_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'requestId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/gio_request_response.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/gio_request_response.rb', line 24 def self.optionals %w[ request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/verizon/models/gio_request_response.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/verizon/models/gio_request_response.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}>" end |