Class: Verizon::GlobalReportingApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/global_reporting_api.rb

Overview

GlobalReportingApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#deviceprovhistory_using_post(body) ⇒ ApiResponse

Retrieve the provisioning history of a specific device or devices. Provisioning History

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/verizon/apis/global_reporting_api.rb', line 13

def deviceprovhistory_using_post(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v2/devices/history/actions/list',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(EsimRequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             EsimRestErrorResponseException)
                .local_error('401',
                             'Unauthorized',
                             EsimRestErrorResponseException)
                .local_error('403',
                             'Forbidden',
                             EsimRestErrorResponseException)
                .local_error('404',
                             'Not Found / Does not exist',
                             EsimRestErrorResponseException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             EsimRestErrorResponseException)
                .local_error('429',
                             'Too many requests',
                             EsimRestErrorResponseException)
                .local_error('default',
                             'Error response',
                             EsimRestErrorResponseException))
    .execute
end

#retrieve_global_list(body) ⇒ ApiResponse

Retrieve a list of all devices associated with an account.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/verizon/apis/global_reporting_api.rb', line 55

def retrieve_global_list(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v2/devices/actions/list',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(EsimRequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             EsimRestErrorResponseException)
                .local_error('401',
                             'Unauthorized',
                             EsimRestErrorResponseException)
                .local_error('403',
                             'Forbidden',
                             EsimRestErrorResponseException)
                .local_error('404',
                             'Not Found / Does not exist',
                             EsimRestErrorResponseException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             EsimRestErrorResponseException)
                .local_error('429',
                             'Too many requests',
                             EsimRestErrorResponseException)
                .local_error('default',
                             'Error response',
                             EsimRestErrorResponseException))
    .execute
end