Class: Verizon::Heading

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/heading.rb

Overview

Heading Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(min:, max:) ⇒ Heading

Returns a new instance of Heading.



38
39
40
41
# File 'lib/verizon/models/heading.rb', line 38

def initialize(min:, max:)
  @min = min
  @max = max
end

Instance Attribute Details

#maxFloat

The maximum value of heading in unit of degrees.

Returns:

  • (Float)


18
19
20
# File 'lib/verizon/models/heading.rb', line 18

def max
  @max
end

#minFloat

The minimum value of heading in unit of degrees.

Returns:

  • (Float)


14
15
16
# File 'lib/verizon/models/heading.rb', line 14

def min
  @min
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/verizon/models/heading.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  min = hash.key?('min') ? hash['min'] : nil
  max = hash.key?('max') ? hash['max'] : nil

  # Create object from extracted values.
  Heading.new(min: min,
              max: max)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/heading.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['min'] = 'min'
  @_hash['max'] = 'max'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/verizon/models/heading.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/verizon/models/heading.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Heading | Hash)

    value against the validation is performed.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/verizon/models/heading.rb', line 58

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.min,
                            ->(val) { val.instance_of? Float }) and
        APIHelper.valid_type?(value.max,
                              ->(val) { val.instance_of? Float })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['min'],
                          ->(val) { val.instance_of? Float }) and
      APIHelper.valid_type?(value['max'],
                            ->(val) { val.instance_of? Float })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
# File 'lib/verizon/models/heading.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} min: #{@min.inspect}, max: #{@max.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/verizon/models/heading.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} min: #{@min}, max: #{@max}>"
end