Class: Verizon::History
- Defined in:
- lib/verizon/models/history.rb
Overview
History data for a selected device and its attributes at a specific time.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The name of the billing account for which you want retrieve history data.
-
#attributes ⇒ HistoryAttributeValue
Streaming RF parameter for which you want to retrieve history data.
-
#device ⇒ Device
Identifies a particular IoT device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, device:, attributes: SKIP, additional_properties: nil) ⇒ History
constructor
A new instance of History.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, device:, attributes: SKIP, additional_properties: nil) ⇒ History
Returns a new instance of History.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/models/history.rb', line 46 def initialize(account_name:, device:, attributes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @device = device @attributes = attributes unless attributes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The name of the billing account for which you want retrieve history data. An account name is usually numeric, and must include any leading zeros.
15 16 17 |
# File 'lib/verizon/models/history.rb', line 15 def account_name @account_name end |
#attributes ⇒ HistoryAttributeValue
Streaming RF parameter for which you want to retrieve history data.
23 24 25 |
# File 'lib/verizon/models/history.rb', line 23 def attributes @attributes end |
#device ⇒ Device
Identifies a particular IoT device.
19 20 21 |
# File 'lib/verizon/models/history.rb', line 19 def device @device end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/history.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil device = Device.from_hash(hash['device']) if hash['device'] attributes = HistoryAttributeValue.from_hash(hash['attributes']) if hash['attributes'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. History.new(account_name: account_name, device: device, attributes: attributes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/history.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device'] = 'device' @_hash['attributes'] = 'attributes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/verizon/models/history.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 |
# File 'lib/verizon/models/history.rb', line 35 def self.optionals %w[ attributes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/verizon/models/history.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device: #{@device.inspect},"\ " attributes: #{@attributes.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/verizon/models/history.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device: #{@device}, attributes:"\ " #{@attributes}, additional_properties: #{@additional_properties}>" end |