Class: Verizon::HistoryAttributeValue

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/history_attribute_value.rb

Overview

Streaming RF parameter for which you want to retrieve history data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, value: SKIP, created_on: SKIP, additional_properties: nil) ⇒ HistoryAttributeValue

Returns a new instance of HistoryAttributeValue.



48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/history_attribute_value.rb', line 48

def initialize(name: SKIP, value: SKIP, created_on: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @value = value unless value == SKIP
  @created_on = created_on unless created_on == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#created_onDateTime

Date and time the request was created.

Returns:

  • (DateTime)


23
24
25
# File 'lib/verizon/models/history_attribute_value.rb', line 23

def created_on
  @created_on
end

#nameAttributeIdentifier

Attribute identifier.

Returns:



15
16
17
# File 'lib/verizon/models/history_attribute_value.rb', line 15

def name
  @name
end

#valueString

Attribute value.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/history_attribute_value.rb', line 19

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/verizon/models/history_attribute_value.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  value = hash.key?('value') ? hash['value'] : SKIP
  created_on = if hash.key?('createdOn')
                 (DateTimeHelper.from_rfc3339(hash['createdOn']) if hash['createdOn'])
               else
                 SKIP
               end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  HistoryAttributeValue.new(name: name,
                            value: value,
                            created_on: created_on,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/verizon/models/history_attribute_value.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['value'] = 'value'
  @_hash['created_on'] = 'createdOn'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/history_attribute_value.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/verizon/models/history_attribute_value.rb', line 35

def self.optionals
  %w[
    name
    value
    created_on
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/verizon/models/history_attribute_value.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, value: #{@value.inspect}, created_on:"\
  " #{@created_on.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_created_onObject



86
87
88
# File 'lib/verizon/models/history_attribute_value.rb', line 86

def to_custom_created_on
  DateTimeHelper.to_rfc3339(created_on)
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/verizon/models/history_attribute_value.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, value: #{@value}, created_on: #{@created_on},"\
  " additional_properties: #{@additional_properties}>"
end