Class: Verizon::HplBullseyeEnable
- Defined in:
- lib/verizon/models/hpl_bullseye_enable.rb
Overview
A flag that shows if Hyper Precise is enabled (true) or disabled (false).
Instance Attribute Summary collapse
-
#bullseye_enable ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bullseye_enable: SKIP, additional_properties: nil) ⇒ HplBullseyeEnable
constructor
A new instance of HplBullseyeEnable.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bullseye_enable: SKIP, additional_properties: nil) ⇒ HplBullseyeEnable
Returns a new instance of HplBullseyeEnable.
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 35 def initialize(bullseye_enable: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bullseye_enable = bullseye_enable unless bullseye_enable == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bullseye_enable ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 14 def bullseye_enable @bullseye_enable end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bullseye_enable = hash.key?('BullseyeEnable') ? hash['BullseyeEnable'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. HplBullseyeEnable.new(bullseye_enable: bullseye_enable, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['bullseye_enable'] = 'BullseyeEnable' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 24 def self.optionals %w[ bullseye_enable ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} bullseye_enable: #{@bullseye_enable.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/verizon/models/hpl_bullseye_enable.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} bullseye_enable: #{@bullseye_enable}, additional_properties:"\ " #{@additional_properties}>" end |