Class: Verizon::HplCustomFields
- Defined in:
- lib/verizon/models/hpl_custom_fields.rb
Overview
User assigned custom fields to use for fitering
Instance Attribute Summary collapse
-
#key ⇒ String
key property.
-
#value ⇒ String
value of the key property.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(key: SKIP, value: SKIP) ⇒ HplCustomFields
constructor
A new instance of HplCustomFields.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(key: SKIP, value: SKIP) ⇒ HplCustomFields
Returns a new instance of HplCustomFields.
41 42 43 44 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 41 def initialize(key: SKIP, value: SKIP) @key = key unless key == SKIP @value = value unless value == SKIP end |
Instance Attribute Details
#key ⇒ String
key property
14 15 16 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 14 def key @key end |
#value ⇒ String
value of the key property
18 19 20 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. key = hash.key?('key') ? hash['key'] : SKIP value = hash.key?('value') ? hash['value'] : SKIP # Create object from extracted values. HplCustomFields.new(key: key, value: value) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['key'] = 'key' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 29 def self.optionals %w[ key value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} key: #{@key.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/hpl_custom_fields.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} key: #{@key}, value: #{@value}>" end |