Class: Verizon::HyperPreciseLocationCallback

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/hyper_precise_location_callback.rb

Overview

Callback registration request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, url:, additional_properties: nil) ⇒ HyperPreciseLocationCallback

Returns a new instance of HyperPreciseLocationCallback.



42
43
44
45
46
47
48
49
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 42

def initialize(name:, url:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @url = url
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

The name of the callback service that you want to subscribe to.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 14

def name
  @name
end

#urlString

The address on your server where you have enabled a listening service for the specific type of callback messages. Specify a URL that is reachable from the Verizon data centers. If your service is running on HTTPS, you should use a one-way authentication certificate with a white-listed IP address.

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 22

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  url = hash.key?('url') ? hash['url'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  HyperPreciseLocationCallback.new(name: name,
                                   url: url,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, url: #{@url.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/verizon/models/hyper_precise_location_callback.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, url: #{@url}, additional_properties:"\
  " #{@additional_properties}>"
end