Class: Verizon::HyperPreciseLocationResultException

Inherits:
APIException
  • Object
show all
Defined in:
lib/verizon/exceptions/hyper_precise_location_result_exception.rb

Overview

Error response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ HyperPreciseLocationResultException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



27
28
29
30
31
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 27

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#faultHyperPreciseLocationFault

Fault occurred while responding.



22
23
24
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 22

def fault
  @fault
end

#messageString

Error message.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 18

def message
  @message
end

#response_codeErrorResponseCode

Error Code.

Returns:



14
15
16
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 14

def response_code
  @response_code
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



51
52
53
54
55
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 51

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} response_code: #{@response_code.inspect}, message: #{@message.inspect},"\
  " fault: #{@fault.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



45
46
47
48
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 45

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} response_code: #{@response_code}, message: #{@message}, fault: #{@fault}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



36
37
38
39
40
41
42
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 36

def unbox(hash)
  return nil unless hash

  @response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP
  @message = hash.key?('message') ? hash['message'] : SKIP
  @fault = HyperPreciseLocationFault.from_hash(hash['fault']) if hash['fault']
end