Class: Verizon::IpPool

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/ip_pool.rb

Overview

IP pool that is available to the account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(pool_name: SKIP, pool_type: SKIP, is_default_pool: SKIP, additional_properties: nil) ⇒ IpPool

Returns a new instance of IpPool.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/ip_pool.rb', line 47

def initialize(pool_name: SKIP, pool_type: SKIP, is_default_pool: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @pool_name = pool_name unless pool_name == SKIP
  @pool_type = pool_type unless pool_type == SKIP
  @is_default_pool = is_default_pool unless is_default_pool == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_default_poolTrueClass | FalseClass

True if this is the default IP pool for the account.

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/verizon/models/ip_pool.rb', line 22

def is_default_pool
  @is_default_pool
end

#pool_nameString

The name of the IP pool.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/ip_pool.rb', line 14

def pool_name
  @pool_name
end

#pool_typeString

The type of IP pool, such as “Static IP” or “Dynamic IP.”

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/ip_pool.rb', line 18

def pool_type
  @pool_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/verizon/models/ip_pool.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  pool_name = hash.key?('poolName') ? hash['poolName'] : SKIP
  pool_type = hash.key?('poolType') ? hash['poolType'] : SKIP
  is_default_pool =
    hash.key?('isDefaultPool') ? hash['isDefaultPool'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IpPool.new(pool_name: pool_name,
             pool_type: pool_type,
             is_default_pool: is_default_pool,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/ip_pool.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['pool_name'] = 'poolName'
  @_hash['pool_type'] = 'poolType'
  @_hash['is_default_pool'] = 'isDefaultPool'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/ip_pool.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/ip_pool.rb', line 34

def self.optionals
  %w[
    pool_name
    pool_type
    is_default_pool
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/verizon/models/ip_pool.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} pool_name: #{@pool_name.inspect}, pool_type: #{@pool_type.inspect},"\
  " is_default_pool: #{@is_default_pool.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/verizon/models/ip_pool.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} pool_name: #{@pool_name}, pool_type: #{@pool_type}, is_default_pool:"\
  " #{@is_default_pool}, additional_properties: #{@additional_properties}>"
end