Class: Verizon::LicenseDeviceId
- Defined in:
- lib/verizon/models/license_device_id.rb
Overview
Id of the devices.
Instance Attribute Summary collapse
-
#id ⇒ String
For 4G devices, IMEI (decimal, up to 15 digits) for unassign and ICCID (decimal, up to 20 digits) for assign.
-
#kind ⇒ String
For 4G devices, ICCID (decimal, up to 20 digits) for unassign and IMEI (decimal, up to 15 digits) for assign.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, kind: SKIP) ⇒ LicenseDeviceId
constructor
A new instance of LicenseDeviceId.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, kind: SKIP) ⇒ LicenseDeviceId
Returns a new instance of LicenseDeviceId.
43 44 45 46 |
# File 'lib/verizon/models/license_device_id.rb', line 43 def initialize(id: SKIP, kind: SKIP) @id = id unless id == SKIP @kind = kind unless kind == SKIP end |
Instance Attribute Details
#id ⇒ String
For 4G devices, IMEI (decimal, up to 15 digits) for unassign and ICCID (decimal, up to 20 digits) for assign.
15 16 17 |
# File 'lib/verizon/models/license_device_id.rb', line 15 def id @id end |
#kind ⇒ String
For 4G devices, ICCID (decimal, up to 20 digits) for unassign and IMEI (decimal, up to 15 digits) for assign.
20 21 22 |
# File 'lib/verizon/models/license_device_id.rb', line 20 def kind @kind end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/verizon/models/license_device_id.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP kind = hash.key?('kind') ? hash['kind'] : SKIP # Create object from extracted values. LicenseDeviceId.new(id: id, kind: kind) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/license_device_id.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['kind'] = 'kind' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/license_device_id.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/license_device_id.rb', line 31 def self.optionals %w[ id kind ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 |
# File 'lib/verizon/models/license_device_id.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, kind: #{@kind.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/verizon/models/license_device_id.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, kind: #{@kind}>" end |