Class: Verizon::ListOptimalServiceEndpointsResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::ListOptimalServiceEndpointsResult
- Defined in:
- lib/verizon/models/list_optimal_service_endpoints_result.rb
Overview
Response on successful retrieval of optimal service endpoints for clients.
Instance Attribute Summary collapse
-
#service_endpoints ⇒ Array[ResourcesEdgeHostedService]
An array of optimal Service Endpoint IDs for clients to connect to.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(service_endpoints: SKIP) ⇒ ListOptimalServiceEndpointsResult
constructor
A new instance of ListOptimalServiceEndpointsResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(service_endpoints: SKIP) ⇒ ListOptimalServiceEndpointsResult
Returns a new instance of ListOptimalServiceEndpointsResult.
35 36 37 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 35 def initialize(service_endpoints: SKIP) @service_endpoints = service_endpoints unless service_endpoints == SKIP end |
Instance Attribute Details
#service_endpoints ⇒ Array[ResourcesEdgeHostedService]
An array of optimal Service Endpoint IDs for clients to connect to.
14 15 16 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 14 def service_endpoints @service_endpoints end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it service_endpoints = nil unless hash['serviceEndpoints'].nil? service_endpoints = [] hash['serviceEndpoints'].each do |structure| service_endpoints << (ResourcesEdgeHostedService.from_hash(structure) if structure) end end service_endpoints = SKIP unless hash.key?('serviceEndpoints') # Create object from extracted values. ListOptimalServiceEndpointsResult.new(service_endpoints: service_endpoints) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['service_endpoints'] = 'serviceEndpoints' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 24 def self.optionals %w[ service_endpoints ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} service_endpoints: #{@service_endpoints.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/list_optimal_service_endpoints_result.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} service_endpoints: #{@service_endpoints}>" end |