Class: Verizon::ListServiceProfilesResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/list_service_profiles_result.rb

Overview

Response on successful retrieval of service profiles.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status: SKIP, data: SKIP) ⇒ ListServiceProfilesResult

Returns a new instance of ListServiceProfilesResult.



42
43
44
45
# File 'lib/verizon/models/list_service_profiles_result.rb', line 42

def initialize(status: SKIP, data: SKIP)
  @status = status unless status == SKIP
  @data = data unless data == SKIP
end

Instance Attribute Details

#dataArray[String]

A comma delimited list of all the service profiles registered under your API key.

Returns:

  • (Array[String])


19
20
21
# File 'lib/verizon/models/list_service_profiles_result.rb', line 19

def data
  @data
end

#statusString

HTTP status code.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/list_service_profiles_result.rb', line 14

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/list_service_profiles_result.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : SKIP
  data = hash.key?('data') ? hash['data'] : SKIP

  # Create object from extracted values.
  ListServiceProfilesResult.new(status: status,
                                data: data)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/list_service_profiles_result.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['data'] = 'data'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/list_service_profiles_result.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/verizon/models/list_service_profiles_result.rb', line 30

def self.optionals
  %w[
    status
    data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/verizon/models/list_service_profiles_result.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, data: #{@data.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/verizon/models/list_service_profiles_result.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, data: #{@data}>"
end