Class: Verizon::Location

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/location.rb

Overview

Device location information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(msid: SKIP, pd: SKIP, error: SKIP, additional_properties: nil) ⇒ Location

Returns a new instance of Location.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/location.rb', line 47

def initialize(msid: SKIP, pd: SKIP, error: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @msid = msid unless msid == SKIP
  @pd = pd unless pd == SKIP
  @error = error unless error == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#errorPositionError

Position error.

Returns:



22
23
24
# File 'lib/verizon/models/location.rb', line 22

def error
  @error
end

#msidString

MDN.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/location.rb', line 14

def msid
  @msid
end

#pdPositionData

Position data.

Returns:



18
19
20
# File 'lib/verizon/models/location.rb', line 18

def pd
  @pd
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/models/location.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  msid = hash.key?('msid') ? hash['msid'] : SKIP
  pd = PositionData.from_hash(hash['pd']) if hash['pd']
  error = PositionError.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Location.new(msid: msid,
               pd: pd,
               error: error,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/location.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['msid'] = 'msid'
  @_hash['pd'] = 'pd'
  @_hash['error'] = 'error'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/location.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/location.rb', line 34

def self.optionals
  %w[
    msid
    pd
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/verizon/models/location.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} msid: #{@msid.inspect}, pd: #{@pd.inspect}, error: #{@error.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/verizon/models/location.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} msid: #{@msid}, pd: #{@pd}, error: #{@error}, additional_properties:"\
  " #{@additional_properties}>"
end