Class: Verizon::Locations
- Defined in:
- lib/verizon/models/locations.rb
Overview
Location details.
Instance Attribute Summary collapse
-
#address_list ⇒ Array[AddressItem]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(address_list: SKIP) ⇒ Locations
constructor
A new instance of Locations.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address_list: SKIP) ⇒ Locations
Returns a new instance of Locations.
35 36 37 |
# File 'lib/verizon/models/locations.rb', line 35 def initialize(address_list: SKIP) @address_list = address_list unless address_list == SKIP end |
Instance Attribute Details
#address_list ⇒ Array[AddressItem]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/locations.rb', line 14 def address_list @address_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/locations.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it address_list = nil unless hash['addressList'].nil? address_list = [] hash['addressList'].each do |structure| address_list << (AddressItem.from_hash(structure) if structure) end end address_list = SKIP unless hash.key?('addressList') # Create object from extracted values. Locations.new(address_list: address_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/locations.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['address_list'] = 'addressList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/locations.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/locations.rb', line 24 def self.optionals %w[ address_list ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/verizon/models/locations.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/verizon/models/locations.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} address_list: #{@address_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/verizon/models/locations.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} address_list: #{@address_list}>" end |