Class: Verizon::Locationscoord

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/locationscoord.rb

Overview

Location coordinates.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(coordinates_list: SKIP) ⇒ Locationscoord

Returns a new instance of Locationscoord.



35
36
37
# File 'lib/verizon/models/locationscoord.rb', line 35

def initialize(coordinates_list: SKIP)
  @coordinates_list = coordinates_list unless coordinates_list == SKIP
end

Instance Attribute Details

#coordinates_listArray[Coordinates]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/locationscoord.rb', line 14

def coordinates_list
  @coordinates_list
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/locationscoord.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  coordinates_list = nil
  unless hash['coordinatesList'].nil?
    coordinates_list = []
    hash['coordinatesList'].each do |structure|
      coordinates_list << (Coordinates.from_hash(structure) if structure)
    end
  end

  coordinates_list = SKIP unless hash.key?('coordinatesList')

  # Create object from extracted values.
  Locationscoord.new(coordinates_list: coordinates_list)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/locationscoord.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['coordinates_list'] = 'coordinatesList'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/locationscoord.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/locationscoord.rb', line 24

def self.optionals
  %w[
    coordinates_list
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Locationscoord | Hash)

    value against the validation is performed.



61
62
63
64
65
66
67
# File 'lib/verizon/models/locationscoord.rb', line 61

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
# File 'lib/verizon/models/locationscoord.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} coordinates_list: #{@coordinates_list.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/verizon/models/locationscoord.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} coordinates_list: #{@coordinates_list}>"
end