Class: Verizon::M403ManagementErrorException

Inherits:
APIException
  • Object
show all
Defined in:
lib/verizon/exceptions/m403_management_error_exception.rb

Overview

403.management.Error class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ M403ManagementErrorException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



27
28
29
30
31
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 27

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#causeString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 22

def cause
  @cause
end

#errorString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 14

def error
  @error
end

#error_descriptionString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 18

def error_description
  @error_description
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



53
54
55
56
57
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 53

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error: #{@error.inspect}, error_description: #{@error_description.inspect},"\
  " cause: #{@cause.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



46
47
48
49
50
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 46

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error: #{@error}, error_description: #{@error_description}, cause:"\
  " #{@cause}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



36
37
38
39
40
41
42
43
# File 'lib/verizon/exceptions/m403_management_error_exception.rb', line 36

def unbox(hash)
  return nil unless hash

  @error = hash.key?('error') ? hash['error'] : SKIP
  @error_description =
    hash.key?('error_description') ? hash['error_description'] : SKIP
  @cause = hash.key?('cause') ? hash['cause'] : SKIP
end