Class: Verizon::M5GBideviceDetailsresponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/m_5g_bidevice_detailsresponse.rb

Overview

M5GBideviceDetailsresponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(has_more_data: SKIP, devices: SKIP, additional_properties: nil) ⇒ M5GBideviceDetailsresponse

Returns a new instance of M5GBideviceDetailsresponse.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 41

def initialize(has_more_data: SKIP, devices: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @has_more_data = has_more_data unless has_more_data == SKIP
  @devices = devices unless devices == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#devicesArray[M5GBiaccountNameobject]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 18

def devices
  @devices
end

#has_more_dataTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 14

def has_more_data
  @has_more_data
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (M5GBiaccountNameobject.from_hash(structure) if structure)
    end
  end

  devices = SKIP unless hash.key?('devices')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  M5GBideviceDetailsresponse.new(has_more_data: has_more_data,
                                 devices: devices,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['has_more_data'] = 'hasMoreData'
  @_hash['devices'] = 'devices'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 29

def self.optionals
  %w[
    has_more_data
    devices
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more_data: #{@has_more_data.inspect}, devices: #{@devices.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more_data: #{@has_more_data}, devices: #{@devices},"\
  " additional_properties: #{@additional_properties}>"
end