Class: Verizon::ManagedAccountCancelRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::ManagedAccountCancelRequest
- Defined in:
- lib/verizon/models/managed_account_cancel_request.rb
Overview
ManagedAccountCancelRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Managed account identifier.
-
#paccount_name ⇒ String
Primary Account identifier.
-
#service_name ⇒ ServiceName
Service name.
-
#txid ⇒ String
Transaction identifier returned by provision request.
-
#type ⇒ String
SKU name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, paccount_name:, service_name: ServiceName::LOCATION, type:, txid:, additional_properties: nil) ⇒ ManagedAccountCancelRequest
constructor
A new instance of ManagedAccountCancelRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, paccount_name:, service_name: ServiceName::LOCATION, type:, txid:, additional_properties: nil) ⇒ ManagedAccountCancelRequest
Returns a new instance of ManagedAccountCancelRequest.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 53 def initialize(account_name:, paccount_name:, service_name: ServiceName::LOCATION, type:, txid:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @paccount_name = paccount_name @service_name = service_name @type = type @txid = txid @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Managed account identifier
14 15 16 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 14 def account_name @account_name end |
#paccount_name ⇒ String
Primary Account identifier
18 19 20 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 18 def paccount_name @paccount_name end |
#service_name ⇒ ServiceName
Service name
22 23 24 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 22 def service_name @service_name end |
#txid ⇒ String
Transaction identifier returned by provision request
30 31 32 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 30 def txid @txid end |
#type ⇒ String
SKU name
26 27 28 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 26 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 68 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil paccount_name = hash.key?('paccountName') ? hash['paccountName'] : nil service_name = hash['serviceName'] ||= ServiceName::LOCATION type = hash.key?('type') ? hash['type'] : nil txid = hash.key?('txid') ? hash['txid'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ManagedAccountCancelRequest.new(account_name: account_name, paccount_name: paccount_name, service_name: service_name, type: type, txid: txid, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['paccount_name'] = 'paccountName' @_hash['service_name'] = 'serviceName' @_hash['type'] = 'type' @_hash['txid'] = 'txid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, paccount_name:"\ " #{@paccount_name.inspect}, service_name: #{@service_name.inspect}, type: #{@type.inspect},"\ " txid: #{@txid.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/verizon/models/managed_account_cancel_request.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, paccount_name: #{@paccount_name},"\ " service_name: #{@service_name}, type: #{@type}, txid: #{@txid}, additional_properties:"\ " #{@additional_properties}>" end |