Class: Verizon::ManagedAccountCancelResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/managed_account_cancel_response.rb

Overview

ManagedAccountCancelResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(txid:, account_name:, paccount_name:, service_name: ServiceName::LOCATION, status:, reason:, additional_properties: nil) ⇒ ManagedAccountCancelResponse

Returns a new instance of ManagedAccountCancelResponse.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 58

def initialize(txid:, account_name:, paccount_name:,
               service_name: ServiceName::LOCATION, status:, reason:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @txid = txid
  @account_name = 
  @paccount_name = paccount_name
  @service_name = service_name
  @status = status
  @reason = reason
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

Managed account identifier

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 18

def 
  @account_name
end

#paccount_nameString

Primary account identifier

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 22

def paccount_name
  @paccount_name
end

#reasonString

Detailed reason

Returns:

  • (String)


34
35
36
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 34

def reason
  @reason
end

#service_nameServiceName

Service name

Returns:



26
27
28
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 26

def service_name
  @service_name
end

#statusString

Deactivate/cancel status, Success or Fail

Returns:

  • (String)


30
31
32
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 30

def status
  @status
end

#txidString

Transaction identifier

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 14

def txid
  @txid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  txid = hash.key?('txid') ? hash['txid'] : nil
   = hash.key?('accountName') ? hash['accountName'] : nil
  paccount_name = hash.key?('paccountName') ? hash['paccountName'] : nil
  service_name = hash['serviceName'] ||= ServiceName::LOCATION
  status = hash.key?('status') ? hash['status'] : nil
  reason = hash.key?('reason') ? hash['reason'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ManagedAccountCancelResponse.new(txid: txid,
                                   account_name: ,
                                   paccount_name: paccount_name,
                                   service_name: service_name,
                                   status: status,
                                   reason: reason,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['txid'] = 'txid'
  @_hash['account_name'] = 'accountName'
  @_hash['paccount_name'] = 'paccountName'
  @_hash['service_name'] = 'serviceName'
  @_hash['status'] = 'status'
  @_hash['reason'] = 'reason'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 49

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
117
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} txid: #{@txid.inspect}, account_name: #{@account_name.inspect},"\
  " paccount_name: #{@paccount_name.inspect}, service_name: #{@service_name.inspect}, status:"\
  " #{@status.inspect}, reason: #{@reason.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/verizon/models/managed_account_cancel_response.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} txid: #{@txid}, account_name: #{@account_name}, paccount_name:"\
  " #{@paccount_name}, service_name: #{@service_name}, status: #{@status}, reason: #{@reason},"\
  " additional_properties: #{@additional_properties}>"
end