Class: Verizon::ManagedAccountsAddRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/managed_accounts_add_request.rb

Overview

ManagedAccountsAddRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name:, service_name: ServiceName::LOCATION, type:, managed_acc_list:, additional_properties: nil) ⇒ ManagedAccountsAddRequest

Returns a new instance of ManagedAccountsAddRequest.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 48

def initialize(account_name:, service_name: ServiceName::LOCATION, type:,
               managed_acc_list:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name = 
  @service_name = service_name
  @type = type
  @managed_acc_list = managed_acc_list
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

Account identifier

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 14

def 
  @account_name
end

#managed_acc_listArray[String]

managed account list

Returns:

  • (Array[String])


26
27
28
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 26

def managed_acc_list
  @managed_acc_list
end

#service_nameServiceName

Service name

Returns:



18
19
20
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 18

def service_name
  @service_name
end

#typeString

SKU name

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 22

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : nil
  service_name = hash['serviceName'] ||= ServiceName::LOCATION
  type = hash.key?('type') ? hash['type'] : nil
  managed_acc_list =
    hash.key?('managedAccList') ? hash['managedAccList'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ManagedAccountsAddRequest.new(account_name: ,
                                service_name: service_name,
                                type: type,
                                managed_acc_list: managed_acc_list,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['service_name'] = 'serviceName'
  @_hash['type'] = 'type'
  @_hash['managed_acc_list'] = 'managedAccList'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, service_name:"\
  " #{@service_name.inspect}, type: #{@type.inspect}, managed_acc_list:"\
  " #{@managed_acc_list.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, service_name: #{@service_name}, type:"\
  " #{@type}, managed_acc_list: #{@managed_acc_list}, additional_properties:"\
  " #{@additional_properties}>"
end