Class: Verizon::MecPlatformsAdditionalSupportInfo
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::MecPlatformsAdditionalSupportInfo
- Defined in:
- lib/verizon/models/mec_platforms_additional_support_info.rb
Overview
Additional service support information for the MEC platform.
Instance Attribute Summary collapse
-
#data ⇒ MecPlatformsAdditionalSupportInfoData
Data about additional service support information for the MEC platform.
-
#type ⇒ String
Type of additional service support information for the MEC platform.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(type: SKIP, data: SKIP) ⇒ MecPlatformsAdditionalSupportInfo
constructor
A new instance of MecPlatformsAdditionalSupportInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, data: SKIP) ⇒ MecPlatformsAdditionalSupportInfo
Returns a new instance of MecPlatformsAdditionalSupportInfo.
41 42 43 44 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 41 def initialize(type: SKIP, data: SKIP) @type = type unless type == SKIP @data = data unless data == SKIP end |
Instance Attribute Details
#data ⇒ MecPlatformsAdditionalSupportInfoData
Data about additional service support information for the MEC platform.
18 19 20 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 18 def data @data end |
#type ⇒ String
Type of additional service support information for the MEC platform.
14 15 16 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 14 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP data = MecPlatformsAdditionalSupportInfoData.from_hash(hash['data']) if hash['data'] # Create object from extracted values. MecPlatformsAdditionalSupportInfo.new(type: type, data: data) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['data'] = 'data' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 29 def self.optionals %w[ type data ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, data: #{@data.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/verizon/models/mec_platforms_additional_support_info.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, data: #{@data}>" end |