Class: Verizon::MessageBase

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/message_base.rb

Overview

MessageBase Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_private:, road_user_type:, trigger_conditions: SKIP, limits: SKIP, distribution_type: SKIP, distribution_schedule: SKIP, additional_properties: nil) ⇒ MessageBase

Returns a new instance of MessageBase.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/verizon/models/message_base.rb', line 71

def initialize(is_private:, road_user_type:, trigger_conditions: SKIP,
               limits: SKIP, distribution_type: SKIP,
               distribution_schedule: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_private = is_private
  @road_user_type = road_user_type
  @trigger_conditions = trigger_conditions unless trigger_conditions == SKIP
  @limits = limits unless limits == SKIP
  @distribution_type = distribution_type unless distribution_type == SKIP
  @distribution_schedule = distribution_schedule unless distribution_schedule == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#distribution_scheduleDistributionSchedule

The distribution schedule parameters for broadcast messages.



42
43
44
# File 'lib/verizon/models/message_base.rb', line 42

def distribution_schedule
  @distribution_schedule
end

#distribution_typeArray[DistributionTypes]

Type of the distribution.

Returns:



38
39
40
# File 'lib/verizon/models/message_base.rb', line 38

def distribution_type
  @distribution_type
end

#is_privateTrueClass | FalseClass

Defines whether the message is private or public. Private messages are published under the Vendor ID defined in the configuration and only visible to devices of selected vendors. Public messages are published under the Public vendor and are visible to all the users.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/verizon/models/message_base.rb', line 18

def is_private
  @is_private
end

#limitsArray[Object]

List of limitations. These limitations can be used for making the trigger condition more precise by defining speed and motion direction requirements to be met before the messages are sent out.

Returns:

  • (Array[Object])


34
35
36
# File 'lib/verizon/models/message_base.rb', line 34

def limits
  @limits
end

#road_user_typeArray[RoadUserTypes]

Type of the Road User.

Returns:



22
23
24
# File 'lib/verizon/models/message_base.rb', line 22

def road_user_type
  @road_user_type
end

#trigger_conditionsArray[TriggerCondition]

Trigger conditions that define on which road user action the message will be sent. If multiple Trigger Conditions are defined any of them will trigger the message.

Returns:



28
29
30
# File 'lib/verizon/models/message_base.rb', line 28

def trigger_conditions
  @trigger_conditions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/verizon/models/message_base.rb', line 87

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_private = hash.key?('isPrivate') ? hash['isPrivate'] : nil
  road_user_type = hash.key?('roadUserType') ? hash['roadUserType'] : nil
  trigger_conditions =
    hash.key?('triggerConditions') ? hash['triggerConditions'] : SKIP
  limits = hash.key?('limits') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:Limits), hash['limits']
  ) : SKIP
  distribution_type =
    hash.key?('distributionType') ? hash['distributionType'] : SKIP
  distribution_schedule = DistributionSchedule.from_hash(hash['distributionSchedule']) if
    hash['distributionSchedule']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MessageBase.new(is_private: is_private,
                  road_user_type: road_user_type,
                  trigger_conditions: trigger_conditions,
                  limits: limits,
                  distribution_type: distribution_type,
                  distribution_schedule: distribution_schedule,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
# File 'lib/verizon/models/message_base.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_private'] = 'isPrivate'
  @_hash['road_user_type'] = 'roadUserType'
  @_hash['trigger_conditions'] = 'triggerConditions'
  @_hash['limits'] = 'limits'
  @_hash['distribution_type'] = 'distributionType'
  @_hash['distribution_schedule'] = 'distributionSchedule'
  @_hash
end

.nullablesObject

An array for nullable fields



67
68
69
# File 'lib/verizon/models/message_base.rb', line 67

def self.nullables
  []
end

.optionalsObject

An array for optional fields



57
58
59
60
61
62
63
64
# File 'lib/verizon/models/message_base.rb', line 57

def self.optionals
  %w[
    trigger_conditions
    limits
    distribution_type
    distribution_schedule
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (MessageBase | Hash)

    value against the validation is performed.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/verizon/models/message_base.rb', line 122

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.is_private,
                            ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
        APIHelper.valid_type?(value.road_user_type,
                              ->(val) { RoadUserTypes.validate(val) })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['isPrivate'],
                          ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
      APIHelper.valid_type?(value['roadUserType'],
                            ->(val) { RoadUserTypes.validate(val) })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



152
153
154
155
156
157
158
159
# File 'lib/verizon/models/message_base.rb', line 152

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_private: #{@is_private.inspect}, road_user_type:"\
  " #{@road_user_type.inspect}, trigger_conditions: #{@trigger_conditions.inspect}, limits:"\
  " #{@limits.inspect}, distribution_type: #{@distribution_type.inspect},"\
  " distribution_schedule: #{@distribution_schedule.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



143
144
145
146
147
148
149
# File 'lib/verizon/models/message_base.rb', line 143

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_private: #{@is_private}, road_user_type: #{@road_user_type},"\
  " trigger_conditions: #{@trigger_conditions}, limits: #{@limits}, distribution_type:"\
  " #{@distribution_type}, distribution_schedule: #{@distribution_schedule},"\
  " additional_properties: #{@additional_properties}>"
end