Class: Verizon::MsgId

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/msg_id.rb

Overview

MsgId Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(further_info_id:, additional_properties: nil) ⇒ MsgId

Returns a new instance of MsgId.



35
36
37
38
39
40
41
# File 'lib/verizon/models/msg_id.rb', line 35

def initialize(further_info_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @further_info_id = further_info_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#further_info_idString

Links to ATIS message. A link to any other incident information data that may be available in the normal ATIS incident description or other messages.

Returns:

  • (String)


16
17
18
# File 'lib/verizon/models/msg_id.rb', line 16

def further_info_id
  @further_info_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/verizon/models/msg_id.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  further_info_id = hash.key?('furtherInfoID') ? hash['furtherInfoID'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MsgId.new(further_info_id: further_info_id,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/verizon/models/msg_id.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['further_info_id'] = 'furtherInfoID'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/msg_id.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
# File 'lib/verizon/models/msg_id.rb', line 26

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (MsgId | Hash)

    value against the validation is performed.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/verizon/models/msg_id.rb', line 64

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.further_info_id,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['furtherInfoID'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/verizon/models/msg_id.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} further_info_id: #{@further_info_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/verizon/models/msg_id.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} further_info_id: #{@further_info_id}, additional_properties:"\
  " #{@additional_properties}>"
end