Class: Verizon::MsgId1
- Defined in:
- lib/verizon/models/msg_id1.rb
Overview
MsgId1 Model.
Instance Attribute Summary collapse
-
#road_sign_id ⇒ RoadSignId
It provide a precise location of one or more roadside signs.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(road_sign_id:, additional_properties: nil) ⇒ MsgId1
constructor
A new instance of MsgId1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(road_sign_id:, additional_properties: nil) ⇒ MsgId1
Returns a new instance of MsgId1.
33 34 35 36 37 38 39 |
# File 'lib/verizon/models/msg_id1.rb', line 33 def initialize(road_sign_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @road_sign_id = road_sign_id @additional_properties = additional_properties end |
Instance Attribute Details
#road_sign_id ⇒ RoadSignId
It provide a precise location of one or more roadside signs.
14 15 16 |
# File 'lib/verizon/models/msg_id1.rb', line 14 def road_sign_id @road_sign_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/msg_id1.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. road_sign_id = RoadSignId.from_hash(hash['roadSignID']) if hash['roadSignID'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MsgId1.new(road_sign_id: road_sign_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/msg_id1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['road_sign_id'] = 'roadSignID' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/msg_id1.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/msg_id1.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/verizon/models/msg_id1.rb', line 62 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.road_sign_id, ->(val) { RoadSignId.validate(val) }, is_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['roadSignID'], ->(val) { RoadSignId.validate(val) }, is_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/verizon/models/msg_id1.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} road_sign_id: #{@road_sign_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/verizon/models/msg_id1.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} road_sign_id: #{@road_sign_id}, additional_properties:"\ " #{@additional_properties}>" end |