Class: Verizon::MultiPolygon

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/multi_polygon.rb

Overview

A MultiPolygon is a type of geometry that represents a collection of Polygon geometries.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type:, coordinates:, additional_properties: nil) ⇒ MultiPolygon

Returns a new instance of MultiPolygon.



39
40
41
42
43
44
45
46
# File 'lib/verizon/models/multi_polygon.rb', line 39

def initialize(type:, coordinates:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type
  @coordinates = coordinates
  @additional_properties = additional_properties
end

Instance Attribute Details

#coordinatesArray[Float]

TODO: Write general description for this method

Returns:

  • (Array[Float])


19
20
21
# File 'lib/verizon/models/multi_polygon.rb', line 19

def coordinates
  @coordinates
end

#typeMultiPolygonType

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/verizon/models/multi_polygon.rb', line 15

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/verizon/models/multi_polygon.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : nil
  coordinates = hash.key?('coordinates') ? hash['coordinates'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MultiPolygon.new(type: type,
                   coordinates: coordinates,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/multi_polygon.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['coordinates'] = 'coordinates'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/verizon/models/multi_polygon.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/verizon/models/multi_polygon.rb', line 30

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (MultiPolygon | Hash)

    value against the validation is performed.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/verizon/models/multi_polygon.rb', line 71

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.type,
                            ->(val) { MultiPolygonType.validate(val) }) and
        APIHelper.valid_type?(value.coordinates,
                              ->(val) { val.instance_of? Float })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['type'],
                          ->(val) { MultiPolygonType.validate(val) }) and
      APIHelper.valid_type?(value['coordinates'],
                            ->(val) { val.instance_of? Float })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/verizon/models/multi_polygon.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, coordinates: #{@coordinates.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/verizon/models/multi_polygon.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, coordinates: #{@coordinates}, additional_properties:"\
  " #{@additional_properties}>"
end