Class: Verizon::NodeListLl

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/node_list_ll.rb

Overview

The NodeListLL data structure provides the sequence of signed offset node point values for determining the latitude and longitude. Each LL point is referred to as a node point.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(nodes:) ⇒ NodeListLl

Returns a new instance of NodeListLl.



36
37
38
# File 'lib/verizon/models/node_list_ll.rb', line 36

def initialize(nodes:)
  @nodes = nodes
end

Instance Attribute Details

#nodesArray[NodeLl]

The NodeSetLL data frame consists of a list of NodeLL entries using LL offsets.

Returns:



17
18
19
# File 'lib/verizon/models/node_list_ll.rb', line 17

def nodes
  @nodes
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/node_list_ll.rb', line 41

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  nodes = nil
  unless hash['nodes'].nil?
    nodes = []
    hash['nodes'].each do |structure|
      nodes << (NodeLl.from_hash(structure) if structure)
    end
  end

  nodes = nil unless hash.key?('nodes')

  # Create object from extracted values.
  NodeListLl.new(nodes: nodes)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/verizon/models/node_list_ll.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['nodes'] = 'nodes'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/verizon/models/node_list_ll.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/verizon/models/node_list_ll.rb', line 27

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (NodeListLl | Hash)

    value against the validation is performed.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/verizon/models/node_list_ll.rb', line 62

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.nodes,
                                 ->(val) { NodeLl.validate(val) },
                                 is_model_hash: true,
                                 is_inner_model_hash: true)
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['nodes'],
                        ->(val) { NodeLl.validate(val) },
                        is_model_hash: true,
                        is_inner_model_hash: true)
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
# File 'lib/verizon/models/node_list_ll.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} nodes: #{@nodes.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/verizon/models/node_list_ll.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} nodes: #{@nodes}>"
end