Class: Verizon::NodeOffsetPointLl

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/node_offset_point_ll.rb

Overview

The NodeOffsetPointLL data frame presents a structure to hold 64 bits sized data frames for a single node geometry path. Nodes are described in terms of latitude and longitude.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(node_lat_lon:) ⇒ NodeOffsetPointLl

Returns a new instance of NodeOffsetPointLl.



36
37
38
# File 'lib/verizon/models/node_offset_point_ll.rb', line 36

def initialize(node_lat_lon:)
  @node_lat_lon = node_lat_lon
end

Instance Attribute Details

#node_lat_lonNodeLLmD64B

A 64-bit node type with lat-long values expressed in standard SAE 1/10th of a microdegree.

Returns:



17
18
19
# File 'lib/verizon/models/node_offset_point_ll.rb', line 17

def node_lat_lon
  @node_lat_lon
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/node_offset_point_ll.rb', line 41

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  node_lat_lon = NodeLLmD64B.from_hash(hash['nodeLatLon']) if hash['nodeLatLon']

  # Create object from extracted values.
  NodeOffsetPointLl.new(node_lat_lon: node_lat_lon)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/verizon/models/node_offset_point_ll.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['node_lat_lon'] = 'nodeLatLon'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/verizon/models/node_offset_point_ll.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/verizon/models/node_offset_point_ll.rb', line 27

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/verizon/models/node_offset_point_ll.rb', line 53

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.node_lat_lon,
                                 ->(val) { NodeLLmD64B.validate(val) },
                                 is_model_hash: true)
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['nodeLatLon'],
                        ->(val) { NodeLLmD64B.validate(val) },
                        is_model_hash: true)
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



74
75
76
77
# File 'lib/verizon/models/node_offset_point_ll.rb', line 74

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} node_lat_lon: #{@node_lat_lon.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



68
69
70
71
# File 'lib/verizon/models/node_offset_point_ll.rb', line 68

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} node_lat_lon: #{@node_lat_lon}>"
end