Class: Verizon::PerformanceMetricsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/performance_metrics_api.rb

Overview

PerformanceMetricsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#query_mec_performance_metrics(body: nil) ⇒ ApiResponse

Query the most recent data for Key Performance Indicators (KPIs) like network availability, MEC hostnames and more. type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/verizon/apis/performance_metrics_api.rb', line 14

def query_mec_performance_metrics(body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/performance/device/network/metrics',
                                 Server::PERFORMANCE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(MecPerformanceMetrics.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request.',
                             EdgePerformanceResultException)
                .local_error('401',
                             'Unauthorized request.',
                             EdgePerformanceResultException)
                .local_error('403',
                             'Request forbidden.',
                             EdgePerformanceResultException)
                .local_error('404',
                             'Resource Not Found.',
                             EdgePerformanceResultException)
                .local_error('405',
                             'Method Not Allowed.',
                             EdgePerformanceResultException)
                .local_error('503',
                             'Service Unavailable.',
                             EdgePerformanceResultException))
    .execute
end