Class: Verizon::PositionError

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/position_error.rb

Overview

Position error.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(time: SKIP, utcoffset: SKIP, type: SKIP, info: SKIP, additional_properties: nil) ⇒ PositionError

Returns a new instance of PositionError.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/verizon/models/position_error.rb', line 53

def initialize(time: SKIP, utcoffset: SKIP, type: SKIP, info: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @time = time unless time == SKIP
  @utcoffset = utcoffset unless utcoffset == SKIP
  @type = type unless type == SKIP
  @info = info unless info == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#infoString

Additional information about the error.

Returns:

  • (String)


26
27
28
# File 'lib/verizon/models/position_error.rb', line 26

def info
  @info
end

#timeString

Time location obtained.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/position_error.rb', line 14

def time
  @time
end

#typeString

Error type returned from location server.

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/position_error.rb', line 22

def type
  @type
end

#utcoffsetString

UTC offset of time.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/position_error.rb', line 18

def utcoffset
  @utcoffset
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/verizon/models/position_error.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  time = hash.key?('time') ? hash['time'] : SKIP
  utcoffset = hash.key?('utcoffset') ? hash['utcoffset'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP
  info = hash.key?('info') ? hash['info'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PositionError.new(time: time,
                    utcoffset: utcoffset,
                    type: type,
                    info: info,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/verizon/models/position_error.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['time'] = 'time'
  @_hash['utcoffset'] = 'utcoffset'
  @_hash['type'] = 'type'
  @_hash['info'] = 'info'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/verizon/models/position_error.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/verizon/models/position_error.rb', line 39

def self.optionals
  %w[
    time
    utcoffset
    type
    info
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/verizon/models/position_error.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} time: #{@time.inspect}, utcoffset: #{@utcoffset.inspect}, type:"\
  " #{@type.inspect}, info: #{@info.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/verizon/models/position_error.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} time: #{@time}, utcoffset: #{@utcoffset}, type: #{@type}, info: #{@info},"\
  " additional_properties: #{@additional_properties}>"
end