Class: Verizon::ProfileChangeStateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/profile_change_state_request.rb

Overview

ProfileChangeStateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(devices:, account_name:, smsr_oid:, additional_properties: nil) ⇒ ProfileChangeStateRequest

Returns a new instance of ProfileChangeStateRequest.



43
44
45
46
47
48
49
50
51
52
# File 'lib/verizon/models/profile_change_state_request.rb', line 43

def initialize(devices:, account_name:, smsr_oid:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @devices = devices
  @account_name = 
  @smsr_oid = smsr_oid
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/profile_change_state_request.rb', line 18

def 
  @account_name
end

#devicesArray[DeviceList]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/profile_change_state_request.rb', line 14

def devices
  @devices
end

#smsr_oidString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/profile_change_state_request.rb', line 22

def smsr_oid
  @smsr_oid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/verizon/models/profile_change_state_request.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (DeviceList.from_hash(structure) if structure)
    end
  end

  devices = nil unless hash.key?('devices')
   = hash.key?('accountName') ? hash['accountName'] : nil
  smsr_oid = hash.key?('smsrOid') ? hash['smsrOid'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProfileChangeStateRequest.new(devices: devices,
                                account_name: ,
                                smsr_oid: smsr_oid,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/profile_change_state_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['devices'] = 'devices'
  @_hash['account_name'] = 'accountName'
  @_hash['smsr_oid'] = 'smsrOid'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/verizon/models/profile_change_state_request.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/verizon/models/profile_change_state_request.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/verizon/models/profile_change_state_request.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices.inspect}, account_name: #{@account_name.inspect},"\
  " smsr_oid: #{@smsr_oid.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/verizon/models/profile_change_state_request.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices}, account_name: #{@account_name}, smsr_oid:"\
  " #{@smsr_oid}, additional_properties: #{@additional_properties}>"
end