Class: Verizon::PromoAlert1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/promo_alert1.rb

Overview

PromoAlert1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(filter_criteria: SKIP, condition: SKIP, enable_promo_exp: SKIP, additional_properties: nil) ⇒ PromoAlert1

Returns a new instance of PromoAlert1.



47
48
49
50
51
52
53
54
55
56
# File 'lib/verizon/models/promo_alert1.rb', line 47

def initialize(filter_criteria: SKIP, condition: SKIP,
               enable_promo_exp: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @filter_criteria = filter_criteria unless filter_criteria == SKIP
  @condition = condition unless condition == SKIP
  @enable_promo_exp = enable_promo_exp unless enable_promo_exp == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#conditionArray[Keyschunk2]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/promo_alert1.rb', line 18

def condition
  @condition
end

#enable_promo_expTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/verizon/models/promo_alert1.rb', line 22

def enable_promo_exp
  @enable_promo_exp
end

#filter_criteriaArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


14
15
16
# File 'lib/verizon/models/promo_alert1.rb', line 14

def filter_criteria
  @filter_criteria
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/models/promo_alert1.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  filter_criteria =
    hash.key?('filterCriteria') ? hash['filterCriteria'] : SKIP
  # Parameter is an array, so we need to iterate through it
  condition = nil
  unless hash['condition'].nil?
    condition = []
    hash['condition'].each do |structure|
      condition << (Keyschunk2.from_hash(structure) if structure)
    end
  end

  condition = SKIP unless hash.key?('condition')
  enable_promo_exp =
    hash.key?('enablePromoExp') ? hash['enablePromoExp'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PromoAlert1.new(filter_criteria: filter_criteria,
                  condition: condition,
                  enable_promo_exp: enable_promo_exp,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/promo_alert1.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['filter_criteria'] = 'filterCriteria'
  @_hash['condition'] = 'condition'
  @_hash['enable_promo_exp'] = 'enablePromoExp'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/promo_alert1.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/promo_alert1.rb', line 34

def self.optionals
  %w[
    filter_criteria
    condition
    enable_promo_exp
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
105
# File 'lib/verizon/models/promo_alert1.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} filter_criteria: #{@filter_criteria.inspect}, condition:"\
  " #{@condition.inspect}, enable_promo_exp: #{@enable_promo_exp.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/verizon/models/promo_alert1.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} filter_criteria: #{@filter_criteria}, condition: #{@condition},"\
  " enable_promo_exp: #{@enable_promo_exp}, additional_properties: #{@additional_properties}>"
end