Class: Verizon::PromotionPeriodInformationApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/promotion_period_information_api.rb

Overview

PromotionPeriodInformationApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#get_promo_device_aggregate_usage_history(body) ⇒ ApiResponse

Retrieves the aggregate usage for an account using pseudo-MDN during the promotional period using a callback. Usage

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/apis/promotion_period_information_api.rb', line 39

def get_promo_device_aggregate_usage_history(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/usage/actions/promoaggregateusage',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(UsageRequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             ReadySimRestErrorResponseException))
    .execute
end

#get_promo_device_usage_history(body) ⇒ ApiResponse

Retrieves the usage history of a device during the promotion period. Usage

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/verizon/apis/promotion_period_information_api.rb', line 13

def get_promo_device_usage_history(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/usage/actions/promodeviceusage',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ResponseToUsageQuery.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'All error responses will be in this format',
                             ReadySimRestErrorResponseException))
    .execute
end