Class: Verizon::PwnApi

Inherits:
BaseApi show all
Defined in:
lib/verizon/apis/pwn_api.rb

Overview

PwnApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#change_pwn_device_ipaddress(body) ⇒ ApiResponse

TODO: type endpoint description here type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/verizon/apis/pwn_api.rb', line 119

def change_pwn_device_ipaddress(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/m2m/v1/devices/pwn/actions/ipaddress',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ChangePwnDeviceIpaddressResponse.method(:from_hash))
                .is_api_response(true))
    .execute
end

#change_pwn_device_profile(body) ⇒ ApiResponse

TODO: type endpoint description here description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/verizon/apis/pwn_api.rb', line 97

def change_pwn_device_profile(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/pwn/actions/profile',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ChangePwnDeviceProfileResponse.method(:from_hash))
                .is_api_response(true))
    .execute
end

#change_pwn_device_state_activate(body) ⇒ ApiResponse

TODO: type endpoint description here TODO: type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/verizon/apis/pwn_api.rb', line 53

def change_pwn_device_state_activate(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/pwn/actions/state/activate',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ChangePwnDeviceStateResponse.method(:from_hash))
                .is_api_response(true))
    .execute
end

#change_pwn_device_state_deactivate(body) ⇒ ApiResponse

TODO: type endpoint description here TODO: type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/verizon/apis/pwn_api.rb', line 75

def change_pwn_device_state_deactivate(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/pwn/actions/state/deactivate',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ChangePwnDeviceStateResponse.method(:from_hash))
                .is_api_response(true))
    .execute
end

#get_profile_list(aname) ⇒ ApiResponse

TODO: type endpoint description here

Parameters:

  • aname (String)

    Required parameter: Account name.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/verizon/apis/pwn_api.rb', line 32

def get_profile_list(aname)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/devices/pwn/profiles/list/{aname}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(PwnProfileList.method(:from_hash))
                .is_api_response(true))
    .execute
end

TODO: type endpoint description here

Parameters:

  • aname (String)

    Required parameter: Account name.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/verizon/apis/pwn_api.rb', line 140

def get_pwn_performance_consent(aname)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/devices/pwn/performance/consent/{aname}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetPwnPerformanceConsentResponse.method(:from_hash))
                .is_api_response(true))
    .execute
end

#kpi_list(aname) ⇒ ApiResponse

TODO: type endpoint description here

Parameters:

  • aname (String)

    Required parameter: Account name.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
# File 'lib/verizon/apis/pwn_api.rb', line 12

def kpi_list(aname)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/devices/pwn/kpi/list/{aname}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(KpiInfoList.method(:from_hash))
                .is_api_response(true))
    .execute
end