Class: Verizon::PwnDeviceList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/pwn_device_list.rb

Overview

PwnDeviceList Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids:, additional_properties: nil) ⇒ PwnDeviceList

Returns a new instance of PwnDeviceList.



33
34
35
36
37
38
39
# File 'lib/verizon/models/pwn_device_list.rb', line 33

def initialize(device_ids:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_ids = device_ids
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_idsArray[PwnDeviceId]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/pwn_device_list.rb', line 14

def device_ids
  @device_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/verizon/models/pwn_device_list.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (PwnDeviceId.from_hash(structure) if structure)
    end
  end

  device_ids = nil unless hash.key?('deviceIds')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PwnDeviceList.new(device_ids: device_ids,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/pwn_device_list.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'deviceIds'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/verizon/models/pwn_device_list.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/verizon/models/pwn_device_list.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/verizon/models/pwn_device_list.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/verizon/models/pwn_device_list.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, additional_properties:"\
  " #{@additional_properties}>"
end