Class: Verizon::QosDeviceInfo
- Defined in:
- lib/verizon/models/qos_device_info.rb
Overview
QosDeviceInfo Model.
Instance Attribute Summary collapse
-
#device_i_pv6_addr ⇒ String
TODO: Write general description for this method.
-
#device_id ⇒ QosDeviceId
TODO: Write general description for this method.
-
#flow_info ⇒ Array[FlowInfo]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id:, flow_info:, device_i_pv6_addr: SKIP, additional_properties: nil) ⇒ QosDeviceInfo
constructor
A new instance of QosDeviceInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id:, flow_info:, device_i_pv6_addr: SKIP, additional_properties: nil) ⇒ QosDeviceInfo
Returns a new instance of QosDeviceInfo.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/qos_device_info.rb', line 45 def initialize(device_id:, flow_info:, device_i_pv6_addr: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id @device_i_pv6_addr = device_i_pv6_addr unless device_i_pv6_addr == SKIP @flow_info = flow_info @additional_properties = additional_properties end |
Instance Attribute Details
#device_i_pv6_addr ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/qos_device_info.rb', line 18 def device_i_pv6_addr @device_i_pv6_addr end |
#device_id ⇒ QosDeviceId
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/qos_device_info.rb', line 14 def device_id @device_id end |
#flow_info ⇒ Array[FlowInfo]
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/qos_device_info.rb', line 22 def flow_info @flow_info end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/verizon/models/qos_device_info.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = QosDeviceId.from_hash(hash['deviceId']) if hash['deviceId'] # Parameter is an array, so we need to iterate through it flow_info = nil unless hash['flowInfo'].nil? flow_info = [] hash['flowInfo'].each do |structure| flow_info << (FlowInfo.from_hash(structure) if structure) end end flow_info = nil unless hash.key?('flowInfo') device_i_pv6_addr = hash.key?('deviceIPv6Addr') ? hash['deviceIPv6Addr'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. QosDeviceInfo.new(device_id: device_id, flow_info: flow_info, device_i_pv6_addr: device_i_pv6_addr, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/qos_device_info.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['device_i_pv6_addr'] = 'deviceIPv6Addr' @_hash['flow_info'] = 'flowInfo' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/verizon/models/qos_device_info.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/verizon/models/qos_device_info.rb', line 34 def self.optionals %w[ device_i_pv6_addr ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/verizon/models/qos_device_info.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, device_i_pv6_addr:"\ " #{@device_i_pv6_addr.inspect}, flow_info: #{@flow_info.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/verizon/models/qos_device_info.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, device_i_pv6_addr: #{@device_i_pv6_addr},"\ " flow_info: #{@flow_info}, additional_properties: #{@additional_properties}>" end |