Class: Verizon::QueryMecPerformanceMetricsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::QueryMecPerformanceMetricsRequest
- Defined in:
- lib/verizon/models/query_mec_performance_metrics_request.rb
Overview
MEC performance metrics request.
Instance Attribute Summary collapse
-
#imei ⇒ String
The 15-digit International Mobile Equipment Identifier.
-
#msisdn ⇒ String
The 12-digit Mobile Station International Subscriber Directory Number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imei:, msisdn:, additional_properties: nil) ⇒ QueryMecPerformanceMetricsRequest
constructor
A new instance of QueryMecPerformanceMetricsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imei:, msisdn:, additional_properties: nil) ⇒ QueryMecPerformanceMetricsRequest
Returns a new instance of QueryMecPerformanceMetricsRequest.
38 39 40 41 42 43 44 45 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 38 def initialize(imei:, msisdn:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @imei = imei @msisdn = msisdn @additional_properties = additional_properties end |
Instance Attribute Details
#imei ⇒ String
The 15-digit International Mobile Equipment Identifier.
14 15 16 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 14 def imei @imei end |
#msisdn ⇒ String
The 12-digit Mobile Station International Subscriber Directory Number.
18 19 20 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 18 def msisdn @msisdn end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imei = hash.key?('IMEI') ? hash['IMEI'] : nil msisdn = hash.key?('MSISDN') ? hash['MSISDN'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. QueryMecPerformanceMetricsRequest.new(imei: imei, msisdn: msisdn, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['imei'] = 'IMEI' @_hash['msisdn'] = 'MSISDN' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei.inspect}, msisdn: #{@msisdn.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/verizon/models/query_mec_performance_metrics_request.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei}, msisdn: #{@msisdn}, additional_properties:"\ " #{@additional_properties}>" end |