Class: Verizon::QuerySubscriptionRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/query_subscription_request.rb

Overview

Fields and values to match.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountidentifier: SKIP, m_selection: SKIP, resourceidentifier: SKIP, additional_properties: nil) ⇒ QuerySubscriptionRequest

Returns a new instance of QuerySubscriptionRequest.



53
54
55
56
57
58
59
60
61
62
# File 'lib/verizon/models/query_subscription_request.rb', line 53

def initialize(accountidentifier: SKIP, m_selection: SKIP,
               resourceidentifier: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accountidentifier = accountidentifier unless accountidentifier == SKIP
  @m_selection = m_selection unless m_selection == SKIP
  @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountidentifierAccountIdentifier

The ID of the authenticating billing account, in the format ‘“billingaccountid”:“1234567890-12345”`.

Returns:



15
16
17
# File 'lib/verizon/models/query_subscription_request.rb', line 15

def accountidentifier
  @accountidentifier
end

#m_selectionHash[String, String]

A comma-separated list of properties and comparator values to match against subscriptions in the ThingSpace account. See Working with Query Filters for more information. If the request does not include ‘$selection`, the response will include all subscriptions to which the requesting user has access.

Returns:

  • (Hash[String, String])


23
24
25
# File 'lib/verizon/models/query_subscription_request.rb', line 23

def m_selection
  @m_selection
end

#resourceidentifierResourceIdentifier

The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.

Returns:



28
29
30
# File 'lib/verizon/models/query_subscription_request.rb', line 28

def resourceidentifier
  @resourceidentifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/verizon/models/query_subscription_request.rb', line 65

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountidentifier = AccountIdentifier.from_hash(hash['accountidentifier']) if
    hash['accountidentifier']
  m_selection = hash.key?('$selection') ? hash['$selection'] : SKIP
  resourceidentifier = ResourceIdentifier.from_hash(hash['resourceidentifier']) if
    hash['resourceidentifier']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  QuerySubscriptionRequest.new(accountidentifier: accountidentifier,
                               m_selection: m_selection,
                               resourceidentifier: resourceidentifier,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
37
# File 'lib/verizon/models/query_subscription_request.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountidentifier'] = 'accountidentifier'
  @_hash['m_selection'] = '$selection'
  @_hash['resourceidentifier'] = 'resourceidentifier'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/verizon/models/query_subscription_request.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
46
# File 'lib/verizon/models/query_subscription_request.rb', line 40

def self.optionals
  %w[
    accountidentifier
    m_selection
    resourceidentifier
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/verizon/models/query_subscription_request.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountidentifier: #{@accountidentifier.inspect}, m_selection:"\
  " #{@m_selection.inspect}, resourceidentifier: #{@resourceidentifier.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
95
# File 'lib/verizon/models/query_subscription_request.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountidentifier: #{@accountidentifier}, m_selection: #{@m_selection},"\
  " resourceidentifier: #{@resourceidentifier}, additional_properties:"\
  " #{@additional_properties}>"
end