Class: Verizon::Rateplan
- Defined in:
- lib/verizon/models/rateplan.rb
Overview
Rateplan Model.
Instance Attribute Summary collapse
-
#rate_plan_group ⇒ Array[Object]
An array of rate plan group names.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(rate_plan_group: SKIP, additional_properties: nil) ⇒ Rateplan
constructor
A new instance of Rateplan.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(rate_plan_group: SKIP, additional_properties: nil) ⇒ Rateplan
Returns a new instance of Rateplan.
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/rateplan.rb', line 35 def initialize(rate_plan_group: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @rate_plan_group = rate_plan_group unless rate_plan_group == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#rate_plan_group ⇒ Array[Object]
An array of rate plan group names
14 15 16 |
# File 'lib/verizon/models/rateplan.rb', line 14 def rate_plan_group @rate_plan_group end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/rateplan.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. rate_plan_group = hash.key?('ratePlanGroup') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:RateplanRatePlanGroup), hash['ratePlanGroup'] ) : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Rateplan.new(rate_plan_group: rate_plan_group, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/rateplan.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['rate_plan_group'] = 'ratePlanGroup' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/rateplan.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/rateplan.rb', line 24 def self.optionals %w[ rate_plan_group ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
66 67 68 69 70 71 72 |
# File 'lib/verizon/models/rateplan.rb', line 66 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/verizon/models/rateplan.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} rate_plan_group: #{@rate_plan_group.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/verizon/models/rateplan.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} rate_plan_group: #{@rate_plan_group}, additional_properties:"\ " #{@additional_properties}>" end |