Class: Verizon::RateplantypeObject

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/rateplantype_object.rb

Overview

RateplantypeObject Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(rate_plan_group_description: SKIP, rate_plan_type: SKIP, rate_plan: SKIP, additional_properties: nil) ⇒ RateplantypeObject

Returns a new instance of RateplantypeObject.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/verizon/models/rateplantype_object.rb', line 47

def initialize(rate_plan_group_description: SKIP, rate_plan_type: SKIP,
               rate_plan: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless rate_plan_group_description == SKIP
    @rate_plan_group_description =
      rate_plan_group_description
  end
  @rate_plan_type = rate_plan_type unless rate_plan_type == SKIP
  @rate_plan = rate_plan unless rate_plan == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#rate_planArray[Rateplantype2]

An array of rateplan names

Returns:



22
23
24
# File 'lib/verizon/models/rateplantype_object.rb', line 22

def rate_plan
  @rate_plan
end

#rate_plan_group_descriptionString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/rateplantype_object.rb', line 14

def rate_plan_group_description
  @rate_plan_group_description
end

#rate_plan_typeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/rateplantype_object.rb', line 18

def rate_plan_type
  @rate_plan_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/verizon/models/rateplantype_object.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  rate_plan_group_description =
    hash.key?('ratePlanGroupDescription') ? hash['ratePlanGroupDescription'] : SKIP
  rate_plan_type = hash.key?('ratePlanType') ? hash['ratePlanType'] : SKIP
  # Parameter is an array, so we need to iterate through it
  rate_plan = nil
  unless hash['ratePlan'].nil?
    rate_plan = []
    hash['ratePlan'].each do |structure|
      rate_plan << (Rateplantype2.from_hash(structure) if structure)
    end
  end

  rate_plan = SKIP unless hash.key?('ratePlan')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RateplantypeObject.new(rate_plan_group_description: rate_plan_group_description,
                         rate_plan_type: rate_plan_type,
                         rate_plan: rate_plan,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/rateplantype_object.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['rate_plan_group_description'] = 'ratePlanGroupDescription'
  @_hash['rate_plan_type'] = 'ratePlanType'
  @_hash['rate_plan'] = 'ratePlan'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/rateplantype_object.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/rateplantype_object.rb', line 34

def self.optionals
  %w[
    rate_plan_group_description
    rate_plan_type
    rate_plan
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



96
97
98
99
100
101
102
# File 'lib/verizon/models/rateplantype_object.rb', line 96

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



113
114
115
116
117
118
# File 'lib/verizon/models/rateplantype_object.rb', line 113

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} rate_plan_group_description: #{@rate_plan_group_description.inspect},"\
  " rate_plan_type: #{@rate_plan_type.inspect}, rate_plan: #{@rate_plan.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
110
# File 'lib/verizon/models/rateplantype_object.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} rate_plan_group_description: #{@rate_plan_group_description},"\
  " rate_plan_type: #{@rate_plan_type}, rate_plan: #{@rate_plan}, additional_properties:"\
  " #{@additional_properties}>"
end