Class: Verizon::Rbstiltconfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/rbstiltconfig.rb

Overview

Rbstiltconfig Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(rbs_high_precision_tilt_config: SKIP, additional_properties: nil) ⇒ Rbstiltconfig

Returns a new instance of Rbstiltconfig.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/verizon/models/rbstiltconfig.rb', line 35

def initialize(rbs_high_precision_tilt_config: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless rbs_high_precision_tilt_config == SKIP
    @rbs_high_precision_tilt_config =
      rbs_high_precision_tilt_config
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#rbs_high_precision_tilt_configRbsHighPrecisionTiltConfig

TODO: Write general description for this method



14
15
16
# File 'lib/verizon/models/rbstiltconfig.rb', line 14

def rbs_high_precision_tilt_config
  @rbs_high_precision_tilt_config
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/verizon/models/rbstiltconfig.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  if hash['RbsHighPrecisionTiltConfig']
    rbs_high_precision_tilt_config = RbsHighPrecisionTiltConfig.from_hash(hash['RbsHighPrecisionTiltConfig'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Rbstiltconfig.new(rbs_high_precision_tilt_config: rbs_high_precision_tilt_config,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/rbstiltconfig.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['rbs_high_precision_tilt_config'] = 'RbsHighPrecisionTiltConfig'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/rbstiltconfig.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/rbstiltconfig.rb', line 24

def self.optionals
  %w[
    rbs_high_precision_tilt_config
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Rbstiltconfig | Hash)

    value against the validation is performed.



70
71
72
73
74
75
76
# File 'lib/verizon/models/rbstiltconfig.rb', line 70

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/verizon/models/rbstiltconfig.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} rbs_high_precision_tilt_config: #{@rbs_high_precision_tilt_config.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/verizon/models/rbstiltconfig.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} rbs_high_precision_tilt_config: #{@rbs_high_precision_tilt_config},"\
  " additional_properties: #{@additional_properties}>"
end