Class: Verizon::RemoveDeviceRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/remove_device_request.rb

Overview

The request body identifies the device to delete.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountidentifier:, resourceidentifier:, additional_properties: nil) ⇒ RemoveDeviceRequest

Returns a new instance of RemoveDeviceRequest.



40
41
42
43
44
45
46
47
48
# File 'lib/verizon/models/remove_device_request.rb', line 40

def initialize(accountidentifier:, resourceidentifier:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accountidentifier = accountidentifier
  @resourceidentifier = resourceidentifier
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountidentifierAccountIdentifier

The ID of the authenticating billing account, in the format ‘“billingaccountid”:“1234567890-12345”`.

Returns:



15
16
17
# File 'lib/verizon/models/remove_device_request.rb', line 15

def accountidentifier
  @accountidentifier
end

#resourceidentifierResourceIdentifier

The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.

Returns:



20
21
22
# File 'lib/verizon/models/remove_device_request.rb', line 20

def resourceidentifier
  @resourceidentifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/verizon/models/remove_device_request.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountidentifier = AccountIdentifier.from_hash(hash['accountidentifier']) if
    hash['accountidentifier']
  resourceidentifier = ResourceIdentifier.from_hash(hash['resourceidentifier']) if
    hash['resourceidentifier']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RemoveDeviceRequest.new(accountidentifier: accountidentifier,
                          resourceidentifier: resourceidentifier,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/verizon/models/remove_device_request.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountidentifier'] = 'accountidentifier'
  @_hash['resourceidentifier'] = 'resourceidentifier'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/verizon/models/remove_device_request.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/verizon/models/remove_device_request.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/verizon/models/remove_device_request.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountidentifier: #{@accountidentifier.inspect}, resourceidentifier:"\
  " #{@resourceidentifier.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/verizon/models/remove_device_request.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountidentifier: #{@accountidentifier}, resourceidentifier:"\
  " #{@resourceidentifier}, additional_properties: #{@additional_properties}>"
end