Class: Verizon::ResourceIdentifier
- Defined in:
- lib/verizon/models/resource_identifier.rb
Overview
The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.
Instance Attribute Summary collapse
-
#id ⇒ String
Target ID.
-
#imei ⇒ String
Device IMEI.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, imei: SKIP, additional_properties: nil) ⇒ ResourceIdentifier
constructor
A new instance of ResourceIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, imei: SKIP, additional_properties: nil) ⇒ ResourceIdentifier
Returns a new instance of ResourceIdentifier.
42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/resource_identifier.rb', line 42 def initialize(id: SKIP, imei: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @imei = imei unless imei == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Target ID.
15 16 17 |
# File 'lib/verizon/models/resource_identifier.rb', line 15 def id @id end |
#imei ⇒ String
Device IMEI.
19 20 21 |
# File 'lib/verizon/models/resource_identifier.rb', line 19 def imei @imei end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/resource_identifier.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP imei = hash.key?('imei') ? hash['imei'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ResourceIdentifier.new(id: id, imei: imei, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/resource_identifier.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['imei'] = 'imei' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/verizon/models/resource_identifier.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/verizon/models/resource_identifier.rb', line 30 def self.optionals %w[ id imei ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/verizon/models/resource_identifier.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, imei: #{@imei.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/verizon/models/resource_identifier.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, imei: #{@imei}, additional_properties:"\ " #{@additional_properties}>" end |