Class: Verizon::ResponseToUsageQuery
- Defined in:
- lib/verizon/models/response_to_usage_query.rb
Overview
ResponseToUsageQuery Model.
Instance Attribute Summary collapse
-
#device_id ⇒ ReadySimDeviceId
TODO: Write general description for this method.
-
#hasmoredata ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#usage_history ⇒ Array[UsageHistory]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(hasmoredata: SKIP, device_id: SKIP, usage_history: SKIP, additional_properties: nil) ⇒ ResponseToUsageQuery
constructor
A new instance of ResponseToUsageQuery.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(hasmoredata: SKIP, device_id: SKIP, usage_history: SKIP, additional_properties: nil) ⇒ ResponseToUsageQuery
Returns a new instance of ResponseToUsageQuery.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 47 def initialize(hasmoredata: SKIP, device_id: SKIP, usage_history: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @hasmoredata = hasmoredata unless hasmoredata == SKIP @device_id = device_id unless device_id == SKIP @usage_history = usage_history unless usage_history == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_id ⇒ ReadySimDeviceId
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 18 def device_id @device_id end |
#hasmoredata ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 14 def hasmoredata @hasmoredata end |
#usage_history ⇒ Array[UsageHistory]
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 22 def usage_history @usage_history end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. hasmoredata = hash.key?('hasmoredata') ? hash['hasmoredata'] : SKIP device_id = ReadySimDeviceId.from_hash(hash['deviceId']) if hash['deviceId'] # Parameter is an array, so we need to iterate through it usage_history = nil unless hash['usageHistory'].nil? usage_history = [] hash['usageHistory'].each do |structure| usage_history << (UsageHistory.from_hash(structure) if structure) end end usage_history = SKIP unless hash.key?('usageHistory') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ResponseToUsageQuery.new(hasmoredata: hasmoredata, device_id: device_id, usage_history: usage_history, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['hasmoredata'] = 'hasmoredata' @_hash['device_id'] = 'deviceId' @_hash['usage_history'] = 'usageHistory' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 34 def self.optionals %w[ hasmoredata device_id usage_history ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} hasmoredata: #{@hasmoredata.inspect}, device_id: #{@device_id.inspect},"\ " usage_history: #{@usage_history.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/verizon/models/response_to_usage_query.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} hasmoredata: #{@hasmoredata}, device_id: #{@device_id}, usage_history:"\ " #{@usage_history}, additional_properties: #{@additional_properties}>" end |