Class: Verizon::SearchDeviceByPropertyResponseList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/search_device_by_property_response_list.rb

Overview

A success response includes an array of all matching devices.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_property: SKIP, additional_properties: nil) ⇒ SearchDeviceByPropertyResponseList

Returns a new instance of SearchDeviceByPropertyResponseList.



35
36
37
38
39
40
41
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 35

def initialize(device_property: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_property = device_property unless device_property == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_propertyArray[SearchDeviceByPropertyResponse]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 14

def device_property
  @device_property
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_property = nil
  unless hash['DeviceProperty'].nil?
    device_property = []
    hash['DeviceProperty'].each do |structure|
      device_property << (SearchDeviceByPropertyResponse.from_hash(structure) if structure)
    end
  end

  device_property = SKIP unless hash.key?('DeviceProperty')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SearchDeviceByPropertyResponseList.new(device_property: device_property,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_property'] = 'DeviceProperty'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 24

def self.optionals
  %w[
    device_property
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_property: #{@device_property.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/verizon/models/search_device_by_property_response_list.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_property: #{@device_property}, additional_properties:"\
  " #{@additional_properties}>"
end