Class: Verizon::SearchDeviceEventHistoryResponseList
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::SearchDeviceEventHistoryResponseList
- Defined in:
- lib/verizon/models/search_device_event_history_response_list.rb
Overview
A success response includes an array of all matching events.
Instance Attribute Summary collapse
-
#search_device_event_history ⇒ Array[SearchDeviceResponse]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(search_device_event_history: SKIP, additional_properties: nil) ⇒ SearchDeviceEventHistoryResponseList
constructor
A new instance of SearchDeviceEventHistoryResponseList.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(search_device_event_history: SKIP, additional_properties: nil) ⇒ SearchDeviceEventHistoryResponseList
Returns a new instance of SearchDeviceEventHistoryResponseList.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 35 def initialize(search_device_event_history: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless search_device_event_history == SKIP @search_device_event_history = search_device_event_history end @additional_properties = additional_properties end |
Instance Attribute Details
#search_device_event_history ⇒ Array[SearchDeviceResponse]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 14 def search_device_event_history @search_device_event_history end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it search_device_event_history = nil unless hash['SearchDeviceEventHistory'].nil? search_device_event_history = [] hash['SearchDeviceEventHistory'].each do |structure| search_device_event_history << (SearchDeviceResponse.from_hash(structure) if structure) end end search_device_event_history = SKIP unless hash.key?('SearchDeviceEventHistory') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SearchDeviceEventHistoryResponseList.new(search_device_event_history: search_device_event_history, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['search_device_event_history'] = 'SearchDeviceEventHistory' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 24 def self.optionals %w[ search_device_event_history ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} search_device_event_history: #{@search_device_event_history.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/verizon/models/search_device_event_history_response_list.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} search_device_event_history: #{@search_device_event_history},"\ " additional_properties: #{@additional_properties}>" end |