Class: Verizon::SecurityResultException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- Verizon::SecurityResultException
- Defined in:
- lib/verizon/exceptions/security_result_exception.rb
Overview
Error response.
Instance Attribute Summary collapse
-
#error_code ⇒ String
TODO: Write general description for this method.
-
#error_message ⇒ String
TODO: Write general description for this method.
-
#error_url ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ SecurityResultException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ SecurityResultException
The constructor.
27 28 29 30 31 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 14 def error_code @error_code end |
#error_message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 18 def @error_message end |
#error_url ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 22 def error_url @error_url end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
52 53 54 55 56 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 52 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, error_message:"\ " #{@error_message.inspect}, error_url: #{@error_url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 49 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, error_message: #{@error_message}, error_url:"\ " #{@error_url}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/verizon/exceptions/security_result_exception.rb', line 36 def unbox(hash) return nil unless hash @error_code = hash.key?('errorCode') ? hash['errorCode'] : SKIP @error_message = hash.key?('errorMessage') ? hash['errorMessage'] : SKIP @error_url = hash.key?('errorUrl') ? hash['errorUrl'] : SKIP end |