Class: Verizon::SecuritySubscriptionResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/security_subscription_result.rb

Overview

Response for a subscription request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name: SKIP, subscription_list: SKIP) ⇒ SecuritySubscriptionResult

Returns a new instance of SecuritySubscriptionResult.



42
43
44
45
# File 'lib/verizon/models/security_subscription_result.rb', line 42

def initialize(account_name: SKIP, subscription_list: SKIP)
  @account_name =  unless  == SKIP
  @subscription_list = subscription_list unless subscription_list == SKIP
end

Instance Attribute Details

#account_nameString

The name of a billing account.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/security_subscription_result.rb', line 14

def 
  @account_name
end

#subscription_listArray[SecuritySubscription]

The list of SKU numbers and counts for each license type specified in the request.

Returns:



19
20
21
# File 'lib/verizon/models/security_subscription_result.rb', line 19

def subscription_list
  @subscription_list
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/verizon/models/security_subscription_result.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : SKIP
  # Parameter is an array, so we need to iterate through it
  subscription_list = nil
  unless hash['subscriptionList'].nil?
    subscription_list = []
    hash['subscriptionList'].each do |structure|
      subscription_list << (SecuritySubscription.from_hash(structure) if structure)
    end
  end

  subscription_list = SKIP unless hash.key?('subscriptionList')

  # Create object from extracted values.
  SecuritySubscriptionResult.new(account_name: ,
                                 subscription_list: subscription_list)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/security_subscription_result.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['subscription_list'] = 'subscriptionList'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/security_subscription_result.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/verizon/models/security_subscription_result.rb', line 30

def self.optionals
  %w[
    account_name
    subscription_list
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/verizon/models/security_subscription_result.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, subscription_list:"\
  " #{@subscription_list.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/verizon/models/security_subscription_result.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, subscription_list: #{@subscription_list}>"
end