Class: Verizon::SensorInsightsNotificationGroupsApi
- Defined in:
- lib/verizon/apis/sensor_insights_notification_groups_api.rb
Overview
SensorInsightsNotificationGroupsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#sensor_insights_add_users_to_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here Add users to a notification group.
-
#sensor_insights_create_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here a notification group.
-
#sensor_insights_delete_notification_group(payload) ⇒ ApiResponse
TODO: type endpoint description here Payload for the delete request.
-
#sensor_insights_list_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here a notification group.
-
#sensor_insights_remove_users_from_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here parameter: Remove users from a notification group.
-
#sensor_insights_update_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here Partially update a notification group.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#sensor_insights_add_users_to_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here Add users to a notification group
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/verizon/apis/sensor_insights_notification_groups_api.rb', line 188 def sensor_insights_add_users_to_notification_group_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/notificationGroups/actions/add-users', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .is_response_void(true) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_create_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here a notification group
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/verizon/apis/sensor_insights_notification_groups_api.rb', line 112 def sensor_insights_create_notification_group_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/notificationGroups', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoNotificationGroupResponseEntity.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_delete_notification_group(payload) ⇒ ApiResponse
TODO: type endpoint description here Payload for the delete request.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/verizon/apis/sensor_insights_notification_groups_api.rb', line 158 def sensor_insights_delete_notification_group(payload) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/dm/v1/notificationGroups', Server::THINGSPACE) .query_param(new_parameter(payload, key: 'payload') .is_required(true)) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .is_response_void(true) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException)) .execute end |
#sensor_insights_list_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here a notification group
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/apis/sensor_insights_notification_groups_api.rb', line 13 def sensor_insights_list_notification_group_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/notificationGroups/actions/query', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoNotificationGroupResponseEntity.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_remove_users_from_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here parameter: Remove users from a notification group
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/verizon/apis/sensor_insights_notification_groups_api.rb', line 235 def sensor_insights_remove_users_from_notification_group_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/notificationGroups/actions/remove-users', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .is_response_void(true) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_update_notification_group_request(body) ⇒ ApiResponse
TODO: type endpoint description here Partially update a notification group
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/verizon/apis/sensor_insights_notification_groups_api.rb', line 63 def sensor_insights_update_notification_group_request(body) @api_call .request(new_request_builder(HttpMethodEnum::PATCH, '/dm/v1/notificationGroups', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoNotificationGroupResponseEntity.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |