Class: Verizon::SensorInsightsSensorsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/sensor_insights_sensors_api.rb

Overview

SensorInsightsSensorsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#sensor_insights_list_sensor_devices_request(body) ⇒ ApiResponse

TODO: type endpoint description here of the sensors

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/apis/sensor_insights_sensors_api.rb', line 13

def sensor_insights_list_sensor_devices_request(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/devices/sensors/actions/query',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ResourceDevice.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('404',
                             'Not Found',
                             M404ManagementErrorException)
                .local_error('406',
                             'Not Acceptable',
                             ManagementErrorException)
                .local_error('415',
                             'Unsupported media type',
                             ManagementErrorException)
                .local_error('429',
                             'Too many requests',
                             ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException)
                .local_error('default',
                             'Unexpected error',
                             ManagementErrorException))
    .execute
end

#sensor_insights_off_board_sensor_request(body) ⇒ ApiResponse

TODO: type endpoint description here sensor

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/verizon/apis/sensor_insights_sensors_api.rb', line 156

def sensor_insights_off_board_sensor_request(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/devices/sensors/offboard',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException))
    .execute
end

#sensor_insights_on_board_sensor_request(body) ⇒ ApiResponse

TODO: type endpoint description here sensor

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/verizon/apis/sensor_insights_sensors_api.rb', line 63

def sensor_insights_on_board_sensor_request(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/devices/sensors/onboard',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('406',
                             'Not Acceptable',
                             ManagementErrorException)
                .local_error('415',
                             'Unsupported media type',
                             ManagementErrorException)
                .local_error('429',
                             'Too many requests',
                             ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException)
                .local_error('default',
                             'Unexpected error',
                             ManagementErrorException))
    .execute
end

#sensor_insights_sensor_off_boarding_status_request(body) ⇒ ApiResponse

TODO: type endpoint description here sensor’s offboarding status

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/verizon/apis/sensor_insights_sensors_api.rb', line 185

def sensor_insights_sensor_off_boarding_status_request(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/devices/sensors/offboard/status/actions/query',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoSensorOffBoardingStatusResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('404',
                             'Not Found',
                             M404ManagementErrorException)
                .local_error('406',
                             'Not Acceptable',
                             ManagementErrorException)
                .local_error('415',
                             'Unsupported media type',
                             ManagementErrorException)
                .local_error('429',
                             'Too many requests',
                             ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException)
                .local_error('default',
                             'Unexpected error',
                             ManagementErrorException))
    .execute
end

#sensor_insights_sensor_on_board_status_request(body) ⇒ ApiResponse

TODO: type endpoint description here sensor’s onboarding status

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/verizon/apis/sensor_insights_sensors_api.rb', line 107

def sensor_insights_sensor_on_board_status_request(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/devices/sensors/onboard/status/actions/query',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoSensorOnBoardingStatusResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('404',
                             'Not Found',
                             M404ManagementErrorException)
                .local_error('406',
                             'Not Acceptable',
                             ManagementErrorException)
                .local_error('415',
                             'Unsupported media type',
                             ManagementErrorException)
                .local_error('429',
                             'Too many requests',
                             ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException)
                .local_error('default',
                             'Unexpected error',
                             ManagementErrorException))
    .execute
end