Class: Verizon::ServicePlansApi
- Defined in:
- lib/verizon/apis/service_plans_api.rb
Overview
ServicePlansApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#list_account_service_plans(aname) ⇒ ApiResponse
Returns a list of all data service plans that are associated with a specified billing account.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#list_account_service_plans(aname) ⇒ ApiResponse
Returns a list of all data service plans that are associated with a specified billing account. When you send a request to /devices/actions/activate to activate a line of service you must specify the code for one of the service plans associated with your account.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/verizon/apis/service_plans_api.rb', line 15 def list_account_service_plans(aname) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/m2m/v1/plans/{aname}', Server::THINGSPACE) .template_param(new_parameter(aname, key: 'aname') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ServicePlan.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |