Class: Verizon::SessionTriggerRequest
- Defined in:
- lib/verizon/models/session_trigger_request.rb
Overview
SessionTriggerRequest Model.
Instance Attribute Summary collapse
-
#comparator ⇒ String
TODO: Write general description for this method.
-
#threshold ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(comparator: SKIP, threshold: SKIP) ⇒ SessionTriggerRequest
constructor
A new instance of SessionTriggerRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(comparator: SKIP, threshold: SKIP) ⇒ SessionTriggerRequest
Returns a new instance of SessionTriggerRequest.
41 42 43 44 |
# File 'lib/verizon/models/session_trigger_request.rb', line 41 def initialize(comparator: SKIP, threshold: SKIP) @comparator = comparator unless comparator == SKIP @threshold = threshold unless threshold == SKIP end |
Instance Attribute Details
#comparator ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/session_trigger_request.rb', line 14 def comparator @comparator end |
#threshold ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/session_trigger_request.rb', line 18 def threshold @threshold end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/session_trigger_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. comparator = hash.key?('comparator') ? hash['comparator'] : SKIP threshold = hash.key?('threshold') ? hash['threshold'] : SKIP # Create object from extracted values. SessionTriggerRequest.new(comparator: comparator, threshold: threshold) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/session_trigger_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['comparator'] = 'comparator' @_hash['threshold'] = 'threshold' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/session_trigger_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/session_trigger_request.rb', line 29 def self.optionals %w[ comparator threshold ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/session_trigger_request.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} comparator: #{@comparator.inspect}, threshold: #{@threshold.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/session_trigger_request.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} comparator: #{@comparator}, threshold: #{@threshold}>" end |