Class: Verizon::SetFallbackAttributeRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::SetFallbackAttributeRequest
- Defined in:
- lib/verizon/models/set_fallback_attribute_request.rb
Overview
SetFallbackAttributeRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
TODO: Write general description for this method.
-
#carrier_name ⇒ String
TODO: Write general description for this method.
-
#devices ⇒ Array[DeviceList]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(devices:, account_name:, carrier_name: SKIP) ⇒ SetFallbackAttributeRequest
constructor
A new instance of SetFallbackAttributeRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(devices:, account_name:, carrier_name: SKIP) ⇒ SetFallbackAttributeRequest
Returns a new instance of SetFallbackAttributeRequest.
45 46 47 48 49 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 45 def initialize(devices:, account_name:, carrier_name: SKIP) @devices = devices @account_name = account_name @carrier_name = carrier_name unless carrier_name == SKIP end |
Instance Attribute Details
#account_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 18 def account_name @account_name end |
#carrier_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 22 def carrier_name @carrier_name end |
#devices ⇒ Array[DeviceList]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 14 def devices @devices end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (DeviceList.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') account_name = hash.key?('accountName') ? hash['accountName'] : nil carrier_name = hash.key?('carrierName') ? hash['carrierName'] : SKIP # Create object from extracted values. SetFallbackAttributeRequest.new(devices: devices, account_name: account_name, carrier_name: carrier_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['devices'] = 'devices' @_hash['account_name'] = 'accountName' @_hash['carrier_name'] = 'carrierName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 34 def self.optionals %w[ carrier_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} devices: #{@devices.inspect}, account_name: #{@account_name.inspect},"\ " carrier_name: #{@carrier_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/verizon/models/set_fallback_attribute_request.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} devices: #{@devices}, account_name: #{@account_name}, carrier_name:"\ " #{@carrier_name}>" end |