Class: Verizon::SimActionsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/sim_actions_api.rb

Overview

SimActionsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#newactivatecode(body) ⇒ ApiResponse

System assign a new activation code to reactivate a deactivated device. Note: the previously assigned ICCID must be used to request a new activation code. Query

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/verizon/apis/sim_actions_api.rb', line 15

def newactivatecode(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/profile/actions/renew_activation_code',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(EsimRequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             EsimRestErrorResponseException)
                .local_error('401',
                             'Unauthorized',
                             EsimRestErrorResponseException)
                .local_error('403',
                             'Forbidden',
                             EsimRestErrorResponseException)
                .local_error('404',
                             'Not Found / Does not exist',
                             EsimRestErrorResponseException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             EsimRestErrorResponseException)
                .local_error('429',
                             'Too many requests',
                             EsimRestErrorResponseException)
                .local_error('default',
                             'Error response',
                             EsimRestErrorResponseException))
    .execute
end

#setactivate_using_post(body) ⇒ ApiResponse

Uses the profile to activate the SIM. Query

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/verizon/apis/sim_actions_api.rb', line 58

def setactivate_using_post(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/profile/actions/activate',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(EsimRequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             EsimRestErrorResponseException)
                .local_error('401',
                             'Unauthorized',
                             EsimRestErrorResponseException)
                .local_error('403',
                             'Forbidden',
                             EsimRestErrorResponseException)
                .local_error('404',
                             'Not Found / Does not exist',
                             EsimRestErrorResponseException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             EsimRestErrorResponseException)
                .local_error('429',
                             'Too many requests',
                             EsimRestErrorResponseException)
                .local_error('default',
                             'Error response',
                             EsimRestErrorResponseException))
    .execute
end

#setdeactivate_using_post(body) ⇒ ApiResponse

Uses the profile to deactivate the SIM.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/verizon/apis/sim_actions_api.rb', line 100

def setdeactivate_using_post(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v1/devices/profile/actions/deactivate',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(EsimRequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             EsimRestErrorResponseException)
                .local_error('401',
                             'Unauthorized',
                             EsimRestErrorResponseException)
                .local_error('403',
                             'Forbidden',
                             EsimRestErrorResponseException)
                .local_error('404',
                             'Not Found / Does not exist',
                             EsimRestErrorResponseException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             EsimRestErrorResponseException)
                .local_error('429',
                             'Too many requests',
                             EsimRestErrorResponseException)
                .local_error('default',
                             'Error response',
                             EsimRestErrorResponseException))
    .execute
end