Class: Verizon::SmsMessage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/sms_message.rb

Overview

SMS messages sent by all M2M devices associated with a billing account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids: SKIP, message: SKIP, timestamp: SKIP, additional_properties: nil) ⇒ SmsMessage

Returns a new instance of SmsMessage.



48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/sms_message.rb', line 48

def initialize(device_ids: SKIP, message: SKIP, timestamp: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_ids = device_ids unless device_ids == SKIP
  @message = message unless message == SKIP
  @timestamp = timestamp unless timestamp == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_idsArray[DeviceId]

One or more IDs of the device that sent the message.

Returns:



14
15
16
# File 'lib/verizon/models/sms_message.rb', line 14

def device_ids
  @device_ids
end

#messageString

The contents of the SMS message.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/sms_message.rb', line 18

def message
  @message
end

#timestampString

The date and time that the message was received by the Verizon ThingSpace Platform.

Returns:

  • (String)


23
24
25
# File 'lib/verizon/models/sms_message.rb', line 23

def timestamp
  @timestamp
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/verizon/models/sms_message.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (DeviceId.from_hash(structure) if structure)
    end
  end

  device_ids = SKIP unless hash.key?('deviceIds')
  message = hash.key?('message') ? hash['message'] : SKIP
  timestamp = hash.key?('timestamp') ? hash['timestamp'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SmsMessage.new(device_ids: device_ids,
                 message: message,
                 timestamp: timestamp,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/verizon/models/sms_message.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'deviceIds'
  @_hash['message'] = 'message'
  @_hash['timestamp'] = 'timestamp'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/sms_message.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/verizon/models/sms_message.rb', line 35

def self.optionals
  %w[
    device_ids
    message
    timestamp
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/verizon/models/sms_message.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, message: #{@message.inspect},"\
  " timestamp: #{@timestamp.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/verizon/models/sms_message.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, message: #{@message}, timestamp: #{@timestamp},"\
  " additional_properties: #{@additional_properties}>"
end