Class: Verizon::SmsMessagesQueryResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::SmsMessagesQueryResult
- Defined in:
- lib/verizon/models/sms_messages_query_result.rb
Overview
Response to SMS messages sent by all M2M devices associated with a billing account.
Instance Attribute Summary collapse
-
#has_more_data ⇒ TrueClass | FalseClass
False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.
-
#messages ⇒ Array[SmsMessage]
An array of up to 100 SMS messages that were sent by devices in the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(has_more_data: SKIP, messages: SKIP, additional_properties: nil) ⇒ SmsMessagesQueryResult
constructor
A new instance of SmsMessagesQueryResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(has_more_data: SKIP, messages: SKIP, additional_properties: nil) ⇒ SmsMessagesQueryResult
Returns a new instance of SmsMessagesQueryResult.
44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 44 def initialize(has_more_data: SKIP, messages: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @has_more_data = has_more_data unless has_more_data == SKIP @messages = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#has_more_data ⇒ TrueClass | FalseClass
False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.
16 17 18 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 16 def has_more_data @has_more_data end |
#messages ⇒ Array[SmsMessage]
An array of up to 100 SMS messages that were sent by devices in the account.
21 22 23 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 21 def @messages end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP # Parameter is an array, so we need to iterate through it = nil unless hash['messages'].nil? = [] hash['messages'].each do |structure| << (SmsMessage.from_hash(structure) if structure) end end = SKIP unless hash.key?('messages') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SmsMessagesQueryResult.new(has_more_data: has_more_data, messages: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['has_more_data'] = 'hasMoreData' @_hash['messages'] = 'messages' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 32 def self.optionals %w[ has_more_data messages ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data.inspect}, messages: #{@messages.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/verizon/models/sms_messages_query_result.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data}, messages: #{@messages},"\ " additional_properties: #{@additional_properties}>" end |