Class: Verizon::SmsTriggerRequest
- Defined in:
- lib/verizon/models/sms_trigger_request.rb
Overview
SmsTriggerRequest Model.
Instance Attribute Summary collapse
-
#comparator ⇒ String
TODO: Write general description for this method.
-
#sms_type ⇒ String
TODO: Write general description for this method.
-
#threshold ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(comparator: SKIP, sms_type: SKIP, threshold: SKIP) ⇒ SmsTriggerRequest
constructor
A new instance of SmsTriggerRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(comparator: SKIP, sms_type: SKIP, threshold: SKIP) ⇒ SmsTriggerRequest
Returns a new instance of SmsTriggerRequest.
47 48 49 50 51 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 47 def initialize(comparator: SKIP, sms_type: SKIP, threshold: SKIP) @comparator = comparator unless comparator == SKIP @sms_type = sms_type unless sms_type == SKIP @threshold = threshold unless threshold == SKIP end |
Instance Attribute Details
#comparator ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 14 def comparator @comparator end |
#sms_type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 18 def sms_type @sms_type end |
#threshold ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 22 def threshold @threshold end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. comparator = hash.key?('comparator') ? hash['comparator'] : SKIP sms_type = hash.key?('smsType') ? hash['smsType'] : SKIP threshold = hash.key?('threshold') ? hash['threshold'] : SKIP # Create object from extracted values. SmsTriggerRequest.new(comparator: comparator, sms_type: sms_type, threshold: threshold) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['comparator'] = 'comparator' @_hash['sms_type'] = 'smsType' @_hash['threshold'] = 'threshold' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 34 def self.optionals %w[ comparator sms_type threshold ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} comparator: #{@comparator.inspect}, sms_type: #{@sms_type.inspect},"\ " threshold: #{@threshold.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/verizon/models/sms_trigger_request.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} comparator: #{@comparator}, sms_type: #{@sms_type}, threshold:"\ " #{@threshold}>" end |