Class: Verizon::SoftwareManagementCallbacksV2Api

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/software_management_callbacks_v2_api.rb

Overview

SoftwareManagementCallbacksV2Api

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#deregister_callback(account) ⇒ ApiResponse

This endpoint allows user to delete a previously registered callback URL.

Parameters:

  • account (String)

    Required parameter: Account identifier.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/verizon/apis/software_management_callbacks_v2_api.rb', line 95

def deregister_callback()
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/callbacks/{account}',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FotaV2SuccessResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#list_registered_callbacks(account) ⇒ ApiResponse

This endpoint allows user to get the registered callback information.

Parameters:

  • account (String)

    Required parameter: Account identifier.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/verizon/apis/software_management_callbacks_v2_api.rb', line 12

def list_registered_callbacks()
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/callbacks/{account}',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CallbackSummary.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#register_callback(account, body) ⇒ ApiResponse

This endpoint allows user to create the HTTPS callback address. Callback URL registration.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/verizon/apis/software_management_callbacks_v2_api.rb', line 67

def register_callback(,
                      body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/callbacks/{account}',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FotaV2CallbackRegistrationResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#update_callback(account, body) ⇒ ApiResponse

This endpoint allows user to update the HTTPS callback address. Callback URL registration.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/verizon/apis/software_management_callbacks_v2_api.rb', line 37

def update_callback(,
                    body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/callbacks/{account}',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FotaV2CallbackRegistrationResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end