Class: Verizon::SoftwareManagementLicensesV2Api

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/software_management_licenses_v2_api.rb

Overview

SoftwareManagementLicensesV2Api

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#assign_licenses_to_devices(account, body) ⇒ ApiResponse

This endpoint allows user to assign licenses to a list of devices.

Parameters:

  • account (String)

    Required parameter: Account identifier.

  • body (V2LicenseImei)

    Required parameter: License assignment.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/verizon/apis/software_management_licenses_v2_api.rb', line 40

def assign_licenses_to_devices(,
                               body)
  warn 'Endpoint assign_licenses_to_devices in SoftwareManagementLicensesV'\
       '2Api is deprecated'
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/licenses/{account}/assign',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(V2LicensesAssignedRemovedResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#create_list_of_licenses_to_remove(account, body) ⇒ ApiResponse

The license cancel endpoint allows user to create a list of license cancellation candidate devices. licensess to remove.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/verizon/apis/software_management_licenses_v2_api.rb', line 133

def create_list_of_licenses_to_remove(,
                                      body)
  warn 'Endpoint create_list_of_licenses_to_remove in SoftwareManagementLi'\
       'censesV2Api is deprecated'
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/licenses/{account}/cancel',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(V2ListOfLicensesToRemoveResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#delete_list_of_licenses_to_remove(account) ⇒ ApiResponse

This endpoint allows user to delete a created cancel candidate device list.

Parameters:

  • account (String)

    Required parameter: Account identifier.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/verizon/apis/software_management_licenses_v2_api.rb', line 164

def delete_list_of_licenses_to_remove()
  warn 'Endpoint delete_list_of_licenses_to_remove in SoftwareManagementLi'\
       'censesV2Api is deprecated'
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/licenses/{account}/cancel',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(FotaV2SuccessResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#get_account_license_status(account, last_seen_device_id: nil) ⇒ ApiResponse

The endpoint allows user to list license usage. identifier.

Parameters:

  • account (String)

    Required parameter: Account identifier.

  • last_seen_device_id (String) (defaults to: nil)

    Optional parameter: Last seen device

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/verizon/apis/software_management_licenses_v2_api.rb', line 14

def (,
                               last_seen_device_id: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/licenses/{account}',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(last_seen_device_id, key: 'lastSeenDeviceId'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(V2LicenseSummary.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#list_licenses_to_remove(account, start_index: nil) ⇒ ApiResponse

The license cancel endpoint allows user to list registered license cancellation candidate devices.

Parameters:

  • account (String)

    Required parameter: Account identifier.

  • start_index (String) (defaults to: nil)

    Optional parameter: Start index to retrieve.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/verizon/apis/software_management_licenses_v2_api.rb', line 103

def list_licenses_to_remove(,
                            start_index: nil)
  warn 'Endpoint list_licenses_to_remove in SoftwareManagementLicensesV2Ap'\
       'i is deprecated'
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/licenses/{account}/cancel',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(start_index, key: 'startIndex'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(V2ListOfLicensesToRemove.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end

#remove_licenses_from_devices(account, body) ⇒ ApiResponse

This endpoint allows user to remove licenses from a list of devices.

Parameters:

  • account (String)

    Required parameter: Account identifier.

  • body (V2LicenseImei)

    Required parameter: License removal.

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/verizon/apis/software_management_licenses_v2_api.rb', line 71

def remove_licenses_from_devices(,
                                 body)
  warn 'Endpoint remove_licenses_from_devices in SoftwareManagementLicense'\
       'sV2Api is deprecated'
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/licenses/{account}/remove',
                                 Server::SOFTWARE_MANAGEMENT_V2)
               .template_param(new_parameter(, key: 'account')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(V2LicensesAssignedRemovedResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Unexpected error.',
                             FotaV2ResultException))
    .execute
end