Class: Verizon::Speed
- Defined in:
- lib/verizon/models/speed.rb
Overview
Speed Model.
Instance Attribute Summary collapse
-
#max ⇒ Float
The maximum acceptable speed in m/s.
-
#min ⇒ Float
The minimum required speed in m/s.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(min:, max:) ⇒ Speed
constructor
A new instance of Speed.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(min:, max:) ⇒ Speed
Returns a new instance of Speed.
38 39 40 41 |
# File 'lib/verizon/models/speed.rb', line 38 def initialize(min:, max:) @min = min @max = max end |
Instance Attribute Details
#max ⇒ Float
The maximum acceptable speed in m/s
18 19 20 |
# File 'lib/verizon/models/speed.rb', line 18 def max @max end |
#min ⇒ Float
The minimum required speed in m/s.
14 15 16 |
# File 'lib/verizon/models/speed.rb', line 14 def min @min end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/speed.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. min = hash.key?('min') ? hash['min'] : nil max = hash.key?('max') ? hash['max'] : nil # Create object from extracted values. Speed.new(min: min, max: max) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/speed.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['min'] = 'min' @_hash['max'] = 'max' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/speed.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/speed.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/verizon/models/speed.rb', line 58 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.min, ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value.max, ->(val) { val.instance_of? Float }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['min'], ->(val) { val.instance_of? Float }) and APIHelper.valid_type?(value['max'], ->(val) { val.instance_of? Float }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 |
# File 'lib/verizon/models/speed.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} min: #{@min.inspect}, max: #{@max.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 |
# File 'lib/verizon/models/speed.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} min: #{@min}, max: #{@max}>" end |