Class: Verizon::SpeedItem
- Defined in:
- lib/verizon/models/speed_item.rb
Overview
Defines the acceptable speed range for road users in m/s. Messages are triggered when: 1. The road user’s speed is below the required minimum OR 2. The road user’s speed is above the acceptable maximum AND 3. The associated TriggerConditions are met. Example: For the speed range of 10-20 m/s and a TriggerCondition of ‘user inside geofence’, the message is sent if the user’s speed is below 10 m/s or above 20 m/s while in the geofence area.
Instance Attribute Summary collapse
-
#speed ⇒ Speed
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(speed:, additional_properties: nil) ⇒ SpeedItem
constructor
A new instance of SpeedItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(speed:, additional_properties: nil) ⇒ SpeedItem
Returns a new instance of SpeedItem.
41 42 43 44 45 46 47 |
# File 'lib/verizon/models/speed_item.rb', line 41 def initialize(speed:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @speed = speed @additional_properties = additional_properties end |
Instance Attribute Details
#speed ⇒ Speed
TODO: Write general description for this method
20 21 22 |
# File 'lib/verizon/models/speed_item.rb', line 20 def speed @speed end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/speed_item.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. speed = Speed.from_hash(hash['speed']) if hash['speed'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SpeedItem.new(speed: speed, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 |
# File 'lib/verizon/models/speed_item.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['speed'] = 'speed' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 38 39 |
# File 'lib/verizon/models/speed_item.rb', line 35 def self.nullables %w[ speed ] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/verizon/models/speed_item.rb', line 30 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/models/speed_item.rb', line 70 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.speed, ->(val) { Speed.validate(val) }, is_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['speed'], ->(val) { Speed.validate(val) }, is_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/verizon/models/speed_item.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} speed: #{@speed.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 |
# File 'lib/verizon/models/speed_item.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} speed: #{@speed}, additional_properties: #{@additional_properties}>" end |