Class: Verizon::StatusResponse
- Defined in:
- lib/verizon/models/status_response.rb
Overview
StatusResponse Model.
Instance Attribute Summary collapse
-
#request_id ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#subrequests ⇒ Array[Subrequest]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id: SKIP, status: SKIP, subrequests: SKIP) ⇒ StatusResponse
constructor
A new instance of StatusResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id: SKIP, status: SKIP, subrequests: SKIP) ⇒ StatusResponse
Returns a new instance of StatusResponse.
47 48 49 50 51 |
# File 'lib/verizon/models/status_response.rb', line 47 def initialize(request_id: SKIP, status: SKIP, subrequests: SKIP) @request_id = request_id unless request_id == SKIP @status = status unless status == SKIP @subrequests = subrequests unless subrequests == SKIP end |
Instance Attribute Details
#request_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/status_response.rb', line 14 def request_id @request_id end |
#status ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/status_response.rb', line 18 def status @status end |
#subrequests ⇒ Array[Subrequest]
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/status_response.rb', line 22 def subrequests @subrequests end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/status_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('requestId') ? hash['requestId'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Parameter is an array, so we need to iterate through it subrequests = nil unless hash['subrequests'].nil? subrequests = [] hash['subrequests'].each do |structure| subrequests << (Subrequest.from_hash(structure) if structure) end end subrequests = SKIP unless hash.key?('subrequests') # Create object from extracted values. StatusResponse.new(request_id: request_id, status: status, subrequests: subrequests) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/status_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'requestId' @_hash['status'] = 'status' @_hash['subrequests'] = 'subrequests' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/status_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/status_response.rb', line 34 def self.optionals %w[ request_id status subrequests ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/verizon/models/status_response.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, status: #{@status.inspect},"\ " subrequests: #{@subrequests.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/verizon/models/status_response.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, status: #{@status}, subrequests:"\ " #{@subrequests}>" end |