Class: Verizon::TargetAuthenticationBody
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::TargetAuthenticationBody
- Defined in:
- lib/verizon/models/target_authentication_body.rb
Overview
TargetAuthenticationBody Model.
Instance Attribute Summary collapse
-
#grant_type ⇒ String
Authentication grant type.
-
#headers ⇒ TargetAuthenticationBodyHeaders
Authentication headers.
-
#host ⇒ TargetAuthenticationBodyHost
Host information.
-
#refresh_token ⇒ String
Refresh token.
-
#scope ⇒ String
Authentication scopes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(grant_type: SKIP, refresh_token: SKIP, scope: SKIP, headers: SKIP, host: SKIP, additional_properties: nil) ⇒ TargetAuthenticationBody
constructor
A new instance of TargetAuthenticationBody.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(grant_type: SKIP, refresh_token: SKIP, scope: SKIP, headers: SKIP, host: SKIP, additional_properties: nil) ⇒ TargetAuthenticationBody
Returns a new instance of TargetAuthenticationBody.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/target_authentication_body.rb', line 59 def initialize(grant_type: SKIP, refresh_token: SKIP, scope: SKIP, headers: SKIP, host: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @grant_type = grant_type unless grant_type == SKIP @refresh_token = refresh_token unless refresh_token == SKIP @scope = scope unless scope == SKIP @headers = headers unless headers == SKIP @host = host unless host == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#grant_type ⇒ String
Authentication grant type.
14 15 16 |
# File 'lib/verizon/models/target_authentication_body.rb', line 14 def grant_type @grant_type end |
#headers ⇒ TargetAuthenticationBodyHeaders
Authentication headers.
26 27 28 |
# File 'lib/verizon/models/target_authentication_body.rb', line 26 def headers @headers end |
#host ⇒ TargetAuthenticationBodyHost
Host information.
30 31 32 |
# File 'lib/verizon/models/target_authentication_body.rb', line 30 def host @host end |
#refresh_token ⇒ String
Refresh token.
18 19 20 |
# File 'lib/verizon/models/target_authentication_body.rb', line 18 def refresh_token @refresh_token end |
#scope ⇒ String
Authentication scopes.
22 23 24 |
# File 'lib/verizon/models/target_authentication_body.rb', line 22 def scope @scope end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/verizon/models/target_authentication_body.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. grant_type = hash.key?('grant_type') ? hash['grant_type'] : SKIP refresh_token = hash.key?('refresh_token') ? hash['refresh_token'] : SKIP scope = hash.key?('scope') ? hash['scope'] : SKIP headers = TargetAuthenticationBodyHeaders.from_hash(hash['headers']) if hash['headers'] host = TargetAuthenticationBodyHost.from_hash(hash['host']) if hash['host'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TargetAuthenticationBody.new(grant_type: grant_type, refresh_token: refresh_token, scope: scope, headers: headers, host: host, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/verizon/models/target_authentication_body.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['grant_type'] = 'grant_type' @_hash['refresh_token'] = 'refresh_token' @_hash['scope'] = 'scope' @_hash['headers'] = 'headers' @_hash['host'] = 'host' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/verizon/models/target_authentication_body.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/target_authentication_body.rb', line 44 def self.optionals %w[ grant_type refresh_token scope headers host ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 |
# File 'lib/verizon/models/target_authentication_body.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} grant_type: #{@grant_type.inspect}, refresh_token:"\ " #{@refresh_token.inspect}, scope: #{@scope.inspect}, headers: #{@headers.inspect}, host:"\ " #{@host.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/verizon/models/target_authentication_body.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} grant_type: #{@grant_type}, refresh_token: #{@refresh_token}, scope:"\ " #{@scope}, headers: #{@headers}, host: #{@host}, additional_properties:"\ " #{@additional_properties}>" end |