Class: Verizon::TargetAuthenticationBodyHeaders

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/target_authentication_body_headers.rb

Overview

Authentication headers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(authorization: SKIP, content_type: SKIP, additional_properties: nil) ⇒ TargetAuthenticationBodyHeaders

Returns a new instance of TargetAuthenticationBodyHeaders.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 41

def initialize(authorization: SKIP, content_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @authorization = authorization unless authorization == SKIP
  @content_type = content_type unless content_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#authorizationString

Authorization header.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 14

def authorization
  @authorization
end

#content_typeString

Content-Type header.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 18

def content_type
  @content_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  authorization = hash.key?('Authorization') ? hash['Authorization'] : SKIP
  content_type = hash.key?('Content-Type') ? hash['Content-Type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TargetAuthenticationBodyHeaders.new(authorization: authorization,
                                      content_type: content_type,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['authorization'] = 'Authorization'
  @_hash['content_type'] = 'Content-Type'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 29

def self.optionals
  %w[
    authorization
    content_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} authorization: #{@authorization.inspect}, content_type:"\
  " #{@content_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/verizon/models/target_authentication_body_headers.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} authorization: #{@authorization}, content_type: #{@content_type},"\
  " additional_properties: #{@additional_properties}>"
end