Class: Verizon::TargetAuthenticationBodyHost

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/target_authentication_body_host.rb

Overview

Host information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(hostandpath: SKIP, additional_properties: nil) ⇒ TargetAuthenticationBodyHost

Returns a new instance of TargetAuthenticationBodyHost.



35
36
37
38
39
40
41
# File 'lib/verizon/models/target_authentication_body_host.rb', line 35

def initialize(hostandpath: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @hostandpath = hostandpath unless hostandpath == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#hostandpathString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/target_authentication_body_host.rb', line 14

def hostandpath
  @hostandpath
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/verizon/models/target_authentication_body_host.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  hostandpath = hash.key?('hostandpath') ? hash['hostandpath'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TargetAuthenticationBodyHost.new(hostandpath: hostandpath,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/target_authentication_body_host.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['hostandpath'] = 'hostandpath'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/target_authentication_body_host.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/target_authentication_body_host.rb', line 24

def self.optionals
  %w[
    hostandpath
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/verizon/models/target_authentication_body_host.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} hostandpath: #{@hostandpath.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
67
# File 'lib/verizon/models/target_authentication_body_host.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} hostandpath: #{@hostandpath}, additional_properties:"\
  " #{@additional_properties}>"
end