Class: Verizon::TextPhraseOrItis
- Defined in:
- lib/verizon/models/text_phrase_or_itis.rb
Overview
TextPhraseOrItis Model.
Instance Attribute Summary collapse
-
#item ⇒ ItisItem
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(item:, additional_properties: nil) ⇒ TextPhraseOrItis
constructor
A new instance of TextPhraseOrItis.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item:, additional_properties: nil) ⇒ TextPhraseOrItis
Returns a new instance of TextPhraseOrItis.
33 34 35 36 37 38 39 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 33 def initialize(item:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item = item @additional_properties = additional_properties end |
Instance Attribute Details
#item ⇒ ItisItem
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 14 def item @item end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item = ItisItem.from_hash(hash['item']) if hash['item'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TextPhraseOrItis.new(item: item, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['item'] = 'item' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 62 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.item, ->(val) { ItisItem.validate(val) }, is_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['item'], ->(val) { ItisItem.validate(val) }, is_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} item: #{@item.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 |
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} item: #{@item}, additional_properties: #{@additional_properties}>" end |