Class: Verizon::TheIDresourceandDeviceId
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::TheIDresourceandDeviceId
- Defined in:
- lib/verizon/models/the_i_dresourceand_device_id.rb
Overview
TheIDresourceandDeviceId Model.
Instance Attribute Summary collapse
-
#deviceid ⇒ String
This is a UUID value of the device created when the device is onboarded.
-
#id ⇒ String
UUID of the user record, assigned at creation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, deviceid: SKIP, additional_properties: nil) ⇒ TheIDresourceandDeviceId
constructor
A new instance of TheIDresourceandDeviceId.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, deviceid: SKIP, additional_properties: nil) ⇒ TheIDresourceandDeviceId
Returns a new instance of TheIDresourceandDeviceId.
41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 41 def initialize(id: SKIP, deviceid: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @deviceid = deviceid unless deviceid == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#deviceid ⇒ String
This is a UUID value of the device created when the device is onboarded
18 19 20 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 18 def deviceid @deviceid end |
#id ⇒ String
UUID of the user record, assigned at creation
14 15 16 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 14 def id @id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP deviceid = hash.key?('deviceid') ? hash['deviceid'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TheIDresourceandDeviceId.new(id: id, deviceid: deviceid, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['deviceid'] = 'deviceid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 29 def self.optionals %w[ id deviceid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, deviceid: #{@deviceid.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/verizon/models/the_i_dresourceand_device_id.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, deviceid: #{@deviceid}, additional_properties:"\ " #{@additional_properties}>" end |