Class: Verizon::TriggerType2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/trigger_type2.rb

Overview

Trigger details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(anomalyattributes: SKIP, notification: SKIP) ⇒ TriggerType2

Returns a new instance of TriggerType2.



41
42
43
44
# File 'lib/verizon/models/trigger_type2.rb', line 41

def initialize(anomalyattributes: SKIP, notification: SKIP)
  @anomalyattributes = anomalyattributes unless anomalyattributes == SKIP
  @notification = notification unless notification == SKIP
end

Instance Attribute Details

#anomalyattributesUsageAnomalyAttributes

The details of the UsageAnomaly trigger.



14
15
16
# File 'lib/verizon/models/trigger_type2.rb', line 14

def anomalyattributes
  @anomalyattributes
end

#notificationTriggerNotification

The notification details of the trigger.

Returns:



18
19
20
# File 'lib/verizon/models/trigger_type2.rb', line 18

def notification
  @notification
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/trigger_type2.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  anomalyattributes = UsageAnomalyAttributes.from_hash(hash['anomalyattributes']) if
    hash['anomalyattributes']
  notification = TriggerNotification.from_hash(hash['notification']) if hash['notification']

  # Create object from extracted values.
  TriggerType2.new(anomalyattributes: anomalyattributes,
                   notification: notification)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/trigger_type2.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['anomalyattributes'] = 'anomalyattributes'
  @_hash['notification'] = 'notification'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/trigger_type2.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/trigger_type2.rb', line 29

def self.optionals
  %w[
    anomalyattributes
    notification
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (TriggerType2 | Hash)

    value against the validation is performed.



62
63
64
65
66
67
68
# File 'lib/verizon/models/trigger_type2.rb', line 62

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/verizon/models/trigger_type2.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} anomalyattributes: #{@anomalyattributes.inspect}, notification:"\
  " #{@notification.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/verizon/models/trigger_type2.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} anomalyattributes: #{@anomalyattributes}, notification: #{@notification}>"
end