Class: Verizon::UpdatePricePlanTriggersApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/verizon/apis/update_price_plan_triggers_api.rb

Overview

UpdatePricePlanTriggersApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Verizon::BaseApi

Instance Method Details

#update_trigger_rules(body) ⇒ ApiResponse

Updates a usage trigger at the account level, device level or a price plan trigger for all devices on the account | AccountGroupShareUpdateTriggerRequest | AccountShareUpdateTriggerRequest | PayAsYouGoUpdateTriggerRequest | Updatetriggerchunk] body Required parameter: Update a trigger

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/verizon/apis/update_price_plan_triggers_api.rb', line 16

def update_trigger_rules(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/v2/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true)
                            .validator(proc do |value|
                              UnionTypeLookUp.get(:UpdateTriggerRulesBody)
                                             .validate(value)
                            end))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(APIHelper.method(:json_serialize))
               .auth(Or.new('thingspace_oauth1', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(TriggerResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             RuleRestErrorResponseException))
    .execute
end