Class: Verizon::V1ListOfLicensesToRemoveRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::V1ListOfLicensesToRemoveRequest
- Defined in:
- lib/verizon/models/v1_list_of_licenses_to_remove_request.rb
Overview
List of devices to removes.
Instance Attribute Summary collapse
-
#device_list ⇒ Array[String]
The IMEIs of the devices.
-
#type ⇒ String
Set to ‘append’ to append the devices in the current request to the existing list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list:, type: SKIP, additional_properties: nil) ⇒ V1ListOfLicensesToRemoveRequest
constructor
A new instance of V1ListOfLicensesToRemoveRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list:, type: SKIP, additional_properties: nil) ⇒ V1ListOfLicensesToRemoveRequest
Returns a new instance of V1ListOfLicensesToRemoveRequest.
43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 43 def initialize(device_list:, type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#device_list ⇒ Array[String]
The IMEIs of the devices.
21 22 23 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 21 def device_list @device_list end |
#type ⇒ String
Set to ‘append’ to append the devices in the current request to the existing list. If there is no existing list then it will be created with only these devices. Leave this parameter out when you want to replace the existing list with the devices in the current request.
17 18 19 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 17 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_list = hash.key?('deviceList') ? hash['deviceList'] : nil type = hash.key?('type') ? hash['type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V1ListOfLicensesToRemoveRequest.new(device_list: device_list, type: type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 32 def self.optionals %w[ type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, device_list: #{@device_list.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_request.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, device_list: #{@device_list}, additional_properties:"\ " #{@additional_properties}>" end |