Class: Verizon::V1ListOfLicensesToRemoveResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::V1ListOfLicensesToRemoveResult
- Defined in:
- lib/verizon/models/v1_list_of_licenses_to_remove_result.rb
Overview
List of licenses assigned.
Instance Attribute Summary collapse
-
#count ⇒ Integer
The total number of devices on the cancellation candidate list.
-
#device_list ⇒ Array[String]
The IMEIs of the devices.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count: SKIP, device_list: SKIP, additional_properties: nil) ⇒ V1ListOfLicensesToRemoveResult
constructor
A new instance of V1ListOfLicensesToRemoveResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count: SKIP, device_list: SKIP, additional_properties: nil) ⇒ V1ListOfLicensesToRemoveResult
Returns a new instance of V1ListOfLicensesToRemoveResult.
41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 41 def initialize(count: SKIP, device_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @count = count unless count == SKIP @device_list = device_list unless device_list == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#count ⇒ Integer
The total number of devices on the cancellation candidate list.
14 15 16 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 14 def count @count end |
#device_list ⇒ Array[String]
The IMEIs of the devices.
18 19 20 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 18 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : SKIP device_list = hash.key?('deviceList') ? hash['deviceList'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V1ListOfLicensesToRemoveResult.new(count: count, device_list: device_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['count'] = 'count' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 29 def self.optionals %w[ count device_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} count: #{@count.inspect}, device_list: #{@device_list.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/verizon/models/v1_list_of_licenses_to_remove_result.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} count: #{@count}, device_list: #{@device_list}, additional_properties:"\ " #{@additional_properties}>" end |