Class: Verizon::V2AddOrRemoveDeviceResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::V2AddOrRemoveDeviceResult
- Defined in:
- lib/verizon/models/v2_add_or_remove_device_result.rb
Overview
Add or remove devices from the existing software upgrade information.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier.
-
#campaign_id ⇒ String
Campaign identifier.
-
#request_id ⇒ String
Request identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, campaign_id:, request_id:, additional_properties: nil) ⇒ V2AddOrRemoveDeviceResult
constructor
A new instance of V2AddOrRemoveDeviceResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, campaign_id:, request_id:, additional_properties: nil) ⇒ V2AddOrRemoveDeviceResult
Returns a new instance of V2AddOrRemoveDeviceResult.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 43 def initialize(account_name:, campaign_id:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @campaign_id = campaign_id @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account identifier.
14 15 16 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 14 def account_name @account_name end |
#campaign_id ⇒ String
Campaign identifier.
18 19 20 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 18 def campaign_id @campaign_id end |
#request_id ⇒ String
Request identifier.
22 23 24 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 22 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil campaign_id = hash.key?('campaignId') ? hash['campaignId'] : nil request_id = hash.key?('requestId') ? hash['requestId'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V2AddOrRemoveDeviceResult.new(account_name: account_name, campaign_id: campaign_id, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['campaign_id'] = 'campaignId' @_hash['request_id'] = 'requestId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, campaign_id:"\ " #{@campaign_id.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/verizon/models/v2_add_or_remove_device_result.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, campaign_id: #{@campaign_id}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |