Class: Verizon::V2LicenseImei
- Defined in:
- lib/verizon/models/v2_license_imei.rb
Overview
IMEIs of the devices to assign or remove licenses.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#device_list ⇒ Array[String]
Device IMEI list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list:, account_name: SKIP, additional_properties: nil) ⇒ V2LicenseImei
constructor
A new instance of V2LicenseImei.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list:, account_name: SKIP, additional_properties: nil) ⇒ V2LicenseImei
Returns a new instance of V2LicenseImei.
40 41 42 43 44 45 46 47 |
# File 'lib/verizon/models/v2_license_imei.rb', line 40 def initialize(device_list:, account_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name unless account_name == SKIP @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account name.
14 15 16 |
# File 'lib/verizon/models/v2_license_imei.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[String]
Device IMEI list.
18 19 20 |
# File 'lib/verizon/models/v2_license_imei.rb', line 18 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/verizon/models/v2_license_imei.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_list = hash.key?('deviceList') ? hash['deviceList'] : nil account_name = hash.key?('accountName') ? hash['accountName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V2LicenseImei.new(device_list: device_list, account_name: account_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/v2_license_imei.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/verizon/models/v2_license_imei.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/verizon/models/v2_license_imei.rb', line 29 def self.optionals %w[ account_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/verizon/models/v2_license_imei.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_list:"\ " #{@device_list.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/verizon/models/v2_license_imei.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_list: #{@device_list},"\ " additional_properties: #{@additional_properties}>" end |