Class: Verizon::V2LicenseSummary

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/v2_license_summary.rb

Overview

Summary of license assignment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name:, assigned_licenses:, has_more_data:, max_page_size:, total_license: SKIP, last_seen_device_id: SKIP, device_list: SKIP, additional_properties: nil) ⇒ V2LicenseSummary

Returns a new instance of V2LicenseSummary.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/verizon/models/v2_license_summary.rb', line 67

def initialize(account_name:, assigned_licenses:, has_more_data:,
               max_page_size:, total_license: SKIP,
               last_seen_device_id: SKIP, device_list: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name = 
  @total_license = total_license unless total_license == SKIP
  @assigned_licenses = assigned_licenses
  @has_more_data = has_more_data
  @last_seen_device_id = last_seen_device_id unless last_seen_device_id == SKIP
  @max_page_size = max_page_size
  @device_list = device_list unless device_list == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

Account identifier.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/v2_license_summary.rb', line 14

def 
  @account_name
end

#assigned_licensesInteger

Assigned FOTA license count.

Returns:

  • (Integer)


22
23
24
# File 'lib/verizon/models/v2_license_summary.rb', line 22

def assigned_licenses
  @assigned_licenses
end

#device_listArray[V2LicenseDevice]

Device IMEI list.

Returns:



38
39
40
# File 'lib/verizon/models/v2_license_summary.rb', line 38

def device_list
  @device_list
end

#has_more_dataTrueClass | FalseClass

True if there are more devices to retrieve.

Returns:

  • (TrueClass | FalseClass)


26
27
28
# File 'lib/verizon/models/v2_license_summary.rb', line 26

def has_more_data
  @has_more_data
end

#last_seen_device_idString

Last seen device identifier.

Returns:

  • (String)


30
31
32
# File 'lib/verizon/models/v2_license_summary.rb', line 30

def last_seen_device_id
  @last_seen_device_id
end

#max_page_sizeInteger

Maximum page size.

Returns:

  • (Integer)


34
35
36
# File 'lib/verizon/models/v2_license_summary.rb', line 34

def max_page_size
  @max_page_size
end

#total_licenseInteger

Total FOTA license count.

Returns:

  • (Integer)


18
19
20
# File 'lib/verizon/models/v2_license_summary.rb', line 18

def total_license
  @total_license
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/verizon/models/v2_license_summary.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : nil
  assigned_licenses =
    hash.key?('assignedLicenses') ? hash['assignedLicenses'] : nil
  has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : nil
  max_page_size = hash.key?('maxPageSize') ? hash['maxPageSize'] : nil
  total_license = hash.key?('totalLicense') ? hash['totalLicense'] : SKIP
  last_seen_device_id =
    hash.key?('lastSeenDeviceId') ? hash['lastSeenDeviceId'] : SKIP
  # Parameter is an array, so we need to iterate through it
  device_list = nil
  unless hash['deviceList'].nil?
    device_list = []
    hash['deviceList'].each do |structure|
      device_list << (V2LicenseDevice.from_hash(structure) if structure)
    end
  end

  device_list = SKIP unless hash.key?('deviceList')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  V2LicenseSummary.new(account_name: ,
                       assigned_licenses: assigned_licenses,
                       has_more_data: has_more_data,
                       max_page_size: max_page_size,
                       total_license: total_license,
                       last_seen_device_id: last_seen_device_id,
                       device_list: device_list,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/verizon/models/v2_license_summary.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['total_license'] = 'totalLicense'
  @_hash['assigned_licenses'] = 'assignedLicenses'
  @_hash['has_more_data'] = 'hasMoreData'
  @_hash['last_seen_device_id'] = 'lastSeenDeviceId'
  @_hash['max_page_size'] = 'maxPageSize'
  @_hash['device_list'] = 'deviceList'
  @_hash
end

.nullablesObject

An array for nullable fields



63
64
65
# File 'lib/verizon/models/v2_license_summary.rb', line 63

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
59
60
# File 'lib/verizon/models/v2_license_summary.rb', line 54

def self.optionals
  %w[
    total_license
    last_seen_device_id
    device_list
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



136
137
138
139
140
141
142
143
# File 'lib/verizon/models/v2_license_summary.rb', line 136

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, total_license:"\
  " #{@total_license.inspect}, assigned_licenses: #{@assigned_licenses.inspect},"\
  " has_more_data: #{@has_more_data.inspect}, last_seen_device_id:"\
  " #{@last_seen_device_id.inspect}, max_page_size: #{@max_page_size.inspect}, device_list:"\
  " #{@device_list.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



127
128
129
130
131
132
133
# File 'lib/verizon/models/v2_license_summary.rb', line 127

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, total_license: #{@total_license},"\
  " assigned_licenses: #{@assigned_licenses}, has_more_data: #{@has_more_data},"\
  " last_seen_device_id: #{@last_seen_device_id}, max_page_size: #{@max_page_size},"\
  " device_list: #{@device_list}, additional_properties: #{@additional_properties}>"
end