Class: Verizon::V2LicensesAssignedRemovedResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/v2_licenses_assigned_removed_result.rb

Overview

License assignment or removal confirmation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name:, lic_total_count:, lic_used_count:, device_list:, additional_properties: nil) ⇒ V2LicensesAssignedRemovedResult

Returns a new instance of V2LicensesAssignedRemovedResult.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 48

def initialize(account_name:, lic_total_count:, lic_used_count:,
               device_list:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_name = 
  @lic_total_count = lic_total_count
  @lic_used_count = lic_used_count
  @device_list = device_list
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nameString

Account name.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 14

def 
  @account_name
end

#device_listArray[V2DeviceStatus]

List of devices with id in IMEI.

Returns:



26
27
28
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 26

def device_list
  @device_list
end

#lic_total_countInteger

Total license count.

Returns:

  • (Integer)


18
19
20
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 18

def lic_total_count
  @lic_total_count
end

#lic_used_countInteger

Assigned license count.

Returns:

  • (Integer)


22
23
24
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 22

def lic_used_count
  @lic_used_count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : nil
  lic_total_count = hash.key?('licTotalCount') ? hash['licTotalCount'] : nil
  lic_used_count = hash.key?('licUsedCount') ? hash['licUsedCount'] : nil
  # Parameter is an array, so we need to iterate through it
  device_list = nil
  unless hash['deviceList'].nil?
    device_list = []
    hash['deviceList'].each do |structure|
      device_list << (V2DeviceStatus.from_hash(structure) if structure)
    end
  end

  device_list = nil unless hash.key?('deviceList')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  V2LicensesAssignedRemovedResult.new(account_name: ,
                                      lic_total_count: lic_total_count,
                                      lic_used_count: lic_used_count,
                                      device_list: device_list,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['lic_total_count'] = 'licTotalCount'
  @_hash['lic_used_count'] = 'licUsedCount'
  @_hash['device_list'] = 'deviceList'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
108
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, lic_total_count:"\
  " #{@lic_total_count.inspect}, lic_used_count: #{@lic_used_count.inspect}, device_list:"\
  " #{@device_list.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
100
# File 'lib/verizon/models/v2_licenses_assigned_removed_result.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, lic_total_count: #{@lic_total_count},"\
  " lic_used_count: #{@lic_used_count}, device_list: #{@device_list}, additional_properties:"\
  " #{@additional_properties}>"
end