Class: Verizon::V2ListOfLicensesToRemoveRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::V2ListOfLicensesToRemoveRequest
- Defined in:
- lib/verizon/models/v2_list_of_licenses_to_remove_request.rb
Overview
License cancellation candidate devices.
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of devices.
-
#device_list ⇒ Array[String]
Device IMEI list.
-
#type ⇒ String
List creation option.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list:, type: SKIP, count: SKIP, additional_properties: nil) ⇒ V2ListOfLicensesToRemoveRequest
constructor
A new instance of V2ListOfLicensesToRemoveRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list:, type: SKIP, count: SKIP, additional_properties: nil) ⇒ V2ListOfLicensesToRemoveRequest
Returns a new instance of V2ListOfLicensesToRemoveRequest.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 46 def initialize(device_list:, type: SKIP, count: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @count = count unless count == SKIP @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#count ⇒ Integer
The number of devices.
18 19 20 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 18 def count @count end |
#device_list ⇒ Array[String]
Device IMEI list.
22 23 24 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 22 def device_list @device_list end |
#type ⇒ String
List creation option.
14 15 16 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 14 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_list = hash.key?('deviceList') ? hash['deviceList'] : nil type = hash.key?('type') ? hash['type'] : SKIP count = hash.key?('count') ? hash['count'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V2ListOfLicensesToRemoveRequest.new(device_list: device_list, type: type, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['count'] = 'count' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 34 def self.optionals %w[ type count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, count: #{@count.inspect}, device_list:"\ " #{@device_list.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove_request.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, count: #{@count}, device_list: #{@device_list},"\ " additional_properties: #{@additional_properties}>" end |