Class: Verizon::V2SoftwareInfo
- Defined in:
- lib/verizon/models/v2_software_info.rb
Overview
Software information.
Instance Attribute Summary collapse
-
#name ⇒ String
Software name.
-
#upgrade_time ⇒ String
Upgrade time.
-
#version ⇒ String
Software version.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, version:, upgrade_time:, additional_properties: nil) ⇒ V2SoftwareInfo
constructor
A new instance of V2SoftwareInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, version:, upgrade_time:, additional_properties: nil) ⇒ V2SoftwareInfo
Returns a new instance of V2SoftwareInfo.
43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/v2_software_info.rb', line 43 def initialize(name:, version:, upgrade_time:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @version = version @upgrade_time = upgrade_time @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
Software name.
14 15 16 |
# File 'lib/verizon/models/v2_software_info.rb', line 14 def name @name end |
#upgrade_time ⇒ String
Upgrade time.
22 23 24 |
# File 'lib/verizon/models/v2_software_info.rb', line 22 def upgrade_time @upgrade_time end |
#version ⇒ String
Software version.
18 19 20 |
# File 'lib/verizon/models/v2_software_info.rb', line 18 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/verizon/models/v2_software_info.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil version = hash.key?('version') ? hash['version'] : nil upgrade_time = hash.key?('upgradeTime') ? hash['upgradeTime'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V2SoftwareInfo.new(name: name, version: version, upgrade_time: upgrade_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/v2_software_info.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['version'] = 'version' @_hash['upgrade_time'] = 'upgradeTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/v2_software_info.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/verizon/models/v2_software_info.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/verizon/models/v2_software_info.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, version: #{@version.inspect}, upgrade_time:"\ " #{@upgrade_time.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/verizon/models/v2_software_info.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, version: #{@version}, upgrade_time: #{@upgrade_time},"\ " additional_properties: #{@additional_properties}>" end |