Class: Verizon::V3AccountDeviceList
- Defined in:
- lib/verizon/models/v3_account_device_list.rb
Overview
Array of devices.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#device_list ⇒ Array[V3AccountDevice]
Account device list.
-
#has_more_data ⇒ TrueClass | FalseClass
Has more device flag?.
-
#last_seen_device_id ⇒ String
Last seen device identifier.
-
#max_page_size ⇒ Integer
Maximum page size.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, has_more_data:, max_page_size:, device_list:, last_seen_device_id: SKIP, additional_properties: nil) ⇒ V3AccountDeviceList
constructor
A new instance of V3AccountDeviceList.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, has_more_data:, max_page_size:, device_list:, last_seen_device_id: SKIP, additional_properties: nil) ⇒ V3AccountDeviceList
Returns a new instance of V3AccountDeviceList.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 55 def initialize(account_name:, has_more_data:, max_page_size:, device_list:, last_seen_device_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @has_more_data = has_more_data @last_seen_device_id = last_seen_device_id unless last_seen_device_id == SKIP @max_page_size = max_page_size @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account name.
14 15 16 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[V3AccountDevice]
Account device list.
30 31 32 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 30 def device_list @device_list end |
#has_more_data ⇒ TrueClass | FalseClass
Has more device flag?
18 19 20 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 18 def has_more_data @has_more_data end |
#last_seen_device_id ⇒ String
Last seen device identifier.
22 23 24 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 22 def last_seen_device_id @last_seen_device_id end |
#max_page_size ⇒ Integer
Maximum page size.
26 27 28 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 26 def max_page_size @max_page_size end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : nil max_page_size = hash.key?('maxPageSize') ? hash['maxPageSize'] : nil # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (V3AccountDevice.from_hash(structure) if structure) end end device_list = nil unless hash.key?('deviceList') last_seen_device_id = hash.key?('lastSeenDeviceId') ? hash['lastSeenDeviceId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V3AccountDeviceList.new(account_name: account_name, has_more_data: has_more_data, max_page_size: max_page_size, device_list: device_list, last_seen_device_id: last_seen_device_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['has_more_data'] = 'hasMoreData' @_hash['last_seen_device_id'] = 'lastSeenDeviceId' @_hash['max_page_size'] = 'maxPageSize' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 44 def self.optionals %w[ last_seen_device_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 120 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, has_more_data:"\ " #{@has_more_data.inspect}, last_seen_device_id: #{@last_seen_device_id.inspect},"\ " max_page_size: #{@max_page_size.inspect}, device_list: #{@device_list.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/verizon/models/v3_account_device_list.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, has_more_data: #{@has_more_data},"\ " last_seen_device_id: #{@last_seen_device_id}, max_page_size: #{@max_page_size},"\ " device_list: #{@device_list}, additional_properties: #{@additional_properties}>" end |