Class: Verizon::AccountDevicesApi
- Defined in:
- lib/verizon/apis/account_devices_api.rb
Overview
AccountDevicesApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_account_device_information(acc, last_seen_device_id: nil, protocol: DevicesProtocol::LW_M2M) ⇒ ApiResponse
Retrieve account device information such as reported firmware on the devices.
-
#list_account_devices_information(acc, body) ⇒ ApiResponse
Retrieve device information for a list of devices on an account.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#get_account_device_information(acc, last_seen_device_id: nil, protocol: DevicesProtocol::LW_M2M) ⇒ ApiResponse
Retrieve account device information such as reported firmware on the devices. identifier. specific protocol type used.
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/verizon/apis/account_devices_api.rb', line 17 def get_account_device_information(acc, last_seen_device_id: nil, protocol: DevicesProtocol::LW_M2M) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/devices/{acc}', Server::SOFTWARE_MANAGEMENT_V3) .template_param(new_parameter(acc, key: 'acc') .is_required(true) .should_encode(true)) .query_param(new_parameter(last_seen_device_id, key: 'lastSeenDeviceId')) .query_param(new_parameter(protocol, key: 'protocol')) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(V3AccountDeviceList.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', FotaV3ResultException)) .execute end |
#list_account_devices_information(acc, body) ⇒ ApiResponse
Retrieve device information for a list of devices on an account. information.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/verizon/apis/account_devices_api.rb', line 46 def list_account_devices_information(acc, body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/devices/{acc}', Server::SOFTWARE_MANAGEMENT_V3) .template_param(new_parameter(acc, key: 'acc') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceListResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', FotaV3ResultException)) .execute end |