Class: Verizon::AccountLevelObject
- Defined in:
- lib/verizon/models/account_level_object.rb
Overview
AccountLevelObject Model.
Instance Attribute Summary collapse
-
#action ⇒ AccountLevelAction
The action taken when trigger conditions are met.
-
#condition ⇒ Object
TODO: Write general description for this method.
-
#filter_criteria ⇒ AccountLevelFilter
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(filter_criteria: SKIP, condition: SKIP, action: SKIP, additional_properties: nil) ⇒ AccountLevelObject
constructor
A new instance of AccountLevelObject.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(filter_criteria: SKIP, condition: SKIP, action: SKIP, additional_properties: nil) ⇒ AccountLevelObject
Returns a new instance of AccountLevelObject.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/account_level_object.rb', line 47 def initialize(filter_criteria: SKIP, condition: SKIP, action: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @filter_criteria = filter_criteria unless filter_criteria == SKIP @condition = condition unless condition == SKIP @action = action unless action == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#action ⇒ AccountLevelAction
The action taken when trigger conditions are met
22 23 24 |
# File 'lib/verizon/models/account_level_object.rb', line 22 def action @action end |
#condition ⇒ Object
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/account_level_object.rb', line 18 def condition @condition end |
#filter_criteria ⇒ AccountLevelFilter
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/account_level_object.rb', line 14 def filter_criteria @filter_criteria end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/models/account_level_object.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. filter_criteria = AccountLevelFilter.from_hash(hash['filterCriteria']) if hash['filterCriteria'] condition = hash.key?('condition') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:AccountLevelObjectCondition), hash['condition'] ) : SKIP action = hash.key?('action') ? hash['action'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountLevelObject.new(filter_criteria: filter_criteria, condition: condition, action: action, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/account_level_object.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['filter_criteria'] = 'filterCriteria' @_hash['condition'] = 'condition' @_hash['action'] = 'action' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/account_level_object.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/account_level_object.rb', line 34 def self.optionals %w[ filter_criteria condition action ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
86 87 88 89 90 91 92 |
# File 'lib/verizon/models/account_level_object.rb', line 86 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/verizon/models/account_level_object.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} filter_criteria: #{@filter_criteria.inspect}, condition:"\ " #{@condition.inspect}, action: #{@action.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/verizon/models/account_level_object.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} filter_criteria: #{@filter_criteria}, condition: #{@condition}, action:"\ " #{@action}, additional_properties: #{@additional_properties}>" end |