Class: Verizon::AccountSubscriptionsApi
- Defined in:
- lib/verizon/apis/account_subscriptions_api.rb
Overview
AccountSubscriptionsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#list_account_subscriptions(body, x_request_id: nil) ⇒ ApiResponse
Retrieves the total number of SIM-Secure for IoT subscription licenses purchased for your account by license type, and lists the number of licenses assigned and available for each license type.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#list_account_subscriptions(body, x_request_id: nil) ⇒ ApiResponse
Retrieves the total number of SIM-Secure for IoT subscription licenses purchased for your account by license type, and lists the number of licenses assigned and available for each license type. account subscription.
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/apis/account_subscriptions_api.rb', line 16 def list_account_subscriptions(body, x_request_id: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/v1/accounts/subscriptions/actions/list', Server::M2M) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter(x_request_id, key: 'X-Request-ID')) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(SecuritySubscriptionResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad request.', SecurityResultException) .local_error('401', 'Unauthorized request.', SecurityResultException) .local_error('403', 'Request forbidden.', SecurityResultException) .local_error('404', 'Not Found / Does not exist.', SecurityResultException) .local_error('406', 'Format / Request Unacceptable.', SecurityResultException) .local_error('429', 'Too many requests.', SecurityResultException) .local_error('default', 'Error response.', SecurityResultException)) .execute end |