Class: Verizon::AnomalySettingsApi
- Defined in:
- lib/verizon/apis/anomaly_settings_api.rb
Overview
AnomalySettingsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#activate_anomaly_detection(body) ⇒ ApiResponse
Uses the subscribed account ID to activate anomaly detection and set threshold values.
-
#list_anomaly_detection_settings(account_name) ⇒ ApiResponse
Retrieves the current anomaly detection settings for an account.
-
#reset_anomaly_detection_parameters(account_name) ⇒ ApiResponse
Resets the thresholds to zero.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#activate_anomaly_detection(body) ⇒ ApiResponse
Uses the subscribed account ID to activate anomaly detection and set threshold values. activate anomaly detection.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/verizon/apis/anomaly_settings_api.rb', line 14 def activate_anomaly_detection(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/intelligence/anomaly/settings', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IntelligenceSuccessResult.method(:from_hash)) .is_api_response(true) .local_error('default', 'An error occurred.', IntelligenceResultException)) .execute end |
#list_anomaly_detection_settings(account_name) ⇒ ApiResponse
Retrieves the current anomaly detection settings for an account. subscribed account.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/apis/anomaly_settings_api.rb', line 39 def list_anomaly_detection_settings(account_name) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/m2m/v1/intelligence/{accountName}/anomaly/settings', Server::THINGSPACE) .template_param(new_parameter(account_name, key: 'accountName') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(AnomalyDetectionSettings.method(:from_hash)) .is_api_response(true) .local_error('default', 'An error occurred.', IntelligenceResultException)) .execute end |
#reset_anomaly_detection_parameters(account_name) ⇒ ApiResponse
Resets the thresholds to zero. subscribed account.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/apis/anomaly_settings_api.rb', line 63 def reset_anomaly_detection_parameters(account_name) @api_call .request(new_request_builder(HttpMethodEnum::PUT, '/m2m/v1/intelligence/{accountName}/anomaly/settings/reset', Server::THINGSPACE) .template_param(new_parameter(account_name, key: 'accountName') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IntelligenceSuccessResult.method(:from_hash)) .is_api_response(true) .local_error('default', 'An error occurred.', IntelligenceResultException)) .execute end |