Class: Verizon::AppConfigResponseErrorException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- Verizon::AppConfigResponseErrorException
- Defined in:
- lib/verizon/exceptions/app_config_response_error_exception.rb
Overview
error response structure
Instance Attribute Summary collapse
-
#description ⇒ String
The detailed description of the error.
-
#error ⇒ String
The short summary of the error.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ AppConfigResponseErrorException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ AppConfigResponseErrorException
The constructor.
23 24 25 26 27 |
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#description ⇒ String
The detailed description of the error
18 19 20 |
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 18 def description @description end |
#error ⇒ String
The short summary of the error
14 15 16 |
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 14 def error @error end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
46 47 48 49 |
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 46 def inspect class_name = self.class.name.split('::').last "<#{class_name} error: #{@error.inspect}, description: #{@description.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
40 41 42 43 |
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 40 def to_s class_name = self.class.name.split('::').last "<#{class_name} error: #{@error}, description: #{@description}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 37 |
# File 'lib/verizon/exceptions/app_config_response_error_exception.rb', line 32 def unbox(hash) return nil unless hash @error = hash.key?('error') ? hash['error'] : nil @description = hash.key?('description') ? hash['description'] : nil end |