Class: Verizon::CallbackCreated
- Defined in:
- lib/verizon/models/callback_created.rb
Overview
CallbackCreated Model.
Instance Attribute Summary collapse
-
#account_name ⇒ HplAccountname
The numeric name of the account and must include leading zeroes.
-
#name ⇒ String
The name of the callback service, which identifies the type and format of messages that will be sent to the registered URL.
-
#url ⇒ String
The address of the callback listening service where the ThingSpace Platform will send callback messages for the service type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, name:, url: SKIP, additional_properties: nil) ⇒ CallbackCreated
constructor
A new instance of CallbackCreated.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, name:, url: SKIP, additional_properties: nil) ⇒ CallbackCreated
Returns a new instance of CallbackCreated.
47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/models/callback_created.rb', line 47 def initialize(account_name:, name:, url: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @name = name @url = url unless url == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ HplAccountname
The numeric name of the account and must include leading zeroes.
14 15 16 |
# File 'lib/verizon/models/callback_created.rb', line 14 def account_name @account_name end |
#name ⇒ String
The name of the callback service, which identifies the type and format of messages that will be sent to the registered URL.
19 20 21 |
# File 'lib/verizon/models/callback_created.rb', line 19 def name @name end |
#url ⇒ String
The address of the callback listening service where the ThingSpace Platform will send callback messages for the service type.
24 25 26 |
# File 'lib/verizon/models/callback_created.rb', line 24 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/callback_created.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = HplAccountname.from_hash(hash['accountName']) if hash['accountName'] name = hash.key?('name') ? hash['name'] : nil url = hash.key?('url') ? hash['url'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CallbackCreated.new(account_name: account_name, name: name, url: url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/verizon/models/callback_created.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['name'] = 'name' @_hash['url'] = 'url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/callback_created.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 |
# File 'lib/verizon/models/callback_created.rb', line 36 def self.optionals %w[ url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/verizon/models/callback_created.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, name: #{@name.inspect}, url:"\ " #{@url.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/verizon/models/callback_created.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, name: #{@name}, url: #{@url},"\ " additional_properties: #{@additional_properties}>" end |