Class: Verizon::ConnectivityCallbacksApi
- Defined in:
- lib/verizon/apis/connectivity_callbacks_api.rb
Overview
ConnectivityCallbacksApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#deregister_callback(aname, sname) ⇒ ApiResponse
Stops ThingSpace from sending callback messages for the specified account and service.
-
#list_registered_callbacks(aname) ⇒ ApiResponse
Returns the name and endpoint URL of the callback listening services registered for a given account.
-
#register_callback(aname, body) ⇒ ApiResponse
You are responsible for creating and running a listening process on your server at that URL.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#deregister_callback(aname, sname) ⇒ ApiResponse
Stops ThingSpace from sending callback messages for the specified account and service.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/verizon/apis/connectivity_callbacks_api.rb', line 70 def deregister_callback(aname, sname) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/m2m/v1/callbacks/{aname}/name/{sname}', Server::THINGSPACE) .template_param(new_parameter(aname, key: 'aname') .is_required(true) .should_encode(true)) .template_param(new_parameter(sname, key: 'sname') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CallbackActionResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |
#list_registered_callbacks(aname) ⇒ ApiResponse
Returns the name and endpoint URL of the callback listening services registered for a given account.
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/verizon/apis/connectivity_callbacks_api.rb', line 13 def list_registered_callbacks(aname) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/m2m/v1/callbacks/{aname}', Server::THINGSPACE) .template_param(new_parameter(aname, key: 'aname') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ConnectivityManagementCallback.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |
#register_callback(aname, body) ⇒ ApiResponse
You are responsible for creating and running a listening process on your server at that URL. register a callback.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/apis/connectivity_callbacks_api.rb', line 40 def register_callback(aname, body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/callbacks/{aname}', Server::THINGSPACE) .template_param(new_parameter(aname, key: 'aname') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CallbackActionResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |