Class: Verizon::ConsentRequest
- Defined in:
- lib/verizon/models/consent_request.rb
Overview
ConsentRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier in “##########-#####”.
-
#all_device ⇒ TrueClass | FalseClass
Exclude all devices or not.
-
#exclusion ⇒ Array[String]
Device ID list.
-
#type ⇒ String
The change to make: append or replace.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, all_device: SKIP, type: SKIP, exclusion: SKIP, additional_properties: nil) ⇒ ConsentRequest
constructor
A new instance of ConsentRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, all_device: SKIP, type: SKIP, exclusion: SKIP, additional_properties: nil) ⇒ ConsentRequest
Returns a new instance of ConsentRequest.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/consent_request.rb', line 52 def initialize(account_name:, all_device: SKIP, type: SKIP, exclusion: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @all_device = all_device unless all_device == SKIP @type = type unless type == SKIP @exclusion = exclusion unless exclusion == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account identifier in “##########-#####”.
14 15 16 |
# File 'lib/verizon/models/consent_request.rb', line 14 def account_name @account_name end |
#all_device ⇒ TrueClass | FalseClass
Exclude all devices or not.
18 19 20 |
# File 'lib/verizon/models/consent_request.rb', line 18 def all_device @all_device end |
#exclusion ⇒ Array[String]
Device ID list.
26 27 28 |
# File 'lib/verizon/models/consent_request.rb', line 26 def exclusion @exclusion end |
#type ⇒ String
The change to make: append or replace.
22 23 24 |
# File 'lib/verizon/models/consent_request.rb', line 22 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/verizon/models/consent_request.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil all_device = hash.key?('allDevice') ? hash['allDevice'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP exclusion = hash.key?('exclusion') ? hash['exclusion'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConsentRequest.new(account_name: account_name, all_device: all_device, type: type, exclusion: exclusion, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/verizon/models/consent_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['all_device'] = 'allDevice' @_hash['type'] = 'type' @_hash['exclusion'] = 'exclusion' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/verizon/models/consent_request.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 |
# File 'lib/verizon/models/consent_request.rb', line 39 def self.optionals %w[ all_device type exclusion ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/verizon/models/consent_request.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, all_device: #{@all_device.inspect},"\ " type: #{@type.inspect}, exclusion: #{@exclusion.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/verizon/models/consent_request.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, all_device: #{@all_device}, type: #{@type},"\ " exclusion: #{@exclusion}, additional_properties: #{@additional_properties}>" end |