Class: Verizon::CreatePricePlanTriggersApi
- Defined in:
- lib/verizon/apis/create_price_plan_triggers_api.rb
Overview
CreatePricePlanTriggersApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#create_trigger_rules(body) ⇒ ApiResponse
Create a usage trigger at the account level, device level or a price plan trigger for all devices on the account DeviceLevelCreateTriggerRequest | AccountGroupShareCreateTriggerRequest | AccountShareCreateTriggerRequest | PayAsYouGoCreateTriggerRequest | Createtriggerchunk] body Required parameter: Create a trigger.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#create_trigger_rules(body) ⇒ ApiResponse
Create a usage trigger at the account level, device level or a price plan trigger for all devices on the account DeviceLevelCreateTriggerRequest | AccountGroupShareCreateTriggerRequest | AccountShareCreateTriggerRequest | PayAsYouGoCreateTriggerRequest | Createtriggerchunk] body Required parameter: Create a trigger
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/verizon/apis/create_price_plan_triggers_api.rb', line 16 def create_trigger_rules(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/v2/triggers', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true) .validator(proc do |value| UnionTypeLookUp.get(:CreateTriggerRulesBody) .validate(value) end)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(APIHelper.method(:json_serialize)) .auth(Or.new('thingspace_oauth1', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(TriggerResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', RuleRestErrorResponseException)) .execute end |