Class: Verizon::DeleteDevicesRequest
- Defined in:
- lib/verizon/models/delete_devices_request.rb
Overview
Request to delete a device request.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The Verizon billing account that the device group belongs to.
-
#devices_to_delete ⇒ Array[AccountDeviceList]
A list of up to 100 devices that you want to delete, specified by device identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(devices_to_delete:, account_name: SKIP, additional_properties: nil) ⇒ DeleteDevicesRequest
constructor
A new instance of DeleteDevicesRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(devices_to_delete:, account_name: SKIP, additional_properties: nil) ⇒ DeleteDevicesRequest
Returns a new instance of DeleteDevicesRequest.
42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/delete_devices_request.rb', line 42 def initialize(devices_to_delete:, account_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @devices_to_delete = devices_to_delete @account_name = account_name unless account_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The Verizon billing account that the device group belongs to. An account name is usually numeric, and must include any leading zeros.
20 21 22 |
# File 'lib/verizon/models/delete_devices_request.rb', line 20 def account_name @account_name end |
#devices_to_delete ⇒ Array[AccountDeviceList]
A list of up to 100 devices that you want to delete, specified by device identifier. You only need to provide one identifier per device.
15 16 17 |
# File 'lib/verizon/models/delete_devices_request.rb', line 15 def devices_to_delete @devices_to_delete end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/verizon/models/delete_devices_request.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it devices_to_delete = nil unless hash['devicesToDelete'].nil? devices_to_delete = [] hash['devicesToDelete'].each do |structure| devices_to_delete << (AccountDeviceList.from_hash(structure) if structure) end end devices_to_delete = nil unless hash.key?('devicesToDelete') account_name = hash.key?('accountName') ? hash['accountName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeleteDevicesRequest.new(devices_to_delete: devices_to_delete, account_name: account_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/delete_devices_request.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['devices_to_delete'] = 'devicesToDelete' @_hash['account_name'] = 'accountName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/verizon/models/delete_devices_request.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 |
# File 'lib/verizon/models/delete_devices_request.rb', line 31 def self.optionals %w[ account_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/verizon/models/delete_devices_request.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} devices_to_delete: #{@devices_to_delete.inspect}, account_name:"\ " #{@account_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/verizon/models/delete_devices_request.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} devices_to_delete: #{@devices_to_delete}, account_name: #{@account_name},"\ " additional_properties: #{@additional_properties}>" end |