Class: Verizon::DeviceActionsApi
- Defined in:
- lib/verizon/apis/device_actions_api.rb
Overview
DeviceActionsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#account_information(account_name) ⇒ ApiResponse
Retrieve all of the service plans, features and carriers associated with the account specified.
-
#aggregate_usage(body) ⇒ ApiResponse
Retrieve the aggregate usage for a device or a number of devices.
-
#daily_usage(body) ⇒ ApiResponse
Retrieve the daily usage for a device, for a specified period of time, segmented by day.
-
#get_asynchronous_request_status(account_name, request_id) ⇒ ApiResponse
Get the status of an asynchronous request made with the Device Actions.
-
#retrieve_device_provisioning_history(body) ⇒ ApiResponse
Retrieve the provisioning history of a specific device or devices.
-
#retrieve_the_global_device_list(body) ⇒ ApiResponse
Allows the profile to fetch the complete device list.
-
#service_plan_list(account_name) ⇒ ApiResponse
Retrieve all of the service plans, features and carriers associated with the account specified.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#account_information(account_name) ⇒ ApiResponse
Retrieve all of the service plans, features and carriers associated with the account specified. here
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/verizon/apis/device_actions_api.rb', line 89 def account_information(account_name) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/v1/accounts/{accountName}', Server::THINGSPACE) .template_param(new_parameter(account_name, key: 'accountName') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(AccountDetails.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |
#aggregate_usage(body) ⇒ ApiResponse
Retrieve the aggregate usage for a device or a number of devices. here
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/verizon/apis/device_actions_api.rb', line 13 def aggregate_usage(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/v1/devices/usage/actions/list/aggregate', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(GioRequestResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |
#daily_usage(body) ⇒ ApiResponse
Retrieve the daily usage for a device, for a specified period of time, segmented by day
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/apis/device_actions_api.rb', line 38 def daily_usage(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/v1/devices/usage/actions/list', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DailyUsageResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |
#get_asynchronous_request_status(account_name, request_id) ⇒ ApiResponse
Get the status of an asynchronous request made with the Device Actions. here here
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/verizon/apis/device_actions_api.rb', line 166 def get_asynchronous_request_status(account_name, request_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/m2m/v2/accounts/{accountName}/requests/{requestID}/status', Server::THINGSPACE) .template_param(new_parameter(account_name, key: 'accountName') .is_required(true) .should_encode(true)) .template_param(new_parameter(request_id, key: 'requestID') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(StatusResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |
#retrieve_device_provisioning_history(body) ⇒ ApiResponse
Retrieve the provisioning history of a specific device or devices. History
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/verizon/apis/device_actions_api.rb', line 139 def retrieve_device_provisioning_history(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v2/devices/history/actions/list', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(GioRequestResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |
#retrieve_the_global_device_list(body) ⇒ ApiResponse
Allows the profile to fetch the complete device list. This works with Verizon US and Global profiles. Profile Query
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/verizon/apis/device_actions_api.rb', line 114 def retrieve_the_global_device_list(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v2/devices/actions/list', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(GioRequestResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |
#service_plan_list(account_name) ⇒ ApiResponse
Retrieve all of the service plans, features and carriers associated with the account specified. here
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/apis/device_actions_api.rb', line 64 def service_plan_list(account_name) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/v1/plans/{accountName}', Server::THINGSPACE) .template_param(new_parameter(account_name, key: 'accountName') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(AccountDetails.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', GioRestErrorResponseException)) .execute end |