Class: Verizon::DeviceExtendedDiagnosticsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceExtendedDiagnosticsRequest
- Defined in:
- lib/verizon/models/device_extended_diagnostics_request.rb
Overview
Request for obtaining device extended diagnostics.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The Verizon billing account that the device belongs to.
-
#device_list ⇒ Array[DeviceId]
The device for which you want diagnostic information, specified by the device’s MDN.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, device_list:, additional_properties: nil) ⇒ DeviceExtendedDiagnosticsRequest
constructor
A new instance of DeviceExtendedDiagnosticsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, device_list:, additional_properties: nil) ⇒ DeviceExtendedDiagnosticsRequest
Returns a new instance of DeviceExtendedDiagnosticsRequest.
40 41 42 43 44 45 46 47 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 40 def initialize(account_name:, device_list:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The Verizon billing account that the device belongs to. An account name is usually numeric, and must include any leading zeros.
15 16 17 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 15 def account_name @account_name end |
#device_list ⇒ Array[DeviceId]
The device for which you want diagnostic information, specified by the device’s MDN.
20 21 22 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 20 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (DeviceId.from_hash(structure) if structure) end end device_list = nil unless hash.key?('deviceList') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceExtendedDiagnosticsRequest.new(account_name: account_name, device_list: device_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_list:"\ " #{@device_list.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/verizon/models/device_extended_diagnostics_request.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_list: #{@device_list},"\ " additional_properties: #{@additional_properties}>" end |