Class: Verizon::DeviceFilterWithoutAccount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceFilterWithoutAccount
- Defined in:
- lib/verizon/models/device_filter_without_account.rb
Overview
Filter for devices without account.
Instance Attribute Summary collapse
-
#custom_fields ⇒ Array[CustomFields]
Custom field names and values, if you want to only include devices that have matching values.
-
#group_name ⇒ String
Only include devices that are in this device group.
-
#service_plan ⇒ String
Only include devices that have this service plan.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(group_name: SKIP, service_plan: SKIP, custom_fields: SKIP, additional_properties: nil) ⇒ DeviceFilterWithoutAccount
constructor
A new instance of DeviceFilterWithoutAccount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(group_name: SKIP, service_plan: SKIP, custom_fields: SKIP, additional_properties: nil) ⇒ DeviceFilterWithoutAccount
Returns a new instance of DeviceFilterWithoutAccount.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 48 def initialize(group_name: SKIP, service_plan: SKIP, custom_fields: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @group_name = group_name unless group_name == SKIP @service_plan = service_plan unless service_plan == SKIP @custom_fields = custom_fields unless custom_fields == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#custom_fields ⇒ Array[CustomFields]
Custom field names and values, if you want to only include devices that have matching values.
23 24 25 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 23 def custom_fields @custom_fields end |
#group_name ⇒ String
Only include devices that are in this device group.
14 15 16 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 14 def group_name @group_name end |
#service_plan ⇒ String
Only include devices that have this service plan.
18 19 20 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 18 def service_plan @service_plan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. group_name = hash.key?('groupName') ? hash['groupName'] : SKIP service_plan = hash.key?('servicePlan') ? hash['servicePlan'] : SKIP # Parameter is an array, so we need to iterate through it custom_fields = nil unless hash['customFields'].nil? custom_fields = [] hash['customFields'].each do |structure| custom_fields << (CustomFields.from_hash(structure) if structure) end end custom_fields = SKIP unless hash.key?('customFields') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceFilterWithoutAccount.new(group_name: group_name, service_plan: service_plan, custom_fields: custom_fields, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['group_name'] = 'groupName' @_hash['service_plan'] = 'servicePlan' @_hash['custom_fields'] = 'customFields' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 35 def self.optionals %w[ group_name service_plan custom_fields ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} group_name: #{@group_name.inspect}, service_plan: #{@service_plan.inspect},"\ " custom_fields: #{@custom_fields.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/verizon/models/device_filter_without_account.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} group_name: #{@group_name}, service_plan: #{@service_plan}, custom_fields:"\ " #{@custom_fields}, additional_properties: #{@additional_properties}>" end |