Class: Verizon::DeviceInfo
- Defined in:
- lib/verizon/models/device_info.rb
Overview
The devices that you want to locate. The array cannot contain more than 20 devices.
Instance Attribute Summary collapse
-
#id ⇒ String
Device identifier.
-
#kind ⇒ String
Device identifier kind.
-
#mdn ⇒ String
Device MDN.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, kind:, mdn:, additional_properties: nil) ⇒ DeviceInfo
constructor
A new instance of DeviceInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, kind:, mdn:, additional_properties: nil) ⇒ DeviceInfo
Returns a new instance of DeviceInfo.
44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/device_info.rb', line 44 def initialize(id:, kind:, mdn:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @kind = kind @mdn = mdn @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Device identifier.
15 16 17 |
# File 'lib/verizon/models/device_info.rb', line 15 def id @id end |
#kind ⇒ String
Device identifier kind.
19 20 21 |
# File 'lib/verizon/models/device_info.rb', line 19 def kind @kind end |
#mdn ⇒ String
Device MDN.
23 24 25 |
# File 'lib/verizon/models/device_info.rb', line 23 def mdn @mdn end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/device_info.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil kind = hash.key?('kind') ? hash['kind'] : nil mdn = hash.key?('mdn') ? hash['mdn'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceInfo.new(id: id, kind: kind, mdn: mdn, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/device_info.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['kind'] = 'kind' @_hash['mdn'] = 'mdn' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/verizon/models/device_info.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/verizon/models/device_info.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/verizon/models/device_info.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, kind: #{@kind.inspect}, mdn: #{@mdn.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/verizon/models/device_info.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, kind: #{@kind}, mdn: #{@mdn}, additional_properties:"\ " #{@additional_properties}>" end |