Class: Verizon::DeviceMonitoringApi
- Defined in:
- lib/verizon/apis/device_monitoring_api.rb
Overview
DeviceMonitoringApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#device_reachability(body) ⇒ ApiResponse
TODO: type endpoint description here Reachability Report Request.
-
#stop_device_reachability(stopreachabilitypayload) ⇒ ApiResponse
TODO: type endpoint description here Payload for the Stop Device Reachability monitors request.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#device_reachability(body) ⇒ ApiResponse
TODO: type endpoint description here Reachability Report Request
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/verizon/apis/device_monitoring_api.rb', line 13 def device_reachability(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/diagnostics/basic/devicereachability', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error Response', RestErrorResponseException)) .execute end |
#stop_device_reachability(stopreachabilitypayload) ⇒ ApiResponse
TODO: type endpoint description here Payload for the Stop Device Reachability monitors request.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/apis/device_monitoring_api.rb', line 38 def stop_device_reachability(stopreachabilitypayload) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/m2m/v1/diagnostics/basic/devicereachability', Server::THINGSPACE) .query_param(new_parameter(stopreachabilitypayload, key: 'stopreachabilitypayload') .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error Response', RestErrorResponseException)) .execute end |