Class: Verizon::DeviceSuspensionStatusRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceSuspensionStatusRequest
- Defined in:
- lib/verizon/models/device_suspension_status_request.rb
Overview
Request to return service suspension information about one or more devices.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The name of a billing account.
-
#device_ids ⇒ Array[DeviceId]
The devices that you want to include in the request, specified by device identifier.
-
#filter ⇒ DeviceFilterWithoutAccount
Filter for devices without account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_ids: SKIP, filter: SKIP, account_name: SKIP, additional_properties: nil) ⇒ DeviceSuspensionStatusRequest
constructor
A new instance of DeviceSuspensionStatusRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_ids: SKIP, filter: SKIP, account_name: SKIP, additional_properties: nil) ⇒ DeviceSuspensionStatusRequest
Returns a new instance of DeviceSuspensionStatusRequest.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 48 def initialize(device_ids: SKIP, filter: SKIP, account_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_ids = device_ids unless device_ids == SKIP @filter = filter unless filter == SKIP @account_name = account_name unless account_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The name of a billing account.
23 24 25 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 23 def account_name @account_name end |
#device_ids ⇒ Array[DeviceId]
The devices that you want to include in the request, specified by device identifier. You only need to provide one identifier per device.
15 16 17 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 15 def device_ids @device_ids end |
#filter ⇒ DeviceFilterWithoutAccount
Filter for devices without account.
19 20 21 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 19 def filter @filter end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_ids = nil unless hash['deviceIds'].nil? device_ids = [] hash['deviceIds'].each do |structure| device_ids << (DeviceId.from_hash(structure) if structure) end end device_ids = SKIP unless hash.key?('deviceIds') filter = DeviceFilterWithoutAccount.from_hash(hash['filter']) if hash['filter'] account_name = hash.key?('accountName') ? hash['accountName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeviceSuspensionStatusRequest.new(device_ids: device_ids, filter: filter, account_name: account_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['device_ids'] = 'deviceIds' @_hash['filter'] = 'filter' @_hash['account_name'] = 'accountName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 35 def self.optionals %w[ device_ids filter account_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_ids: #{@device_ids.inspect}, filter: #{@filter.inspect},"\ " account_name: #{@account_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/verizon/models/device_suspension_status_request.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_ids: #{@device_ids}, filter: #{@filter}, account_name:"\ " #{@account_name}, additional_properties: #{@additional_properties}>" end |