Class: Verizon::Devicepropertyfilter
- Defined in:
- lib/verizon/models/devicepropertyfilter.rb
Overview
Devicepropertyfilter Model.
Instance Attribute Summary collapse
-
#m_querytotalcount ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#m_selection ⇒ Devicepropertyselection
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(m_selection: SKIP, m_querytotalcount: SKIP, additional_properties: nil) ⇒ Devicepropertyfilter
constructor
A new instance of Devicepropertyfilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(m_selection: SKIP, m_querytotalcount: SKIP, additional_properties: nil) ⇒ Devicepropertyfilter
Returns a new instance of Devicepropertyfilter.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 41 def initialize(m_selection: SKIP, m_querytotalcount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @m_selection = m_selection unless m_selection == SKIP @m_querytotalcount = m_querytotalcount unless m_querytotalcount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#m_querytotalcount ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 18 def m_querytotalcount @m_querytotalcount end |
#m_selection ⇒ Devicepropertyselection
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 14 def m_selection @m_selection end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. m_selection = Devicepropertyselection.from_hash(hash['$selection']) if hash['$selection'] m_querytotalcount = hash.key?('$querytotalcount') ? hash['$querytotalcount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Devicepropertyfilter.new(m_selection: m_selection, m_querytotalcount: m_querytotalcount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['m_selection'] = '$selection' @_hash['m_querytotalcount'] = '$querytotalcount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 29 def self.optionals %w[ m_selection m_querytotalcount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} m_selection: #{@m_selection.inspect}, m_querytotalcount:"\ " #{@m_querytotalcount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/devicepropertyfilter.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} m_selection: #{@m_selection}, m_querytotalcount: #{@m_querytotalcount},"\ " additional_properties: #{@additional_properties}>" end |