Class: Verizon::DevicesLocationSubscriptionsApi
- Defined in:
- lib/verizon/apis/devices_location_subscriptions_api.rb
Overview
DevicesLocationSubscriptionsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_location_service_subscription_status(account_name) ⇒ ApiResponse
This subscriptions endpoint retrieves an account’s current location subscription status.
-
#get_location_service_usage(body) ⇒ ApiResponse
This endpoint allows user to search for billable usage for accounts based on the provided date range.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#get_location_service_subscription_status(account_name) ⇒ ApiResponse
This subscriptions endpoint retrieves an account’s current location subscription status. “##########-#####”.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/verizon/apis/devices_location_subscriptions_api.rb', line 14 def get_location_service_subscription_status(account_name) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/subscriptions/{accountName}', Server::DEVICE_LOCATION) .template_param(new_parameter(account_name, key: 'accountName') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceLocationSubscription.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', DeviceLocationResultException)) .execute end |
#get_location_service_usage(body) ⇒ ApiResponse
This endpoint allows user to search for billable usage for accounts based on the provided date range. billable usage for accounts.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/apis/devices_location_subscriptions_api.rb', line 39 def get_location_service_usage(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/usage', Server::DEVICE_LOCATION) .header_param(new_parameter('*/*', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:json_deserialize)) .is_api_response(true) .local_error('400', 'Unexpected error.', DeviceLocationResultException)) .execute end |