Class: Verizon::DiagnosticsCategory
- Defined in:
- lib/verizon/models/diagnostics_category.rb
Overview
Various types of information about the device, grouped into categories. Each category object contains the category name and a list of Extended Attribute objects as key-value pairs.
Instance Attribute Summary collapse
-
#category_name ⇒ String
The name of the category.
-
#extended_attributes ⇒ Array[CustomFields]
A list of Extended Attribute objects as key-value pairs.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(category_name: SKIP, extended_attributes: SKIP, additional_properties: nil) ⇒ DiagnosticsCategory
constructor
A new instance of DiagnosticsCategory.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category_name: SKIP, extended_attributes: SKIP, additional_properties: nil) ⇒ DiagnosticsCategory
Returns a new instance of DiagnosticsCategory.
43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/diagnostics_category.rb', line 43 def initialize(category_name: SKIP, extended_attributes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @category_name = category_name unless category_name == SKIP @extended_attributes = extended_attributes unless extended_attributes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#category_name ⇒ String
The name of the category.
16 17 18 |
# File 'lib/verizon/models/diagnostics_category.rb', line 16 def category_name @category_name end |
#extended_attributes ⇒ Array[CustomFields]
A list of Extended Attribute objects as key-value pairs.
20 21 22 |
# File 'lib/verizon/models/diagnostics_category.rb', line 20 def extended_attributes @extended_attributes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/models/diagnostics_category.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category_name = hash.key?('categoryName') ? hash['categoryName'] : SKIP # Parameter is an array, so we need to iterate through it extended_attributes = nil unless hash['extendedAttributes'].nil? extended_attributes = [] hash['extendedAttributes'].each do |structure| extended_attributes << (CustomFields.from_hash(structure) if structure) end end extended_attributes = SKIP unless hash.key?('extendedAttributes') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DiagnosticsCategory.new(category_name: category_name, extended_attributes: extended_attributes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/diagnostics_category.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['category_name'] = 'categoryName' @_hash['extended_attributes'] = 'extendedAttributes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/diagnostics_category.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/diagnostics_category.rb', line 31 def self.optionals %w[ category_name extended_attributes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/verizon/models/diagnostics_category.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} category_name: #{@category_name.inspect}, extended_attributes:"\ " #{@extended_attributes.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/verizon/models/diagnostics_category.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} category_name: #{@category_name}, extended_attributes:"\ " #{@extended_attributes}, additional_properties: #{@additional_properties}>" end |