Class: Verizon::DtoDeviceCommand
- Defined in:
- lib/verizon/models/dto_device_command.rb
Overview
DtoDeviceCommand Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The numeric account name, which must include leading zeros.
-
#configuration ⇒ Rbstiltconfig
The numeric account name, which must include leading zeros.
-
#resourceidentifier ⇒ DtoResourceidentifier
The numeric account name, which must include leading zeros.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(account_name: SKIP, configuration: SKIP, resourceidentifier: SKIP, additional_properties: nil) ⇒ DtoDeviceCommand
constructor
A new instance of DtoDeviceCommand.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name: SKIP, configuration: SKIP, resourceidentifier: SKIP, additional_properties: nil) ⇒ DtoDeviceCommand
Returns a new instance of DtoDeviceCommand.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/dto_device_command.rb', line 47 def initialize(account_name: SKIP, configuration: SKIP, resourceidentifier: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name unless account_name == SKIP @configuration = configuration unless configuration == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_device_command.rb', line 14 def account_name @account_name end |
#configuration ⇒ Rbstiltconfig
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_device_command.rb', line 18 def configuration @configuration end |
#resourceidentifier ⇒ DtoResourceidentifier
The numeric account name, which must include leading zeros
22 23 24 |
# File 'lib/verizon/models/dto_device_command.rb', line 22 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/verizon/models/dto_device_command.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP configuration = Rbstiltconfig.from_hash(hash['configuration']) if hash['configuration'] resourceidentifier = DtoResourceidentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DtoDeviceCommand.new(account_name: account_name, configuration: configuration, resourceidentifier: resourceidentifier, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_device_command.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['configuration'] = 'configuration' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_device_command.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_device_command.rb', line 34 def self.optionals %w[ account_name configuration resourceidentifier ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 |
# File 'lib/verizon/models/dto_device_command.rb', line 84 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/verizon/models/dto_device_command.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, configuration:"\ " #{@configuration.inspect}, resourceidentifier: #{@resourceidentifier.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/verizon/models/dto_device_command.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, configuration: #{@configuration},"\ " resourceidentifier: #{@resourceidentifier}, additional_properties:"\ " #{@additional_properties}>" end |