Class: Verizon::DtoOffBoardSensorRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoOffBoardSensorRequest
- Defined in:
- lib/verizon/models/dto_off_board_sensor_request.rb
Overview
DtoOffBoardSensorRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#configuration ⇒ Sensorinsightsconfig
The configuration of the remove request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, configuration: SKIP) ⇒ DtoOffBoardSensorRequest
constructor
A new instance of DtoOffBoardSensorRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, configuration: SKIP) ⇒ DtoOffBoardSensorRequest
Returns a new instance of DtoOffBoardSensorRequest.
41 42 43 44 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 41 def initialize(accountname: SKIP, configuration: SKIP) @accountname = accountname unless accountname == SKIP @configuration = configuration unless configuration == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 14 def accountname @accountname end |
#configuration ⇒ Sensorinsightsconfig
The configuration of the remove request
18 19 20 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 18 def configuration @configuration end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP configuration = Sensorinsightsconfig.from_hash(hash['configuration']) if hash['configuration'] # Create object from extracted values. DtoOffBoardSensorRequest.new(accountname: accountname, configuration: configuration) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['configuration'] = 'configuration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 29 def self.optionals %w[ accountname configuration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 71 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, configuration:"\ " #{@configuration.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/verizon/models/dto_off_board_sensor_request.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, configuration: #{@configuration}>" end |