Class: Verizon::DtoSensorOffBoardStatusRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoSensorOffBoardStatusRequest
- Defined in:
- lib/verizon/models/dto_sensor_off_board_status_request.rb
Overview
DtoSensorOffBoardStatusRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#gatewayidentifier ⇒ Gatewayidentifier
The numeric account name, which must include leading zeros.
-
#offboarding ⇒ Offboarding
The numeric account name, which must include leading zeros.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, gatewayidentifier: SKIP, offboarding: SKIP) ⇒ DtoSensorOffBoardStatusRequest
constructor
A new instance of DtoSensorOffBoardStatusRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, gatewayidentifier: SKIP, offboarding: SKIP) ⇒ DtoSensorOffBoardStatusRequest
Returns a new instance of DtoSensorOffBoardStatusRequest.
47 48 49 50 51 52 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 47 def initialize(accountname: SKIP, gatewayidentifier: SKIP, offboarding: SKIP) @accountname = accountname unless accountname == SKIP @gatewayidentifier = gatewayidentifier unless gatewayidentifier == SKIP @offboarding = offboarding unless offboarding == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 14 def accountname @accountname end |
#gatewayidentifier ⇒ Gatewayidentifier
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 18 def gatewayidentifier @gatewayidentifier end |
#offboarding ⇒ Offboarding
The numeric account name, which must include leading zeros
22 23 24 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 22 def offboarding @offboarding end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP gatewayidentifier = Gatewayidentifier.from_hash(hash['gatewayidentifier']) if hash['gatewayidentifier'] offboarding = Offboarding.from_hash(hash['offboarding']) if hash['offboarding'] # Create object from extracted values. DtoSensorOffBoardStatusRequest.new(accountname: accountname, gatewayidentifier: gatewayidentifier, offboarding: offboarding) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['gatewayidentifier'] = 'gatewayidentifier' @_hash['offboarding'] = 'offboarding' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 34 def self.optionals %w[ accountname gatewayidentifier offboarding ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, gatewayidentifier:"\ " #{@gatewayidentifier.inspect}, offboarding: #{@offboarding.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/verizon/models/dto_sensor_off_board_status_request.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, gatewayidentifier: #{@gatewayidentifier},"\ " offboarding: #{@offboarding}>" end |