Class: Verizon::DtoUpdateNotificationGroupRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoUpdateNotificationGroupRequest
- Defined in:
- lib/verizon/models/dto_update_notification_group_request.rb
Overview
DtoUpdateNotificationGroupRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#group ⇒ DtoNotificationGroupRequestEntity
The numeric account name, which must include leading zeros.
-
#id ⇒ String
UUID of the user record, assigned at creation.
-
#userids ⇒ Array[String]
UUID of the user record, assigned at creation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(group:, accountname: SKIP, id: SKIP, userids: SKIP) ⇒ DtoUpdateNotificationGroupRequest
constructor
A new instance of DtoUpdateNotificationGroupRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(group:, accountname: SKIP, id: SKIP, userids: SKIP) ⇒ DtoUpdateNotificationGroupRequest
Returns a new instance of DtoUpdateNotificationGroupRequest.
52 53 54 55 56 57 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 52 def initialize(group:, accountname: SKIP, id: SKIP, userids: SKIP) @accountname = accountname unless accountname == SKIP @group = group @id = id unless id == SKIP @userids = userids unless userids == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 14 def accountname @accountname end |
#group ⇒ DtoNotificationGroupRequestEntity
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 18 def group @group end |
#id ⇒ String
UUID of the user record, assigned at creation
22 23 24 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 22 def id @id end |
#userids ⇒ Array[String]
UUID of the user record, assigned at creation
26 27 28 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 26 def userids @userids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. group = DtoNotificationGroupRequestEntity.from_hash(hash['group']) if hash['group'] accountname = hash.key?('accountname') ? hash['accountname'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP userids = hash.key?('userids') ? hash['userids'] : SKIP # Create object from extracted values. DtoUpdateNotificationGroupRequest.new(group: group, accountname: accountname, id: id, userids: userids) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['group'] = 'group' @_hash['id'] = 'id' @_hash['userids'] = 'userids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 39 def self.optionals %w[ accountname id userids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, group: #{@group.inspect}, id:"\ " #{@id.inspect}, userids: #{@userids.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/verizon/models/dto_update_notification_group_request.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, group: #{@group}, id: #{@id}, userids:"\ " #{@userids}>" end |