Class: Verizon::DtoUpdateUserRequest
- Defined in:
- lib/verizon/models/dto_update_user_request.rb
Overview
DtoUpdateUserRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#id ⇒ String
UUID of the user record, assigned at creation.
-
#user ⇒ DtoUserDto
UUID of the user record, assigned at creation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname: SKIP, id: SKIP, user: SKIP) ⇒ DtoUpdateUserRequest
constructor
A new instance of DtoUpdateUserRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname: SKIP, id: SKIP, user: SKIP) ⇒ DtoUpdateUserRequest
Returns a new instance of DtoUpdateUserRequest.
47 48 49 50 51 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 47 def initialize(accountname: SKIP, id: SKIP, user: SKIP) @accountname = accountname unless accountname == SKIP @id = id unless id == SKIP @user = user unless user == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 14 def accountname @accountname end |
#id ⇒ String
UUID of the user record, assigned at creation
18 19 20 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 18 def id @id end |
#user ⇒ DtoUserDto
UUID of the user record, assigned at creation
22 23 24 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 22 def user @user end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP user = DtoUserDto.from_hash(hash['user']) if hash['user'] # Create object from extracted values. DtoUpdateUserRequest.new(accountname: accountname, id: id, user: user) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['id'] = 'id' @_hash['user'] = 'user' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 34 def self.optionals %w[ accountname id user ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, id: #{@id.inspect}, user:"\ " #{@user.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/dto_update_user_request.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, id: #{@id}, user: #{@user}>" end |