Class: Verizon::EuiccDeviceProfileManagementApi
- Defined in:
- lib/verizon/apis/euicc_device_profile_management_api.rb
Overview
EuiccDeviceProfileManagementApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#delete_local_profile(body) ⇒ ApiResponse
Delete a local profile from eUICC devices.
-
#disable_local_profile(body) ⇒ ApiResponse
Disable a local profile on eUICC devices.
-
#download_local_profile_to_disable(body) ⇒ ApiResponse
Downloads an eUICC local profile to devices and leaves the profile disabled.
-
#download_local_profile_to_enable(body) ⇒ ApiResponse
Downloads an eUICC local profile to devices and enables the profile.
-
#enable_local_profile(body) ⇒ ApiResponse
Enable a local profile that has been downloaded to eUICC devices.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#delete_local_profile(body) ⇒ ApiResponse
Delete a local profile from eUICC devices. If the local profile is enabled, it will first be disabled and the boot or default profile will be enabled.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/verizon/apis/euicc_device_profile_management_api.rb', line 114 def delete_local_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/delete', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error Response', RestErrorResponseException)) .execute end |
#disable_local_profile(body) ⇒ ApiResponse
Disable a local profile on eUICC devices. The default or boot profile will become the enabled profile.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/verizon/apis/euicc_device_profile_management_api.rb', line 88 def disable_local_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/disable', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error Response', RestErrorResponseException)) .execute end |
#download_local_profile_to_disable(body) ⇒ ApiResponse
Downloads an eUICC local profile to devices and leaves the profile disabled. Query
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/apis/euicc_device_profile_management_api.rb', line 39 def download_local_profile_to_disable(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/download_disable', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceManagementResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |
#download_local_profile_to_enable(body) ⇒ ApiResponse
Downloads an eUICC local profile to devices and enables the profile. Query
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/verizon/apis/euicc_device_profile_management_api.rb', line 13 def download_local_profile_to_enable(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/download_enable', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DeviceManagementResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error response.', ConnectivityManagementResultException)) .execute end |
#enable_local_profile(body) ⇒ ApiResponse
Enable a local profile that has been downloaded to eUICC devices.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/verizon/apis/euicc_device_profile_management_api.rb', line 63 def enable_local_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/m2m/v1/devices/profile/actions/enable', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(RequestResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Error Response', RestErrorResponseException)) .execute end |