Class: Verizon::FilterCriteria1
- Defined in:
- lib/verizon/models/filter_criteria1.rb
Overview
FilterCriteria1 Model.
Instance Attribute Summary collapse
-
#account_name_list ⇒ Array[String]
An array of account names.
-
#carrier_service_plan_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(carrier_service_plan_code: SKIP, account_name_list: SKIP, additional_properties: nil) ⇒ FilterCriteria1
constructor
A new instance of FilterCriteria1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(carrier_service_plan_code: SKIP, account_name_list: SKIP, additional_properties: nil) ⇒ FilterCriteria1
Returns a new instance of FilterCriteria1.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/verizon/models/filter_criteria1.rb', line 41 def initialize(carrier_service_plan_code: SKIP, account_name_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless carrier_service_plan_code == SKIP @carrier_service_plan_code = carrier_service_plan_code end @account_name_list = account_name_list unless account_name_list == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name_list ⇒ Array[String]
An array of account names
18 19 20 |
# File 'lib/verizon/models/filter_criteria1.rb', line 18 def account_name_list @account_name_list end |
#carrier_service_plan_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/filter_criteria1.rb', line 14 def carrier_service_plan_code @carrier_service_plan_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/filter_criteria1.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. carrier_service_plan_code = hash.key?('carrierServicePlanCode') ? hash['carrierServicePlanCode'] : SKIP account_name_list = hash.key?('accountNameList') ? hash['accountNameList'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FilterCriteria1.new(carrier_service_plan_code: carrier_service_plan_code, account_name_list: account_name_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/filter_criteria1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['carrier_service_plan_code'] = 'carrierServicePlanCode' @_hash['account_name_list'] = 'accountNameList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/filter_criteria1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/filter_criteria1.rb', line 29 def self.optionals %w[ carrier_service_plan_code account_name_list ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
79 80 81 82 83 84 85 |
# File 'lib/verizon/models/filter_criteria1.rb', line 79 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/verizon/models/filter_criteria1.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} carrier_service_plan_code: #{@carrier_service_plan_code.inspect},"\ " account_name_list: #{@account_name_list.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 93 |
# File 'lib/verizon/models/filter_criteria1.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} carrier_service_plan_code: #{@carrier_service_plan_code},"\ " account_name_list: #{@account_name_list}, additional_properties:"\ " #{@additional_properties}>" end |