Class: Verizon::FotaV1CallbackRegistrationResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::FotaV1CallbackRegistrationResult
- Defined in:
- lib/verizon/models/fota_v1_callback_registration_result.rb
Overview
Registered callback account name and service name.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The name of the billing account for which callback messages will be sent.
-
#service_name ⇒ String
The name of the callback service, which identifies the type and format of messages that will be sent to the registered URL.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name: SKIP, service_name: SKIP, additional_properties: nil) ⇒ FotaV1CallbackRegistrationResult
constructor
A new instance of FotaV1CallbackRegistrationResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name: SKIP, service_name: SKIP, additional_properties: nil) ⇒ FotaV1CallbackRegistrationResult
Returns a new instance of FotaV1CallbackRegistrationResult.
43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 43 def initialize(account_name: SKIP, service_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name unless account_name == SKIP @service_name = service_name unless service_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
The name of the billing account for which callback messages will be sent.
14 15 16 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 14 def account_name @account_name end |
#service_name ⇒ String
The name of the callback service, which identifies the type and format of messages that will be sent to the registered URL. This will be ‘Fota’ for the Software Management Services callback.
20 21 22 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 20 def service_name @service_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP service_name = hash.key?('serviceName') ? hash['serviceName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FotaV1CallbackRegistrationResult.new(account_name: account_name, service_name: service_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['service_name'] = 'serviceName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 31 def self.optionals %w[ account_name service_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, service_name:"\ " #{@service_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/verizon/models/fota_v1_callback_registration_result.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, service_name: #{@service_name},"\ " additional_properties: #{@additional_properties}>" end |