Class: Verizon::GetDeviceExperienceScoreBulkRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::GetDeviceExperienceScoreBulkRequest
- Defined in:
- lib/verizon/models/get_device_experience_score_bulk_request.rb
Overview
Get device experience score bulk request.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#device_list ⇒ Array[DeviceIdentifier]
Account name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, device_list:) ⇒ GetDeviceExperienceScoreBulkRequest
constructor
A new instance of GetDeviceExperienceScoreBulkRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, device_list:) ⇒ GetDeviceExperienceScoreBulkRequest
Returns a new instance of GetDeviceExperienceScoreBulkRequest.
38 39 40 41 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 38 def initialize(account_name:, device_list:) @account_name = account_name @device_list = device_list end |
Instance Attribute Details
#account_name ⇒ String
Account name.
14 15 16 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[DeviceIdentifier]
Account name.
18 19 20 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 18 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (DeviceIdentifier.from_hash(structure) if structure) end end device_list = nil unless hash.key?('deviceList') # Create object from extracted values. GetDeviceExperienceScoreBulkRequest.new(account_name: account_name, device_list: device_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_list:"\ " #{@device_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/verizon/models/get_device_experience_score_bulk_request.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_list: #{@device_list}>" end |