Class: Verizon::GioSmsMessage
- Defined in:
- lib/verizon/models/gio_sms_message.rb
Overview
GioSmsMessage Model.
Instance Attribute Summary collapse
-
#device_ids ⇒ Array[GioDeviceId]
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#timestamp ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_ids: SKIP, message: SKIP, timestamp: SKIP, additional_properties: nil) ⇒ GioSmsMessage
constructor
A new instance of GioSmsMessage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_timestamp ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_ids: SKIP, message: SKIP, timestamp: SKIP, additional_properties: nil) ⇒ GioSmsMessage
Returns a new instance of GioSmsMessage.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/gio_sms_message.rb', line 48 def initialize(device_ids: SKIP, message: SKIP, timestamp: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_ids = device_ids unless device_ids == SKIP @message = unless == SKIP @timestamp = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_ids ⇒ Array[GioDeviceId]
TODO: Write general description for this method
15 16 17 |
# File 'lib/verizon/models/gio_sms_message.rb', line 15 def device_ids @device_ids end |
#message ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/verizon/models/gio_sms_message.rb', line 19 def @message end |
#timestamp ⇒ DateTime
TODO: Write general description for this method
23 24 25 |
# File 'lib/verizon/models/gio_sms_message.rb', line 23 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/verizon/models/gio_sms_message.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_ids = nil unless hash['deviceIds'].nil? device_ids = [] hash['deviceIds'].each do |structure| device_ids << (GioDeviceId.from_hash(structure) if structure) end end device_ids = SKIP unless hash.key?('deviceIds') = hash.key?('message') ? hash['message'] : SKIP = if hash.key?('timestamp') (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GioSmsMessage.new(device_ids: device_ids, message: , timestamp: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/gio_sms_message.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['device_ids'] = 'deviceIds' @_hash['message'] = 'message' @_hash['timestamp'] = 'timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/gio_sms_message.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/gio_sms_message.rb', line 35 def self.optionals %w[ device_ids message timestamp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 |
# File 'lib/verizon/models/gio_sms_message.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_ids: #{@device_ids.inspect}, message: #{@message.inspect},"\ " timestamp: #{@timestamp.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_timestamp ⇒ Object
95 96 97 |
# File 'lib/verizon/models/gio_sms_message.rb', line 95 def DateTimeHelper.to_rfc3339() end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 |
# File 'lib/verizon/models/gio_sms_message.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_ids: #{@device_ids}, message: #{@message}, timestamp: #{@timestamp},"\ " additional_properties: #{@additional_properties}>" end |