Class: Verizon::HistorySearchLimitTime
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::HistorySearchLimitTime
- Defined in:
- lib/verizon/models/history_search_limit_time.rb
Overview
The time period for which a request should retrieve data, beginning with the limitTime.startOn and proceeding with the limitTime.duration.
Instance Attribute Summary collapse
-
#duration ⇒ NumericalData
Describes value and unit of time.
-
#start_on ⇒ DateTime
The starting date-time for this request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_on: SKIP, duration: SKIP, additional_properties: nil) ⇒ HistorySearchLimitTime
constructor
A new instance of HistorySearchLimitTime.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_start_on ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_on: SKIP, duration: SKIP, additional_properties: nil) ⇒ HistorySearchLimitTime
Returns a new instance of HistorySearchLimitTime.
43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 43 def initialize(start_on: SKIP, duration: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_on = start_on unless start_on == SKIP @duration = duration unless duration == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#duration ⇒ NumericalData
Describes value and unit of time.
20 21 22 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 20 def duration @duration end |
#start_on ⇒ DateTime
The starting date-time for this request.
16 17 18 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 16 def start_on @start_on end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_on = if hash.key?('startOn') (DateTimeHelper.from_rfc3339(hash['startOn']) if hash['startOn']) else SKIP end duration = NumericalData.from_hash(hash['duration']) if hash['duration'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. HistorySearchLimitTime.new(start_on: start_on, duration: duration, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['start_on'] = 'startOn' @_hash['duration'] = 'duration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 31 def self.optionals %w[ start_on duration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_on: #{@start_on.inspect}, duration: #{@duration.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_start_on ⇒ Object
77 78 79 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 77 def to_custom_start_on DateTimeHelper.to_rfc3339(start_on) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_on: #{@start_on}, duration: #{@duration}, additional_properties:"\ " #{@additional_properties}>" end |