Class: Verizon::HyperPreciseLocationResultException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- Verizon::HyperPreciseLocationResultException
- Defined in:
- lib/verizon/exceptions/hyper_precise_location_result_exception.rb
Overview
Error response.
Instance Attribute Summary collapse
-
#fault ⇒ HyperPreciseLocationFault
Fault occurred while responding.
-
#message ⇒ String
Error message.
-
#response_code ⇒ ErrorResponseCode
Error Code.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ HyperPreciseLocationResultException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ HyperPreciseLocationResultException
The constructor.
27 28 29 30 31 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#fault ⇒ HyperPreciseLocationFault
Fault occurred while responding.
22 23 24 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 22 def fault @fault end |
#message ⇒ String
Error message.
18 19 20 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 18 def @message end |
#response_code ⇒ ErrorResponseCode
Error Code.
14 15 16 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 14 def response_code @response_code end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} response_code: #{@response_code.inspect}, message: #{@message.inspect},"\ " fault: #{@fault.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} response_code: #{@response_code}, message: #{@message}, fault: #{@fault}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/verizon/exceptions/hyper_precise_location_result_exception.rb', line 36 def unbox(hash) return nil unless hash @response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP @message = hash.key?('message') ? hash['message'] : SKIP @fault = HyperPreciseLocationFault.from_hash(hash['fault']) if hash['fault'] end |