Class: Verizon::Item1
- Defined in:
- lib/verizon/models/item1.rb
Overview
Item1 Model.
Instance Attribute Summary collapse
-
#text ⇒ String
Simple text used with ITIS codes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(text:) ⇒ Item1
constructor
A new instance of Item1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(text:) ⇒ Item1
Returns a new instance of Item1.
33 34 35 |
# File 'lib/verizon/models/item1.rb', line 33 def initialize(text:) @text = text end |
Instance Attribute Details
#text ⇒ String
Simple text used with ITIS codes. (Text taken from SAE J2540.)
14 15 16 |
# File 'lib/verizon/models/item1.rb', line 14 def text @text end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/verizon/models/item1.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. text = hash.key?('text') ? hash['text'] : nil # Create object from extracted values. Item1.new(text: text) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/item1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['text'] = 'text' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/item1.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/item1.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/verizon/models/item1.rb', line 50 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.text, ->(val) { val.instance_of? String }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['text'], ->(val) { val.instance_of? String }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 |
# File 'lib/verizon/models/item1.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} text: #{@text.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/verizon/models/item1.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} text: #{@text}>" end |