Class: Verizon::M5GBiprimaryPlaceofuse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::M5GBiprimaryPlaceofuse
- Defined in:
- lib/verizon/models/m_5g_biprimary_placeofuse.rb
Overview
M5GBiprimaryPlaceofuse Model.
Instance Attribute Summary collapse
-
#address ⇒ M5GBiAddress
TODO: Write general description for this method.
-
#customer_name ⇒ M5GBiCustomerName
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(address: SKIP, customer_name: SKIP, additional_properties: nil) ⇒ M5GBiprimaryPlaceofuse
constructor
A new instance of M5GBiprimaryPlaceofuse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address: SKIP, customer_name: SKIP, additional_properties: nil) ⇒ M5GBiprimaryPlaceofuse
Returns a new instance of M5GBiprimaryPlaceofuse.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 41 def initialize(address: SKIP, customer_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @address = address unless address == SKIP @customer_name = customer_name unless customer_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ M5GBiAddress
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 14 def address @address end |
#customer_name ⇒ M5GBiCustomerName
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 18 def customer_name @customer_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address = M5GBiAddress.from_hash(hash['address']) if hash['address'] customer_name = M5GBiCustomerName.from_hash(hash['customerName']) if hash['customerName'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. M5GBiprimaryPlaceofuse.new(address: address, customer_name: customer_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['address'] = 'address' @_hash['customer_name'] = 'customerName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 29 def self.optionals %w[ address customer_name ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
74 75 76 77 78 79 80 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 74 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} address: #{@address.inspect}, customer_name: #{@customer_name.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} address: #{@address}, customer_name: #{@customer_name},"\ " additional_properties: #{@additional_properties}>" end |