Class: Verizon::NotificationReportRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::NotificationReportRequest
- Defined in:
- lib/verizon/models/notification_report_request.rb
Overview
NotificationReportRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
TODO: Write general description for this method.
-
#devices ⇒ Array[DeviceList]
TODO: Write general description for this method.
-
#monitor_expiration_time ⇒ String
TODO: Write general description for this method.
-
#request_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, request_type:, devices:, monitor_expiration_time:, additional_properties: nil) ⇒ NotificationReportRequest
constructor
A new instance of NotificationReportRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, request_type:, devices:, monitor_expiration_time:, additional_properties: nil) ⇒ NotificationReportRequest
Returns a new instance of NotificationReportRequest.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/notification_report_request.rb', line 48 def initialize(account_name:, request_type:, devices:, monitor_expiration_time:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name @request_type = request_type @devices = devices @monitor_expiration_time = monitor_expiration_time @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/notification_report_request.rb', line 14 def account_name @account_name end |
#devices ⇒ Array[DeviceList]
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/notification_report_request.rb', line 22 def devices @devices end |
#monitor_expiration_time ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/verizon/models/notification_report_request.rb', line 26 def monitor_expiration_time @monitor_expiration_time end |
#request_type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/notification_report_request.rb', line 18 def request_type @request_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/verizon/models/notification_report_request.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil request_type = hash.key?('requestType') ? hash['requestType'] : nil # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (DeviceList.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') monitor_expiration_time = hash.key?('monitorExpirationTime') ? hash['monitorExpirationTime'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NotificationReportRequest.new(account_name: account_name, request_type: request_type, devices: devices, monitor_expiration_time: monitor_expiration_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/verizon/models/notification_report_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['request_type'] = 'requestType' @_hash['devices'] = 'devices' @_hash['monitor_expiration_time'] = 'monitorExpirationTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/notification_report_request.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/verizon/models/notification_report_request.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/verizon/models/notification_report_request.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, request_type:"\ " #{@request_type.inspect}, devices: #{@devices.inspect}, monitor_expiration_time:"\ " #{@monitor_expiration_time.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/verizon/models/notification_report_request.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, request_type: #{@request_type}, devices:"\ " #{@devices}, monitor_expiration_time: #{@monitor_expiration_time}, additional_properties:"\ " #{@additional_properties}>" end |