Class: Verizon::Notify
- Defined in:
- lib/verizon/models/notify.rb
Overview
Notify Model.
Instance Attribute Summary collapse
-
#alert_type ⇒ String
TODO: Write general description for this method.
-
#threshold ⇒ Array[Object]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(alert_type: SKIP, threshold: SKIP, additional_properties: nil) ⇒ Notify
constructor
A new instance of Notify.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(alert_type: SKIP, threshold: SKIP, additional_properties: nil) ⇒ Notify
Returns a new instance of Notify.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/notify.rb', line 41 def initialize(alert_type: SKIP, threshold: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @alert_type = alert_type unless alert_type == SKIP @threshold = threshold unless threshold == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#alert_type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/notify.rb', line 14 def alert_type @alert_type end |
#threshold ⇒ Array[Object]
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/notify.rb', line 18 def threshold @threshold end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/verizon/models/notify.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. alert_type = hash.key?('alertType') ? hash['alertType'] : SKIP threshold = hash.key?('threshold') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:NotifyThreshold), hash['threshold'] ) : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Notify.new(alert_type: alert_type, threshold: threshold, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/notify.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['alert_type'] = 'alertType' @_hash['threshold'] = 'threshold' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/notify.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/notify.rb', line 29 def self.optionals %w[ alert_type threshold ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
76 77 78 79 80 81 82 |
# File 'lib/verizon/models/notify.rb', line 76 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/verizon/models/notify.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} alert_type: #{@alert_type.inspect}, threshold: #{@threshold.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/verizon/models/notify.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} alert_type: #{@alert_type}, threshold: #{@threshold},"\ " additional_properties: #{@additional_properties}>" end |