Class: Verizon::Offset
- Defined in:
- lib/verizon/models/offset.rb
Overview
The sequence of node offsets then describes a path or polygon in the Lat-Long system.
Instance Attribute Summary collapse
-
#ll ⇒ NodeListLl
The NodeListLL data structure provides the sequence of signed offset node point values for determining the latitude and longitude.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(ll:) ⇒ Offset
constructor
A new instance of Offset.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ll:) ⇒ Offset
Returns a new instance of Offset.
36 37 38 |
# File 'lib/verizon/models/offset.rb', line 36 def initialize(ll:) @ll = ll end |
Instance Attribute Details
#ll ⇒ NodeListLl
The NodeListLL data structure provides the sequence of signed offset node point values for determining the latitude and longitude. Each LL point is referred to as a node point.
17 18 19 |
# File 'lib/verizon/models/offset.rb', line 17 def ll @ll end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/offset.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ll = NodeListLl.from_hash(hash['ll']) if hash['ll'] # Create object from extracted values. Offset.new(ll: ll) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/verizon/models/offset.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['ll'] = 'll' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/offset.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 |
# File 'lib/verizon/models/offset.rb', line 27 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/verizon/models/offset.rb', line 53 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.ll, ->(val) { NodeListLl.validate(val) }, is_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['ll'], ->(val) { NodeListLl.validate(val) }, is_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 |
# File 'lib/verizon/models/offset.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} ll: #{@ll.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 |
# File 'lib/verizon/models/offset.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} ll: #{@ll}>" end |