Class: Verizon::Rateplantype2
- Defined in:
- lib/verizon/models/rateplantype2.rb
Overview
Rateplantype2 Model.
Instance Attribute Summary collapse
-
#account ⇒ Array[Accountid]
Account information.
-
#carrier_rate_plan_code ⇒ String
TODO: Write general description for this method.
-
#description ⇒ String
TODO: Write general description for this method.
-
#promotion_days ⇒ Integer
TODO: Write general description for this method.
-
#promotion_offered ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#rate_plan_type ⇒ String
TODO: Write general description for this method.
-
#size_kb ⇒ String
TODO: Write general description for this method.
-
#zero_dollar_billing ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(description: SKIP, size_kb: SKIP, carrier_rate_plan_code: SKIP, zero_dollar_billing: SKIP, promotion_offered: SKIP, promotion_days: SKIP, rate_plan_type: SKIP, account: SKIP, additional_properties: nil) ⇒ Rateplantype2
constructor
A new instance of Rateplantype2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(description: SKIP, size_kb: SKIP, carrier_rate_plan_code: SKIP, zero_dollar_billing: SKIP, promotion_offered: SKIP, promotion_days: SKIP, rate_plan_type: SKIP, account: SKIP, additional_properties: nil) ⇒ Rateplantype2
Returns a new instance of Rateplantype2.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/verizon/models/rateplantype2.rb', line 77 def initialize(description: SKIP, size_kb: SKIP, carrier_rate_plan_code: SKIP, zero_dollar_billing: SKIP, promotion_offered: SKIP, promotion_days: SKIP, rate_plan_type: SKIP, account: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @description = description unless description == SKIP @size_kb = size_kb unless size_kb == SKIP @carrier_rate_plan_code = carrier_rate_plan_code unless carrier_rate_plan_code == SKIP @zero_dollar_billing = zero_dollar_billing unless zero_dollar_billing == SKIP @promotion_offered = promotion_offered unless promotion_offered == SKIP @promotion_days = promotion_days unless promotion_days == SKIP @rate_plan_type = rate_plan_type unless rate_plan_type == SKIP @account = account unless account == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account ⇒ Array[Accountid]
Account information
42 43 44 |
# File 'lib/verizon/models/rateplantype2.rb', line 42 def account @account end |
#carrier_rate_plan_code ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/rateplantype2.rb', line 22 def carrier_rate_plan_code @carrier_rate_plan_code end |
#description ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/rateplantype2.rb', line 14 def description @description end |
#promotion_days ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/verizon/models/rateplantype2.rb', line 34 def promotion_days @promotion_days end |
#promotion_offered ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/verizon/models/rateplantype2.rb', line 30 def promotion_offered @promotion_offered end |
#rate_plan_type ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/verizon/models/rateplantype2.rb', line 38 def rate_plan_type @rate_plan_type end |
#size_kb ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/rateplantype2.rb', line 18 def size_kb @size_kb end |
#zero_dollar_billing ⇒ TrueClass | FalseClass
TODO: Write general description for this method
26 27 28 |
# File 'lib/verizon/models/rateplantype2.rb', line 26 def zero_dollar_billing @zero_dollar_billing end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/verizon/models/rateplantype2.rb', line 97 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. description = hash.key?('description') ? hash['description'] : SKIP size_kb = hash.key?('sizeKb') ? hash['sizeKb'] : SKIP carrier_rate_plan_code = hash.key?('carrierRatePlanCode') ? hash['carrierRatePlanCode'] : SKIP zero_dollar_billing = hash.key?('zeroDollarBilling') ? hash['zeroDollarBilling'] : SKIP promotion_offered = hash.key?('promotionOffered') ? hash['promotionOffered'] : SKIP promotion_days = hash.key?('promotionDays') ? hash['promotionDays'] : SKIP rate_plan_type = hash.key?('ratePlanType') ? hash['ratePlanType'] : SKIP # Parameter is an array, so we need to iterate through it account = nil unless hash['account'].nil? account = [] hash['account'].each do |structure| account << (Accountid.from_hash(structure) if structure) end end account = SKIP unless hash.key?('account') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Rateplantype2.new(description: description, size_kb: size_kb, carrier_rate_plan_code: carrier_rate_plan_code, zero_dollar_billing: zero_dollar_billing, promotion_offered: promotion_offered, promotion_days: promotion_days, rate_plan_type: rate_plan_type, account: account, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/rateplantype2.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['description'] = 'description' @_hash['size_kb'] = 'sizeKb' @_hash['carrier_rate_plan_code'] = 'carrierRatePlanCode' @_hash['zero_dollar_billing'] = 'zeroDollarBilling' @_hash['promotion_offered'] = 'promotionOffered' @_hash['promotion_days'] = 'promotionDays' @_hash['rate_plan_type'] = 'ratePlanType' @_hash['account'] = 'account' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/verizon/models/rateplantype2.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/rateplantype2.rb', line 59 def self.optionals %w[ description size_kb carrier_rate_plan_code zero_dollar_billing promotion_offered promotion_days rate_plan_type account ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
143 144 145 146 147 148 149 |
# File 'lib/verizon/models/rateplantype2.rb', line 143 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
162 163 164 165 166 167 168 169 |
# File 'lib/verizon/models/rateplantype2.rb', line 162 def inspect class_name = self.class.name.split('::').last "<#{class_name} description: #{@description.inspect}, size_kb: #{@size_kb.inspect},"\ " carrier_rate_plan_code: #{@carrier_rate_plan_code.inspect}, zero_dollar_billing:"\ " #{@zero_dollar_billing.inspect}, promotion_offered: #{@promotion_offered.inspect},"\ " promotion_days: #{@promotion_days.inspect}, rate_plan_type: #{@rate_plan_type.inspect},"\ " account: #{@account.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
152 153 154 155 156 157 158 159 |
# File 'lib/verizon/models/rateplantype2.rb', line 152 def to_s class_name = self.class.name.split('::').last "<#{class_name} description: #{@description}, size_kb: #{@size_kb}, carrier_rate_plan_code:"\ " #{@carrier_rate_plan_code}, zero_dollar_billing: #{@zero_dollar_billing},"\ " promotion_offered: #{@promotion_offered}, promotion_days: #{@promotion_days},"\ " rate_plan_type: #{@rate_plan_type}, account: #{@account}, additional_properties:"\ " #{@additional_properties}>" end |