Class: Verizon::RequestBodyForUsage
- Defined in:
- lib/verizon/models/request_body_for_usage.rb
Overview
RequestBodyForUsage Model.
Instance Attribute Summary collapse
-
#account_id ⇒ String
TODO: Write general description for this method.
-
#device_id ⇒ Array[ReadySimDeviceId]
TODO: Write general description for this method.
-
#end_time ⇒ DateTime
TODO: Write general description for this method.
-
#start_time ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id: SKIP, device_id: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ RequestBodyForUsage
constructor
A new instance of RequestBodyForUsage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_end_time ⇒ Object
- #to_custom_start_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id: SKIP, device_id: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ RequestBodyForUsage
Returns a new instance of RequestBodyForUsage.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 54 def initialize(account_id: SKIP, device_id: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id unless account_id == SKIP @device_id = device_id unless device_id == SKIP @start_time = start_time unless start_time == SKIP @end_time = end_time unless end_time == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 15 def account_id @account_id end |
#device_id ⇒ Array[ReadySimDeviceId]
TODO: Write general description for this method
19 20 21 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 19 def device_id @device_id end |
#end_time ⇒ DateTime
TODO: Write general description for this method
27 28 29 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 27 def end_time @end_time end |
#start_time ⇒ DateTime
TODO: Write general description for this method
23 24 25 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 23 def start_time @start_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('accountId') ? hash['accountId'] : SKIP # Parameter is an array, so we need to iterate through it device_id = nil unless hash['deviceId'].nil? device_id = [] hash['deviceId'].each do |structure| device_id << (ReadySimDeviceId.from_hash(structure) if structure) end end device_id = SKIP unless hash.key?('deviceId') start_time = if hash.key?('startTime') (DateTimeHelper.from_rfc3339(hash['startTime']) if hash['startTime']) else SKIP end end_time = if hash.key?('endTime') (DateTimeHelper.from_rfc3339(hash['endTime']) if hash['endTime']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RequestBodyForUsage.new(account_id: account_id, device_id: device_id, start_time: start_time, end_time: end_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'accountId' @_hash['device_id'] = 'deviceId' @_hash['start_time'] = 'startTime' @_hash['end_time'] = 'endTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 46 47 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 40 def self.optionals %w[ account_id device_id start_time end_time ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
124 125 126 127 128 129 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 124 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, device_id: #{@device_id.inspect},"\ " start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_end_time ⇒ Object
112 113 114 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 112 def to_custom_end_time DateTimeHelper.to_rfc3339(end_time) end |
#to_custom_start_time ⇒ Object
108 109 110 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 108 def to_custom_start_time DateTimeHelper.to_rfc3339(start_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
117 118 119 120 121 |
# File 'lib/verizon/models/request_body_for_usage.rb', line 117 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, device_id: #{@device_id}, start_time:"\ " #{@start_time}, end_time: #{@end_time}, additional_properties: #{@additional_properties}>" end |