Class: Verizon::RetrieveMonitorsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::RetrieveMonitorsRequest
- Defined in:
- lib/verizon/models/retrieve_monitors_request.rb
Overview
RetrieveMonitorsRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The name of a billing account.
-
#devices ⇒ Array[AccountDeviceList]
The devices for which you want to restore service, specified by device identifier.
-
#monitor_type ⇒ String
The name of a billing account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name:, devices:, monitor_type: SKIP) ⇒ RetrieveMonitorsRequest
constructor
A new instance of RetrieveMonitorsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name:, devices:, monitor_type: SKIP) ⇒ RetrieveMonitorsRequest
Returns a new instance of RetrieveMonitorsRequest.
46 47 48 49 50 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 46 def initialize(account_name:, devices:, monitor_type: SKIP) @account_name = account_name @devices = devices @monitor_type = monitor_type unless monitor_type == SKIP end |
Instance Attribute Details
#account_name ⇒ String
The name of a billing account.
14 15 16 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 14 def account_name @account_name end |
#devices ⇒ Array[AccountDeviceList]
The devices for which you want to restore service, specified by device identifier.
19 20 21 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 19 def devices @devices end |
#monitor_type ⇒ String
The name of a billing account.
23 24 25 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 23 def monitor_type @monitor_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil # Parameter is an array, so we need to iterate through it devices = nil unless hash['devices'].nil? devices = [] hash['devices'].each do |structure| devices << (AccountDeviceList.from_hash(structure) if structure) end end devices = nil unless hash.key?('devices') monitor_type = hash.key?('monitorType') ? hash['monitorType'] : SKIP # Create object from extracted values. RetrieveMonitorsRequest.new(account_name: account_name, devices: devices, monitor_type: monitor_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['devices'] = 'devices' @_hash['monitor_type'] = 'monitorType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 35 def self.optionals %w[ monitor_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, devices: #{@devices.inspect},"\ " monitor_type: #{@monitor_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/verizon/models/retrieve_monitors_request.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, devices: #{@devices}, monitor_type:"\ " #{@monitor_type}>" end |