Class: Verizon::RetrieveRatePlanListApi
- Defined in:
- lib/verizon/apis/retrieve_rate_plan_list_api.rb
Overview
RetrieveRatePlanListApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_rate_plan_list(ecpd_id) ⇒ ApiResponse
Retrieves the rate plans and rate plan details for a profile ID.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#get_rate_plan_list(ecpd_id) ⇒ ApiResponse
Retrieves the rate plans and rate plan details for a profile ID. Profile Database ID. This is the same as the accountName value
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/verizon/apis/retrieve_rate_plan_list_api.rb', line 13 def get_rate_plan_list(ecpd_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/v2/triggers/rateplanlist/{ecpdId}', Server::THINGSPACE) .template_param(new_parameter(ecpd_id, key: 'ecpdId') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Or.new('thingspace_oauth1', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Rateplan.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', RuleRestErrorResponseException)) .execute end |