Class: Verizon::SaeInfo
- Defined in:
- lib/verizon/models/sae_info.rb
Overview
SaeInfo Model.
Instance Attribute Summary collapse
-
#data_frames ⇒ Array[DataFrame]
List of data frames.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(data_frames:) ⇒ SaeInfo
constructor
A new instance of SaeInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data_frames:) ⇒ SaeInfo
Returns a new instance of SaeInfo.
33 34 35 |
# File 'lib/verizon/models/sae_info.rb', line 33 def initialize(data_frames:) @data_frames = data_frames end |
Instance Attribute Details
#data_frames ⇒ Array[DataFrame]
List of data frames.
14 15 16 |
# File 'lib/verizon/models/sae_info.rb', line 14 def data_frames @data_frames end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/models/sae_info.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it data_frames = nil unless hash['dataFrames'].nil? data_frames = [] hash['dataFrames'].each do |structure| data_frames << (DataFrame.from_hash(structure) if structure) end end data_frames = nil unless hash.key?('dataFrames') # Create object from extracted values. SaeInfo.new(data_frames: data_frames) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/sae_info.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['data_frames'] = 'dataFrames' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/sae_info.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/sae_info.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/verizon/models/sae_info.rb', line 59 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.data_frames, ->(val) { DataFrame.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['dataFrames'], ->(val) { DataFrame.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 |
# File 'lib/verizon/models/sae_info.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} data_frames: #{@data_frames.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 |
# File 'lib/verizon/models/sae_info.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} data_frames: #{@data_frames}>" end |