Class: Verizon::SearchDeviceEventHistoryRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::SearchDeviceEventHistoryRequest
- Defined in:
- lib/verizon/models/search_device_event_history_request.rb
Overview
Search Device By Property resource definition.
Instance Attribute Summary collapse
-
#accountidentifier ⇒ AccountIdentifier
The ID of the authenticating billing account, in the format ‘“billingaccountid”:“1234567890-12345”`.
-
#m_limitnumber ⇒ Integer
The maximum number of events to include in the response.
-
#m_page ⇒ String
The maximum number of events to include in the response.
-
#m_selection ⇒ Hash[String, String]
A comma-separated list of properties and comparator values to match against subscriptions in the ThingSpace account.
-
#resourceidentifier ⇒ ResourceIdentifier
The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountidentifier:, resourceidentifier:, m_selection: SKIP, m_limitnumber: SKIP, m_page: SKIP, additional_properties: nil) ⇒ SearchDeviceEventHistoryRequest
constructor
A new instance of SearchDeviceEventHistoryRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountidentifier:, resourceidentifier:, m_selection: SKIP, m_limitnumber: SKIP, m_page: SKIP, additional_properties: nil) ⇒ SearchDeviceEventHistoryRequest
Returns a new instance of SearchDeviceEventHistoryRequest.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 63 def initialize(accountidentifier:, resourceidentifier:, m_selection: SKIP, m_limitnumber: SKIP, m_page: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @accountidentifier = accountidentifier @m_selection = m_selection unless m_selection == SKIP @resourceidentifier = resourceidentifier @m_limitnumber = m_limitnumber unless m_limitnumber == SKIP @m_page = m_page unless m_page == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#accountidentifier ⇒ AccountIdentifier
The ID of the authenticating billing account, in the format ‘“billingaccountid”:“1234567890-12345”`.
15 16 17 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 15 def accountidentifier @accountidentifier end |
#m_limitnumber ⇒ Integer
The maximum number of events to include in the response.
32 33 34 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 32 def m_limitnumber @m_limitnumber end |
#m_page ⇒ String
The maximum number of events to include in the response.
36 37 38 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 36 def m_page @m_page end |
#m_selection ⇒ Hash[String, String]
A comma-separated list of properties and comparator values to match against subscriptions in the ThingSpace account. See Working with Query Filters for more information. If the request does not include ‘$selection`, the response will include all subscriptions to which the requesting user has access.
23 24 25 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 23 def m_selection @m_selection end |
#resourceidentifier ⇒ ResourceIdentifier
The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.
28 29 30 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 28 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 78 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountidentifier = AccountIdentifier.from_hash(hash['accountidentifier']) if hash['accountidentifier'] resourceidentifier = ResourceIdentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] m_selection = hash.key?('$selection') ? hash['$selection'] : SKIP m_limitnumber = hash.key?('$limitnumber') ? hash['$limitnumber'] : SKIP m_page = hash.key?('$page') ? hash['$page'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SearchDeviceEventHistoryRequest.new(accountidentifier: accountidentifier, resourceidentifier: resourceidentifier, m_selection: m_selection, m_limitnumber: m_limitnumber, m_page: m_page, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
39 40 41 42 43 44 45 46 47 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 39 def self.names @_hash = {} if @_hash.nil? @_hash['accountidentifier'] = 'accountidentifier' @_hash['m_selection'] = '$selection' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash['m_limitnumber'] = '$limitnumber' @_hash['m_page'] = '$page' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 55 56 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 50 def self.optionals %w[ m_selection m_limitnumber m_page ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 121 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountidentifier: #{@accountidentifier.inspect}, m_selection:"\ " #{@m_selection.inspect}, resourceidentifier: #{@resourceidentifier.inspect},"\ " m_limitnumber: #{@m_limitnumber.inspect}, m_page: #{@m_page.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
107 108 109 110 111 112 |
# File 'lib/verizon/models/search_device_event_history_request.rb', line 107 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountidentifier: #{@accountidentifier}, m_selection: #{@m_selection},"\ " resourceidentifier: #{@resourceidentifier}, m_limitnumber: #{@m_limitnumber}, m_page:"\ " #{@m_page}, additional_properties: #{@additional_properties}>" end |