Class: Verizon::SensorInsightsDeviceProfileApi
- Defined in:
- lib/verizon/apis/sensor_insights_device_profile_api.rb
Overview
SensorInsightsDeviceProfileApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#create_a_profile(body) ⇒ ApiResponse
Create a device profile description here.
-
#delete_a_profile(deleterequest) ⇒ ApiResponse
Delete a device profile payload for the delete request.
-
#query_a_profile(body) ⇒ ApiResponse
Query a device profile for an individual device.
-
#update_a_profile(body) ⇒ ApiResponse
Partially update a device profile description here.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#create_a_profile(body) ⇒ ApiResponse
Create a device profile description here
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/verizon/apis/sensor_insights_device_profile_api.rb', line 13 def create_a_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/deviceConfigurationProfiles', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoProfileResponse.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException)) .execute end |
#delete_a_profile(deleterequest) ⇒ ApiResponse
Delete a device profile payload for the delete request
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/apis/sensor_insights_device_profile_api.rb', line 48 def delete_a_profile(deleterequest) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/dm/v1/deviceConfigurationProfiles', Server::THINGSPACE) .header_param(new_parameter(deleterequest, key: 'deleterequest') .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoProfileResponse.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException)) .execute end |
#query_a_profile(body) ⇒ ApiResponse
Query a device profile for an individual device
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/verizon/apis/sensor_insights_device_profile_api.rb', line 115 def query_a_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/deviceConfigurationProfiles/actions/query', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoProfileResponse.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException)) .execute end |
#update_a_profile(body) ⇒ ApiResponse
Partially update a device profile description here
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/verizon/apis/sensor_insights_device_profile_api.rb', line 81 def update_a_profile(body) @api_call .request(new_request_builder(HttpMethodEnum::PATCH, '/dm/v1/deviceConfigurationProfiles', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoProfileResponse.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException)) .execute end |