Class: Verizon::SensorInsightsDevicesApi
- Defined in:
- lib/verizon/apis/sensor_insights_devices_api.rb
Overview
SensorInsightsDevicesApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#sensor_insights_device_action_set_request(body) ⇒ ApiResponse
TODO: type endpoint description here parameter: Set device configuration.
-
#sensor_insights_last_reported_time_request(body) ⇒ ApiResponse
TODO: type endpoint description here reported information for a device.
-
#sensor_insights_list_device_experience_history_request(body) ⇒ ApiResponse
TODO: type endpoint description here List the device experience.
-
#sensor_insights_list_devices_request(body) ⇒ ApiResponse
TODO: type endpoint description here details on an account.
-
#sensor_insights_list_network_experience_history_request(body) ⇒ ApiResponse
TODO: type endpoint description here List the network experience.
-
#sensor_insights_patch_device_request(body) ⇒ ApiResponse
TODO: type endpoint description here device’s details.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#sensor_insights_device_action_set_request(body) ⇒ ApiResponse
TODO: type endpoint description here parameter: Set device configuration
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/verizon/apis/sensor_insights_devices_api.rb', line 143 def sensor_insights_device_action_set_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/devices/actions/set', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true) .validator(proc do |value| UnionTypeLookUp.get(:SensorInsightsDeviceActionSetRequestBody) .validate(value) end)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(APIHelper.method(:json_serialize)) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoDeviceActionSetResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException)) .execute end |
#sensor_insights_last_reported_time_request(body) ⇒ ApiResponse
TODO: type endpoint description here reported information for a device
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/verizon/apis/sensor_insights_devices_api.rb', line 112 def sensor_insights_last_reported_time_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/devices/lastreported', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoLastReportedTimeResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException)) .execute end |
#sensor_insights_list_device_experience_history_request(body) ⇒ ApiResponse
TODO: type endpoint description here List the device experience
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/verizon/apis/sensor_insights_devices_api.rb', line 178 def sensor_insights_list_device_experience_history_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/devices/experience/actions/query', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(UserDeviceExperienceHistory.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_list_devices_request(body) ⇒ ApiResponse
TODO: type endpoint description here details on an account
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/apis/sensor_insights_devices_api.rb', line 13 def sensor_insights_list_devices_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/devices/actions/query', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoExpandedDeviceResponse.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', ManagementErrorException) .local_error('404', 'Not Found', ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_list_network_experience_history_request(body) ⇒ ApiResponse
TODO: type endpoint description here List the network experience
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/verizon/apis/sensor_insights_devices_api.rb', line 228 def sensor_insights_list_network_experience_history_request(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/devices/networkexperience/actions/query', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(UserNetworkExperienceHistory.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |
#sensor_insights_patch_device_request(body) ⇒ ApiResponse
TODO: type endpoint description here device’s details
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/verizon/apis/sensor_insights_devices_api.rb', line 63 def sensor_insights_patch_device_request(body) @api_call .request(new_request_builder(HttpMethodEnum::PATCH, '/dm/v1/devices', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ResourceDevice.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('404', 'Not Found', M404ManagementErrorException) .local_error('406', 'Not Acceptable', ManagementErrorException) .local_error('415', 'Unsupported media type', ManagementErrorException) .local_error('429', 'Too many requests', ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException) .local_error('default', 'Unexpected error', ManagementErrorException)) .execute end |