Class: Verizon::SensorInsightsSmartAlertMetricsApi
- Defined in:
- lib/verizon/apis/sensor_insights_smart_alert_metrics_api.rb
Overview
SensorInsightsSmartAlertMetricsApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#sensorinsightsmetricsquery(body) ⇒ ApiResponse
Get Device Alerts for the most recent daily period, up to 30 days.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#sensorinsightsmetricsquery(body) ⇒ ApiResponse
Get Device Alerts for the most recent daily period, up to 30 days. up to 30 days.
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/verizon/apis/sensor_insights_smart_alert_metrics_api.rb', line 13 def sensorinsightsmetricsquery(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/smartAlerts/actions/metrics', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoQueryMetricsResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException)) .execute end |