Class: Verizon::ServerLoggingApi
- Defined in:
- lib/verizon/apis/server_logging_api.rb
Overview
ServerLoggingApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#get_device_check_in_history(account, device_id) ⇒ ApiResponse
Check-in history can be retrieved for any device belonging to the account, not necessarily with logging enabled.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#get_device_check_in_history(account, device_id) ⇒ ApiResponse
Check-in history can be retrieved for any device belonging to the account, not necessarily with logging enabled.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/verizon/apis/server_logging_api.rb', line 14 def get_device_check_in_history(account, device_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/logging/{account}/devices/{deviceId}/checkInHistory', Server::SOFTWARE_MANAGEMENT_V2) .template_param(new_parameter(account, key: 'account') .is_required(true) .should_encode(true)) .template_param(new_parameter(device_id, key: 'deviceId') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CheckInHistoryItem.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('400', 'Unexpected error.', FotaV2ResultException)) .execute end |