Class: Verizon::ServiceUsage
- Defined in:
- lib/verizon/models/service_usage.rb
Overview
ServiceUsage Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier.
-
#transactions_count ⇒ String
Total requests for the account during the reporting period.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name: SKIP, transactions_count: SKIP, additional_properties: nil) ⇒ ServiceUsage
constructor
A new instance of ServiceUsage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name: SKIP, transactions_count: SKIP, additional_properties: nil) ⇒ ServiceUsage
Returns a new instance of ServiceUsage.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/service_usage.rb', line 41 def initialize(account_name: SKIP, transactions_count: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name unless account_name == SKIP @transactions_count = transactions_count unless transactions_count == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account identifier.
14 15 16 |
# File 'lib/verizon/models/service_usage.rb', line 14 def account_name @account_name end |
#transactions_count ⇒ String
Total requests for the account during the reporting period.
18 19 20 |
# File 'lib/verizon/models/service_usage.rb', line 18 def transactions_count @transactions_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/service_usage.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP transactions_count = hash.key?('transactionsCount') ? hash['transactionsCount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ServiceUsage.new(account_name: account_name, transactions_count: transactions_count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/service_usage.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['transactions_count'] = 'transactionsCount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/service_usage.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/service_usage.rb', line 29 def self.optionals %w[ account_name transactions_count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/service_usage.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, transactions_count:"\ " #{@transactions_count.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/service_usage.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, transactions_count: #{@transactions_count},"\ " additional_properties: #{@additional_properties}>" end |