Class: Verizon::SmsMessagesResponse
- Defined in:
- lib/verizon/models/sms_messages_response.rb
Overview
SmsMessagesResponse Model.
Instance Attribute Summary collapse
-
#has_more_data ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#messages ⇒ Array[GioSmsMessage]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(messages: SKIP, has_more_data: SKIP) ⇒ SmsMessagesResponse
constructor
A new instance of SmsMessagesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(messages: SKIP, has_more_data: SKIP) ⇒ SmsMessagesResponse
Returns a new instance of SmsMessagesResponse.
41 42 43 44 |
# File 'lib/verizon/models/sms_messages_response.rb', line 41 def initialize(messages: SKIP, has_more_data: SKIP) @messages = unless == SKIP @has_more_data = has_more_data unless has_more_data == SKIP end |
Instance Attribute Details
#has_more_data ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/sms_messages_response.rb', line 18 def has_more_data @has_more_data end |
#messages ⇒ Array[GioSmsMessage]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/sms_messages_response.rb', line 14 def @messages end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/sms_messages_response.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it = nil unless hash['messages'].nil? = [] hash['messages'].each do |structure| << (GioSmsMessage.from_hash(structure) if structure) end end = SKIP unless hash.key?('messages') has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP # Create object from extracted values. SmsMessagesResponse.new(messages: , has_more_data: has_more_data) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/sms_messages_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['messages'] = 'messages' @_hash['has_more_data'] = 'hasMoreData' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/sms_messages_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/sms_messages_response.rb', line 29 def self.optionals %w[ messages has_more_data ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/verizon/models/sms_messages_response.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} messages: #{@messages.inspect}, has_more_data: #{@has_more_data.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/sms_messages_response.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} messages: #{@messages}, has_more_data: #{@has_more_data}>" end |