Class: Verizon::SoftwareManagementLicensesV3Api
- Defined in:
- lib/verizon/apis/software_management_licenses_v3_api.rb
Overview
SoftwareManagementLicensesV3Api
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#assign_licenses_to_devices(acc, body) ⇒ ApiResponse
This endpoint allows user to assign licenses to a list of devices.
-
#get_account_licenses_status(acc, last_seen_device_id: nil) ⇒ ApiResponse
The endpoint allows user to list license usage.
-
#remove_licenses_from_devices(acc, body) ⇒ ApiResponse
This endpoint allows user to remove licenses from a list of devices.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Verizon::BaseApi
Instance Method Details
#assign_licenses_to_devices(acc, body) ⇒ ApiResponse
This endpoint allows user to assign licenses to a list of devices.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/apis/software_management_licenses_v3_api.rb', line 40 def assign_licenses_to_devices(acc, body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/licenses/{acc}/assign', Server::SOFTWARE_MANAGEMENT_V3) .template_param(new_parameter(acc, key: 'acc') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(V3LicenseAssignedRemovedResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', FotaV3ResultException)) .execute end |
#get_account_licenses_status(acc, last_seen_device_id: nil) ⇒ ApiResponse
The endpoint allows user to list license usage. identifier.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/verizon/apis/software_management_licenses_v3_api.rb', line 14 def get_account_licenses_status(acc, last_seen_device_id: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/licenses/{acc}', Server::SOFTWARE_MANAGEMENT_V3) .template_param(new_parameter(acc, key: 'acc') .is_required(true) .should_encode(true)) .query_param(new_parameter(last_seen_device_id, key: 'lastSeenDeviceId')) .header_param(new_parameter('application/json', key: 'accept')) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(V3LicenseSummary.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', FotaV3ResultException)) .execute end |
#remove_licenses_from_devices(acc, body) ⇒ ApiResponse
This endpoint allows user to remove licenses from a list of devices.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/verizon/apis/software_management_licenses_v3_api.rb', line 69 def remove_licenses_from_devices(acc, body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/licenses/{acc}/remove', Server::SOFTWARE_MANAGEMENT_V3) .template_param(new_parameter(acc, key: 'acc') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(V3LicenseAssignedRemovedResult.method(:from_hash)) .is_api_response(true) .local_error('400', 'Unexpected error.', FotaV3ResultException)) .execute end |