Class: Verizon::State
- Defined in:
- lib/verizon/models/state.rb
Overview
Each service includes custom states.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the state.
-
#service_plans ⇒ Array[String]
The service plans that can be used to charge for services for devices in this state.
-
#workflow_sequence_number ⇒ Float
The workflow sequence number of this state.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, workflow_sequence_number: SKIP, service_plans: SKIP, additional_properties: nil) ⇒ State
constructor
A new instance of State.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, workflow_sequence_number: SKIP, service_plans: SKIP, additional_properties: nil) ⇒ State
Returns a new instance of State.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/state.rb', line 48 def initialize(name: SKIP, workflow_sequence_number: SKIP, service_plans: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @workflow_sequence_number = workflow_sequence_number unless workflow_sequence_number == SKIP @service_plans = service_plans unless service_plans == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
The name of the state.
14 15 16 |
# File 'lib/verizon/models/state.rb', line 14 def name @name end |
#service_plans ⇒ Array[String]
The service plans that can be used to charge for services for devices in this state.
23 24 25 |
# File 'lib/verizon/models/state.rb', line 23 def service_plans @service_plans end |
#workflow_sequence_number ⇒ Float
The workflow sequence number of this state.
18 19 20 |
# File 'lib/verizon/models/state.rb', line 18 def workflow_sequence_number @workflow_sequence_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/models/state.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP workflow_sequence_number = hash.key?('workflowSequenceNumber') ? hash['workflowSequenceNumber'] : SKIP service_plans = hash.key?('servicePlans') ? hash['servicePlans'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. State.new(name: name, workflow_sequence_number: workflow_sequence_number, service_plans: service_plans, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/state.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['workflow_sequence_number'] = 'workflowSequenceNumber' @_hash['service_plans'] = 'servicePlans' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/state.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/state.rb', line 35 def self.optionals %w[ name workflow_sequence_number service_plans ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 96 |
# File 'lib/verizon/models/state.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, workflow_sequence_number:"\ " #{@workflow_sequence_number.inspect}, service_plans: #{@service_plans.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/verizon/models/state.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, workflow_sequence_number: #{@workflow_sequence_number},"\ " service_plans: #{@service_plans}, additional_properties: #{@additional_properties}>" end |