Class: Verizon::UploadConfigurationFilesResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::UploadConfigurationFilesResponse
- Defined in:
- lib/verizon/models/upload_configuration_files_response.rb
Overview
UploadConfigurationFilesResponse Model.
Instance Attribute Summary collapse
-
#device_platform_id ⇒ String
The platform (Android, iOS, etc.) that the software can be applied to.
-
#distribution_type ⇒ String
LWM2M, OMD-DM or HTTP.
-
#file_name ⇒ String
The name of the file you are upgrading to.
-
#file_version ⇒ String
The version of the file you are upgrading to.
-
#launch_date ⇒ Date
Software launch date.
-
#local_target_path ⇒ String
Local target path on the device.
-
#make ⇒ String
Software applicable device make.
-
#model ⇒ String
Software applicable device model.
-
#release_note ⇒ String
Software release note.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(file_name: SKIP, file_version: SKIP, launch_date: SKIP, release_note: SKIP, model: SKIP, make: SKIP, distribution_type: SKIP, device_platform_id: SKIP, local_target_path: SKIP, additional_properties: nil) ⇒ UploadConfigurationFilesResponse
constructor
A new instance of UploadConfigurationFilesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(file_name: SKIP, file_version: SKIP, launch_date: SKIP, release_note: SKIP, model: SKIP, make: SKIP, distribution_type: SKIP, device_platform_id: SKIP, local_target_path: SKIP, additional_properties: nil) ⇒ UploadConfigurationFilesResponse
Returns a new instance of UploadConfigurationFilesResponse.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 83 def initialize(file_name: SKIP, file_version: SKIP, launch_date: SKIP, release_note: SKIP, model: SKIP, make: SKIP, distribution_type: SKIP, device_platform_id: SKIP, local_target_path: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @file_name = file_name unless file_name == SKIP @file_version = file_version unless file_version == SKIP @launch_date = launch_date unless launch_date == SKIP @release_note = release_note unless release_note == SKIP @model = model unless model == SKIP @make = make unless make == SKIP @distribution_type = distribution_type unless distribution_type == SKIP @device_platform_id = device_platform_id unless device_platform_id == SKIP @local_target_path = local_target_path unless local_target_path == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_platform_id ⇒ String
The platform (Android, iOS, etc.) that the software can be applied to.
42 43 44 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 42 def device_platform_id @device_platform_id end |
#distribution_type ⇒ String
LWM2M, OMD-DM or HTTP.
38 39 40 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 38 def distribution_type @distribution_type end |
#file_name ⇒ String
The name of the file you are upgrading to.
14 15 16 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 14 def file_name @file_name end |
#file_version ⇒ String
The version of the file you are upgrading to.
18 19 20 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 18 def file_version @file_version end |
#launch_date ⇒ Date
Software launch date.
22 23 24 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 22 def launch_date @launch_date end |
#local_target_path ⇒ String
Local target path on the device.
46 47 48 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 46 def local_target_path @local_target_path end |
#make ⇒ String
Software applicable device make.
34 35 36 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 34 def make @make end |
#model ⇒ String
Software applicable device model.
30 31 32 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 30 def model @model end |
#release_note ⇒ String
Software release note.
26 27 28 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 26 def release_note @release_note end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 103 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. file_name = hash.key?('fileName') ? hash['fileName'] : SKIP file_version = hash.key?('fileVersion') ? hash['fileVersion'] : SKIP launch_date = hash.key?('launchDate') ? hash['launchDate'] : SKIP release_note = hash.key?('releaseNote') ? hash['releaseNote'] : SKIP model = hash.key?('model') ? hash['model'] : SKIP make = hash.key?('make') ? hash['make'] : SKIP distribution_type = hash.key?('distributionType') ? hash['distributionType'] : SKIP device_platform_id = hash.key?('devicePlatformId') ? hash['devicePlatformId'] : SKIP local_target_path = hash.key?('localTargetPath') ? hash['localTargetPath'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UploadConfigurationFilesResponse.new(file_name: file_name, file_version: file_version, launch_date: launch_date, release_note: release_note, model: model, make: make, distribution_type: distribution_type, device_platform_id: device_platform_id, local_target_path: local_target_path, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['file_name'] = 'fileName' @_hash['file_version'] = 'fileVersion' @_hash['launch_date'] = 'launchDate' @_hash['release_note'] = 'releaseNote' @_hash['model'] = 'model' @_hash['make'] = 'make' @_hash['distribution_type'] = 'distributionType' @_hash['device_platform_id'] = 'devicePlatformId' @_hash['local_target_path'] = 'localTargetPath' @_hash end |
.nullables ⇒ Object
An array for nullable fields
79 80 81 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 79 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 64 def self.optionals %w[ file_name file_version launch_date release_note model make distribution_type device_platform_id local_target_path ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
151 152 153 154 155 156 157 158 159 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 151 def inspect class_name = self.class.name.split('::').last "<#{class_name} file_name: #{@file_name.inspect}, file_version: #{@file_version.inspect},"\ " launch_date: #{@launch_date.inspect}, release_note: #{@release_note.inspect}, model:"\ " #{@model.inspect}, make: #{@make.inspect}, distribution_type:"\ " #{@distribution_type.inspect}, device_platform_id: #{@device_platform_id.inspect},"\ " local_target_path: #{@local_target_path.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
141 142 143 144 145 146 147 148 |
# File 'lib/verizon/models/upload_configuration_files_response.rb', line 141 def to_s class_name = self.class.name.split('::').last "<#{class_name} file_name: #{@file_name}, file_version: #{@file_version}, launch_date:"\ " #{@launch_date}, release_note: #{@release_note}, model: #{@model}, make: #{@make},"\ " distribution_type: #{@distribution_type}, device_platform_id: #{@device_platform_id},"\ " local_target_path: #{@local_target_path}, additional_properties:"\ " #{@additional_properties}>" end |