Class: Verizon::V1LicensesAssignedRemovedResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::V1LicensesAssignedRemovedResult
- Defined in:
- lib/verizon/models/v1_licenses_assigned_removed_result.rb
Overview
License assignment or removal confirmation.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier in “##########-#####”.
-
#device_list ⇒ Array[V1DeviceListItem]
A JSON object for each device that was in the request.
-
#lic_count ⇒ Integer
Total number of monthly licenses in an MRC subscription.
-
#lic_used_count ⇒ Integer
Number of licenses assigned to devices after the request completed.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name: SKIP, lic_count: SKIP, lic_used_count: SKIP, device_list: SKIP, additional_properties: nil) ⇒ V1LicensesAssignedRemovedResult
constructor
A new instance of V1LicensesAssignedRemovedResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name: SKIP, lic_count: SKIP, lic_used_count: SKIP, device_list: SKIP, additional_properties: nil) ⇒ V1LicensesAssignedRemovedResult
Returns a new instance of V1LicensesAssignedRemovedResult.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 53 def initialize(account_name: SKIP, lic_count: SKIP, lic_used_count: SKIP, device_list: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_name = account_name unless account_name == SKIP @lic_count = lic_count unless lic_count == SKIP @lic_used_count = lic_used_count unless lic_used_count == SKIP @device_list = device_list unless device_list == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
Account identifier in “##########-#####”.
14 15 16 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[V1DeviceListItem]
A JSON object for each device that was in the request.
26 27 28 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 26 def device_list @device_list end |
#lic_count ⇒ Integer
Total number of monthly licenses in an MRC subscription.
18 19 20 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 18 def lic_count @lic_count end |
#lic_used_count ⇒ Integer
Number of licenses assigned to devices after the request completed.
22 23 24 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 22 def lic_used_count @lic_used_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP lic_count = hash.key?('licCount') ? hash['licCount'] : SKIP lic_used_count = hash.key?('licUsedCount') ? hash['licUsedCount'] : SKIP # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (V1DeviceListItem.from_hash(structure) if structure) end end device_list = SKIP unless hash.key?('deviceList') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V1LicensesAssignedRemovedResult.new(account_name: account_name, lic_count: lic_count, lic_used_count: lic_used_count, device_list: device_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['lic_count'] = 'licCount' @_hash['lic_used_count'] = 'licUsedCount' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 39 def self.optionals %w[ account_name lic_count lic_used_count device_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, lic_count: #{@lic_count.inspect},"\ " lic_used_count: #{@lic_used_count.inspect}, device_list: #{@device_list.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/verizon/models/v1_licenses_assigned_removed_result.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, lic_count: #{@lic_count}, lic_used_count:"\ " #{@lic_used_count}, device_list: #{@device_list}, additional_properties:"\ " #{@additional_properties}>" end |