Class: Verizon::V2ListOfLicensesToRemove
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::V2ListOfLicensesToRemove
- Defined in:
- lib/verizon/models/v2_list_of_licenses_to_remove.rb
Overview
A list of license cancellation candidate devices.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Cancellation candidate devices count.
-
#device_list ⇒ Array[String]
Device IMEI list.
-
#has_more_data ⇒ TrueClass | FalseClass
Flag to indicat more devices.
-
#update_time ⇒ String
Last update time.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count:, has_more_data:, update_time:, device_list:, additional_properties: nil) ⇒ V2ListOfLicensesToRemove
constructor
A new instance of V2ListOfLicensesToRemove.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count:, has_more_data:, update_time:, device_list:, additional_properties: nil) ⇒ V2ListOfLicensesToRemove
Returns a new instance of V2ListOfLicensesToRemove.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 48 def initialize(count:, has_more_data:, update_time:, device_list:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @count = count @has_more_data = has_more_data @update_time = update_time @device_list = device_list @additional_properties = additional_properties end |
Instance Attribute Details
#count ⇒ Integer
Cancellation candidate devices count.
14 15 16 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 14 def count @count end |
#device_list ⇒ Array[String]
Device IMEI list.
26 27 28 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 26 def device_list @device_list end |
#has_more_data ⇒ TrueClass | FalseClass
Flag to indicat more devices.
18 19 20 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 18 def has_more_data @has_more_data end |
#update_time ⇒ String
Last update time.
22 23 24 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 22 def update_time @update_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : nil has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : nil update_time = hash.key?('updateTime') ? hash['updateTime'] : nil device_list = hash.key?('deviceList') ? hash['deviceList'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V2ListOfLicensesToRemove.new(count: count, has_more_data: has_more_data, update_time: update_time, device_list: device_list, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['count'] = 'count' @_hash['has_more_data'] = 'hasMoreData' @_hash['update_time'] = 'updateTime' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} count: #{@count.inspect}, has_more_data: #{@has_more_data.inspect},"\ " update_time: #{@update_time.inspect}, device_list: #{@device_list.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 91 |
# File 'lib/verizon/models/v2_list_of_licenses_to_remove.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} count: #{@count}, has_more_data: #{@has_more_data}, update_time:"\ " #{@update_time}, device_list: #{@device_list}, additional_properties:"\ " #{@additional_properties}>" end |