Class: Verizon::V3DeviceListItem
- Defined in:
- lib/verizon/models/v3_device_list_item.rb
Overview
Device changed.
Instance Attribute Summary collapse
-
#device_id ⇒ String
Device IMEI.
-
#reason ⇒ String
Result reason.
-
#status ⇒ String
Success or failure.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_id: SKIP, status: SKIP, reason: SKIP, additional_properties: nil) ⇒ V3DeviceListItem
constructor
A new instance of V3DeviceListItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id: SKIP, status: SKIP, reason: SKIP, additional_properties: nil) ⇒ V3DeviceListItem
Returns a new instance of V3DeviceListItem.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 47 def initialize(device_id: SKIP, status: SKIP, reason: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_id = device_id unless device_id == SKIP @status = status unless status == SKIP @reason = reason unless reason == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#device_id ⇒ String
Device IMEI.
14 15 16 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 14 def device_id @device_id end |
#reason ⇒ String
Result reason.
22 23 24 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 22 def reason @reason end |
#status ⇒ String
Success or failure.
18 19 20 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = hash.key?('deviceId') ? hash['deviceId'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reason = hash.key?('Reason') ? hash['Reason'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V3DeviceListItem.new(device_id: device_id, status: status, reason: reason, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash['status'] = 'status' @_hash['reason'] = 'Reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 34 def self.optionals %w[ device_id status reason ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}, status: #{@status.inspect}, reason:"\ " #{@reason.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/verizon/models/v3_device_list_item.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}, status: #{@status}, reason: #{@reason},"\ " additional_properties: #{@additional_properties}>" end |